var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, ViewChild, forwardRef, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators } from '@angular/forms';
import { Location } from '@angular/common';
//Wijmo
import { Control } from 'wijmo/wijmo';
//Azteca Kernel
import { Context, BaseComponent, CatalogService } from '../../core';
import { CatalogEditor, TrackableCollection } from '../../editors';
//Features
import { DatasetService } from '../services/dataset.service';
import { DatasetInfo } from '../models/dataset';
import { DatasetValor } from '../models/dataset-valor';
import { DatasetParametro } from '../models/dataset-parametro';
import { DatasetValueEditor } from './parts/dataset-value.editor';
import { DatasetCampo } from '../models/dataset-campo';
import { DatasetFiltro } from '../models/dataset-filtro';
import { DatasetCampoEditor } from './parts/dataset-campo.editor';
import { DatasetFiltroEditor } from './parts/dataset-filtro.editor';
import { DatasetParameterEditor } from './parts/dataset-parameter.editor';
import { DocumentoService } from '../services/documento.service';
var DatasetsEditor = /** @class */ (function (_super) {
    __extends(DatasetsEditor, _super);
    //
    function DatasetsEditor(router, route, formBuilder, changeDetector, context, location, datasetService, documentoService) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.changeDetector = changeDetector;
        _this.context = context;
        _this.location = location;
        _this.datasetService = datasetService;
        _this.documentoService = documentoService;
        _this.dataset = new DatasetInfo();
        _this.documentos = [];
        //Collections
        _this.staticValuesCollection = new TrackableCollection();
        _this.parametersCollection = new TrackableCollection();
        _this.camposCollection = new TrackableCollection();
        _this.filtrosCollection = new TrackableCollection();
        //New Objects
        _this.newStaticValue = new DatasetValor();
        _this.newParametro = new DatasetParametro();
        _this.newCampoEntidad = new DatasetCampo();
        _this.newFiltroEntidad = new DatasetFiltro();
        _this.tiposDataset = [{ id: '', tipo: '[Seleccione]' }, { id: 'F', tipo: 'Estático' }, { id: 'S', tipo: 'Sentencia SQL' }, { id: 'E', tipo: 'Entidad' }];
        _this.catalogForm = formBuilder.group({
            'codigo': ['', Validators.required],
            'nombre': ['', Validators.required],
            'tipo': ['', Validators.required],
            'idDocumento': [0],
            'expresion': [''],
            'offlineExpression': [''],
            'agrupador': [false]
        });
        _this.staticValuesCollection.pageSize = 10;
        return _this;
    }
    DatasetsEditor_1 = DatasetsEditor;
    ///////////////////////// METODOS ///////////////////////////////////////
    DatasetsEditor.prototype.loadDocumentos = function () {
        var _this = this;
        this.documentoService.loadList(this.context.app.defaultSite.identity)
            .then(function (documentos) { return _this.documentos = documentos; })
            .catch(function (error) { return _this.handleError(error); });
    };
    ///////////////////////// HANDLERS ///////////////////////////////////////
    DatasetsEditor.prototype.onConfigureCatalog = function (options) {
        this.autogeneratedCode = options.codigoAutogenerado;
        //Carga inicial de listas
        this.loadDocumentos();
        this.applyPolicies();
    };
    DatasetsEditor.prototype.onCreatingItem = function () {
        this.staticValuesCollection.sourceCollection = this.dataset.valores;
    };
    DatasetsEditor.prototype.onViewingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.datasetService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.dataset = info;
            _this.staticValuesCollection.sourceCollection = _this.dataset.valores;
            _this.parametersCollection.sourceCollection = _this.dataset.parametros;
            _this.camposCollection.sourceCollection = _this.dataset.camposEntidad;
            _this.filtrosCollection.sourceCollection = _this.dataset.filtrosEntidad;
            _this.setReadonlyMode();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    DatasetsEditor.prototype.onCloningItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        //
        this.datasetService.clone(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.dataset = info;
            _this.staticValuesCollection.sourceCollection = _this.dataset.valores;
            _this.parametersCollection.sourceCollection = _this.dataset.parametros;
            _this.camposCollection.sourceCollection = _this.dataset.camposEntidad;
            _this.filtrosCollection.sourceCollection = _this.dataset.filtrosEntidad;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    DatasetsEditor.prototype.onLoadingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.datasetService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.dataset = info;
            _this.staticValuesCollection.sourceCollection = _this.dataset.valores;
            _this.parametersCollection.sourceCollection = _this.dataset.parametros;
            _this.camposCollection.sourceCollection = _this.dataset.camposEntidad;
            _this.filtrosCollection.sourceCollection = _this.dataset.filtrosEntidad;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    DatasetsEditor.prototype.onSavingItem = function (args) {
        var _this = this;
        this.context.app.showSpinner();
        this.datasetService.update(this.dataset)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.dataset = info;
            _this.reset();
            if (args.closeEditor)
                _this.location.back();
            else
                _this.showAlert('La información ha sido actualizada con éxito', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    ////////// Valores Estáticos ////////////////////////
    DatasetsEditor.prototype.onStaticToolbar = function (button) {
        if (button.name == 'ADD') {
            this.newStaticValue = new DatasetValor();
            this.valueEditor.show();
        }
    };
    DatasetsEditor.prototype.onStaticValueUpdated = function (newValue) {
        var newValues = this.dataset.valores.slice();
        newValues.push(newValue);
        this.dataset.valores = newValues;
        this.staticValuesCollection.sourceCollection = newValues;
    };
    DatasetsEditor.prototype.onStaticRowDelete = function (row) {
        this.staticValuesCollection.remove(row);
    };
    ////////// Entidad ////////////////////////////
    DatasetsEditor.prototype.onCamposToolbar = function (button) {
        if (button.name == 'ADD') {
            this.newCampoEntidad = new DatasetCampo();
            this.campoEditor.show();
        }
    };
    DatasetsEditor.prototype.onCampoDelete = function (campo) {
        this.camposCollection.remove(campo);
    };
    DatasetsEditor.prototype.onCampoUpdated = function (campo) {
        var newCampos = this.dataset.camposEntidad.slice();
        newCampos.push(campo);
        this.dataset.camposEntidad = newCampos;
        this.camposCollection.sourceCollection = newCampos;
    };
    DatasetsEditor.prototype.onFiltrosToolbar = function (button) {
        if (button.name == 'ADD') {
            this.newFiltroEntidad = new DatasetFiltro();
            this.filtroEditor.show();
        }
    };
    DatasetsEditor.prototype.onFiiltroDelete = function (filtro) {
        this.filtrosCollection.remove(filtro);
    };
    DatasetsEditor.prototype.onFiltroUpdated = function (filtro) {
        var newFiltros = this.dataset.filtrosEntidad.slice();
        newFiltros.push(filtro);
        this.dataset.filtrosEntidad = newFiltros;
        this.filtrosCollection.sourceCollection = newFiltros;
    };
    ////////// Parámetros ////////////////////////////
    DatasetsEditor.prototype.onParametersToolbar = function (button) {
        if (button.name == 'ADD') {
            this.newParametro = new DatasetParametro();
            this.parameterEditor.show();
        }
    };
    DatasetsEditor.prototype.onParameterDelete = function (parametro) {
        this.parametersCollection.remove(parametro);
    };
    DatasetsEditor.prototype.onParameterUpdated = function (parametro) {
        var newParams = this.dataset.parametros.slice();
        newParams.push(parametro);
        this.dataset.parametros = newParams;
        this.parametersCollection.sourceCollection = newParams;
    };
    //
    DatasetsEditor.prototype.onSelectTab = function (args) {
        if (args.heading) {
            Control.invalidateAll();
        }
    };
    var DatasetsEditor_1;
    __decorate([
        ViewChild(DatasetValueEditor),
        __metadata("design:type", DatasetValueEditor)
    ], DatasetsEditor.prototype, "valueEditor", void 0);
    __decorate([
        ViewChild(DatasetParameterEditor),
        __metadata("design:type", DatasetParameterEditor)
    ], DatasetsEditor.prototype, "parameterEditor", void 0);
    __decorate([
        ViewChild(DatasetCampoEditor),
        __metadata("design:type", DatasetCampoEditor)
    ], DatasetsEditor.prototype, "campoEditor", void 0);
    __decorate([
        ViewChild(DatasetFiltroEditor),
        __metadata("design:type", DatasetFiltroEditor)
    ], DatasetsEditor.prototype, "filtroEditor", void 0);
    DatasetsEditor = DatasetsEditor_1 = __decorate([
        Component({
            selector: 'bpm-datasets-editor',
            template: "\n      <form [formGroup]=\"catalogForm\">\n\n          <azteca-catalog-editor #catalogEditor \n                                 [title]=\"'Dataset'\"\n                                 [info]=\"dataset\"\n                                 [valid]=\"valid\"\n                                 (configureCatalog)=\"onConfigureCatalog($event)\"\n                                 (creatingItem)=\"onCreatingItem()\"\n                                 (viewingItem)=\"onViewingItem($event)\"\n                                 (cloningItem)=\"onCloningItem($event)\"\n                                 (savingItem)=\"onSavingItem($event)\"\n                                 (loadingItem)=\"onLoadingItem($event)\">\n\n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <azteca-form-field [label]=\"'C\u00F3digo:'\">\n                          <catalog-code formControlName=\"codigo\" [(ngModel)]=\"dataset.code\" [automatic]=\"autogeneratedCode\"></catalog-code>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Nombre:'\">\n                          <az-textbox formControlName=\"nombre\" [(ngModel)]=\"dataset.nombre\"></az-textbox>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Tipo:'\">\n                          <az-combobox formControlName=\"tipo\" [(ngModel)]=\"dataset.tipo\" [enabled]=\"dataset.identity == 0\" [items]=\"tiposDataset\" [valueMember]=\"'id'\" [displayMember]=\"'tipo'\"></az-combobox>\n                      </azteca-form-field>\n\n                      <azteca-form-field *ngIf=\"dataset.tipo == 'E'\" [label]=\"'Documento:'\">\n                          <az-combobox formControlName=\"idDocumento\" [(ngModel)]=\"dataset.idDocumento\" [items]=\"documentos\" [valueMember]=\"'id'\" [displayMember]=\"'nombre'\"></az-combobox>\n                      </azteca-form-field>\n\n\n                      <tabset>\n                          <tab [heading]=\"'Definici\u00F3n'\" (select)=\"onSelectTab($event)\">\n\n                              <!-- Grid de valores est\u00E1ticos-->\n                              <az-panel *ngIf=\"dataset.tipo == 'F'\" [header]=\"'Valores est\u00E1ticos'\">\n\n                                  <az-toolbar (buttonClick)=\"onStaticToolbar($event)\">\n                                      <az-toolbar-button [name]=\"'ADD'\" [type]=\"'primary'\" [text]=\"'Nuevo'\" [toolTip]=\"'Agregar nuevo valor'\" [icon]=\"'glyphicon glyphicon-plus'\"></az-toolbar-button>\n                                  </az-toolbar>\n\n                                  <az-checkbox [label]=\"'Inclu\u00EDr agrupador de valores est\u00E1ticos'\" formControlName=\"agrupador\" [(ngModel)]=\"dataset.agrupador\"></az-checkbox>\n\n                                  <wj-flex-grid style=\"height:400px\" [itemsSource]=\"staticValuesCollection\">\n                                      <wj-flex-grid-column [header]=\"''\" [width]=\"60\" [isReadOnly]=\"true\">\n                                          <ng-template wjFlexGridCellTemplate [cellType]=\"'Cell'\" let-cell=\"cell\">\n                                              <button type=\"button\" class=\"btn btn-default\" (click)=\"onStaticRowDelete(cell.item)\">\n                                                  <span class=\"glyphicon glyphicon-trash\"></span>\n                                              </button>\n                                          </ng-template>\n                                      </wj-flex-grid-column>\n\n                                      <wj-flex-grid-column [header]=\"'Descripci\u00F3n'\" [binding]=\"'etiqueta'\" [width]=\"'70*'\"></wj-flex-grid-column>\n                                      <wj-flex-grid-column [header]=\"'Valor'\" [binding]=\"'valor'\" [width]=\"'30*'\"></wj-flex-grid-column>\n                                      <wj-flex-grid-column [header]=\"'Agrupador'\" [binding]=\"'agrupador'\" [width]=\"'30*'\" [visible]=\"dataset.agrupador\"></wj-flex-grid-column>\n                                  </wj-flex-grid>\n                                  <!--Pager-->\n                                  <div class=\"row\">\n                                      <div class=\"col-12 col-md-6\">\n                                          <az-pager [totalRows]=\"staticValuesCollection.totalItemCount\"\n                                                    [pageSize]=\"staticValuesCollection.pageSize\"\n                                                    [pageIndex]=\"staticValuesCollection.pageIndex\"\n                                                    (moveToPage)=\"staticValuesCollection.moveToPage($event)\">\n\n                                          </az-pager>\n                                      </div>\n                                  </div>\n\n                              </az-panel>\n\n\n                              <!-- Sentencias SQL-->\n                              <az-panel *ngIf=\"dataset.tipo == 'S'\" [header]=\"'Sentencias SQL'\">\n                                  <azteca-form-field [label]=\"'Query Online:'\">\n                                      <az-textarea formControlName=\"expresion\" [(ngModel)]=\"dataset.expresion\" style=\"height:150px\"></az-textarea>\n                                  </azteca-form-field>\n\n                                  <azteca-form-field [label]=\"'Query Offline:'\">\n                                      <az-textarea formControlName=\"offlineExpression\" [(ngModel)]=\"dataset.offlineExpression\" style=\"height:150px\"></az-textarea>\n                                  </azteca-form-field>\n\n                              </az-panel>\n\n                              <!-- Entidad -->\n                              <div *ngIf=\"dataset.tipo == 'E'\">\n                                  <!--Campos-->\n                                  <az-panel [header]=\"'Campos de la entidad'\">\n                                      <az-toolbar (buttonClick)=\"onCamposToolbar($event)\">\n                                          <az-toolbar-button [name]=\"'ADD'\" [type]=\"'primary'\" [text]=\"'Nuevo'\" [toolTip]=\"'Agregar campo'\" [icon]=\"'glyphicon glyphicon-plus'\"></az-toolbar-button>\n                                      </az-toolbar>\n\n                                      <wj-flex-grid style=\"height:250px\" [itemsSource]=\"camposCollection\">\n\n                                          <wj-flex-grid-column [header]=\"''\" [width]=\"60\" [isReadOnly]=\"true\">\n                                              <ng-template wjFlexGridCellTemplate [cellType]=\"'Cell'\" let-cell=\"cell\">\n                                                  <button type=\"button\" class=\"btn btn-default\" (click)=\"onCampoDelete(cell.item)\">\n                                                      <span class=\"glyphicon glyphicon-trash\"></span>\n                                                  </button>\n                                              </ng-template>\n                                          </wj-flex-grid-column>\n\n                                          <wj-flex-grid-column [header]=\"'Nombre'\" [binding]=\"'nombre'\" [width]=\"'4*'\"></wj-flex-grid-column>\n                                          <wj-flex-grid-column [header]=\"'XML Path'\" [binding]=\"'xmlPath'\" [width]=\"'6*'\"></wj-flex-grid-column>\n\n                                      </wj-flex-grid>\n\n                                  </az-panel>\n                                  <!--Filtros-->\n                                  <az-panel [header]=\"'Filtros'\">\n                                      <az-toolbar (buttonClick)=\"onFiltrosToolbar($event)\">\n                                          <az-toolbar-button [name]=\"'ADD'\" [type]=\"'primary'\" [text]=\"'Nuevo'\" [toolTip]=\"'Agregar filtro'\" [icon]=\"'glyphicon glyphicon-plus'\"></az-toolbar-button>\n                                      </az-toolbar>\n\n\n                                      <wj-flex-grid style=\"height:250px\" [itemsSource]=\"filtrosCollection\">\n\n                                          <wj-flex-grid-filter #filter></wj-flex-grid-filter>\n\n                                          <wj-flex-grid-column [header]=\"''\" [width]=\"45\" [isReadOnly]=\"true\">\n                                              <ng-template wjFlexGridCellTemplate [cellType]=\"'Cell'\" let-cell=\"cell\">\n                                                  <button type=\"button\" class=\"btn btn-default\" (click)=\"onFiiltroDelete(cell.item)\">\n                                                      <span class=\"glyphicon glyphicon-trash\"></span>\n                                                  </button>\n                                              </ng-template>\n                                          </wj-flex-grid-column>\n\n                                          <wj-flex-grid-column [header]=\"'XML Path'\" [binding]=\"'xmlPath'\" [width]=\"'30*'\"></wj-flex-grid-column>\n                                          <wj-flex-grid-column [header]=\"'Par\u00E1metro'\" [binding]=\"'parametro'\" [width]=\"'20*'\"></wj-flex-grid-column>\n                                      </wj-flex-grid>\n\n                                  </az-panel>\n                              </div>\n\n                          </tab>\n\n                          <!----- Par\u00E1metros ---->\n                          <tab [heading]=\"'Par\u00E1metros'\" [disabled]=\"dataset.tipo == 'F'\" (select)=\"onSelectTab($event)\">\n\n                              <az-toolbar (buttonClick)=\"onParametersToolbar($event)\">\n                                  <az-toolbar-button [name]=\"'ADD'\" [type]=\"'primary'\" [text]=\"'Nuevo'\" [toolTip]=\"'Agregar par\u00E1metro'\" [icon]=\"'glyphicon glyphicon-plus'\"></az-toolbar-button>                            \n                              </az-toolbar>\n\n\n                              <wj-flex-grid style=\"height:300px\" [itemsSource]=\"parametersCollection\">                            \n\n                                  <wj-flex-grid-column [header]=\"''\" [width]=\"60\" [isReadOnly]=\"true\">\n                                      <ng-template wjFlexGridCellTemplate [cellType]=\"'Cell'\" let-cell=\"cell\">\n                                          <button type=\"button\" class=\"btn btn-default\" (click)=\"onParameterDelete(cell.item)\">\n                                              <span class=\"glyphicon glyphicon-trash\"></span>\n                                          </button>\n                                      </ng-template>\n                                  </wj-flex-grid-column>\n\n                                  <wj-flex-grid-column [header]=\"'Nombre'\" [binding]=\"'nombre'\" [width]=\"'5*'\"></wj-flex-grid-column>\n                                  <wj-flex-grid-column [header]=\"'Etiqueta'\" [binding]=\"'etiqueta'\" [width]=\"'5*'\" [dataMap]=\"sampleMap\"></wj-flex-grid-column>\n                              </wj-flex-grid>\n\n                          </tab>\n                      </tabset>\n\n                  </div> <!--Col-->\n              </div> <!--Row-->\n       \n          </azteca-catalog-editor>\n\n      </form>\n\n      <bpm-dataset-value-editor [data]=\"newStaticValue\" (dataUpdated)=\"onStaticValueUpdated($event)\">\n\n      </bpm-dataset-value-editor>\n\n      <bpm-dataset-parameter-editor [data]=\"newParametro\" (dataUpdated)=\"onParameterUpdated($event)\">\n\n      </bpm-dataset-parameter-editor>\n\n      <bpm-dataset-campo-editor [data]=\"newCampoEntidad\" (dataUpdated)=\"onCampoUpdated($event)\">\n\n      </bpm-dataset-campo-editor>\n\n      <bpm-dataset-filtro-editor [data]=\"newFiltroEntidad\" (dataUpdated)=\"onFiltroUpdated($event)\">\n\n      </bpm-dataset-filtro-editor>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return DatasetsEditor_1; })
                },
                {
                    provide: CatalogService, useExisting: DatasetService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, FormBuilder, ChangeDetectorRef,
            Context, Location, DatasetService, DocumentoService])
    ], DatasetsEditor);
    return DatasetsEditor;
}(CatalogEditor));
export { DatasetsEditor };
