var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, forwardRef, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators } from '@angular/forms';
import { Location } from '@angular/common';
//Azteca Kernel
import { Context, BaseComponent, CatalogService } from '../../core';
import { CatalogEditor } from '../../editors';
//Features
import { DocumentoService } from '../services/documento.service';
import { DocumentoInfo } from '../models/documento';
var DocumentosEditor = /** @class */ (function (_super) {
    __extends(DocumentosEditor, _super);
    //
    function DocumentosEditor(router, route, formBuilder, changeDetector, context, location, documentoService) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.changeDetector = changeDetector;
        _this.context = context;
        _this.location = location;
        _this.documentoService = documentoService;
        _this.documento = new DocumentoInfo();
        _this.catalogForm = formBuilder.group({
            'codigo': [''],
            'nombre': ['', Validators.required],
            'filtroPeriodo': [false]
        });
        return _this;
    }
    DocumentosEditor_1 = DocumentosEditor;
    DocumentosEditor.prototype.onConfigureCatalog = function (options) {
        this.autogeneratedCode = options.codigoAutogenerado;
        this.applyPolicies();
    };
    DocumentosEditor.prototype.onCreatingItem = function () {
    };
    DocumentosEditor.prototype.onViewingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.documentoService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.documento = info;
            _this.setReadonlyMode();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    DocumentosEditor.prototype.onCloningItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        //
        this.documentoService.clone(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.documento = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    DocumentosEditor.prototype.onLoadingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.documentoService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.documento = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    DocumentosEditor.prototype.onSavingItem = function (args) {
        var _this = this;
        this.context.app.showSpinner();
        this.documentoService.update(this.documento)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.documento = info;
            _this.reset();
            if (args.closeEditor)
                _this.location.back();
            else
                _this.showAlert('La información ha sido actualizada con éxito', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    DocumentosEditor.prototype.onMenuItemClick = function (item) {
        if (item.name == 'VERSIONS') {
            this.router.navigate(['versiones'], { relativeTo: this.route });
        }
    };
    var DocumentosEditor_1;
    DocumentosEditor = DocumentosEditor_1 = __decorate([
        Component({
            selector: 'bpm-documentos-editor',
            template: "\n      <form [formGroup]=\"catalogForm\">\n\n          <azteca-catalog-editor #catalogEditor \n                                 [title]=\"'Documento'\"\n                                 [info]=\"documento\"                           \n                                 [valid]=\"valid\"\n                                 (configureCatalog)=\"onConfigureCatalog($event)\"\n                                 (creatingItem)=\"onCreatingItem()\"\n                                 (viewingItem)=\"onViewingItem($event)\"\n                                 (cloningItem)=\"onCloningItem($event)\"\n                                 (savingItem)=\"onSavingItem($event)\"\n                                 (menuItemClick)=\"onMenuItemClick($event)\"\n                                 (loadingItem)=\"onLoadingItem($event)\">\n\n              <!------------------- Menu de acciones adicionales --------------------->\n              <azteca-menu-item [name]=\"'VERSIONS'\" [icon]=\"'fa fa-code-fork'\" [text]=\"'Versiones'\" [smallText]=\"'administrar versiones'\"></azteca-menu-item>\n              <azteca-menu-item [name]=\"'USERS'\" [icon]=\"'glyphicon glyphicon-user'\" [text]=\"'Miembros'\" [smallText]=\"'editar usuarios miembro'\"></azteca-menu-item>\n              <azteca-menu-item [name]=\"'GROUPS'\" [icon]=\"'fa fa-users'\" [text]=\"'Grupos'\" [smallText]=\"'editar grupos miembro'\"></azteca-menu-item>\n\n              <!------------------- Controles del editor ----------------------------->\n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <azteca-form-field [label]=\"'C\u00F3digo:'\">\n                          <catalog-code formControlName=\"codigo\" [(ngModel)]=\"documento.code\" [automatic]=\"autogeneratedCode\"></catalog-code>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Nombre:'\">\n                          <az-textbox formControlName=\"nombre\" [(ngModel)]=\"documento.nombre\"></az-textbox>\n                      </azteca-form-field>\n\n                      <az-checkbox [label]=\"'Filtrado por per\u00EDodo'\" formControlName=\"filtroPeriodo\" [(ngModel)]=\"documento.filtroPeriodo\"></az-checkbox>\n                \n                  </div>\n              </div>                   \n\n          </azteca-catalog-editor>\n      </form>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return DocumentosEditor_1; })
                },
                {
                    provide: CatalogService, useExisting: DocumentoService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, FormBuilder, ChangeDetectorRef,
            Context, Location, DocumentoService])
    ], DocumentosEditor);
    return DocumentosEditor;
}(CatalogEditor));
export { DocumentosEditor };
