import { ViewContainerRef, ComponentRef, SimpleChange, ChangeDetectorRef } from '@angular/core';
import { Location } from '@angular/common';
import { Router, ActivatedRoute, UrlTree } from '@angular/router';
import { FormGroup, FormControl } from '@angular/forms';
import { ModalDirective } from 'ngx-bootstrap';
import { Context } from '../../core';
import { ToolbarButton, AlertsBarComponent, MenuItem } from '../../controls';
import { MapIcon } from '../../geolocation';
import { FormularioService } from '../services/formulario.service';
import { FormularioInfo } from '../models/formulario';
import { FormControl as AztecaFormControl } from '../models/form-control';
import { DocumentoService } from '../services/documento.service';
import { DocumentoInfo } from '../models/documento';
import { DocumentInstance } from '../models/document-instance';
import { WorkflowStep } from '../models/workflow-step';
import { WorkflowOption } from '../models/workflow-option';
import { DatasetService } from '../services/dataset.service';
import { CampoInfo } from '../models/campo';
import { DynamicComponent } from '../models/dynamic-component';
import { TypeBuilderService } from '../services/type-builder.service';
import { CollectionEventArgs } from '../models/collection-event-args';
export declare class FormGeneratorComponent {
    protected context: Context;
    protected router: Router;
    protected route: ActivatedRoute;
    private location;
    protected changeDetector: ChangeDetectorRef;
    protected formularioService: FormularioService;
    protected documentService: DocumentoService;
    protected datasetService: DatasetService;
    protected typeBuilder: TypeBuilderService;
    idFormulario: number;
    folio: string;
    idCollectionField: number;
    collectionAction: string;
    controls: AztecaFormControl[];
    datasets: any;
    parameters: any;
    mapIcons: MapIcon[];
    correlaciones: {
        [field: string]: boolean;
    };
    currentEditItems: {
        [collectionField: string]: any;
    };
    collections: {
        [collectionField: string]: any[];
    };
    collectionsCounters: {
        [collectionField: string]: number;
    };
    deletingCollectionField: number;
    keepModel: boolean;
    callStack: string[];
    formValid: boolean;
    closeUrl: UrlTree;
    navigationAllowed: boolean;
    documento: DocumentoInfo;
    formulario: FormularioInfo;
    instance: DocumentInstance;
    currentOptions: WorkflowOption[];
    menuItems: MenuItem[];
    form: FormGroup;
    protected wasViewInitialized: boolean;
    protected dynamicContent: ViewContainerRef;
    protected componentRef: ComponentRef<DynamicComponent>;
    alerts: AlertsBarComponent;
    deleteColItemDialog: ModalDirective;
    optionsDialog: ModalDirective;
    constructor(context: Context, router: Router, route: ActivatedRoute, location: Location, changeDetector: ChangeDetectorRef, formularioService: FormularioService, documentService: DocumentoService, datasetService: DatasetService, typeBuilder: TypeBuilderService);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    createMenu(): void;
    enableMenuItem(optionName: string, enable: boolean): void;
    loadCommonData(): void;
    loadMapIcons(): void;
    loadFormulario(): void;
    loadDocumento(): void;
    loadInstance(): void;
    createInstance(): void;
    createCollectionItem(): void;
    editCollectionItem(): void;
    startForm(): void;
    createFormGroup(): void;
    handleStateChange(valid: boolean): void;
    createDatasetsSubscriptions(): void;
    createAutocompleteSubscriptions(): void;
    createCorrelatedFieldsSubscriptions(): void;
    registerCollections(): void;
    loadDataset(field: CampoInfo): Promise<void | any[]>;
    loadDatasets(): void;
    registerParameters(): void;
    datasetValidator: (azControl: AztecaFormControl) => (ngControl: FormControl) => {
        valid: boolean;
    };
    getMemberPath(field: CampoInfo): string;
    getInstanceMember(path: string): any;
    getCollectionItemMember(path: string): any;
    newCollectionClientID(idCollectionField: number): number;
    /** Get a Factory and create a component */
    protected refreshContent(): void;
    save(): void;
    nextStep(step: WorkflowStep): void;
    previousStep(): void;
    ngOnChanges(changes: {
        [key: string]: SimpleChange;
    }): void;
    ngOnDestroy(): void;
    onMainToolbar(button: ToolbarButton): void;
    onMenuItemClick(option: MenuItem): void;
    onChildToolbar(button: ToolbarButton): void;
    onAddingCollectionItem(args: CollectionEventArgs): void;
    onEditCollectionItem(args: CollectionEventArgs): void;
    onDeleteCollectionItem(args: CollectionEventArgs): void;
    onConfirmDeleteCollectionItem(): void;
    onWorkflowOptionSelected(option: WorkflowOption): void;
    handleError(error: any): void;
}
