var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, ViewChild, ViewContainerRef, ChangeDetectorRef } from '@angular/core';
import { Location } from '@angular/common';
import { Router, ActivatedRoute } from '@angular/router';
import { FormGroup, FormControl, Validators } from '@angular/forms';
import { switchMap } from 'rxjs/operators';
//ngx bootstrap
import { ModalDirective } from 'ngx-bootstrap';
//Azteca kernel
import { Context } from '../../core';
import { AztecaValidators, AlertsBarComponent } from '../../controls';
//
import { FormularioService } from '../services/formulario.service';
import { FormularioInfo } from '../models/formulario';
import { DocumentoService } from '../services/documento.service';
import { DocumentoInfo } from '../models/documento';
import { DatasetService } from '../services/dataset.service';
import { ControlType } from '../models/control-type';
import { TypeBuilderService } from '../services/type-builder.service';
var FormGeneratorComponent = /** @class */ (function () {
    function FormGeneratorComponent(context, router, route, location, changeDetector, formularioService, documentService, datasetService, typeBuilder) {
        this.context = context;
        this.router = router;
        this.route = route;
        this.location = location;
        this.changeDetector = changeDetector;
        this.formularioService = formularioService;
        this.documentService = documentService;
        this.datasetService = datasetService;
        this.typeBuilder = typeBuilder;
        this.folio = '';
        this.idCollectionField = 0;
        this.collectionAction = '';
        //Colección de controles del formulario actual
        this.controls = [];
        //Conjuntos de datos de los controles que lo requieren en el formulario actual
        this.datasets = {};
        //Valores de los parametros de un dataset
        this.parameters = {};
        //Set de iconos que se utilizarán en los controles de mapa
        this.mapIcons = [];
        //Controles que dependen de los valores de otros controles para incluirse en el formulario
        this.correlaciones = {};
        //Registros de las colecciones actualmente en edición
        this.currentEditItems = {};
        //Colecciones registradas en el formulario actual
        this.collections = {};
        //LLeva el control del contador interno utilizado como llave (_clientID) para los registros de cada colección
        this.collectionsCounters = {};
        //Indica la colección (ID del campo raíz) que tiene pendiente un registro por eliminar
        this.deletingCollectionField = 0;
        //Indica si se debe o no cargar el modelo completo o sólo el formulario UI
        this.keepModel = false;
        //Pila de llamadas entre formularios hijo
        this.callStack = [];
        //Indica si la información actual del formulario es válida
        this.formValid = false;
        //Bandera para impedir navegación a través de acciones fuera del control del formulario (atrás, adelante, etc)
        this.navigationAllowed = false;
        //
        this.documento = new DocumentoInfo();
        this.formulario = new FormularioInfo();
        this.currentOptions = [];
        this.menuItems = [];
        // until ngAfterViewInit, we cannot start (firstly) to process dynamic stuff
        this.wasViewInitialized = false;
        this.datasetValidator = function (azControl) {
            return function (ngControl) {
                if (!ngControl || ngControl.value == '' || ngControl.value == 0)
                    return { valid: false };
                else
                    return null;
            };
        };
        this.createMenu();
    }
    ;
    FormGeneratorComponent.prototype.ngOnInit = function () {
        this.loadCommonData();
    };
    // this is the best moment where to start to process dynamic stuff
    FormGeneratorComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        this.closeUrl = this.context.navigator.previousUrl;
        this.wasViewInitialized = true;
        //Cargar información del formulario, al terminar cargar template y compilar        
        this.route.params.pipe(switchMap(function (params) {
            _this.idFormulario = +params['formulario'];
            _this.folio = params['folio'] ? params['folio'] : '';
            _this.keepModel = params['keepModel'] ? params['keepModel'] : false;
            //Si se está cargando un formulario de edición de elementos de una colección                
            if (params['idCollectionField']) {
                _this.collectionAction = params['collectionAction'];
                _this.idCollectionField = +params['idCollectionField'];
            }
            else {
                _this.collectionAction = '';
                _this.idCollectionField = 0;
            }
            return Promise.resolve();
        }))
            .subscribe(function (_) {
            setTimeout(function (_) { return _this.loadFormulario(); });
        });
    };
    /////////////////////////////////////////// METODOS /////////////////////////////////////////////////////////////////////////////////////
    FormGeneratorComponent.prototype.createMenu = function () {
        //Agregar opciones estándar del catálogo
        //let mnuEdit: MenuItem = { icon: "glyphicon glyphicon-refresh", text: "Actualizar", name: "REFRESH", smallText: "actualizar información del formulario" };        
        var mnuSave = { icon: "glyphicon glyphicon-floppy-disk", text: "Guardar", name: "SAVE", smallText: "guardar captura parcial" };
        var mnuBack = { icon: "glyphicon glyphicon-arrow-left", text: "Regresar", name: "BACK", smallText: "establecer documento en el paso anterior" };
        this.menuItems.push(mnuSave, mnuBack);
        this.menuItems.forEach(function (option) { return option.enabled = true; });
    };
    FormGeneratorComponent.prototype.enableMenuItem = function (optionName, enable) {
        var option = this.menuItems.find(function (opt) { return opt.name == optionName; });
        if (option)
            option.enabled = enable;
    };
    FormGeneratorComponent.prototype.loadCommonData = function () {
        this.loadMapIcons();
    };
    FormGeneratorComponent.prototype.loadMapIcons = function () {
        var _this = this;
        this.formularioService.loadMapIcons()
            .then(function (icons) { return _this.mapIcons = icons; })
            .catch(function (error) { return _this.handleError(error); });
    };
    FormGeneratorComponent.prototype.loadFormulario = function () {
        var _this = this;
        this.navigationAllowed = false;
        this.context.app.showSpinner();
        var promiseDetail = this.formularioService.getDetailByID(this.idFormulario)
            .then(function (formulario) { return _this.formulario = formulario; })
            .catch(function (error) { return _this.handleError(error); });
        var promiseControls = this.formularioService.loadFormControls(this.idFormulario)
            .then(function (controls) { return _this.controls = controls; })
            .catch(function (error) { return _this.handleError(error); });
        //Una vez completada la carga de información, cargar model
        Promise.all([promiseDetail, promiseControls])
            .then(function (_) {
            //Determinar si se está operando con el documento principal o con un elemento de colección
            if (_this.idCollectionField == 0) {
                //Si keepModel está activo, significa que se está regresando a la edición del formulario principal después de haber editado un elemento de colección
                //y por lo tanto ya no es necesario cargar el modelo, sólo iniciar la forma
                if (_this.keepModel) {
                    _this.startForm();
                }
                else {
                    //Crear o cargar instancia y al terminar crear form group y contenido dinámico
                    if (_this.folio != '') {
                        _this.enableMenuItem('BACK', true);
                        _this.loadInstance();
                    }
                    else {
                        _this.enableMenuItem('BACK', false);
                        _this.createInstance();
                    }
                }
            }
            //Si se trata de la edición de una colección, determinar si se está agregando un elemento o editando uno existente
            else {
                if (_this.collectionAction == 'ADD') {
                    _this.createCollectionItem();
                }
                else if (_this.collectionAction == 'EDIT') {
                    _this.editCollectionItem();
                }
            }
        });
    };
    FormGeneratorComponent.prototype.loadDocumento = function () {
    };
    FormGeneratorComponent.prototype.loadInstance = function () {
        var _this = this;
        this.documentService.loadInstance(this.folio)
            .then(function (instance) {
            _this.instance = instance;
            _this.startForm();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    FormGeneratorComponent.prototype.createInstance = function () {
        var _this = this;
        this.documentService.createInstance(this.formulario.idDocumento, this.formulario.version)
            .then(function (instance) {
            _this.instance = instance;
            _this.startForm();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    FormGeneratorComponent.prototype.createCollectionItem = function () {
        var _this = this;
        this.documentService.createCollectionItem(this.formulario.idDocumento, this.formulario.version, this.idCollectionField)
            .then(function (colItem) {
            _this.currentEditItems['colField_' + _this.idCollectionField.toString()] = colItem;
            _this.startForm();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    FormGeneratorComponent.prototype.editCollectionItem = function () {
        this.startForm();
    };
    FormGeneratorComponent.prototype.startForm = function () {
        //Cargar conjuntos de datos, controles, template y crear componentes dinámicos
        this.registerParameters();
        this.loadDatasets();
    };
    FormGeneratorComponent.prototype.createFormGroup = function () {
        var _this = this;
        var group = {};
        this.controls.forEach(function (c) {
            var formControl = new FormControl('');
            //Si es un campo requerido, agregar validador correspondiente
            if (c.field.ocurrenciaMinima > 0 && !c.readOnly && c.control.tag != ControlType.CHECKBOX) {
                if (c.field.idDataset > 0) {
                    formControl.setValidators(_this.datasetValidator(c));
                }
                else if (c.control.tag == ControlType.TEXTBOX) {
                    var validators = [];
                    //Validación de expresión regular
                    if (c.field.regularExpression != '') {
                        validators.push(Validators.pattern(c.field.regularExpression));
                    }
                    //Validación de longitud máxima
                    if (c.field.longitud > 0) {
                        validators.push(Validators.maxLength(c.field.longitud));
                    }
                    formControl.setValidators(validators);
                }
                else if (c.field.coleccion) {
                    //TODO: Agregar validador de mínimos y máximos
                }
                else if (c.control.tag == ControlType.MAP) {
                    //TODO: Crear validador para mapa
                }
                else if (c.control.tag == ControlType.IMAGEBOX || c.control.tag == ControlType.FILEBOX) {
                    formControl.setValidators(AztecaValidators.validFile);
                }
                else {
                    formControl.setValidators(Validators.required);
                }
            }
            group['field_' + c.idCampo.toString()] = formControl;
        });
        this.form = new FormGroup(group);
    };
    FormGeneratorComponent.prototype.handleStateChange = function (valid) {
        this.formValid = valid;
    };
    FormGeneratorComponent.prototype.createDatasetsSubscriptions = function () {
        var _this = this;
        //Obtener todos los controles que tienen asociado un dataset, un control combobox y que tienen al menos un parámetro
        this.controls.filter(function (c) { return c.field.idDataset > 0 && c.control.tag == ControlType.COMBOBOX && c.field.parametros.length > 0; }).forEach(function (c) {
            //Agregar una suscripción a cada campo relacionado con el parámetro
            c.field.parametros.forEach(function (param) {
                //Encontrar el form control relacionado con el campo
                var formCtrl = _this.form.controls['field_' + param.campoOrigen.identity.toString()];
                if (formCtrl) {
                    formCtrl.valueChanges.subscribe(function (value) {
                        //Volver a cargar dataset asociado al campo
                        setTimeout(function (_) { return _this.loadDataset(c.field); });
                    });
                }
                else {
                    var message = 'El campo: "' + c.field.namedPath + '" tiene como parámetro el campo: "' + param.campoOrigen.namedPath + '" pero no se encuentra en el formulario.';
                    console.warn(message);
                    _this.alerts.showAlert(message, 'warning');
                }
            });
        });
    };
    FormGeneratorComponent.prototype.createAutocompleteSubscriptions = function () {
        var _this = this;
        //Obtener todos los controles que tienen asociado un dataset, un control combobox y que tienen al menos un parámetro
        this.controls.filter(function (c) { return c.field.idDataset > 0 && c.control.tag == ControlType.AUTOCOMPLETE && c.field.parametros.length > 0; }).forEach(function (c) {
            //Agregar una suscripción a cada campo relacionado con el parámetro
            c.field.parametros.forEach(function (param) {
                //Encontrar el form control relacionado con el campo
                var formCtrl = _this.form.controls['field_' + param.campoOrigen.identity.toString()];
                if (formCtrl) {
                    formCtrl.valueChanges.subscribe(function (value) {
                        //Asignar valor a al parámetro
                        var params = _this.parameters['dataset_params_' + c.field.idDataset.toString()];
                        setTimeout(function (_) { return params[param.nombre] = value; });
                    });
                }
                else {
                    var message = 'El campo: "' + c.field.namedPath + '" tiene como parámetro el campo: "' + param.campoOrigen.namedPath + '" pero no se encuentra en el formulario.';
                    console.warn(message);
                    _this.alerts.showAlert(message, 'warning');
                }
            });
        });
    };
    FormGeneratorComponent.prototype.createCorrelatedFieldsSubscriptions = function () {
        var _this = this;
        this.controls.filter(function (c) { return c.field.campoCorrelacion > 0; }).forEach(function (c) {
            var formCtrl = _this.form.controls['field_' + c.field.campoCorrelacion.toString()];
            if (formCtrl) {
                formCtrl.valueChanges.subscribe(function (value) {
                    _this.correlaciones['field_' + c.field.identity.toString()] = c.field.expresionCorrelacion.split('|').find(function (v) { return v.trim().toLowerCase() == value.toString().toLowerCase(); }) ? true : false;
                });
            }
        });
    };
    FormGeneratorComponent.prototype.registerCollections = function () {
        var _this = this;
        this.controls.filter(function (c) { return c.field.coleccion; }).forEach(function (c) {
            //Si es el formulario principal, obtener colección del módelo raíz de la instancia
            var colMember;
            if (_this.idCollectionField == 0) {
                colMember = _this.getInstanceMember(c.field.memberPath);
            }
            //Si es un formulario hijo para la edición de un elemento de colección, obtener colección del item que se está editando
            else {
                colMember = _this.getCollectionItemMember(c.field.memberPath);
            }
            _this.collections['colField_' + c.field.identity.toString()] = colMember;
            _this.collectionsCounters['colField_' + c.field.identity.toString()] = colMember.length;
        });
    };
    FormGeneratorComponent.prototype.loadDataset = function (field) {
        var _this = this;
        var fieldKey = 'field_' + field.identity.toString();
        var params = {};
        field.parametros.forEach(function (p) {
            var memberPath = _this.getMemberPath(p.campoOrigen);
            var value = _this.getInstanceMember(memberPath);
            params[p.nombre] = value;
        });
        //
        return this.datasetService.getDataset(field.idDataset, params)
            .then(function (result) {
            _this.datasets[fieldKey] = result;
            return result;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    FormGeneratorComponent.prototype.loadDatasets = function () {
        var _this = this;
        var datasetsProm = [];
        //Filtrar los campos que tienen asignado un dataset y el control es un combobox
        this.controls.filter(function (c) { return c.field.idDataset > 0 && c.control.tag == ControlType.COMBOBOX; }).forEach(function (c) {
            var dsPromise = _this.loadDataset(c.field);
            datasetsProm.push(dsPromise);
        });
        //Al terminar de cargar todos los datasets, continuar con la generación de interfase
        Promise.all(datasetsProm)
            .then(function (_) {
            _this.createFormGroup();
            _this.refreshContent();
            _this.createDatasetsSubscriptions();
            _this.registerCollections();
            _this.createCorrelatedFieldsSubscriptions();
            _this.createAutocompleteSubscriptions();
        });
    };
    FormGeneratorComponent.prototype.registerParameters = function () {
        var _this = this;
        //Filtrar los campos que tienen asignado un dataset y el control es un autocomplete
        this.controls.filter(function (c) { return c.field.idDataset > 0 && c.control.tag == ControlType.AUTOCOMPLETE; }).forEach(function (c) {
            var datasetParams = {};
            //Agregar una suscripción a cada campo relacionado con el parámetro
            c.field.parametros.forEach(function (param) {
                datasetParams[param.nombre] = '0';
            });
            _this.parameters['dataset_params_' + c.field.idDataset.toString()] = datasetParams;
        });
    };
    FormGeneratorComponent.prototype.getMemberPath = function (field) {
        if (field.memberPath != '') {
            return field.memberPath + '.' + field.xmlTag;
        }
        else {
            return field.xmlPath;
        }
    };
    FormGeneratorComponent.prototype.getInstanceMember = function (path) {
        return path.split('.').reduce(function (o, i) { return o[i]; }, this.instance.contenidoJson);
    };
    FormGeneratorComponent.prototype.getCollectionItemMember = function (path) {
        var colItem = this.currentEditItems['colField_' + this.idCollectionField.toString()];
        return path.split('.').reduce(function (o, i) { return o[i]; }, colItem);
    };
    FormGeneratorComponent.prototype.newCollectionClientID = function (idCollectionField) {
        var lastIndex = this.collectionsCounters['colField_' + idCollectionField.toString()];
        lastIndex += 1;
        this.collectionsCounters['colField_' + idCollectionField.toString()] = lastIndex;
        return lastIndex;
    };
    /** Get a Factory and create a component */
    FormGeneratorComponent.prototype.refreshContent = function () {
        var _this = this;
        if (this.componentRef) {
            this.componentRef.destroy();
        }
        // Generar template en el servidor        
        this.formularioService.loadHtmlUI(this.idFormulario)
            .then(function (template) {
            var formTemplate = '<form [formGroup]="form"> \r\n' + template + '\r\n </form>';
            //                
            console.log(formTemplate);
            // here we get Factory (just compiled or from cache)
            _this.typeBuilder
                .createComponentFactory(formTemplate)
                .then(function (factory) {
                // Target will instantiate and inject component (we'll keep reference to it)
                _this.componentRef = _this.dynamicContent.createComponent(factory);
                // Injectar valors de entrada y suscribirse a eventos
                var component = _this.componentRef.instance;
                component.mapIcons = _this.mapIcons;
                //Si es el formulario principal, asignar modelo completo de la instancia
                if (_this.idCollectionField == 0) {
                    console.log(_this.instance.contenidoJson);
                    component.model = _this.instance.contenidoJson;
                }
                //Si es el formulario hijo de una colección, asignar el item que se está agregando o editando como modelo
                else {
                    var colItem = _this.currentEditItems['colField_' + _this.idCollectionField.toString()];
                    console.log(colItem);
                    component.model = colItem;
                }
                component.form = _this.form;
                component.parameters = _this.parameters;
                component.datasets = _this.datasets;
                component.correlaciones = _this.correlaciones;
                //                        
                component.addingCollectionItem.subscribe(function (args) { return _this.onAddingCollectionItem(args); });
                component.editingCollectionItem.subscribe(function (args) { return _this.onEditCollectionItem(args); });
                component.deletingCollectionItem.subscribe(function (args) { return _this.onDeleteCollectionItem(args); });
                component.formStateChange.subscribe(function (valid) { return _this.handleStateChange(valid); });
                //
                _this.context.app.hideSpinner();
            });
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    FormGeneratorComponent.prototype.save = function () {
        var _this = this;
        this.context.app.showSpinner();
        this.documentService.saveInstance(this.instance)
            .then(function (newInstance) {
            _this.instance = newInstance;
            _this.context.app.hideSpinner();
            _this.alerts.showAlert('La información ha sido guardada con éxito.', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    FormGeneratorComponent.prototype.nextStep = function (step) {
        var _this = this;
        this.context.app.showSpinner();
        this.documentService.nextStep(this.instance, step.id)
            .then(function (newInstance) {
            _this.instance = newInstance;
            _this.context.app.hideSpinner();
            _this.alerts.showAlert('La operación se realizó con éxito.', 'success');
            _this.router.navigate(['kernel/bpm/form-generator', _this.instance.currentStep.idFormulario, { folio: _this.instance.folio }]);
            _this.documentService.executeUnboundAction(_this.instance.idDocumento, _this.instance.version, 'NEXT_STEP', _this.instance.folio)
                .then(function (result) {
                if (result != '') {
                    window.open('/file-server/' + result, '_blank');
                }
            })
                .catch(function (error) { return _this.handleError(error); });
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    FormGeneratorComponent.prototype.previousStep = function () {
        var _this = this;
        this.context.app.showSpinner();
        this.documentService.previousStep(this.instance.folio)
            .then(function (updatedInstance) {
            _this.instance = updatedInstance;
            _this.context.app.hideSpinner();
            _this.alerts.showAlert('La operación se realizó existosamente.', 'success');
            _this.router.navigate(['kernel/bpm/form-generator', _this.instance.currentStep.idFormulario, { folio: _this.instance.folio }]);
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    /////////////////////////////////////////// HANDLERS /////////////////////////////////////////////////////////////////////////////////////
    // wasViewInitialized is an IMPORTANT switch 
    // when this component would have its own changing @Input()
    // - then we have to wait till view is intialized - first OnChange is too soon
    FormGeneratorComponent.prototype.ngOnChanges = function (changes) {
        if (this.wasViewInitialized) {
            return;
        }
        this.refreshContent();
    };
    FormGeneratorComponent.prototype.ngOnDestroy = function () {
        if (this.componentRef) {
            this.componentRef.destroy();
            this.componentRef = null;
        }
    };
    FormGeneratorComponent.prototype.onMainToolbar = function (button) {
        if (button.name == 'NEXT') {
            this.navigationAllowed = true;
            if (this.instance.currentStep.hasOptions) {
                this.currentOptions = this.instance.currentStep.options;
                this.optionsDialog.config.backdrop = false;
                this.optionsDialog.show();
            }
            else {
                //Si aún existe un paso siguiente
                if (this.instance.currentStep.nextStep) {
                    this.nextStep(this.instance.currentStep.nextStep);
                }
                else {
                    this.alerts.showAlert('El documento ya se encuentra al final de su flujo de trabajo', 'info');
                }
            }
        }
        else if (button.name == 'CLOSE') {
            this.navigationAllowed = true;
            this.router.navigateByUrl(this.closeUrl);
        }
    };
    FormGeneratorComponent.prototype.onMenuItemClick = function (option) {
        if (option.name == 'REFRESH') {
        }
        else if (option.name == 'BACK') {
            this.navigationAllowed = true;
            this.previousStep();
        }
        else if (option.name == 'SAVE') {
            this.save();
        }
    };
    FormGeneratorComponent.prototype.onChildToolbar = function (button) {
        var parentUrl = this.callStack.pop();
        if (button.name == 'SAVE') {
            //Obtener refencia a la colección y al elemento que se está editando actualmente
            var collection = this.collections['colField_' + this.idCollectionField.toString()];
            var colItem_1 = this.currentEditItems['colField_' + this.idCollectionField.toString()];
            //
            if (this.collectionAction == 'ADD') {
                //Incrementar contador interno de registros de la colección
                var newID = this.newCollectionClientID(this.idCollectionField);
                colItem_1._clientID = newID;
                collection.push(colItem_1);
            }
            else if (this.collectionAction == 'EDIT') {
                //Buscar posición en la colección del elemento en edición y reemplazarlo
                var colIndex = collection.findIndex(function (i) { return i._clientID == colItem_1._clientID; });
                collection[colIndex] = colItem_1;
            }
            this.navigationAllowed = true;
            this.router.navigate([parentUrl, { folio: this.folio, keepModel: true }]);
        }
        else if (button.name == 'CLOSE') {
            this.navigationAllowed = true;
            this.router.navigate([parentUrl, { folio: this.folio, keepModel: true }]);
        }
    };
    FormGeneratorComponent.prototype.onAddingCollectionItem = function (args) {
        var colControl = this.controls.find(function (c) { return c.field.identity == args.idCampo; });
        if (colControl.idChildForm && colControl.idChildForm > 0) {
            this.navigationAllowed = true;
            this.callStack.push('kernel/bpm/form-generator/' + this.idFormulario.toString());
            this.router.navigate(['kernel/bpm/form-generator', colControl.idChildForm, { folio: this.folio, idCollectionField: args.idCampo, collectionAction: 'ADD' }]);
        }
        else {
            this.alerts.showAlert('No se ha configurado un formulario de edición para la colección', 'warning');
        }
    };
    FormGeneratorComponent.prototype.onEditCollectionItem = function (args) {
        var colControl = this.controls.find(function (c) { return c.field.identity == args.idCampo; });
        if (colControl.idChildForm && colControl.idChildForm > 0) {
            this.navigationAllowed = true;
            //Crear una copia del registro a editar y establecer en diccionario de elementos en edición
            var itemCopy = JSON.parse(JSON.stringify(args.item));
            this.currentEditItems['colField_' + args.idCampo.toString()] = itemCopy;
            //Navegar a formulario de edición
            this.callStack.push('kernel/bpm/form-generator/' + this.idFormulario.toString());
            this.router.navigate(['kernel/bpm/form-generator', colControl.idChildForm, { folio: this.folio, idCollectionField: args.idCampo, collectionAction: 'EDIT' }]);
        }
        else {
            this.alerts.showAlert('No se ha configurado un formulario de edición para la colección', 'warning');
        }
    };
    FormGeneratorComponent.prototype.onDeleteCollectionItem = function (args) {
        this.deletingCollectionField = args.idCampo;
        this.currentEditItems['colField_' + args.idCampo.toString()] = args.item;
        this.deleteColItemDialog.config.backdrop = false;
        this.deleteColItemDialog.show();
    };
    FormGeneratorComponent.prototype.onConfirmDeleteCollectionItem = function () {
        var collection = this.collections['colField_' + this.deletingCollectionField.toString()];
        var colItem = this.currentEditItems['colField_' + this.deletingCollectionField.toString()];
        var colIndex = collection.findIndex(function (i) { return i._clientID == colItem._clientID; });
        setTimeout(function (_) { return collection.splice(colIndex, 1); });
        this.deleteColItemDialog.hide();
    };
    FormGeneratorComponent.prototype.onWorkflowOptionSelected = function (option) {
        this.optionsDialog.hide();
        this.nextStep(option.nextStep);
    };
    FormGeneratorComponent.prototype.handleError = function (error) {
        console.log(error);
        this.context.app.hideSpinner();
        var message = this.context.getExceptionMessage(error);
        this.alerts.showAlert(message, 'danger');
    };
    __decorate([
        ViewChild('dynamicContent', { read: ViewContainerRef }),
        __metadata("design:type", ViewContainerRef)
    ], FormGeneratorComponent.prototype, "dynamicContent", void 0);
    __decorate([
        ViewChild(AlertsBarComponent),
        __metadata("design:type", AlertsBarComponent)
    ], FormGeneratorComponent.prototype, "alerts", void 0);
    __decorate([
        ViewChild('deleteColItemDialog'),
        __metadata("design:type", ModalDirective)
    ], FormGeneratorComponent.prototype, "deleteColItemDialog", void 0);
    __decorate([
        ViewChild('optionsDialog'),
        __metadata("design:type", ModalDirective)
    ], FormGeneratorComponent.prototype, "optionsDialog", void 0);
    FormGeneratorComponent = __decorate([
        Component({
            selector: 'bpm-form-generator',
            template: "\n      <div class=\"row\">\n          <div class=\"col-12\">\n              <az-panel [header]=\"formulario.titulo\">\n                  <alerts-bar></alerts-bar>\n\n                  <az-toolbar *ngIf=\"idCollectionField == 0\" (buttonClick)=\"onMainToolbar($event)\" (menuItemClick)=\"onMenuItemClick($event)\">\n                      <az-toolbar-button [name]=\"'NEXT'\" [type]=\"'primary'\" [text]=\"'Siguiente'\" [icon]=\"'glyphicon glyphicon-arrow-right'\" [enabled]=\"formValid\"></az-toolbar-button>\n                      <az-toolbar-button [name]=\"'CLOSE'\" [text]=\"'Cerrar'\" [icon]=\"'glyphicon glyphicon-remove'\"></az-toolbar-button>\n                      <az-toolbar-menu [name]=\"'OPTIONS'\" [menuItems]=\"menuItems\" [header]=\"'Opciones'\"></az-toolbar-menu>                \n                  </az-toolbar>\n\n                  <az-toolbar *ngIf=\"idCollectionField > 0\" (buttonClick)=\"onChildToolbar($event)\">\n                      <az-toolbar-button [name]=\"'SAVE'\" [type]=\"'primary'\" [text]=\"'Aceptar'\" [icon]=\"'glyphicon glyphicon-ok'\" [enabled]=\"formValid\"></az-toolbar-button>\n                      <az-toolbar-button [name]=\"'CLOSE'\" [text]=\"'Cancelar'\" [icon]=\"'glyphicon glyphicon-remove'\"></az-toolbar-button>\n                  </az-toolbar>\n\n                  <div #dynamicContent></div>\n              </az-panel>\n          </div>\n      </div>\n\n      <!--DIALOGO DE CONFIRMACI\u00D3N AL ELMINAR REGISTRO DE UNA COLECCI\u00D3N-->\n      <div bsModal #deleteColItemDialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"mySmallModalLabel\" aria-hidden=\"true\">\n          <div class=\"modal-dialog modal-sm\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-header\">\n                      <h4>Eliminar registro de colecci\u00F3n</h4>\n                  </div>\n                  <div class=\"modal-body\">\n                      <div>\u00BFEst\u00E1 seguro que desea eliminar el registro?</div>\n                  </div> <!--Modal Body-->\n                  <div class=\"modal-footer\">\n                      <button type=\"button\" class=\"btn btn-primary\" (click)=\"deleteColItemDialog.hide()\">Cancelar</button>\n                      <button type=\"button\" class=\"btn btn-danger\" (click)=\"onConfirmDeleteCollectionItem()\">Eliminar</button>\n                  </div> <!--Modal Footer-->\n              </div> <!-- Modal Content-->\n          </div> <!--Modal-->\n      </div> <!--Modal directive-->\n\n      <!--DIALOGO DE BIFURCACIONES-->\n      <div bsModal #optionsDialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"mySmallModalLabel\" aria-hidden=\"true\">\n          <div class=\"modal-dialog modal-sm\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-header\">\n                      <h5>Elegir el siguiente paso</h5>\n                  </div>\n                  <div class=\"modal-body\">\n                      <ul class=\"list-group\">\n                          <button *ngFor=\"let option of currentOptions\" class=\"list-group-item list-group-item-action\" (click)=\"onWorkflowOptionSelected(option)\">\n                              <span class=\"glyphicon glyphicon-arrow-right\" style=\"margin-right:5px;\"></span>{{option.text}}\n                          </button>\n                      </ul>\n                  </div> <!--Modal Body-->\n                  <div class=\"modal-footer\">\n                      <button type=\"button\" class=\"btn btn-danger\" (click)=\"optionsDialog.hide()\">Cancelar</button>\n                  </div> <!--Modal Footer-->\n\n              </div> <!-- Modal Content-->\n          </div> <!--Modal-->\n      </div> <!--Modal directive-->\n    "
        }),
        __metadata("design:paramtypes", [Context, Router, ActivatedRoute,
            Location, ChangeDetectorRef,
            FormularioService, DocumentoService,
            DatasetService, TypeBuilderService])
    ], FormGeneratorComponent);
    return FormGeneratorComponent;
}());
export { FormGeneratorComponent };
