var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, forwardRef, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators } from '@angular/forms';
import { Location } from '@angular/common';
//Azteca Kernel
import { Context, BaseComponent, CatalogService } from '../../core';
import { CatalogEditor } from '../../editors';
//Features
import { FormularioService } from '../services/formulario.service';
import { FormularioInfo } from '../models/formulario';
import { DocumentoService } from '../services/documento.service';
var FormulariosEditor = /** @class */ (function (_super) {
    __extends(FormulariosEditor, _super);
    //
    function FormulariosEditor(router, route, formBuilder, changeDetector, context, location, formularioService, documentoService) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.changeDetector = changeDetector;
        _this.context = context;
        _this.location = location;
        _this.formularioService = formularioService;
        _this.documentoService = documentoService;
        _this.formulario = new FormularioInfo();
        _this.dominios = [];
        _this.catalogForm = formBuilder.group({
            'codigo': ['', Validators.required],
            'nombre': ['', Validators.required],
            'titulo': ['', Validators.required],
            'idCampoDominio': [0],
            'ancho': [0],
            'alto': [0]
        });
        return _this;
    }
    FormulariosEditor_1 = FormulariosEditor;
    FormulariosEditor.prototype.ngOnInit = function () {
        var _this = this;
        this.route.params.forEach(function (params) {
            _this.idDocumento = +params['idDocumento'];
            _this.version = +params['version'];
        });
    };
    ///////////////////////// METODOS ///////////////////////////////////////
    FormulariosEditor.prototype.loadDominios = function (idDocumento, version) {
        var _this = this;
        this.documentoService.loadDominios(idDocumento, version)
            .then(function (dominios) { return _this.dominios = dominios; })
            .catch(function (error) { return _this.handleError(error); });
    };
    ///////////////////////// HANDLERS ///////////////////////////////////////
    FormulariosEditor.prototype.onConfigureCatalog = function (options) {
        this.autogeneratedCode = options.codigoAutogenerado;
        this.loadDominios(this.idDocumento, this.version);
        this.applyPolicies();
    };
    FormulariosEditor.prototype.onCreatingItem = function () {
    };
    FormulariosEditor.prototype.onViewingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.formularioService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.formulario = info;
            _this.setReadonlyMode();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    FormulariosEditor.prototype.onCloningItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        //
        this.formularioService.clone(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.formulario = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    FormulariosEditor.prototype.onLoadingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.formularioService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.formulario = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    FormulariosEditor.prototype.onSavingItem = function (args) {
        var _this = this;
        this.context.app.showSpinner();
        this.formulario.idDocumento = this.idDocumento;
        this.formulario.version = this.version;
        this.formularioService.update(this.formulario)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.formulario = info;
            _this.reset();
            if (args.closeEditor)
                _this.location.back();
            else
                _this.showAlert('La información ha sido actualizada con éxito', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    FormulariosEditor.prototype.onMenuItemClick = function (item) {
        if (item.name == 'PREVIEW') {
            this.router.navigate(['kernel/bpm/form-generator', this.formulario.identity]);
        }
        if (item.name == 'CONTAINERS') {
            this.router.navigate(['contenedores'], { relativeTo: this.route });
        }
        if (item.name == 'CONTROLS') {
            this.router.navigate(['controles'], { relativeTo: this.route });
        }
    };
    var FormulariosEditor_1;
    FormulariosEditor = FormulariosEditor_1 = __decorate([
        Component({
            selector: 'bpm-formularios-editor',
            template: "\n      <form [formGroup]=\"catalogForm\">\n\n          <azteca-catalog-editor #catalogEditor \n                                 [title]=\"'Formulario'\"\n                                 [info]=\"formulario\"\n                                 [valid]=\"valid\"\n                                 (configureCatalog)=\"onConfigureCatalog($event)\"\n                                 (menuItemClick)=\"onMenuItemClick($event)\"\n                                 (creatingItem)=\"onCreatingItem()\"\n                                 (viewingItem)=\"onViewingItem($event)\"\n                                 (cloningItem)=\"onCloningItem($event)\"\n                                 (savingItem)=\"onSavingItem($event)\"\n                                 (loadingItem)=\"onLoadingItem($event)\">\n\n\n              <!------------------- Menu de acciones adicionales --------------------->\n              <azteca-menu-item [name]=\"'CONTAINERS'\" [icon]=\"'fa fa-sitemap'\" [text]=\"'Contenedores'\" [smallText]=\"'definir contenedores'\"></azteca-menu-item>\n              <azteca-menu-item [name]=\"'CONTROLS'\" [icon]=\"'glyphicon glyphicon-th-list'\" [text]=\"'Controles'\" [smallText]=\"'asociar controles'\"></azteca-menu-item>\n              <azteca-menu-item [name]=\"'PREVIEW'\" [icon]=\"'glyphicon glyphicon-modal-window'\" [text]=\"'Vista Previa'\" [smallText]=\"'mostrar vista previa'\"></azteca-menu-item>\n\n              <!------------------- Controles del editor ----------------------------->\n\n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <azteca-form-field [label]=\"'C\u00F3digo:'\">\n                          <catalog-code formControlName=\"codigo\" [(ngModel)]=\"formulario.code\" [automatic]=\"autogeneratedCode\"></catalog-code>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Nombre:'\">\n                          <az-textbox formControlName=\"nombre\" [(ngModel)]=\"formulario.nombre\"></az-textbox>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'T\u00EDtulo:'\">\n                          <az-textbox formControlName=\"titulo\" [(ngModel)]=\"formulario.titulo\"></az-textbox>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Dominio:'\">\n                          <az-combobox formControlName=\"idCampoDominio\" [(ngModel)]=\"formulario.idCampoDominio\" [items]=\"dominios\" [valueMember]=\"'id'\" [displayMember]=\"'nombre'\"></az-combobox>\n                      </azteca-form-field>\n\n                  </div>\n              </div>\n\n          </azteca-catalog-editor>\n      </form>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return FormulariosEditor_1; })
                },
                {
                    provide: CatalogService, useExisting: FormularioService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, FormBuilder, ChangeDetectorRef,
            Context, Location, FormularioService, DocumentoService])
    ], FormulariosEditor);
    return FormulariosEditor;
}(CatalogEditor));
export { FormulariosEditor };
