var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, ViewChild } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
//ng2 bootstrap
import { ModalDirective } from 'ngx-bootstrap';
//Azteca Kernel
import { Context, BaseComponent } from '../../core';
import { AlertsBarComponent } from '../../controls';
import { ChangeState } from '../../editors';
//Locales
import { FormularioService } from '../services/formulario.service';
import { GridControl } from '../models/grid-control';
import { GridColumn } from '../models/grid-column';
import { GridColumnEditor } from './parts/grid-column.editor';
var GridColumnsEditor = /** @class */ (function (_super) {
    __extends(GridColumnsEditor, _super);
    function GridColumnsEditor(context, router, route, formularioService) {
        var _this = _super.call(this) || this;
        _this.context = context;
        _this.router = router;
        _this.route = route;
        _this.formularioService = formularioService;
        _this.title = '';
        _this.gridControl = new GridControl();
        _this.currentColumn = new GridColumn();
        //
        _this._lastColID = 0;
        return _this;
    }
    GridColumnsEditor.prototype.ngOnInit = function () {
        var _this = this;
        this.route.params.forEach(function (params) {
            _this.idControlGrid = +params['idFormControl'];
            _this.idFormulario = +params['id'];
        });
    };
    GridColumnsEditor.prototype.ngAfterViewInit = function () {
        var _this = this;
        setTimeout(function (_) { return _this.loadGridControl(); });
    };
    ////////////////////////// METODOS /////////////////////////////////////
    GridColumnsEditor.prototype.loadGridControl = function () {
        var _this = this;
        this.formularioService.loadFormControl(this.idControlGrid)
            .then(function (control) {
            _this.gridControl = control;
            _this.title = 'Columnas de ' + _this.gridControl.field.namedPath;
            _this._lastColID = _this.gridControl.columns.length;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    GridColumnsEditor.prototype.save = function () {
        var _this = this;
        this.context.app.showSpinner();
        this.formularioService.saveFormControl(this.idFormulario, this.gridControl)
            .then(function (grid) {
            _this.context.app.hideSpinner();
            _this.gridControl = grid;
            _this.alerts.showAlert('Los cambios han sido guardados con éxito.', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    GridColumnsEditor.prototype.copy = function (original) {
        return JSON.parse(JSON.stringify(original));
    };
    ///////////////////////// HANDLERS /////////////////////////////////////
    GridColumnsEditor.prototype.onMainToolbarClick = function (button) {
        if (button.name == 'ADD') {
            this.currentColumn = new GridColumn();
            this.columnEditor.show();
        }
        else if (button.name == 'SAVE') {
            this.save();
        }
        else if (button.name == 'CLOSE') {
            this.router.navigate(['../../'], { relativeTo: this.route });
        }
    };
    GridColumnsEditor.prototype.onChangeColumns = function (columns) {
        columns.forEach(function (c) {
            if (c.state == ChangeState.UNCHANGED) {
                c.state = ChangeState.MODIFIED;
            }
        });
        this.gridControl.columns = columns;
    };
    GridColumnsEditor.prototype.onEditColumn = function (column) {
        this.currentColumn = this.copy(column);
        this.columnEditor.show();
        return false;
    };
    GridColumnsEditor.prototype.onDeleteColumn = function (column) {
        this.currentColumn = column;
        this.confirmDelDialog.config.backdrop = false;
        this.confirmDelDialog.show();
        return false;
    };
    GridColumnsEditor.prototype.onConfirmDelete = function () {
        this.currentColumn.state = ChangeState.DELETED;
        this.confirmDelDialog.hide();
    };
    GridColumnsEditor.prototype.onColumnUpdated = function (column) {
        var newColumns = this.gridControl.columns.slice();
        //Si no tiene un client id, es un elemento nuevo. 
        if (column._clientID == 0) {
            //Verificar que no exista otra columna con el mismo campo
            var existing = this.gridControl.columns.find(function (col) { return col.idCampo == column.idCampo && col.state != ChangeState.DELETED; });
            if (!existing) {
                //Asignar consecutivo de client id y agregar al nuevo array
                this._lastColID += 1;
                column._clientID = this._lastColID;
                newColumns.push(column);
            }
            else {
                this.alerts.showAlert('Ya existe una columna con el mismo campo', 'warning');
            }
        }
        else {
            column.state = ChangeState.MODIFIED;
            var index = newColumns.findIndex(function (c) { return c._clientID == column._clientID; });
            newColumns[index] = column;
        }
        this.gridControl.columns = newColumns;
    };
    GridColumnsEditor.prototype.applyPolicy = function (policy) {
    };
    GridColumnsEditor.prototype.handleError = function (error) {
        console.error(error);
        this.alerts.showAlert('Error al guardar los cambios', 'danger');
        this.context.app.hideSpinner();
    };
    __decorate([
        ViewChild(GridColumnEditor),
        __metadata("design:type", GridColumnEditor)
    ], GridColumnsEditor.prototype, "columnEditor", void 0);
    __decorate([
        ViewChild('confirmDelDialog'),
        __metadata("design:type", ModalDirective)
    ], GridColumnsEditor.prototype, "confirmDelDialog", void 0);
    __decorate([
        ViewChild(AlertsBarComponent),
        __metadata("design:type", AlertsBarComponent)
    ], GridColumnsEditor.prototype, "alerts", void 0);
    GridColumnsEditor = __decorate([
        Component({
            selector: 'bpm-grid-columns-editor',
            template: "\n      <alerts-bar></alerts-bar>\n      <!--------------------------TEMPLATE PARA SORTABLE DE COLUMNAS --------------------------------------->\n      <ng-template #itemTemplate let-item=\"item\" let-index=\"index\">\n          <div *ngIf=\"item.initData.state != 'DELETED'\" class=\"card-body\">\n              <div class=\"row\">\n                  <div class=\"col-10\">\n                      <b>{{item.initData.header}}</b>\n                      <br />\n                      <i>{{item.initData.field.namedPath}}</i>\n                  </div>\n                  <div class=\"col-2\">\n                      <div class=\"dropdown pull-right\">\n                          <button class=\"btn btn-secondary dropdown-toggle\" type=\"button\" id=\"dropdownMenuButton\" data-toggle=\"dropdown\" aria-haspopup=\"true\" aria-expanded=\"false\">\n                              <span class=\"glyphicon glyphicon-cog\"></span>\n                          </button>\n                          <div class=\"dropdown-menu dropdown-menu-right\">\n                              <a class=\"dropdown-item\" href=\"#\" (click)=\"onEditColumn(item.initData)\">Editar...</a>                        \n                              <div class=\"dropdown-divider\"></div>\n                              <a class=\"dropdown-item\" href=\"#\" (click)=\"onDeleteColumn(item.initData)\">Eliminar</a>\n                          </div>\n                      </div>\n                  </div>\n              </div>\n          </div>\n      </ng-template>\n\n      <div class=\"row\">\n          <div class=\"col-12 col-md-10 col-lg-8\">\n\n              <az-panel [header]=\"title\">\n                  <!-- Men\u00FA principal -->\n                  <az-toolbar (buttonClick)=\"onMainToolbarClick($event)\">\n                      <az-toolbar-button [name]=\"'ADD'\" [type]=\"'primary'\" [text]=\"'Nueva'\" [toolTip]=\"'Agregar nueva columna'\" [icon]=\"'glyphicon glyphicon-plus'\"></az-toolbar-button>\n                      <az-toolbar-button [name]=\"'SAVE'\" [text]=\"'Guardar'\" [toolTip]=\"'Guardar cambios'\" [icon]=\"'glyphicon glyphicon-floppy-disk'\"></az-toolbar-button>\n                      <az-toolbar-button [name]=\"'CLOSE'\" [text]=\"'Cerrar'\" [icon]=\"'glyphicon glyphicon-remove'\"></az-toolbar-button>\n                  </az-toolbar>\n\n                  <!--Lista de columnas-->\n                  <bs-sortable (onChange)=\"onChangeColumns($event)\"\n                               [(ngModel)]=\"gridControl.columns\"\n                               [itemTemplate]=\"itemTemplate\"\n                               itemClass=\"card\"\n                               itemActiveClass=\"card card-outline-primary\"\n                               placeholderItem=\"No hay columnas...\">\n                  </bs-sortable>\n\n              </az-panel>\n\n          </div> <!--Col-->\n      </div> <!--Row-->\n\n      <bpm-grid-column-editor \n                              [column]=\"currentColumn\" \n                              [idDocumento]=\"gridControl.field.idDocumento\" \n                              [version]=\"gridControl.field.version\" \n                              [idPadre]=\"gridControl.field.identity\"\n                              (columnUpdated)=\"onColumnUpdated($event)\">\n      </bpm-grid-column-editor>\n\n\n      <div bsModal #confirmDelDialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"mySmallModalLabel\" aria-hidden=\"true\">\n          <div class=\"modal-dialog modal-sm\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-body\">\n                      <p>\u00BFEst\u00E1 seguro que desea eliminar la columna?</p>\n                  </div> <!--Modal Body-->\n                  <div class=\"modal-footer\">\n                      <button type=\"button\" class=\"btn btn-danger\" (click)=\"onConfirmDelete()\">Aceptar</button>\n                      <button type=\"button\" class=\"btn btn-primary\" (click)=\"confirmDelDialog.hide()\">Cancelar</button>\n                  </div> <!--Modal Footer-->\n\n              </div> <!-- Modal Content-->\n          </div> <!--Modal-->\n      </div> <!--Modal directive-->\n    "
        }),
        __metadata("design:paramtypes", [Context, Router, ActivatedRoute, FormularioService])
    ], GridColumnsEditor);
    return GridColumnsEditor;
}(BaseComponent));
export { GridColumnsEditor };
