var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, ViewChild } from '@angular/core';
import { FormBuilder } from '@angular/forms';
import { Router, ActivatedRoute } from '@angular/router';
//
import * as moment from 'moment';
//Azteca Kernel
import { Context, ProcessComponent } from '../../core';
import { AztecaValidators, AlertsBarComponent } from '../../controls';
//
import { DocumentoService } from '../services/documento.service';
import { InstanceListComponent } from './parts/instance-list.component';
var InstanceManager = /** @class */ (function (_super) {
    __extends(InstanceManager, _super);
    function InstanceManager(context, router, route, formBuilder, documentService) {
        var _this = _super.call(this, context, router, route) || this;
        _this.context = context;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.documentService = documentService;
        _this.documentTypes = [];
        _this.instanceList = [];
        //Model de parametros
        _this.idTipoDocumento = 0;
        _this.fechaInicial = new Date();
        _this.fechaFinal = new Date();
        //Crear formulario de parámetros
        _this.form = formBuilder.group({
            'idTipoDocumento': ['', AztecaValidators.selected],
            'fechaInicial': [new Date()],
            'fechaFinal': [new Date()]
        });
        return _this;
    }
    InstanceManager.prototype.ngAfterViewInit = function () {
        var _this = this;
        setTimeout(function (_) { return _this.loadTiposDocumento(); });
    };
    ////////////////////////////////// HANDLERS ///////////////////////////////////////////////////
    InstanceManager.prototype.onParamsToolbar = function (button) {
        if (button.name == 'REFRESH') {
            this.loadInstanceList();
        }
    };
    InstanceManager.prototype.onOpeningInstance = function (instance) {
        if (instance.idFormulario > 0) {
            this.listComponent.openInstance(instance);
        }
        else {
            this.alerts.showAlert('El documento se encuentra en un estatus sin formulario.', 'warning');
        }
    };
    InstanceManager.prototype.onActionExecuted = function () {
        this.alerts.showAlert('La acción ha sido ejecutada con éxito.', 'success');
    };
    InstanceManager.prototype.onDocumentReturned = function (instance) {
        this.loadInstanceList();
        this.alerts.showAlert('Se estableció el documento - ' + instance.folio + ' - a su estatus anterior', 'success');
    };
    InstanceManager.prototype.onCreatingInstance = function (step) {
        if (step && step.idFormulario > 0) {
            this.listComponent.createInstance(step.idFormulario);
        }
        else {
            this.alerts.showAlert('No se encontró un paso inicial. \r\n No se ha definido un flujo de trabajo o el paso inicial no tiene asignado un formulario', 'warning');
        }
    };
    InstanceManager.prototype.onSelectedDocumentChanged = function (idDocumento) {
        this.selectedDocType = this.documentTypes.find(function (d) { return d.id == idDocumento; });
        if (this.selectedDocType) {
            //Si el documento admite filtros por período, establecer un mes por default
            if (this.selectedDocType.filtroPeriodo) {
                this.fechaInicial = moment().subtract(1, 'month').toDate();
                this.fechaFinal = moment().add(1, 'day').toDate();
            }
            //Si el documento no admite filtros, establecer un filtro amplio para que se muestren todos los registros
            else {
                this.fechaInicial = moment().subtract(10, 'year').toDate();
                this.fechaFinal = moment().add(1, 'day').toDate();
            }
        }
    };
    ////////////////////////////////// METODOS ///////////////////////////////////////////////////
    InstanceManager.prototype.loadTiposDocumento = function () {
        var _this = this;
        this.documentService.loadListByUser(this.context.app.defaultSite.identity, this.context.session.user.identity)
            .then(function (tipos) {
            _this.documentTypes = tipos;
        })
            .catch(function (error) { return _this.handlerError(error); });
    };
    InstanceManager.prototype.loadInstanceList = function () {
        var _this = this;
        this.context.app.showSpinner();
        this.documentService.loadInstanceList(this.idTipoDocumento, this.fechaInicial, this.fechaFinal)
            .then(function (list) {
            _this.instanceList = list;
            _this.context.app.hideSpinner();
        })
            .catch(function (error) { return _this.handlerError(error); });
    };
    InstanceManager.prototype.applyPolicy = function (policy) {
    };
    InstanceManager.prototype.handlerError = function (error) {
        console.log(error);
        this.alerts.showAlert('Ha ocurrido un error al realizar la operación.', 'danger');
        this.context.app.hideSpinner();
    };
    __decorate([
        ViewChild(AlertsBarComponent),
        __metadata("design:type", AlertsBarComponent)
    ], InstanceManager.prototype, "alerts", void 0);
    __decorate([
        ViewChild(InstanceListComponent),
        __metadata("design:type", InstanceListComponent)
    ], InstanceManager.prototype, "listComponent", void 0);
    InstanceManager = __decorate([
        Component({
            selector: 'bpm-instance-manager',
            template: "\n      <form [formGroup]=\"form\">\n          <alerts-bar></alerts-bar>\n\n          <div class=\"row\">\n              <!----------- PAR\u00C1METROS DE B\u00DASQUEDA --------------->\n              <div class=\"col-12 col-lg-4\">\n\n                  <az-panel [header]=\"'Par\u00E1metros de consulta'\">\n\n                      <azteca-form-field [label]=\"'Tipo de documento:'\">\n                          <az-combobox formControlName=\"idTipoDocumento\" \n                                       [(ngModel)]=\"idTipoDocumento\" \n                                       [items]=\"documentTypes\" [valueMember]=\"'id'\" \n                                       [displayMember]=\"'nombre'\"\n                                       (selectedItemChanged)=\"onSelectedDocumentChanged($event)\">\n\n                          </az-combobox>\n                      </azteca-form-field>\n\n                      <div *ngIf=\"selectedDocType ? selectedDocType.filtroPeriodo : false\">\n                          <azteca-form-field [label]=\"'Fecha inicial:'\">\n                              <az-input-date formControlName=\"fechaInicial\" [(ngModel)]=\"fechaInicial\"></az-input-date>\n                          </azteca-form-field>\n\n                          <azteca-form-field [label]=\"'Fecha final:'\">\n                              <az-input-date formControlName=\"fechaFinal\" [(ngModel)]=\"fechaFinal\"></az-input-date>\n                          </azteca-form-field>\n                      </div>\n\n                      <br />\n\n                      <az-toolbar (buttonClick)=\"onParamsToolbar($event)\">\n                          <az-toolbar-button [name]=\"'REFRESH'\" [type]=\"'primary'\" [text]=\"'Actualizar listado'\" [icon]=\"'glyphicon glyphicon-refresh'\" [enabled]=\"form.valid\"></az-toolbar-button>\n                      </az-toolbar>\n\n\n                  </az-panel>\n\n              </div>\n\n              <!-----------LISTADO DE DOCUMENTOS--------------->\n              <div class=\"col-12- col-lg-8\">\n\n                  <az-panel [header]=\"'Relaci\u00F3n de documentos'\">\n                      <bpm-instance-list [idDocumento]=\"idTipoDocumento\" \n                                         [list]=\"instanceList\" \n                                         [allowNew]=\"true\"\n                                         (creatingInstance)=\"onCreatingInstance($event)\"\n                                         (actionExecuted)=\"onActionExecuted($event)\"\n                                         (documentReturned)=\"onDocumentReturned($event)\"\n                                         (openingInstance)=\"onOpeningInstance($event)\">\n\n                      </bpm-instance-list>\n\n                  </az-panel>\n\n              </div>\n          </div>\n      </form>\n    "
        }),
        __metadata("design:paramtypes", [Context, Router, ActivatedRoute, FormBuilder,
            DocumentoService])
    ], InstanceManager);
    return InstanceManager;
}(ProcessComponent));
export { InstanceManager };
