var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, Input, Output, EventEmitter, ViewChild } from '@angular/core';
import { FormBuilder } from '@angular/forms';
//ng2 bootstrap
import { ModalDirective } from 'ngx-bootstrap';
//
import { Context } from '../../../core';
import { AztecaValidators } from '../../../controls';
//
import { CampoSelectorComponent } from '../controls/campo-selector.component';
import { ControlService } from '../../services/control.service';
import { FormControl } from '../../models/form-control';
import { ControlType } from '../../models/control-type';
import { GridControl } from '../../models/grid-control';
import { CarouselControl } from '../../models/carousel-control';
import { MultiPointMapControl } from '../../models/multi-point-map-control';
var AddControlEditor = /** @class */ (function () {
    function AddControlEditor(context, formBuilder, controlService) {
        this.context = context;
        this.formBuilder = formBuilder;
        this.controlService = controlService;
        this.idCampo = 0;
        this.idControl = 0;
        this.selectedField = null;
        this.controles = [];
        //Inputs
        this.idDocumento = 0;
        this.version = 0;
        this.idPadre = 0;
        //Outputs
        this.controlAdded = new EventEmitter();
        this.form = this.formBuilder.group({
            'idCampo': [0, AztecaValidators.selected],
            'idControl': [0, AztecaValidators.selected]
        });
    }
    //////////// METODOS //////////////////////////
    AddControlEditor.prototype.show = function () {
        var _this = this;
        this.dialog.config.backdrop = false;
        this.dialog.show();
        this.idControl = 0;
        this.idCampo = 0;
        this.campoSelector.clear();
        setTimeout(function (_) { return _this.form.reset({ idCampo: 0, idControl: 0 }); });
    };
    AddControlEditor.prototype.loadControls = function () {
        var _this = this;
        //Si el campo es una colección, cargar controles especializados, si no, cargar controles configurados para el tipo de datos
        if (this.selectedField.complexType && this.selectedField.coleccion) {
            this.controles = this.controlService.getCollectionControls();
        }
        else if (!this.selectedField.complexType && this.selectedField.idDataset > 0) {
            this.controles = this.controlService.getDatasetControls();
        }
        else if (!this.selectedField.complexType) {
            this.controlService.loadListByTipoDato(this.selectedField.idTipoDato)
                .then(function (controles) {
                _this.controles = controles;
                if (_this.controles.length > 0)
                    _this.idControl = _this.controles[0].id;
            })
                .catch(function (error) { return _this.handleError(error); });
        }
        else {
            this.controles = [];
        }
        //Seleccionar el primer control de la lista
        if (this.controles.length > 0)
            this.idControl = this.controles[0].id;
    };
    AddControlEditor.prototype.loadControl = function () {
        var _this = this;
        this.controlService.getDetailByID(this.idControl)
            .then(function (control) {
            var formControl;
            //Instanciar el tipo correcto de control
            if (control.tag == ControlType.GRID) {
                formControl = new GridControl();
            }
            else if (control.tag == ControlType.CAROUSEL) {
                formControl = new CarouselControl();
            }
            else if (control.tag == ControlType.MULTI_POINT_MAP) {
                formControl = new MultiPointMapControl();
            }
            else {
                formControl = new FormControl();
            }
            //
            formControl.field = _this.selectedField;
            formControl.control = control;
            formControl.idCampo = _this.selectedField.identity;
            formControl.idChildForm = 0;
            formControl.idControl = _this.idControl;
            formControl.readOnly = false;
            formControl.tabOrder = 0;
            formControl.width = 1;
            _this.controlAdded.emit(formControl);
            _this.dialog.hide();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    //////////// HANDLERS //////////////////////////
    AddControlEditor.prototype.onSelectedFieldChanged = function (campo) {
        this.selectedField = campo;
        this.idControl = 0;
        if (campo != null) {
            this.loadControls();
        }
    };
    AddControlEditor.prototype.onUpdate = function () {
        //Cargar información del control seleccionado y notificar sobre control agregado
        this.loadControl();
    };
    AddControlEditor.prototype.handleError = function (error) {
        console.error(error);
        this.context.app.hideSpinner();
    };
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], AddControlEditor.prototype, "idDocumento", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], AddControlEditor.prototype, "version", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], AddControlEditor.prototype, "idPadre", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], AddControlEditor.prototype, "controlAdded", void 0);
    __decorate([
        ViewChild(CampoSelectorComponent),
        __metadata("design:type", CampoSelectorComponent)
    ], AddControlEditor.prototype, "campoSelector", void 0);
    __decorate([
        ViewChild(ModalDirective),
        __metadata("design:type", ModalDirective)
    ], AddControlEditor.prototype, "dialog", void 0);
    AddControlEditor = __decorate([
        Component({
            selector: 'bpm-add-control-editor',
            template: "\n      <form [formGroup]=\"form\">\n          <div bsModal #dialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"myLargeModalLabel\" aria-hidden=\"true\">\n              <div class=\"modal-dialog modal-lg\">\n                  <div class=\"modal-content\">\n                      <div class=\"modal-body\">\n\n                          <azteca-form-field [label]=\"'Campo:'\">\n                              <bpm-campo-selector formControlName=\"idCampo\"\n                                                  [(ngModel)]=\"idCampo\"\n                                                  [idDocumento]=\"idDocumento\"\n                                                  [version]=\"version\"\n                                                  [idPadre]=\"idPadre\"\n                                                  [showListButton]=\"false\"\n                                                  [showTreeButton]=\"false\"\n                                                  (selectedItemChanged)=\"onSelectedFieldChanged($event)\">\n                              </bpm-campo-selector>\n                          </azteca-form-field>\n\n                          <azteca-form-field [label]=\"'Control:'\">\n                              <az-combobox formControlName=\"idControl\"\n                                           [(ngModel)]=\"idControl\"\n                                           [items]=\"controles\"\n                                           [valueMember]=\"'id'\"\n                                           [displayMember]=\"'nombre'\">\n                              </az-combobox>\n                          </azteca-form-field>\n\n                      </div> <!--Modal Body-->\n                      <div class=\"modal-footer\">\n                          <button type=\"button\" class=\"btn btn-primary\" (click)=\"onUpdate($event)\" [disabled]=\"!form.valid\">Aceptar</button>\n                          <button type=\"button\" class=\"btn btn-danger\" (click)=\"dialog.hide()\">Cancelar</button>\n                      </div> <!--Modal Footer-->\n\n                  </div> <!-- Modal Content-->\n              </div> <!--Modal-->\n          </div>\n      </form> <!--Modal directive-->\n    "
        }),
        __metadata("design:paramtypes", [Context, FormBuilder, ControlService])
    ], AddControlEditor);
    return AddControlEditor;
}());
export { AddControlEditor };
