var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, Input, Output, EventEmitter, ViewChild, ChangeDetectorRef } from '@angular/core';
import { FormBuilder, Validators } from '@angular/forms';
//ng2 bootstrap
import { ModalDirective } from 'ngx-bootstrap';
//
import { Context } from '../../../core';
import { AztecaValidators } from '../../../controls';
//
import { CampoSelectorComponent } from '../controls/campo-selector.component';
import { GridColumn } from '../../models/grid-column';
import { DataType } from '../../models/data-type';
var GridColumnEditor = /** @class */ (function () {
    function GridColumnEditor(context, formBuilder, changeDetector) {
        this.context = context;
        this.formBuilder = formBuilder;
        this.changeDetector = changeDetector;
        this.alignments = [];
        //Inputs
        this.column = new GridColumn();
        this.idDocumento = 0;
        this.version = 0;
        this.idPadre = 0;
        //Outputs
        this.columnUpdated = new EventEmitter();
        this.editForm = this.formBuilder.group({
            'idCampo': [0, AztecaValidators.selected],
            'header': ['', Validators.required],
            'width': [1],
            'format': [''],
            'readOnly': [true],
            'alignment': ['']
        });
        //Inicializar grid de alineaciones
        this.alignments.push({ id: 'left', name: 'izquierda' });
        this.alignments.push({ id: 'center', name: 'centro' });
        this.alignments.push({ id: 'derecha', name: 'right' });
    }
    //////////// METODOS //////////////////////////
    GridColumnEditor.prototype.show = function () {
        var _this = this;
        this.dialog.config.backdrop = false;
        this.dialog.show();
        setTimeout(function (_) { return _this.selectAction(); });
    };
    GridColumnEditor.prototype.selectAction = function () {
        if (this.column._clientID == 0) {
            this.editForm.reset({ idCampo: 0, width: 1, alignment: 'left', readOnly: true, format: '' });
        }
    };
    //////////// HANDLERS //////////////////////////
    GridColumnEditor.prototype.onUpdate = function () {
        this.column.field = this.campoSelector.selectedItem;
        this.columnUpdated.emit(this.column);
        this.dialog.hide();
    };
    GridColumnEditor.prototype.onCampoSelected = function (campo) {
        //Validar que no se seleccionen campos complejos y los campos simples sean de tipos de dato cadena, fecha o numpericos        
        if (campo && (campo.complexType || !DataType.PRIMITIVES.find(function (s) { return s == campo.tipoDato.tag; }))) {
            this.campoSelector.clear();
        }
    };
    GridColumnEditor.prototype.handleError = function (error) {
        console.error(error);
        this.context.app.hideSpinner();
    };
    __decorate([
        Input(),
        __metadata("design:type", GridColumn)
    ], GridColumnEditor.prototype, "column", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], GridColumnEditor.prototype, "idDocumento", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], GridColumnEditor.prototype, "version", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], GridColumnEditor.prototype, "idPadre", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], GridColumnEditor.prototype, "columnUpdated", void 0);
    __decorate([
        ViewChild(ModalDirective),
        __metadata("design:type", ModalDirective)
    ], GridColumnEditor.prototype, "dialog", void 0);
    __decorate([
        ViewChild('campoSelector'),
        __metadata("design:type", CampoSelectorComponent)
    ], GridColumnEditor.prototype, "campoSelector", void 0);
    GridColumnEditor = __decorate([
        Component({
            selector: 'bpm-grid-column-editor',
            template: "\n      <form [formGroup]=\"editForm\">\n          <div bsModal #dialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"myLargeModalLabel\" aria-hidden=\"true\">\n              <div class=\"modal-dialog modal-lg\">\n                  <div class=\"modal-content\">\n                      <div class=\"modal-body\">\n\n                    \n                          <azteca-form-field [label]=\"'Campo:'\">\n                              <bpm-campo-selector #campoSelector\n                                                  formControlName=\"idCampo\"\n                                                  [enabled]=\"column._clientID == 0\"\n                                                  [(ngModel)]=\"column.idCampo\"\n                                                  [idDocumento]=\"idDocumento\"\n                                                  [version]=\"version\"\n                                                  [idPadre]=\"idPadre\"\n                                                  [showListButton]=\"false\"\n                                                  [showTreeButton]=\"false\"\n                                                  (selectedItemChanged)=\"onCampoSelected($event)\">\n                              </bpm-campo-selector>\n                          </azteca-form-field>\n\n                \n                          <azteca-form-field [label]=\"'Encabezado:'\">\n                              <az-textbox formControlName=\"header\" [(ngModel)]=\"column.header\"></az-textbox>\n                          </azteca-form-field>\n                \n                          <azteca-form-field [label]=\"'Ancho:'\">\n                              <az-input-number formControlName=\"width\" [(ngModel)]=\"column.width\"></az-input-number>\n                          </azteca-form-field>\n                                    \n                          <azteca-form-field [label]=\"'Formato:'\">\n                              <az-textbox formControlName=\"format\" [(ngModel)]=\"column.format\"></az-textbox>\n                          </azteca-form-field>\n\n\n                          <azteca-form-field [label]=\"'Alineaci\u00F3n:'\">\n                              <az-combobox formControlName=\"alignment\" [(ngModel)]=\"column.horizontalAlignment\" [items]=\"alignments\" [valueMember]=\"'id'\" [displayMember]=\"'name'\"></az-combobox>\n                          </azteca-form-field>\n\n                    \n                          <az-checkbox [label]=\"'S\u00F3lo lectura'\" formControlName=\"readOnly\" [(ngModel)]=\"column.readOnly\"></az-checkbox>\n\n                        \n                      </div> <!--Modal Body-->\n                      <div class=\"modal-footer\">\n                          <button type=\"button\" class=\"btn btn-primary\" (click)=\"onUpdate($event)\" [disabled]=\"!editForm.valid\">Aceptar</button>\n                          <button type=\"button\" class=\"btn btn-danger\" (click)=\"dialog.hide()\">Cancelar</button>\n                      </div> <!--Modal Footer-->\n\n                  </div> <!-- Modal Content-->\n              </div> <!--Modal-->\n          </div>\n      </form> <!--Modal directive-->\n    "
        }),
        __metadata("design:paramtypes", [Context, FormBuilder, ChangeDetectorRef])
    ], GridColumnEditor);
    return GridColumnEditor;
}());
export { GridColumnEditor };
