var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, Input, Output, EventEmitter, ViewChild, forwardRef } from '@angular/core';
import { FormBuilder } from '@angular/forms';
import { Router, ActivatedRoute } from '@angular/router';
//Wijmo
import { CollectionView } from 'wijmo/wijmo';
import { CellRange, CellType } from 'wijmo/wijmo.grid';
//Azteca Kernel
import { Context, BaseComponent } from '../../../core';
import { ContentViewerComponent } from '../../../controls';
//
import { WorkflowService } from '../../services/workflow.service';
import { DocumentoService } from '../../services/documento.service';
import { DocumentoInfo } from '../../models/documento';
import { VersionInfo } from '../../models/version';
var InstanceListComponent = /** @class */ (function (_super) {
    __extends(InstanceListComponent, _super);
    function InstanceListComponent(context, router, route, formBuilder, documentService, workflowService) {
        var _this = _super.call(this) || this;
        _this.context = context;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.documentService = documentService;
        _this.workflowService = workflowService;
        _this.menuItems = [];
        _this._list = [];
        _this.instanceCollection = new CollectionView([], { pageSize: 20 });
        _this.documento = new DocumentoInfo();
        _this.activeVersion = new VersionInfo();
        _this.instanceVersion = new VersionInfo();
        _this.currentInstance = null;
        _this.currentWorkflow = [];
        _this.activeWorkflow = [];
        //
        //INPUTS
        _this.idDocumento = 0;
        _this.allowNew = false;
        //OUTPUTS
        _this.creatingInstance = new EventEmitter();
        _this.openingInstance = new EventEmitter();
        _this.executingAction = new EventEmitter();
        _this.actionExecuted = new EventEmitter();
        _this.documentReturned = new EventEmitter();
        //
        _this.createMenu();
        return _this;
    }
    InstanceListComponent_1 = InstanceListComponent;
    Object.defineProperty(InstanceListComponent.prototype, "list", {
        get: function () {
            return this._list;
        },
        set: function (value) {
            this._list = value;
            this.instanceCollection.sourceCollection = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(InstanceListComponent.prototype, "pageSize", {
        get: function () {
            return this.instanceCollection.pageSize;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(InstanceListComponent.prototype, "pagetSize", {
        set: function (value) {
            this.instanceCollection.pageSize = value;
        },
        enumerable: true,
        configurable: true
    });
    InstanceListComponent.prototype.ngOnChanges = function (changes) {
        var _this = this;
        if (changes['idDocumento'] && this.idDocumento > 0) {
            setTimeout(function (_) { return _this.loadDocumentTypeInfo(); });
        }
    };
    ////////////////////////////////// HANDLERS ///////////////////////////////////////////////////
    InstanceListComponent.prototype.gridInitialized = function (grid) {
        var _this = this;
        var self = this;
        //Agregar manejador para menú contextual        
        grid.addEventListener(grid.hostElement, "contextmenu", function (e) {
            var ht = grid.hitTest(e);
            grid.select(new CellRange(ht.row, ht.col), true);
            if (_this.instanceCollection.currentItem) {
                _this.loadInstanceVersion();
            }
        });
        grid.addEventListener(grid.hostElement, "dblclick", function (e) {
            var ht = grid.hitTest(e);
            if (ht.cellType == CellType.Cell) {
                _this.openingInstance.emit(_this.currentInstance);
            }
        });
        this.instanceCollection.currentChanged.addHandler(function (args) {
            _this.currentInstance = self.instanceCollection.currentItem;
        }, self);
    };
    InstanceListComponent.prototype.onToolbarButtonClick = function (button) {
        if (button.name == 'ADD') {
            var startStep = this.activeWorkflow.find(function (step) { return step.isStart; });
            this.creatingInstance.emit(startStep);
        }
    };
    InstanceListComponent.prototype.menuClick = function (menu) {
        var option = this.menuItems[menu.selectedIndex];
        this.selectMenuAction(option);
    };
    InstanceListComponent.prototype.selectMenuAction = function (option) {
        if (!this.currentInstance)
            return;
        //        
        if (option.name == 'OPEN') {
            this.openingInstance.emit(this.currentInstance);
        }
        else if (option.name == 'PREVIOUS') {
            this.previousStep();
        }
        else {
            this.executingAction.emit({ action: option.name, instance: this.currentInstance });
            this.executeAction(this.currentInstance.idDocumento, this.currentInstance.version, option.name, this.currentInstance.folio);
        }
    };
    InstanceListComponent.prototype.onOpeningMenu = function (menu) {
        if (this.instanceCollection.currentItem) {
            this.loadInstanceVersion();
        }
    };
    ////////////////////////////////// METODOS ///////////////////////////////////////////////////
    InstanceListComponent.prototype.createMenu = function () {
        var _this = this;
        this.menuItems = [];
        this.menuItems.push({ name: 'OPEN', icon: 'glyphicon glyphicon-folder-open', text: 'Abrir', smallText: 'abrir documento para edición', enabled: true });
        this.menuItems.push({ name: 'PREVIOUS', icon: 'glyphicon glyphicon-arrow-left', text: 'Retroceder', smallText: 'regresar al paso anterior', enabled: true });
        //Agregar opciones de menú de acciones personalizadas
        this.instanceVersion.actions.forEach(function (action) {
            _this.menuItems.push({ name: action.actionTag, icon: 'glyphicon glyphicon-cog', text: action.menuText, smallText: '', enabled: true });
        });
    };
    InstanceListComponent.prototype.createInstance = function (idStartForm) {
        if (idStartForm > 0) {
            this.router.navigate(['kernel/bpm/form-generator', idStartForm]);
        }
        else {
            console.error('No se especificó el formulario de inicio.');
        }
    };
    InstanceListComponent.prototype.loadInstanceVersion = function () {
        var _this = this;
        //Checar si ya se había cargado la información para la versión de la instancia actual       
        if (this.currentInstance.version == this.instanceVersion.version) {
            return;
        }
        else {
            this.context.app.showSpinner();
            var verPromise = this.documentService.loadVersion(this.currentInstance.idDocumento, this.currentInstance.version)
                .then(function (ver) { return _this.instanceVersion = ver; })
                .catch(function (error) { return _this.handleError(error); });
            var wfPromise = this.workflowService.loadWorkflow(this.currentInstance.idDocumento, this.currentInstance.version)
                .then(function (wf) { return _this.currentWorkflow = wf; })
                .catch(function (error) { return _this.handleError(error); });
            Promise.all([verPromise, wfPromise])
                .then(function (_) {
                _this.createMenu();
                _this.context.app.hideSpinner();
            });
        }
    };
    InstanceListComponent.prototype.loadActiveWorkflow = function () {
        var _this = this;
        this.workflowService.loadWorkflow(this.idDocumento, this.activeVersion.version)
            .then(function (wf) { return _this.activeWorkflow = wf; })
            .catch(function (error) { return _this.handleError(error); });
    };
    InstanceListComponent.prototype.loadDocumentTypeInfo = function () {
        var _this = this;
        this.context.app.showSpinner();
        this.instanceCollection.sourceCollection = [];
        this.instanceVersion = new VersionInfo();
        var docPromise = this.documentService.getDetailByID(this.idDocumento)
            .then(function (doc) { return _this.documento = doc; })
            .catch(function (error) { return _this.handleError(error); });
        var verPromise = this.documentService.loadActiveVersion(this.idDocumento)
            .then(function (ver) { return _this.activeVersion = ver; })
            .catch(function (error) { return _this.handleError(error); });
        Promise.all([docPromise, verPromise])
            .then(function (_) {
            _this.loadActiveWorkflow();
            _this.context.app.hideSpinner();
        });
    };
    InstanceListComponent.prototype.openInstance = function (instance) {
        if (instance.idFormulario > 0) {
            this.router.navigate(['kernel/bpm/form-generator', instance.idFormulario, { folio: instance.folio }]);
        }
        else {
            console.warn('El documento se encuentra en un estatus que no tiene formulario o el formulario no ha sido asignado');
        }
    };
    InstanceListComponent.prototype.executeAction = function (idDocumento, version, actionTag, folio) {
        var _this = this;
        this.documentService.executeUnboundAction(idDocumento, version, actionTag, folio)
            .then(function (result) {
            var action = _this.instanceVersion.actions.find(function (a) { return a.actionTag == actionTag; });
            if (action) {
                if (action.returnType == 'V') {
                    //Acción sin valor de retorno
                }
                else if (action.returnType == 'L') {
                    //El retorno es un link que debe abrirse en otra ventana
                    window.open('/file-server/' + result, '_blank');
                }
                else if (action.returnType == 'P') {
                    //El retorno es un PDF base 64
                    _this.contentViewer.show('data:application/pdf;base64, ' + result);
                }
                _this.actionExecuted.emit({ action: action.actionTag, instance: _this.currentInstance });
            }
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    InstanceListComponent.prototype.previousStep = function () {
        var _this = this;
        this.context.app.showSpinner();
        this.documentService.previousStep(this.currentInstance.folio)
            .then(function (updatedInstance) {
            _this.context.app.hideSpinner();
            _this.documentReturned.emit(_this.currentInstance);
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    InstanceListComponent.prototype.applyPolicy = function (policy) {
    };
    InstanceListComponent.prototype.toPascalCase = function (s) {
        if (s && s.length > 1) {
            return s[0].toLowerCase() + s.substring(1);
        }
        else {
            return s;
        }
    };
    InstanceListComponent.prototype.handleError = function (error) {
        console.log(error);
        this.context.app.hideSpinner();
    };
    var InstanceListComponent_1;
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], InstanceListComponent.prototype, "idDocumento", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], InstanceListComponent.prototype, "allowNew", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Array),
        __metadata("design:paramtypes", [Array])
    ], InstanceListComponent.prototype, "list", null);
    __decorate([
        Input(),
        __metadata("design:type", Object),
        __metadata("design:paramtypes", [])
    ], InstanceListComponent.prototype, "pageSize", null);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], InstanceListComponent.prototype, "creatingInstance", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], InstanceListComponent.prototype, "openingInstance", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], InstanceListComponent.prototype, "executingAction", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], InstanceListComponent.prototype, "actionExecuted", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], InstanceListComponent.prototype, "documentReturned", void 0);
    __decorate([
        ViewChild(ContentViewerComponent),
        __metadata("design:type", ContentViewerComponent)
    ], InstanceListComponent.prototype, "contentViewer", void 0);
    InstanceListComponent = InstanceListComponent_1 = __decorate([
        Component({
            selector: 'bpm-instance-list',
            template: "\n      <!--Listado-->\n      <div class=\"row\">\n          <div class=\"col-12\">\n\n              <az-toolbar (buttonClick)=\"onToolbarButtonClick($event)\" (menuItemClick)=\"selectMenuAction($event)\" (openingMenu)=\"onOpeningMenu($event)\">\n                  <az-toolbar-button *ngIf=\"allowNew\" [name]=\"'ADD'\" [type]=\"'primary'\" [text]=\"'Nuevo'\" [icon]=\"'glyphicon glyphicon-plus'\" [enabled]=\"activeWorkflow.length > 0\"></az-toolbar-button>\n                  <az-toolbar-menu [name]=\"'OPTIONS'\" [header]=\"'Opciones'\" [menuItems]=\"menuItems\"></az-toolbar-menu>\n              </az-toolbar>\n\n              <wj-flex-grid #instanceGrid\n                            style=\"height:550px\"                       \n                            (initialized)=\"gridInitialized(instanceGrid)\"\n                            [isReadOnly]=\"true\"\n                            [itemsSource]=\"instanceCollection\" \n                            [selectionMode]=\"'Row'\" \n                            [wjContextMenu]=\"ctxMenu\">\n\n                  <wj-flex-grid-filter #filter></wj-flex-grid-filter>\n\n                  <wj-flex-grid-column [header]=\"'Folio'\" [binding]=\"'folio'\" [width]=\"100\"></wj-flex-grid-column>\n                  <wj-flex-grid-column [header]=\"'Fecha'\" [binding]=\"'fecha'\" [width]=\"150\" dataType=\"Date\" [format]=\"'dd-MM-yyyy'\"></wj-flex-grid-column>\n\n                  <!--COLUMNAS PERSONALIZADAS-->\n                  <wj-flex-grid-column *ngFor=\"let col of activeVersion.columns\" [header]=\"col.headerText\" [binding]=\"toPascalCase(col.fieldName)\" [width]=\"'20*'\"></wj-flex-grid-column>\n\n                  <wj-flex-grid-column [header]=\"'Estatus'\" [binding]=\"'workflowStep'\" [width]=\"'20*'\"></wj-flex-grid-column>\n                  <wj-flex-grid-column [header]=\"'Ver.'\" [binding]=\"'version'\" [width]=\"'5*'\"></wj-flex-grid-column>\n              </wj-flex-grid>\n          </div>\n      </div>\n\n      <!--Pager-->\n      <div class=\"row\">\n          <div class=\"col-12 col-md-6\">\n              <az-pager [totalRows]=\"instanceCollection.totalItemCount\"\n                        [pageSize]=\"instanceCollection.pageSize\"\n                        [pageIndex]=\"instanceCollection.pageIndex\"\n                        (moveToPage)=\"instanceCollection.moveToPage($event)\">\n\n              </az-pager>\n          </div>\n      </div>\n\n      <!--Men\u00FA contextual-->\n      <wj-menu #ctxMenu (itemClicked)=\"menuClick(ctxMenu, $event)\" style=\"display:none\">\n          <wj-menu-item *ngFor=\"let item of menuItems\">\n              <div *ngIf=\"item.enabled\">\n                  <span [class]=\"item.icon\"></span>\n                  <b>{{item.text}}</b>\n                  <br>\n                  <small><i>{{item.smallText}}</i></small>\n              </div>\n          </wj-menu-item>\n      </wj-menu>\n\n\n      <azteca-content-viewer></azteca-content-viewer>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return InstanceListComponent_1; })
                }
            ]
        }),
        __metadata("design:paramtypes", [Context, Router, ActivatedRoute, FormBuilder,
            DocumentoService, WorkflowService])
    ], InstanceListComponent);
    return InstanceListComponent;
}(BaseComponent));
export { InstanceListComponent };
