var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, ViewChild, forwardRef } from '@angular/core';
import { FormBuilder } from '@angular/forms';
import { Router, ActivatedRoute } from '@angular/router';
//Wijmo
import { Control } from 'wijmo/wijmo';
//ngx bootstrap
import { ModalDirective } from 'ngx-bootstrap';
//Azteca Kernel
import { Context, BaseComponent, ProcessComponent, EnsambladoService } from '../../core';
import { TrackableCollection } from '../../editors';
//
import { DocumentoService } from '../services/documento.service';
import { VersionInfo } from '../models/version';
import { VersionColumn } from '../models/version-column';
import { CampoSelectorComponent } from '../components/controls/campo-selector.component';
var VersionesEditor = /** @class */ (function (_super) {
    __extends(VersionesEditor, _super);
    function VersionesEditor(context, router, route, formBuilder, documentoService, ensambladoService) {
        var _this = _super.call(this, context, router, route) || this;
        _this.context = context;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.documentoService = documentoService;
        _this.ensambladoService = ensambladoService;
        _this.info = new VersionInfo();
        _this.ensamblados = [];
        _this.columnsCollection = new TrackableCollection();
        _this.idDocumento = 0;
        _this.editorForm = formBuilder.group({
            'idEnsamblado': [0],
            'clase': [''],
            'idFormaBorrador': [0]
        });
        return _this;
    }
    VersionesEditor_1 = VersionesEditor;
    VersionesEditor.prototype.ngAfterViewInit = function () {
        var _this = this;
        setTimeout(function (_) { return _this.loadEnsamblados(); });
        //Determinar si se está agregando una nueva versión o se editará una existente
        var version = 0;
        this.route.params.forEach(function (params) {
            _this.idDocumento = +params['id'];
            version = +params['ver'];
        });
        if (version > 0) {
            setTimeout(function (_) { return _this.loadVersion(version); });
        }
        setTimeout(function (_) { return _this.applyPolicies(); });
    };
    //////////////// METODOS ///////////////////////
    VersionesEditor.prototype.loadEnsamblados = function () {
        var _this = this;
        this.ensambladoService.loadList()
            .then(function (ensamblados) { return _this.ensamblados = ensamblados; })
            .catch(function (error) { return _this.handleError(error); });
    };
    VersionesEditor.prototype.loadVersion = function (version) {
        var _this = this;
        this.documentoService.loadVersion(this.idDocumento, version)
            .then(function (info) {
            _this.info = info;
            _this.columnsCollection.sourceCollection = _this.info.columns;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    VersionesEditor.prototype.saveVersion = function () {
        var _this = this;
        this.context.app.showSpinner();
        this.documentoService.saveVersion(this.idDocumento, this.info)
            .then(function (updatedVersion) {
            _this.info = updatedVersion;
            _this.context.app.hideSpinner();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    /////////////// HANDLERS ////////////////////
    VersionesEditor.prototype.applyPolicy = function (policy) {
    };
    VersionesEditor.prototype.onMainToolbarClick = function (button) {
        if (button.name == 'SAVE') {
            this.saveVersion();
        }
        if (button.name == 'CLOSE') {
            this.router.navigate(['../'], { relativeTo: this.route });
        }
    };
    VersionesEditor.prototype.onColumnsToolbarClick = function (button) {
        var _this = this;
        if (button.name == 'ADD') {
            this.addColumnDialog.config.backdrop = false;
            this.addColumnDialog.show();
            setTimeout(function (_) { return _this.columnField.clear(); });
        }
    };
    VersionesEditor.prototype.onRowDelete = function (row) {
        this.columnsCollection.remove(row);
    };
    VersionesEditor.prototype.addColumn = function () {
        var newColumns = this.info.columns.slice();
        newColumns.push(this.currentColumn);
        this.info.columns = newColumns;
        this.columnsCollection.sourceCollection = this.info.columns;
        this.addColumnDialog.hide();
    };
    VersionesEditor.prototype.onCampoSelected = function (campo) {
        if (campo) {
            this.currentColumn = new VersionColumn();
            this.currentColumn.headerText = campo.nombre;
            this.currentColumn.fieldName = campo.xmlTag;
            this.currentColumn.width = 100;
            this.currentColumn.xmlPath = campo.xmlPath + '/@' + campo.xmlTag;
        }
    };
    VersionesEditor.prototype.onColumnsSelect = function (args) {
        if (args.heading) {
            Control.invalidateAll();
        }
    };
    VersionesEditor.prototype.handleError = function (error) {
        console.error(error);
        this.context.app.hideSpinner();
    };
    var VersionesEditor_1;
    __decorate([
        ViewChild('addColumnDialog'),
        __metadata("design:type", ModalDirective)
    ], VersionesEditor.prototype, "addColumnDialog", void 0);
    __decorate([
        ViewChild(CampoSelectorComponent),
        __metadata("design:type", CampoSelectorComponent)
    ], VersionesEditor.prototype, "columnField", void 0);
    VersionesEditor = VersionesEditor_1 = __decorate([
        Component({
            selector: 'bpm-versiones-editor',
            template: "\n      <div class=\"row\">\n          <div class=\"col-12 col-lg-10\">             \n           \n              <form [formGroup]=\"editorForm\">\n                  <az-panel [header]=\"'Editor de versiones'\">\n\n                      <az-toolbar (buttonClick)=\"onMainToolbarClick($event)\">\n                          <az-toolbar-button [name]=\"'SAVE'\" [type]=\"'primary'\" [text]=\"'Guardar'\" [toolTip]=\"'Guardar informaci\u00F3n'\" [icon]=\"'glyphicon glyphicon-floppy-disk'\"></az-toolbar-button>\n                          <az-toolbar-button [name]=\"'CLOSE'\" [text]=\"'Cancelar'\" [icon]=\"'glyphicon glyphicon-remove'\"></az-toolbar-button>\n                      </az-toolbar>\n\n                      <tabset>\n                          <tab [heading]=\"'General'\">\n\n                              <label>Versi\u00F3n:</label>\n                              <az-label [text]=\"info.version\"></az-label>\n\n                              <azteca-form-field [label]=\"'Ensamblado de personalizaciones:'\">\n                                  <az-combobox formControlName=\"idEnsamblado\" [(ngModel)]=\"info.idEnsamblado\" [items]=\"ensamblados\" [displayMember]=\"'nombre'\" [valueMember]=\"'id'\"></az-combobox>\n                              </azteca-form-field>\n\n                              <azteca-form-field [label]=\"'Clase de personalizaciones:'\">\n                                  <az-textbox formControlName=\"clase\" [(ngModel)]=\"info.claseBusiness\"></az-textbox>\n                              </azteca-form-field>\n\n                              <azteca-form-field *ngIf=\"info.version > 0\" [label]=\"'Formulario para borradores:'\">\n                                  <az-textbox formControlName=\"idFormaBorrador\" [(ngModel)]=\"info.idFormaBorrador\"></az-textbox>\n                              </azteca-form-field>\n\n\n                          </tab>\n                          <tab [heading]=\"'Columnas'\" [disabled]=\"info.version == 0\" (select)=\"onColumnsSelect($event)\">\n\n                              <az-toolbar (buttonClick)=\"onColumnsToolbarClick($event)\">\n                                  <az-toolbar-button [name]=\"'ADD'\" [type]=\"'primary'\" [text]=\"'Nueva'\" [toolTip]=\"'Agregar columna'\" [icon]=\"'glyphicon glyphicon-plus'\"></az-toolbar-button>                            \n                              </az-toolbar>\n\n                              <wj-flex-grid style=\"height:550px\" [itemsSource]=\"columnsCollection\">                            \n\n                                  <wj-flex-grid-column [header]=\"''\" [width]=\"60\" [isReadOnly]=\"true\">\n                                      <ng-template wjFlexGridCellTemplate [cellType]=\"'Cell'\" let-cell=\"cell\">\n                                          <button type=\"button\" class=\"btn btn-default\" (click)=\"onRowDelete(cell.item)\">\n                                              <span class=\"glyphicon glyphicon-trash\"></span>\n                                          </button>\n                                      </ng-template>\n                                  </wj-flex-grid-column>\n\n                                  <wj-flex-grid-column [header]=\"'Encabezado'\" [binding]=\"'headerText'\" [width]=\"'20*'\"></wj-flex-grid-column>\n                                  <wj-flex-grid-column [header]=\"'Campo'\" [binding]=\"'fieldName'\" [width]=\"'30*'\"></wj-flex-grid-column>                            \n                                  <wj-flex-grid-column [header]=\"'Xml Path'\" [binding]=\"'xmlPath'\" [width]=\"'40*'\"></wj-flex-grid-column>\n                                  <wj-flex-grid-column [header]=\"'Ancho'\" [binding]=\"'width'\" [width]=\"'10*'\"></wj-flex-grid-column>\n                              </wj-flex-grid>\n\n                          </tab>\n                      </tabset>\n                  </az-panel>\n              </form>\n\n          </div>\n      </div>\n\n\n      <div bsModal #addColumnDialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"myLargeModalLabel\" aria-hidden=\"true\">\n          <div class=\"modal-dialog modal-lg\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-header\">\n                      <h4 class=\"modal-title\">Agregar columna</h4>\n                  </div>\n                  <div class=\"modal-body\">\n                      <bpm-campo-selector [showListButton]=\"false\"\n                                          [showTreeButton]=\"false\"\n                                          [idDocumento]=\"idDocumento\" \n                                          [version]=\"info.version\" \n                                          (selectedItemChanged)=\"onCampoSelected($event)\"></bpm-campo-selector>\n                  </div> <!--Modal Body-->\n                  <div class=\"modal-footer\">\n                      <button type=\"button\" class=\"btn btn-primary\" (click)=\"addColumn()\">Aceptar</button>\n                      <button type=\"button\" class=\"btn btn-danger\" (click)=\"addColumnDialog.hide()\">Cancelar</button>\n                  </div> <!--Modal Footer-->\n\n              </div> <!-- Modal Content-->\n          </div> <!--Modal-->\n      </div> <!--Modal directive-->\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return VersionesEditor_1; })
                }
            ]
        }),
        __metadata("design:paramtypes", [Context, Router, ActivatedRoute, FormBuilder,
            DocumentoService, EnsambladoService])
    ], VersionesEditor);
    return VersionesEditor;
}(ProcessComponent));
export { VersionesEditor };
