import { Router, ActivatedRoute } from '@angular/router';
import { Location } from '@angular/common';
import { ModalDirective } from 'ngx-bootstrap';
import { Context } from '../../core';
import { ToolbarButton, MenuItem, AzInputNumber, AlertsBarComponent } from '../../controls';
import { ILink, PaperComponent, PaperEventArgs, ConnectionEventArgs, CellView, ElementView, BBox, LinkDirective } from '../../drawing';
import { WorkflowService } from '../services/workflow.service';
import { DocumentoService } from '../services/documento.service';
import { VersionInfo } from '../models/version';
import { WorkflowStep } from '../models/workflow-step';
import { Start } from '../models/start';
import { Activity } from '../models/activity';
import { Condition } from '../models/condition';
import { ConditionOption } from '../models/condition-option';
import { WorkflowElement } from '../models/workflow-element';
import { ActivityEditor } from './parts/activity.editor';
import { ConditionsEditor } from './parts/conditions.editor';
export declare class WorkflowEditor {
    private context;
    private router;
    private route;
    private location;
    private workflowService;
    private documentoService;
    idDocumento: number;
    version: number;
    shapesMenu: MenuItem[];
    versionInfo: VersionInfo;
    workflow: WorkflowStep[];
    start: Start;
    conditions: Condition[];
    activities: Activity[];
    links: ILink[];
    lastElementID: number;
    lastConditionID: number;
    lastLinkID: number;
    lastPosition: {
        x: number;
        y: number;
    };
    currentCell: ElementView;
    currentBox: BBox;
    currentElement: WorkflowElement;
    paper: PaperComponent;
    inputWidth: AzInputNumber;
    inputHeight: AzInputNumber;
    deleteDialog: ModalDirective;
    activityEditor: ActivityEditor;
    conditionsEditor: ConditionsEditor;
    alertsBar: AlertsBarComponent;
    constructor(context: Context, router: Router, route: ActivatedRoute, location: Location, workflowService: WorkflowService, documentoService: DocumentoService);
    ngAfterViewInit(): void;
    loadVersion(): void;
    loadWorkflow(updateVersion: boolean): void;
    createDiagram(): void;
    updateNextElement(link: LinkDirective, previousElement: WorkflowElement, workflow: WorkflowStep[]): void;
    updateWorkflow(): void;
    findElementByID(clientID: number): WorkflowElement;
    findElement(shapeID: string): WorkflowElement;
    findLink(linkID: string): ILink;
    setCurrentElement(cell: CellView): void;
    createShapesMenu(): void;
    createElementID(): number;
    createStepID(): number;
    createShapeID(): number;
    getNewElementPosition(): {
        x: number;
        y: number;
    };
    crearActividad(): void;
    crearCondicion(): void;
    createNewLink(): void;
    createLink(source: number, target: number, label?: string, vertices?: string): ILink;
    trackShape(index: any, item: any): any;
    isOptionsShape(shapeID: string): boolean;
    removeConditionOption(condition: Condition, activityID: number): void;
    createConditionOption(targetActivity: Activity, tag?: string, text?: string): ConditionOption;
    setElementSize(width: number, height: number): void;
    onCellClick(args: PaperEventArgs): void;
    onCellDblClick(args: PaperEventArgs): void;
    onBlankClick(args: PaperEventArgs): void;
    onLinkConnect(args: ConnectionEventArgs): void;
    onLinkDisconnect(args: ConnectionEventArgs): void;
    onLinkDeleted(link: LinkDirective): void;
    shapeMoved(pos: {
        x: number;
        y: number;
    }, element: WorkflowElement): void;
    changeSize(): void;
    onMainToolBar(button: ToolbarButton): void;
    onShapesMenu(option: MenuItem): void;
    onEditActivity(): void;
    onEditOptions(): void;
    onActivityUpdated(activity: Activity): void;
    onConditionUpdate(condition: Condition): void;
    onConfirmDelete(): void;
    handleError(error: any): void;
}
