var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, ViewChild } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { Location } from '@angular/common';
//Ng2 bootstrap
import { ModalDirective } from 'ngx-bootstrap';
//Kernel
import { Context } from '../../core';
import { ChangeState } from '../../editors';
import { AzInputNumber, AlertsBarComponent } from '../../controls';
import { PaperComponent } from '../../drawing';
//BPM
import { WorkflowService } from '../services/workflow.service';
import { DocumentoService } from '../services/documento.service';
import { WorkflowStep } from '../models/workflow-step';
import { WorkflowOption } from '../models/workflow-option';
import { Start } from '../models/start';
import { Activity } from '../models/activity';
import { Condition } from '../models/condition';
import { ConditionOption } from '../models/condition-option';
import { WorkflowElement } from '../models/workflow-element';
import { ActivityEditor } from './parts/activity.editor';
import { ConditionsEditor } from './parts/conditions.editor';
var WorkflowEditor = /** @class */ (function () {
    function WorkflowEditor(context, router, route, location, workflowService, documentoService) {
        var _this = this;
        this.context = context;
        this.router = router;
        this.route = route;
        this.location = location;
        this.workflowService = workflowService;
        this.documentoService = documentoService;
        this.shapesMenu = [];
        this.workflow = [];
        this.start = new Start();
        this.conditions = [];
        this.activities = [];
        this.links = [];
        //
        this.lastElementID = 0;
        this.lastConditionID = 0;
        this.lastLinkID = 0;
        //
        this.route.params.forEach(function (params) {
            _this.idDocumento = +params['idDocumento'];
            _this.version = +params['version'];
        });
        //
        this.createShapesMenu();
    }
    WorkflowEditor.prototype.ngAfterViewInit = function () {
        var _this = this;
        setTimeout(function (_) { return _this.loadVersion(); });
    };
    WorkflowEditor.prototype.loadVersion = function () {
        var _this = this;
        this.context.app.showSpinner();
        this.documentoService.loadVersion(this.idDocumento, this.version)
            .then(function (vi) {
            _this.versionInfo = vi;
            _this.loadWorkflow(false);
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    WorkflowEditor.prototype.loadWorkflow = function (updateVersion) {
        var _this = this;
        this.workflowService.loadWorkflow(this.idDocumento, this.version)
            .then(function (workflow) {
            _this.workflow = workflow;
            if (updateVersion) {
                //Guardar informacion de la version (informacion del paso de inicio) para despues guardar el workflow
                var startStep = _this.workflow.find(function (s) { return s.isStart == true; });
                _this.versionInfo.idStartStep = startStep.id;
                _this.versionInfo.startShape = _this.start.shape;
                _this.documentoService.saveVersion(_this.idDocumento, _this.versionInfo)
                    .then(function (updatedVersion) {
                    _this.versionInfo = updatedVersion;
                    setTimeout(function (_) { return _this.createDiagram(); });
                });
            }
            else {
                _this.createDiagram();
            }
            _this.context.app.hideSpinner();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    WorkflowEditor.prototype.createDiagram = function () {
        var _this = this;
        this.links = [];
        //Si la versión tiene asignado el paso inicial, cargar información, crearlo en caso contario
        if (this.versionInfo.idStartStep > 0) {
            this.start.shape = this.versionInfo.startShape;
            this.start.startStep = this.versionInfo.startStep;
        }
        else {
            this.start.shape.position = { x: 50, y: 50 };
            this.start.shape.size = { width: 100, height: 100 };
        }
        this.start.shape._clientID = this.createShapeID();
        this.start._clientID = this.createElementID();
        //Crear actividades
        this.activities = this.workflow.map(function (s) {
            var activity = new Activity();
            activity.id = s.stepShape._clientID;
            activity._clientID = _this.createElementID();
            activity.tag = s.tag;
            activity.actionText = s.actionText;
            activity.statusText = s.statusText;
            activity.idFormulario = s.idFormulario;
            activity.duracion = s.duracion;
            activity.offline = s.offline;
            activity.shape = s.stepShape;
            activity.isEnd = s.isEnd;
            activity.data = s;
            activity.state = ChangeState.UNCHANGED;
            return activity;
        });
        //Crear bifurcaciones
        this.conditions = this.workflow.filter(function (s) { return s.hasOptions; })
            .map(function (s) {
            var condition = new Condition();
            condition.id = s.optionsShape._clientID;
            condition._clientID = _this.createElementID();
            condition.shape = s.optionsShape;
            condition.data = s;
            condition.state = ChangeState.UNCHANGED;
            condition.options = s.options.map(function (o) {
                var targetActivity = _this.activities.find(function (a) { return a.data.id == o.nextStep.id; });
                var option = _this.createConditionOption(targetActivity, o.tag, o.text);
                return option;
            });
            return condition;
        });
        //Crear los links entre las actividades
        this.workflow.forEach(function (s) {
            if (s.nextStep && s.stepShape && s.stepShape._clientID > 0) {
                var nextStep = _this.workflow.find(function (n) { return n.id == s.nextStep.id; });
                _this.createLink(s.stepShape._clientID, nextStep.stepShape._clientID, '', s.linkVertices);
            }
            if (s.hasOptions && s.optionsShape && s.optionsShape._clientID > 0) {
                //Crear link entre figura de actividad y de bifurcación                                
                _this.createLink(s.stepShape._clientID, s.optionsShape._clientID, '', s.linkVertices);
                //Crear link entre figura de bifurcación y cada una de sus actividades
                s.options.forEach(function (o) {
                    var nextStep = _this.workflow.find(function (n) { return n.id == o.nextStep.id; });
                    _this.createLink(s.optionsShape._clientID, nextStep.stepShape._clientID, o.text, o.linkVertices);
                });
            }
        });
        //Crear link entre figura de inicio y primer elemento
        var startStep = this.workflow.find(function (s) { return s.id == _this.versionInfo.startStep.id; });
        if (startStep) {
            this.createLink(this.start.shape._clientID, startStep.stepShape._clientID);
        }
    };
    WorkflowEditor.prototype.updateNextElement = function (link, previousElement, workflow) {
        var _this = this;
        var element = this.findElementByID(link.targetID);
        var shapeDirective = this.paper.shapes.find(function (s) { return s.id == element.shape._clientID; });
        var connectedLinks = this.paper.getConnectedLinks(shapeDirective, { outbound: true })
            .filter(function (l) { return l.sourceID && l.targetID; });
        if (element.type == WorkflowElement.TYPE_ACTIVITY) {
            var activity_1 = element;
            var nextLink = void 0;
            if (connectedLinks.length > 0) {
                nextLink = connectedLinks[0];
            }
            //Determinar si es una nueva actividad o ya existe en el flujo actual
            var step = workflow.find(function (s) { return s._clientID == element.data._clientID; });
            if (!step) {
                step = element.data;
                workflow.push(step);
            }
            step.state = ChangeState.MODIFIED;
            step.tag = activity_1.tag;
            step.actionText = activity_1.actionText;
            step.statusText = activity_1.statusText;
            step.duracion = activity_1.duracion;
            step.idFormulario = activity_1.idFormulario;
            step.isStart = false;
            step.isEnd = activity_1.isEnd;
            step.offline = activity_1.offline;
            step.stepShape = activity_1.shape;
            step.linkVertices = nextLink ? JSON.stringify(nextLink.vertices) : '[]';
            //Buscar paso asociado al elemento previo (excepto cuando el paso previo es START)
            var previousStep = void 0;
            if (previousElement.type != WorkflowElement.TYPE_START) {
                previousStep = workflow.find(function (s) { return s._clientID == previousElement.data._clientID; });
            }
            //Si el elemento previo era una actividad, actualizar la información de su workflow step            
            if (previousElement.type == WorkflowElement.TYPE_ACTIVITY) {
                previousStep.hasOptions = false;
                previousStep.options = [];
                previousStep.nextStep = step;
            }
            //Si el elemento previo es una bifurcación, actualizar información de la opción correspondiente
            else if (previousElement.type == WorkflowElement.TYPE_CONDITION) {
                //Buscar la opción que conduce a ésta actividad para crear una nueva opción en el workflow step asignado
                var condition = previousElement;
                var option = condition.options.find(function (o) { return o.activity._clientID == activity_1._clientID; });
                var newOption = new WorkflowOption();
                newOption.tag = option.tag;
                newOption.text = option.text;
                newOption.nextStep = step;
                newOption.linkVertices = JSON.stringify(link.vertices);
                previousStep.options.push(newOption);
            }
            else if (previousElement.type == WorkflowElement.TYPE_START) {
                step.isStart = true;
            }
            //Si la actividad está conectada a otro elemento, llamar de forma recursiva a éste método
            if (nextLink) {
                this.updateNextElement(nextLink, element, workflow);
            }
        }
        else if (element.type == WorkflowElement.TYPE_CONDITION) {
            var condition = element;
            var step = void 0;
            //Si no tiene asignado un paso y el paso previo es una actividad, asignar paso de la actividad
            if (previousElement.type == WorkflowElement.TYPE_ACTIVITY) {
                step = workflow.find(function (s) { return s._clientID == previousElement.data._clientID; });
                step.hasOptions = true;
                step.options = [];
                step.optionsShape = condition.shape;
                condition.data = step;
                //LLamar de forma recursiva a éste método por cada link al que se hace referencia
                connectedLinks.forEach(function (l) { return _this.updateNextElement(l, element, workflow); });
            }
        }
    };
    WorkflowEditor.prototype.updateWorkflow = function () {
        var _this = this;
        var updatedWorkflow = this.workflow.slice();
        var startDirective = this.paper.shapes.find(function (s) { return s.data._clientID == _this.start._clientID; });
        var connectedLinks = this.paper.getConnectedLinks(startDirective, { outbound: true })
            .filter(function (l) { return l.sourceID && l.targetID; });
        if (connectedLinks.length > 0) {
            this.updateNextElement(connectedLinks[0], this.start, updatedWorkflow);
        }
        //Encontrar todas las actividades que no no son referenciadas por el flujo principal
        var isolatedActivities = [];
        this.paper.textBlocks.forEach(function (el) {
            //Obtener links de entrada
            var inputLinks = _this.paper.getConnectedLinks(el, { inbound: true });
            //Si no se encontro ningun link de entrada, entonces es una actividad aislada (nadie hace referencia a el)
            if (inputLinks.length == 0) {
                var activity = _this.activities.find(function (a) { return a.shape._clientID == el.id; });
                isolatedActivities.push(activity);
            }
        });
        //Actualizar flujo de las actividades aisladas
        isolatedActivities.forEach(function (actividad) {
            //Las directivas del diagrama tienen el mismo id que el workflow shape de la actividad
            var shapeDirective = _this.paper.textBlocks.find(function (block) { return block.id == actividad.shape._clientID; });
            //Obtener links a la siguiente actividad
            var connectedLinks = _this.paper.getConnectedLinks(shapeDirective, { outbound: true })
                .filter(function (l) { return l.sourceID && l.targetID; });
            if (connectedLinks.length > 0) {
                _this.updateNextElement(connectedLinks[0], actividad, updatedWorkflow);
            }
        });
        //Eliminar las cadenas con mas de dos niveles de profunidad para reducir el tamanio de la informacion a enviar
        updatedWorkflow = JSON.parse(JSON.stringify(updatedWorkflow));
        updatedWorkflow.forEach(function (s) {
            if (s.nextStep && s.nextStep.nextStep) {
                s.nextStep.nextStep = null;
            }
        });
        console.log(updatedWorkflow);
        this.context.app.showSpinner();
        //Guardar workflow y al terminar cargar workflow actualizado
        this.workflowService.saveWorkflow(this.idDocumento, this.version, updatedWorkflow)
            .then(function (_) {
            _this.loadWorkflow(true);
            _this.alertsBar.showAlert('Los cambios han sido guardados con éxito.', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    WorkflowEditor.prototype.findElementByID = function (clientID) {
        var element = this.activities.find(function (a) { return a.shape._clientID == clientID; });
        if (!element) {
            element = this.conditions.find(function (c) { return c.shape._clientID == clientID; });
        }
        return element;
    };
    WorkflowEditor.prototype.findElement = function (shapeID) {
        var shape = this.paper.shapes.find(function (s) { return s.shape.id == shapeID; });
        if (shape) {
            return shape.data;
        }
        else {
            return null;
        }
    };
    WorkflowEditor.prototype.findLink = function (linkID) {
        var linkDirective = this.paper.links.find(function (l) { return l.shape.id == linkID; });
        if (linkDirective) {
            return linkDirective.data;
        }
        else {
            return null;
        }
    };
    WorkflowEditor.prototype.setCurrentElement = function (cell) {
        if (cell) {
            this.currentElement = this.findElement(cell.model.id);
            if (this.currentElement.type != WorkflowElement.TYPE_START) {
                if (this.currentCell) {
                    this.currentCell.unhighlight();
                    this.currentCell = null;
                }
                cell.highlight();
                this.currentCell = cell;
                this.currentBox = cell.getBBox();
                this.currentBox.width -= 3;
                this.currentBox.height -= 3;
                this.currentBox.height = Math.round(this.currentBox.height);
                this.lastPosition = this.currentElement.shape.position;
            }
        }
        else {
            if (this.currentCell) {
                this.currentCell.unhighlight();
                this.currentCell = null;
                this.currentBox = null;
                this.currentElement = null;
            }
        }
    };
    WorkflowEditor.prototype.createShapesMenu = function () {
        var mnuActividad = { icon: "fa fa-square-o", text: "Actividad", name: "ACTIVITY", smallText: "paso del flujo" };
        var mnuDecision = { icon: "glyphicon glyphicon-random", text: "Decisión", name: "CONDITION", smallText: "bifurcación del flujo" };
        var mnuLink = { icon: "fa fa-link", text: "Conector", name: "LINK", smallText: "conector de actividades" };
        this.shapesMenu.push(mnuActividad, mnuDecision, mnuLink);
        //Marcar como habilitadas todas las opciones
        this.shapesMenu.forEach(function (item) {
            if (item.enabled == undefined)
                item.enabled = true;
        });
    };
    WorkflowEditor.prototype.createElementID = function () {
        this.lastElementID += 1;
        return this.lastElementID;
    };
    WorkflowEditor.prototype.createStepID = function () {
        var lastStepID = 0;
        this.workflow.forEach(function (step) {
            if (step._clientID > lastStepID) {
                lastStepID = step._clientID;
            }
        });
        return lastStepID + 1;
    };
    WorkflowEditor.prototype.createShapeID = function () {
        var lastShapeID = this.start.shape._clientID;
        this.workflow.forEach(function (s) {
            if (s.stepShape._clientID > lastShapeID)
                lastShapeID = s.stepShape._clientID;
            if (s.optionsShape && s.optionsShape._clientID > lastShapeID)
                lastShapeID = s.stepShape._clientID;
        });
        return lastShapeID + 1;
    };
    WorkflowEditor.prototype.getNewElementPosition = function () {
        if (this.currentElement) {
            return {
                x: this.currentElement.shape.position.x + 20, y: this.currentElement.shape.position.y + 20
            };
        }
        else if (this.lastPosition) {
            return {
                x: this.lastPosition.x + 20, y: this.lastPosition.y + 20
            };
        }
        else {
            return { x: 50, y: 50 };
        }
    };
    WorkflowEditor.prototype.crearActividad = function () {
        var newActivity = new Activity();
        newActivity._clientID = this.createElementID();
        newActivity.tag = 'STEP' + newActivity._clientID.toString();
        newActivity.actionText = 'Nuevo paso';
        newActivity.shape.size = { width: 250, height: 65 };
        newActivity.shape.position = this.getNewElementPosition();
        //Crear paso para la actividad
        var step = new WorkflowStep();
        step._clientID = this.createStepID();
        step.idWorkflowStep = step._clientID;
        newActivity.data = step;
        //        
        newActivity.shape._clientID = this.createShapeID();
        this.activities.push(newActivity);
    };
    WorkflowEditor.prototype.crearCondicion = function () {
        var newCondition = new Condition();
        newCondition.shape.size = { width: 100, height: 100 };
        newCondition.shape.position = this.getNewElementPosition();
        //
        newCondition._clientID = this.createElementID();
        newCondition.shape._clientID = this.createShapeID();
        this.conditions.push(newCondition);
    };
    WorkflowEditor.prototype.createNewLink = function () {
        this.lastLinkID += 1;
        var pos = this.getNewElementPosition();
        var link = { id: this.lastLinkID, sourceX: pos.x + 10, sourceY: pos.y + 10, targetX: pos.x + 100, targetY: pos.y + 100 };
        this.links.push(link);
    };
    WorkflowEditor.prototype.createLink = function (source, target, label, vertices) {
        this.lastLinkID += 1;
        var vertPoints = [];
        if (vertices && vertices != '') {
            vertPoints = JSON.parse(vertices);
        }
        var link = { id: this.lastLinkID, sourceID: source, targetID: target, label: label, vertices: vertPoints };
        this.links.push(link);
        return link;
    };
    WorkflowEditor.prototype.trackShape = function (index, item) {
        return item.id;
    };
    WorkflowEditor.prototype.isOptionsShape = function (shapeID) {
        var shape = this.paper.rhombus.find(function (r) { return r.shape.id == shapeID; });
        return shape ? true : false;
    };
    WorkflowEditor.prototype.removeConditionOption = function (condition, activityID) {
        //Encontrar opción representada por el link que se borró
        var option = condition.options.find(function (o) { return (o.activity._clientID == activityID); });
        if (option) {
            option.state = ChangeState.DELETED;
        }
    };
    WorkflowEditor.prototype.createConditionOption = function (targetActivity, tag, text) {
        this.lastConditionID += 1;
        var newOption = new ConditionOption();
        newOption._clientID = this.lastConditionID;
        newOption.tag = tag ? tag : 'TAG_' + this.lastConditionID.toString();
        newOption.text = text ? text : 'Opción ' + this.lastConditionID.toString();
        newOption.activity = targetActivity;
        return newOption;
    };
    WorkflowEditor.prototype.setElementSize = function (width, height) {
        this.currentElement.shape.size = { width: width, height: height };
    };
    //////////////////////////// HANDLERS ///////////////////////////////////////////////////
    WorkflowEditor.prototype.onCellClick = function (args) {
        if (args.cellView.model.isElement()) {
            this.setCurrentElement(args.cellView);
        }
    };
    WorkflowEditor.prototype.onCellDblClick = function (args) {
        if (args.cellView.model.isElement()) {
            this.setCurrentElement(args.cellView);
            if (this.currentElement.type == WorkflowElement.TYPE_ACTIVITY) {
                this.onEditActivity();
            }
            else if (this.currentElement.type == WorkflowElement.TYPE_CONDITION) {
                this.onEditOptions();
            }
        }
    };
    WorkflowEditor.prototype.onBlankClick = function (args) {
        this.setCurrentElement(null);
    };
    WorkflowEditor.prototype.onLinkConnect = function (args) {
        var sourceElement = args.current.source.data;
        var targetElement = args.current.target.data;
        var optionsElement;
        //Si el origen de la conexión es una bifurcación, agregar al colección de opciones
        if (sourceElement.type == WorkflowElement.TYPE_CONDITION) {
            optionsElement = sourceElement;
            var newCondition = this.createConditionOption(targetElement);
            optionsElement.options.push(newCondition);
        }
    };
    WorkflowEditor.prototype.onLinkDisconnect = function (args) {
        if (args.previous.source && args.previous.target) {
            var sourceElement = args.previous.source.data;
            var targetElement = args.previous.target.data;
            var condition = void 0;
            //Determinar si uno de los extremos es una bifurcación
            if (sourceElement.type == WorkflowElement.TYPE_CONDITION) {
                condition = sourceElement;
                this.removeConditionOption(condition, targetElement._clientID);
            }
            else if (targetElement.type == WorkflowElement.TYPE_CONDITION) {
                condition = targetElement;
                this.removeConditionOption(condition, sourceElement._clientID);
            }
        }
    };
    WorkflowEditor.prototype.onLinkDeleted = function (link) {
        var index = this.links.findIndex(function (l) { return l.id == link.id; });
        if (index >= 0) {
            this.links.splice(index, 1);
        }
    };
    WorkflowEditor.prototype.shapeMoved = function (pos, element) {
        if (element.type == WorkflowElement.TYPE_CONDITION) {
            var rhombusDirective = this.paper.rhombus.find(function (s) { return s.data == element; });
        }
        else {
            var textBlock = this.paper.textBlocks.find(function (s) { return s.data == element; });
        }
        element.shape.position = pos;
        this.lastPosition = pos;
        this.paper.fitToContent();
    };
    WorkflowEditor.prototype.changeSize = function () {
        if (this.currentCell) {
            var width = this.inputWidth.value;
            var height = this.inputHeight.value;
            this.setElementSize(width, height);
        }
    };
    WorkflowEditor.prototype.onMainToolBar = function (button) {
        if (button.name == 'SAVE') {
            this.updateWorkflow();
        }
        else if (button.name == 'DELETE') {
            if (this.currentElement && this.currentElement.type != WorkflowElement.TYPE_START) {
                this.deleteDialog.config.backdrop = false;
                this.deleteDialog.show();
            }
        }
        else if (button.name == 'CLOSE') {
            this.location.back();
        }
    };
    WorkflowEditor.prototype.onShapesMenu = function (option) {
        if (option.name == 'ACTIVITY') {
            this.crearActividad();
        }
        else if (option.name == 'CONDITION') {
            this.crearCondicion();
        }
        else if (option.name == 'LINK') {
            this.createNewLink();
        }
    };
    WorkflowEditor.prototype.onEditActivity = function () {
        this.activityEditor.show();
    };
    WorkflowEditor.prototype.onEditOptions = function () {
        this.conditionsEditor.show();
    };
    WorkflowEditor.prototype.onActivityUpdated = function (activity) {
        this.currentElement = activity;
        //Buscar dentro de array y reemplazar
        var index = this.activities.findIndex(function (a) { return a._clientID == activity._clientID; });
        this.activities[index] = activity;
    };
    WorkflowEditor.prototype.onConditionUpdate = function (condition) {
        var _this = this;
        this.currentElement = condition;
        //Buscar dentro de array de condiciones y reemplazar
        var index = this.conditions.findIndex(function (c) { return c._clientID == condition._clientID; });
        this.conditions[index] = condition;
        //Actualizar información de los links        
        var shapeDirective = this.paper.shapes.find(function (s) { return s.id == condition.shape._clientID; });
        var connectedLinks = this.paper.getConnectedLinks(shapeDirective, { outbound: true });
        connectedLinks.forEach(function (ld) {
            var link = _this.links.find(function (l) { return l.id == ld.id; });
            var option = condition.options.find(function (o) { return o.activity.shape._clientID == ld.targetID; });
            if (link) {
                link.label = option.text;
            }
        });
    };
    WorkflowEditor.prototype.onConfirmDelete = function () {
        var _this = this;
        //Si se trata de una actividad y ya se encontraba en la base de datos, buscar paso y marcar para borrar en la próxima actualización
        if (this.currentElement.type == WorkflowElement.TYPE_ACTIVITY) {
            if (this.currentElement.id > 0) {
                var step = this.workflow.find(function (s) { return s.id == _this.currentElement.data.id; });
                if (step != null) {
                    step.state = ChangeState.DELETED;
                }
            }
            var activityIndex = this.activities.findIndex(function (a) { return a._clientID == _this.currentElement._clientID; });
            this.activities.splice(activityIndex, 1);
        }
        else {
            var conditionIndex = this.conditions.findIndex(function (c) { return c._clientID == _this.currentElement._clientID; });
            this.conditions.splice(conditionIndex, 1);
        }
        this.deleteDialog.hide();
    };
    WorkflowEditor.prototype.handleError = function (error) {
        console.log(error);
        var message = this.context.getExceptionMessage(error);
        this.alertsBar.showAlert(message, 'danger');
        this.context.app.hideSpinner();
    };
    __decorate([
        ViewChild(PaperComponent),
        __metadata("design:type", PaperComponent)
    ], WorkflowEditor.prototype, "paper", void 0);
    __decorate([
        ViewChild('inputWidth'),
        __metadata("design:type", AzInputNumber)
    ], WorkflowEditor.prototype, "inputWidth", void 0);
    __decorate([
        ViewChild('inputHeight'),
        __metadata("design:type", AzInputNumber)
    ], WorkflowEditor.prototype, "inputHeight", void 0);
    __decorate([
        ViewChild('deleteDialog'),
        __metadata("design:type", ModalDirective)
    ], WorkflowEditor.prototype, "deleteDialog", void 0);
    __decorate([
        ViewChild(ActivityEditor),
        __metadata("design:type", ActivityEditor)
    ], WorkflowEditor.prototype, "activityEditor", void 0);
    __decorate([
        ViewChild(ConditionsEditor),
        __metadata("design:type", ConditionsEditor)
    ], WorkflowEditor.prototype, "conditionsEditor", void 0);
    __decorate([
        ViewChild(AlertsBarComponent),
        __metadata("design:type", AlertsBarComponent)
    ], WorkflowEditor.prototype, "alertsBar", void 0);
    WorkflowEditor = __decorate([
        Component({
            selector: 'bpm-workflow-editor',
            template: "\n      <az-panel [header]=\"'Editor de flujo de trabajo'\">\n          <alerts-bar></alerts-bar>\n          <!--Toolbar principal-->\n          <div class=\"row\">\n              <div class=\"col-12\">\n                  <az-toolbar (buttonClick)=\"onMainToolBar($event)\" (menuItemClick)=\"onShapesMenu($event)\">\n                      <az-toolbar-button [name]=\"'SAVE'\" [type]=\"'primary'\" [text]=\"'Guardar'\" [title]=\"'Guardar cambios'\" [icon]=\"'glyphicon glyphicon-floppy-disk'\"></az-toolbar-button>\n                      <az-toolbar-button *ngIf=\"currentCell\" [name]=\"'DELETE'\" [text]=\"'Eliminar'\" [icon]=\"'glyphicon glyphicon-trash'\"></az-toolbar-button>\n                      <az-toolbar-button [name]=\"'CLOSE'\" [text]=\"'Cerrar'\" [icon]=\"'glyphicon glyphicon-remove'\"></az-toolbar-button>\n                      <az-toolbar-menu [name]=\"'SHAPES'\" [header]=\"'Agregar'\" [menuItems]=\"shapesMenu\"></az-toolbar-menu>\n                  </az-toolbar>\n              </div>\n          </div>\n\n          <div class=\"row\">\n\n              <div class=\"col-12 col-lg-9\" style=\"overflow:auto;height: 100%\">\n                  <joint-paper [gridSize]=\"10\"\n                               (cellClick)=\"onCellClick($event)\"\n                               (cellDblClick)=\"onCellDblClick($event)\"\n                               (linkConnect)=\"onLinkConnect($event)\"\n                               (linkDisconnect)=\"onLinkDisconnect($event)\"\n                               (linkDeleted)=\"onLinkDeleted($event)\"\n                               (blankClick)=\"onBlankClick($event)\">\n\n                      <joint-circle   [id]=\"start.shape._clientID\"\n                                      [text]=\"start.text\"\n                                      [width]=\"start.shape.size.width\"\n                                      [height]=\"start.shape.size.height\"\n                                      [x]=\"start.shape.position.x\"\n                                      [y]=\"start.shape.position.y\"\n                                      [data]=\"start\"\n                                      (positionChange)=\"shapeMoved($event, start)\">\n                      </joint-circle>\n\n                      <joint-text-block *ngFor=\"let activity of activities; trackBy: trackShape\"\n                                        [id]=\"activity.shape._clientID\"\n                                        [text]=\"activity.actionText\"\n                                        [width]=\"activity.shape.size.width\"\n                                        [height]=\"activity.shape.size.height\"\n                                        [x]=\"activity.shape.position.x\"\n                                        [y]=\"activity.shape.position.y\"\n                                        [data]=\"activity\"\n                                        (positionChange)=\"shapeMoved($event, activity)\">\n\n                      </joint-text-block>\n\n                      <joint-rhombus *ngFor=\"let condition of conditions; trackBy: trackShape\"\n                                     [id]=\"condition.shape._clientID\"\n                                     [text]=\"\"\n                                     [width]=\"100\"\n                                     [height]=\"100\"\n                                     [x]=\"condition.shape.position.x\"\n                                     [y]=\"condition.shape.position.y\"\n                                     [data]=\"condition\"\n                                     (positionChange)=\"shapeMoved($event, condition)\">\n\n                      </joint-rhombus>\n\n                      <joint-link *ngFor=\"let link of links\"\n                                  [id]=\"link.id\"\n                                  [sourceID]=\"link.sourceID\"\n                                  [targetID]=\"link.targetID\"\n                                  [sourceX]=\"link.sourceX\"\n                                  [sourceY]=\"link.sourceY\"\n                                  [targetX]=\"link.targetX\"\n                                  [targetY]=\"link.targetY\"\n                                  [label]=\"link.label\"\n                                  [vertices]=\"link.vertices\"\n                                  [data]=\"link\">\n\n                      </joint-link>\n\n                  </joint-paper>\n              </div>\n              <div class=\"col-12 col-lg-3\">\n                  <az-panel [header]=\"'Propiedades'\">\n                      <!--ANCHO-->\n                      <label class=\"form-control-label\">Ancho:</label>\n                      <az-input-number #inputWidth [value]=\"currentBox ? currentBox.width : 0\" (valueChange)=\"changeSize()\"></az-input-number>\n                      <!--ALTO-->\n                      <label class=\"form-control-label\">Alto:</label>\n                      <az-input-number #inputHeight [value]=\"currentBox ? currentBox.height : 0\" (valueChange)=\"changeSize()\"></az-input-number>\n                      <br />\n                      <button *ngIf=\"currentElement && currentElement.type == 'A'\" class=\"btn btn-default\" (click)=\"onEditActivity()\">\n                          <span class=\"glyphicon glyphicon-edit\"></span> Editar actividad\n                      </button>\n                      <button *ngIf=\"currentElement && currentElement.type == 'C'\" class=\"btn btn-default\" (click)=\"onEditOptions()\">\n                          <span class=\"glyphicon glyphicon-edit\"></span> Editar opciones\n                      </button>\n                  </az-panel>\n              </div>\n          </div>\n\n      </az-panel>\n\n      <bpm-activity-editor \n                          [activity]=\"currentElement\" \n                          [idDocumento]=\"idDocumento\" \n                          [version]=\"version\"\n                          (activityUpdated)=\"onActivityUpdated($event)\">\n\n      </bpm-activity-editor>\n\n      <bpm-conditions-editor \n                              [condition]=\"currentElement\"\n                              [idDocumento]=\"idDocumento\" \n                              [version]=\"version\"\n                              (conditionUpdated)=\"onConditionUpdate($event)\">\n\n      </bpm-conditions-editor>\n\n\n      <div bsModal #deleteDialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"mySmallModalLabel\" aria-hidden=\"true\">\n          <div class=\"modal-dialog modal-sm\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-body\">\n                      <h4>\u00BFEst\u00E1 seguro que desea eliminar el elemento seleccionado?</h4>\n                  </div> <!--Modal Body-->\n                  <div class=\"modal-footer\">\n                      <button type=\"button\" class=\"btn btn-danger\" (click)=\"onConfirmDelete()\">Aceptar</button>\n                      <button type=\"button\" class=\"btn btn-primary\" (click)=\"deleteDialog.hide()\">Cancelar</button>\n                  </div> <!--Modal Footer-->\n\n              </div> <!-- Modal Content-->\n          </div> <!--Modal-->\n      </div> <!--Modal directive-->\n    "
        }),
        __metadata("design:paramtypes", [Context, Router, ActivatedRoute, Location,
            WorkflowService, DocumentoService])
    ], WorkflowEditor);
    return WorkflowEditor;
}());
export { WorkflowEditor };
