var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, Input, Output, EventEmitter } from '@angular/core';
//
import { Subject } from 'rxjs';
import { startOfDay, endOfDay, startOfWeek, endOfWeek, startOfMonth, endOfMonth, isSameDay, isSameMonth } from 'date-fns';
import { CalendarDateFormatter } from 'angular-calendar';
import { ScheduleDayEventArgs } from '../models/schedule-day-event-args';
import { ScheduleHourEventArgs } from '../models/schedule-hour-event-args';
import { Period } from '../models/period';
import { CustomDateFormatter } from '../services/custom-date-formatter.service';
var ScheduleComponent = /** @class */ (function () {
    function ScheduleComponent() {
        this.view = 'month';
        this.viewDate = new Date();
        this.activeDayIsOpen = true;
        this.refresh = new Subject();
        this.locale = 'es';
        //
        this.events = [];
        this.viewMonthVisible = true;
        this.viewWeekVisible = true;
        this.viewDayVisible = true;
        //
        this.activeDayOpened = new EventEmitter();
        this.dayClicked = new EventEmitter();
        this.dayHeaderClicked = new EventEmitter();
        this.hourSegmentClicked = new EventEmitter();
        this.eventClicked = new EventEmitter();
        this.periodChanged = new EventEmitter();
        this.headerConfig = {
            left: 'prev,next today',
            center: 'title',
            right: 'month,agendaWeek,agendaDay'
        };
    }
    ScheduleComponent.prototype.getStartOfPeriod = function () {
        var start = new Date();
        if (this.view == 'day')
            start = startOfDay(this.viewDate);
        else if (this.view == 'week')
            start = startOfWeek(this.viewDate);
        else if (this.view == 'month')
            start = startOfMonth(this.viewDate);
        return start;
    };
    ScheduleComponent.prototype.getEndOfPeriod = function () {
        var end = new Date();
        if (this.view == 'day')
            end = endOfDay(this.viewDate);
        else if (this.view == 'week')
            end = endOfWeek(this.viewDate);
        else if (this.view == 'month')
            end = endOfMonth(this.viewDate);
        return end;
    };
    ScheduleComponent.prototype.getPeriod = function () {
        var period = new Period();
        period.start = this.getStartOfPeriod();
        period.end = this.getEndOfPeriod();
        return period;
    };
    ScheduleComponent.prototype.onDayClicked = function (_a) {
        var date = _a.date, events = _a.events;
        if (isSameMonth(date, this.viewDate)) {
            if ((isSameDay(this.viewDate, date) && this.activeDayIsOpen) || events.length === 0) {
                this.activeDayIsOpen = false;
            }
            else {
                this.activeDayIsOpen = true;
                this.viewDate = date;
                this.activeDayOpened.emit();
            }
        }
        var args = new ScheduleDayEventArgs();
        args.date = date;
        args.events = events;
        this.dayClicked.emit(args);
    };
    ScheduleComponent.prototype.onDayHeaderClicked = function (day) {
        this.dayHeaderClicked.emit(day);
    };
    ScheduleComponent.prototype.onHourSegmentClicked = function (date) {
        var args = new ScheduleHourEventArgs();
        args.date = date;
        this.hourSegmentClicked.emit(args);
    };
    ScheduleComponent.prototype.eventTimesChanged = function (_a) {
        var event = _a.event, newStart = _a.newStart, newEnd = _a.newEnd;
        event.start = newStart;
        event.end = newEnd;
        this.refresh.next();
    };
    ScheduleComponent.prototype.onViewChanged = function (view) {
        this.view = view;
        var period = this.getPeriod();
        this.periodChanged.emit(period);
    };
    ScheduleComponent.prototype.onViewDateChanged = function () {
        this.activeDayIsOpen = false;
        var period = this.getPeriod();
        this.periodChanged.emit(period);
    };
    ScheduleComponent.prototype.handleEvent = function (event) {
        this.eventClicked.emit(event);
    };
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], ScheduleComponent.prototype, "events", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], ScheduleComponent.prototype, "viewMonthVisible", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], ScheduleComponent.prototype, "viewWeekVisible", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], ScheduleComponent.prototype, "viewDayVisible", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], ScheduleComponent.prototype, "activeDayOpened", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], ScheduleComponent.prototype, "dayClicked", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], ScheduleComponent.prototype, "dayHeaderClicked", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], ScheduleComponent.prototype, "hourSegmentClicked", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], ScheduleComponent.prototype, "eventClicked", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], ScheduleComponent.prototype, "periodChanged", void 0);
    ScheduleComponent = __decorate([
        Component({
            selector: 'azteca-schedule',
            template: "\n      <div class=\"row-text-center\">\n          <!--CONTROLES DE ANTERIOR, SIGUIENTE Y HOY-->\n          <div class=\"col-md-4\">\n              <div class=\"btn-group\">\n                  <div class=\"btn btn-primary\" mwlCalendarPreviousView [view]=\"view\" [(viewDate)]=\"viewDate\" (viewDateChange)=\"onViewDateChanged()\">\n                      Anterior\n                  </div>\n                  <div class=\"btn btn-outline-secondary\" mwlCalendarToday  [(viewDate)]=\"viewDate\" (viewDateChange)=\"onViewDateChanged()\">\n                      Hoy\n                  </div>\n                  <div class=\"btn btn-primary\" mwlCalendarNextView [view]=\"view\" [(viewDate)]=\"viewDate\" (viewDateChange)=\"onViewDateChanged()\">\n                      Siguiente\n                  </div>\n              </div>\n          </div>\n\n          <!--INDICADOR DE MES, SEMANA O DIA ACTUAL-->\n          <div class=\"col-md-4\">\n              <h3>{{ viewDate | calendarDate:(view + 'ViewTitle'):'es' }}</h3>\n          </div>\n\n          <!-- CONTROL DE VISTA -->\n          <div class=\"col-md-4\">\n              <div class=\"btn-group\">\n                  <div class=\"btn btn-primary\" (click)=\"onViewChanged('month')\" [class.active]=\"view === 'month'\" *ngIf=\"viewMonthVisible\">\n                      Mes\n                  </div>\n                  <div class=\"btn btn-primary\" (click)=\"onViewChanged('week')\" [class.active]=\"view === 'week'\" *ngIf=\"viewWeekVisible\">\n                      Semana\n                  </div>\n                  <div class=\"btn btn-primary\" (click)=\"onViewChanged('day')\" [class.active]=\"view === 'day'\" *ngIf=\"viewDayVisible\">\n                      D\u00EDa\n                  </div>\n              </div>\n          </div>\n\n      </div>\n\n      <br>\n      <!-- VISTAS DE MES, SEMANA Y DIA -->\n      <div [ngSwitch]=\"view\">\n          <mwl-calendar-month-view *ngSwitchCase=\"'month'\"\n                                   [viewDate]=\"viewDate\"\n                                   [events]=\"events\"\n                                   [refresh]=\"refresh\"\n                                   [locale]=\"locale\"\n                                   [activeDayIsOpen]=\"activeDayIsOpen\"\n                                   (dayClicked)=\"onDayClicked($event.day)\"\n                                   (eventClicked)=\"handleEvent($event.event)\"\n                                   (eventTimesChanged)=\"eventTimesChanged($event)\">\n          </mwl-calendar-month-view>\n          <mwl-calendar-week-view *ngSwitchCase=\"'week'\"\n                                  [viewDate]=\"viewDate\"\n                                  [events]=\"events\"\n                                  [refresh]=\"refresh\"\n                                  [locale]=\"locale\"\n                                  (dayHeaderClicked)=\"onDayHeaderClicked($event.day)\"\n                                  (eventClicked)=\"handleEvent($event.event)\"\n                                  (eventTimesChanged)=\"eventTimesChanged($event)\">\n          </mwl-calendar-week-view>\n          <mwl-calendar-day-view *ngSwitchCase=\"'day'\"\n                                 [viewDate]=\"viewDate\"\n                                 [events]=\"events\"\n                                 [refresh]=\"refresh\"\n                                 [locale]=\"locale\"\n                                 (hourSegmentClicked)=\"onHourSegmentClicked($event.date)\"\n                                 (eventClicked)=\"handleEvent($event.event)\"\n                                 (eventTimesChanged)=\"eventTimesChanged($event)\">\n          </mwl-calendar-day-view>\n      </div>\n    ",
            providers: [
                {
                    provide: CalendarDateFormatter,
                    useClass: CustomDateFormatter
                }
            ],
            styles: ["\n        h3 {\n          margin: 0 0 10px;\n        }\n\n        pre {\n          background-color: #f5f5f5;\n          padding: 15px;\n        }\n"]
        }),
        __metadata("design:paramtypes", [])
    ], ScheduleComponent);
    return ScheduleComponent;
}());
export { ScheduleComponent };
