var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Injectable } from '@angular/core';
import { HttpClient, HttpParams } from '@angular/common/http';
import 'rxjs/add/operator/toPromise';
//
import { Context } from './context';
//
import { BaseService } from './base-service';
/**
 * Clase base para servicios básicos de un catálogo
 */
var CatalogService = /** @class */ (function (_super) {
    __extends(CatalogService, _super);
    function CatalogService(http, context, serviceUrl) {
        var _this = _super.call(this, http, context, serviceUrl) || this;
        _this.http = http;
        _this.context = context;
        _this.serviceUrl = serviceUrl;
        _this.options = null;
        _this.classifiers = null;
        return _this;
    }
    /**
     * Carga las opciones de configuración del catálogo
     */
    CatalogService.prototype.getOptions = function () {
        if (this.options == null) {
            var params = new HttpParams()
                .set('idEmpresa', this.context.app.defaultCompany.identity.toString());
            //
            return this.apiService.get('get-options', params)
                .toPromise();
        }
        else {
            return Promise.resolve(this.options);
        }
    };
    /**
     * Envía la información al servidor
     * @param info Paquete de información que se enviará al servidor
     */
    CatalogService.prototype.update = function (info) {
        //Si no tiene asignado la empresa y sucursal, asignar la actual
        if (info.idBranch == 0)
            info.idBranch = this.context.app.defaultSite.identity;
        if (info.idCompany == 0)
            info.idCompany = this.context.app.defaultCompany.identity;
        //
        var params = new HttpParams();
        return this.apiService.post('update', params, info)
            .toPromise();
    };
    /**
     * Carga la información del ID especificado
     * @param itemID ID del elemento a cargar
     */
    CatalogService.prototype.getDetailByID = function (itemID) {
        var params = new HttpParams()
            .set('itemID', itemID.toString());
        //
        return this.apiService.get('get-detail-id', params)
            .toPromise();
    };
    /**
     * Carga la información del elemento especificado a través de su código de usuario
     * @param idBranch En caso del que el código no sea único, se buscará en la sucursal especificada
     * @param code Codigo del elemento
     */
    CatalogService.prototype.getDetailByCode = function (idBranch, code) {
        var params = new HttpParams()
            .set('idBranch', idBranch.toString())
            .set('code', code);
        //
        return this.apiService.get('get-detail-code', params)
            .toPromise();
    };
    /**
     * Carga la información del elemento con ID, pero primero lo buscará en la caché del servidor
     * @param itemID ID del elemento a cargar
     */
    CatalogService.prototype.getDetailFromCache = function (itemID) {
        var params = new HttpParams()
            .set('itemID', itemID.toString());
        //
        return this.apiService.get('get-detail-cache', params)
            .toPromise();
    };
    /**
     * Crea una copia del elemento con el ID especificado
     * @param itemID ID del elemento a clonar
     */
    CatalogService.prototype.clone = function (itemID) {
        var params = new HttpParams()
            .set('originalID', itemID.toString());
        //
        return this.apiService.get('clone', params)
            .toPromise();
    };
    /**
     * Crea una copia del objecto especificado
     * @param info Objeto a clonar
     */
    CatalogService.prototype.copy = function (info) {
        return JSON.parse(JSON.stringify(info));
    };
    /**
     * Elimina el elemento con el ID especificado
     * @param itemID ID del elemento a eliminar
     */
    CatalogService.prototype.delete = function (itemID) {
        var params = new HttpParams()
            .set('itemID', itemID.toString());
        //
        return this.apiService.delete('delete', params)
            .toPromise();
    };
    /**
     * Verifica si existe un elemento con el ID especificado
     * @param itemID ID del elemento a verificar
     */
    CatalogService.prototype.exists = function (itemID) {
        var params = new HttpParams()
            .set('itemID', itemID.toString());
        //
        return this.apiService.delete('exists', params)
            .toPromise();
    };
    /**
     * Ejecuta el proceso de exportación a otros sistemas o formatos
     * @param itemID
     */
    CatalogService.prototype.export = function (itemID) {
        var params = new HttpParams()
            .set('itemID', itemID.toString());
        //
        return this.apiService.get('export', params)
            .toPromise();
    };
    /**
     * Cambia el estado del elemento con el ID especificado
     * @param itemID ID del elemento a cambiar
     * @param active Nuevo estatus
     */
    CatalogService.prototype.changeStatus = function (itemID, active) {
        var params = new HttpParams()
            .set('itemID', itemID.toString())
            .set('active', active ? 'true' : 'false');
        //
        return this.apiService.post('change-status', params, '')
            .toPromise();
    };
    /**
     * Obtiene los registros que cambiaron desde la fecha especificada
     * @param lastUpdate Fecha desde la cual se obtendrán los registros modificados
     */
    CatalogService.prototype.sync = function (lastUpdate) {
        return Promise.resolve(null);
    };
    /**
     * Realiza una búsqueda de los registros que cumplen con ciertas condiciones
     * @param idBranch ID de la sucursal donde se realizará la busqueda, algunos catálogos ignoran éste parámetro
     * @param request Condiciones de la búsqueda, orden de los resultados y parámetros de paginación
     */
    CatalogService.prototype.search = function (idBranch, request) {
        var params = new HttpParams()
            .set('idBranch', idBranch.toString());
        //
        return this.apiService.post('search', params, request)
            .toPromise();
    };
    /**
     * Realiza la búsqueda de los elementos que coinciden con una palabra clave
     * @param idBranch Sucursal dóndde se acotará la búsqueda. Algunos catálogos ingnoran éste parámetro
     * @param keryword Palabra clave que se buscará
     */
    CatalogService.prototype.searchKeyword = function (idBranch, keyword) {
        var params = new HttpParams()
            .set('idBranch', idBranch.toString())
            .set('keyword', keyword);
        //
        return this.apiService.get('search-keyword', params);
    };
    /**
     * Carga los clasificadores de los grupos de clasificación asignados a la entidad
     * @param idBranch Se filtrarán sólo los clasificadores registrados en la empresa a la que pertenece la sucursal especificada
     */
    CatalogService.prototype.loadClassifiers = function (idBranch) {
        if (this.classifiers != null) {
            return Promise.resolve(this.classifiers);
        }
        else {
            var params = new HttpParams()
                .set('idBranch', idBranch.toString());
            //
            return this.apiService.get('classifiers', params)
                .toPromise();
        }
    };
    CatalogService.prototype.applyAction = function (itemID, action, data) {
        var params = new HttpParams()
            .set('itemID', itemID.toString())
            .set('actionName', action);
        //
        return this.apiService.post('apply-action', params, data)
            .toPromise();
    };
    CatalogService.prototype.handleError = function (error) {
        console.error('An error occurred', error);
        return Promise.reject(error.message || error);
    };
    CatalogService = __decorate([
        Injectable(),
        __metadata("design:paramtypes", [HttpClient, Context, String])
    ], CatalogService);
    return CatalogService;
}(BaseService));
export { CatalogService };
