import { HttpClient } from '@angular/common/http';
import 'rxjs/add/operator/toPromise';
import { SearchResult, SearchRequest } from '../../search';
import { BaseService } from './base-service';
import { Context } from './context';
import { DocumentInfo } from '../models/document';
import { DocumentTypeInfo } from '../models/document-type';
import { DocumentDetail } from '../models/document-detail';
/**
*Interface para servicios de documentos
**/
export interface IDocumentService<TDetail extends DocumentDetail, TDocument extends DocumentInfo<TDetail>> {
    getDocumentType(): Promise<DocumentTypeInfo>;
    create(): Promise<TDocument>;
    update(info: TDocument): Promise<TDocument>;
    clone(documentID: string): Promise<TDocument>;
    delete(documentID: string): Promise<any>;
    exists(documentID: string): Promise<boolean>;
    export(documentID: string): Promise<any>;
    getDetail(documentID: string): Promise<TDocument>;
    nextStep(documentID: string, idWorkflowStep: number, data: any): Promise<any>;
    previousStep(documentID: string, data: any): Promise<any>;
    search(idBranch: number, request: SearchRequest): Promise<SearchResult>;
}
/**
 * Clase base para servicios de documentos
 */
export declare abstract class DocumentService<TDetail extends DocumentDetail, TDocument extends DocumentInfo<TDetail>> extends BaseService implements IDocumentService<TDetail, TDocument> {
    protected http: HttpClient;
    protected context: Context;
    protected serviceUrl: string;
    documentType: DocumentTypeInfo;
    abstract create(): Promise<TDocument>;
    constructor(http: HttpClient, context: Context, serviceUrl: string);
    getDocumentType(): Promise<DocumentTypeInfo>;
    update(info: TDocument): Promise<TDocument>;
    clone(originalID: string): Promise<TDocument>;
    getDetail(documentID: string): Promise<TDocument>;
    delete(documentID: string): Promise<any>;
    exists(documentID: string): Promise<boolean>;
    export(documentID: string): Promise<any>;
    search(idSucursal: number, request: SearchRequest): Promise<SearchResult>;
    nextStep(documentID: string, idWorkflowStep: number, data: any): Promise<any>;
    previousStep(documentID: string, data: any): Promise<any>;
    /**
     * Sobreescribir en clases derviadas para realizar conversiones en los campos del resultado de la búsqueda (ej. los campos de fecha que vienen como texto del server)
     * @param row
     */
    protected mapSearchResult(row: any): void;
    /**
     * Sobreescribir en clases derviadas para realizar conversiones en los campos del documento (ej. los campos de fecha que vienen como texto del server)
     * @param document
     */
    protected mapDocument(document: TDocument): void;
}
