var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Injectable } from '@angular/core';
import { HttpClient, HttpParams } from '@angular/common/http';
import { map } from 'rxjs/operators';
import 'rxjs/add/operator/toPromise';
import * as moment from 'moment';
import { BaseService } from './base-service';
import { Context } from './context';
/**
 * Clase base para servicios de documentos
 */
var DocumentService = /** @class */ (function (_super) {
    __extends(DocumentService, _super);
    function DocumentService(http, context, serviceUrl) {
        var _this = _super.call(this, http, context, serviceUrl) || this;
        _this.http = http;
        _this.context = context;
        _this.serviceUrl = serviceUrl;
        _this.documentType = null;
        return _this;
    }
    DocumentService.prototype.getDocumentType = function () {
        if (this.documentType == null) {
            return this.apiService.get('document-type')
                .toPromise();
        }
        else {
            return Promise.resolve(this.documentType);
        }
    };
    DocumentService.prototype.update = function (info) {
        //Si no tiene asignado la empresa y sucursal, asignar la actual
        if (info.idSucursal == 0)
            info.idSucursal = this.context.app.defaultSite.identity;
        //
        var params = new HttpParams();
        return this.apiService.post('update', params, info)
            .toPromise();
    };
    DocumentService.prototype.clone = function (originalID) {
        var params = new HttpParams()
            .set('originalID', originalID);
        //
        return this.apiService.get('clone', params)
            .toPromise();
    };
    DocumentService.prototype.getDetail = function (documentID) {
        var _this = this;
        var params = new HttpParams()
            .set('documentID', documentID);
        //
        return this.apiService.get('get-detail', params)
            .pipe(map(function (document) {
            _this.mapDocument(document);
            return document;
        }))
            .toPromise();
    };
    DocumentService.prototype.delete = function (documentID) {
        var params = new HttpParams()
            .set('documentID', documentID);
        //
        return this.apiService.delete('delete', params)
            .toPromise();
    };
    DocumentService.prototype.exists = function (documentID) {
        var params = new HttpParams()
            .set('documentID', documentID);
        //
        return this.apiService.delete('exists', params)
            .toPromise();
    };
    DocumentService.prototype.export = function (documentID) {
        var params = new HttpParams()
            .set('documentID', documentID);
        //
        return this.apiService.get('export', params)
            .toPromise();
    };
    DocumentService.prototype.search = function (idSucursal, request) {
        var _this = this;
        var params = new HttpParams()
            .set('idSucursal', idSucursal.toString());
        //
        return this.apiService.post('search', params, request)
            .pipe(map(function (result) {
            result.rows.forEach(function (row) {
                row.fechaSys = moment(row.fechaSys).toDate();
                row.fechaCreacion = moment(row.fechaCreacion).toDate();
                _this.mapSearchResult(row);
            });
            return result;
        })).toPromise();
    };
    DocumentService.prototype.nextStep = function (documentID, idWorkflowStep, data) {
        var params = new HttpParams()
            .set('documentID', documentID)
            .set('idWorkflowStep', idWorkflowStep.toString());
        //
        return this.apiService.post('next-step', params, data)
            .toPromise();
    };
    DocumentService.prototype.previousStep = function (documentID, data) {
        var params = new HttpParams()
            .set('documentID', documentID);
        //
        return this.apiService.post('previous-step', params, data)
            .toPromise();
    };
    /**
     * Sobreescribir en clases derviadas para realizar conversiones en los campos del resultado de la búsqueda (ej. los campos de fecha que vienen como texto del server)
     * @param row
     */
    DocumentService.prototype.mapSearchResult = function (row) {
    };
    /**
     * Sobreescribir en clases derviadas para realizar conversiones en los campos del documento (ej. los campos de fecha que vienen como texto del server)
     * @param document
     */
    DocumentService.prototype.mapDocument = function (document) {
    };
    DocumentService = __decorate([
        Injectable(),
        __metadata("design:paramtypes", [HttpClient, Context, String])
    ], DocumentService);
    return DocumentService;
}(BaseService));
export { DocumentService };
