var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, ViewChild } from '@angular/core';
import { Router } from '@angular/router';
import { Location } from '@angular/common';
//Wijmo
import { CollectionView } from 'wijmo/wijmo';
import { FlexGrid, DataMap } from 'wijmo/wijmo.grid';
//Bootstrap
import { ModalDirective } from 'ngx-bootstrap';
//Azteca Kernel
import { Context } from '../../core/services/context';
import { EnsambladoService } from '../../core/services/ensamblado.service';
import { CatalogOptions } from '../models/catalog-options';
import { CustomCatalogService } from '../services/custom-catalog.service';
var CustomCatalogManager = /** @class */ (function () {
    function CustomCatalogManager(context, customService, router, location, ensambladoService) {
        this.context = context;
        this.customService = customService;
        this.router = router;
        this.location = location;
        this.ensambladoService = ensambladoService;
        this.alerts = [];
        this.collectionView = new CollectionView();
        this.ensamblados = [];
        this.currentItem = new CatalogOptions();
    }
    CustomCatalogManager.prototype.ngOnInit = function () {
        this.collectionView.pageSize = 15;
    };
    CustomCatalogManager.prototype.ngAfterViewInit = function () {
        var _this = this;
        setTimeout(function (_) { return _this.loadEnsamblados(); });
        setTimeout(function (_) { return _this.loadData(); });
    };
    CustomCatalogManager.prototype.loadData = function () {
        var _this = this;
        this.customService.load(this.context.app.defaultCompany.identity)
            .then(function (options) { return _this.collectionView.sourceCollection = options; })
            .catch(function (error) { return _this.handleError(error); });
    };
    CustomCatalogManager.prototype.loadEnsamblados = function () {
        var _this = this;
        this.ensambladoService.loadList()
            .then(function (ensamblados) {
            _this.currentItem.idEnsamblado = 0;
            _this.ensamblados = ensamblados;
            _this.ensamblados.push({ id: 0, codigo: '0', nombre: '[NO SELECCIONADA]', ensamblado: '', activo: true });
            _this.ensambladosMap = new DataMap(_this.ensamblados, 'id', 'nombre');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    CustomCatalogManager.prototype.saveData = function () {
        var _this = this;
        this.customService.update(this.context.app.defaultCompany.identity, this.collectionView.sourceCollection)
            .then(function () { return _this.showAlert('Los cambios han sido guardados con éxito', 'success'); })
            .catch(function (error) { return _this.handleError(error); });
    };
    CustomCatalogManager.prototype.mainToolbarHandler = function (button) {
        if (button.name == "SAVE") {
            this.saveData();
        }
        if (button.name == "LOAD") {
            this.loadData();
        }
        else if (button.name == "CLOSE") {
            this.location.back();
        }
    };
    CustomCatalogManager.prototype.detailsToolbarHandler = function (button) {
        if (button.name == "OK") {
            this.collectionView.commitEdit();
            this.detailsDialog.hide();
        }
        if (button.name == "CANCEL") {
            this.collectionView.cancelEdit();
            this.detailsDialog.hide();
        }
    };
    CustomCatalogManager.prototype.onRowEdit = function (item) {
        this.currentItem = item;
        this.collectionView.editItem(this.collectionView.currentItem);
        this.detailsDialog.config.backdrop = false;
        this.detailsDialog.show();
    };
    CustomCatalogManager.prototype.hideDetailsDialog = function () {
        this.collectionView.cancelEdit();
        this.detailsDialog.hide();
    };
    CustomCatalogManager.prototype.showAlert = function (message, type) {
        var newAlert = { msg: message, type: type, dismissOnTimeout: 5000, closable: true };
        this.alerts.push(newAlert);
    };
    CustomCatalogManager.prototype.closeAlert = function (i) {
        this.alerts.splice(i, 1);
    };
    CustomCatalogManager.prototype.handleError = function (error) {
        console.error(error);
        this.showAlert('Error al guardar los cambios', 'danger');
    };
    __decorate([
        ViewChild('detailsDialog'),
        __metadata("design:type", ModalDirective)
    ], CustomCatalogManager.prototype, "detailsDialog", void 0);
    __decorate([
        ViewChild('grid'),
        __metadata("design:type", FlexGrid)
    ], CustomCatalogManager.prototype, "grid", void 0);
    CustomCatalogManager = __decorate([
        Component({
            selector: 'custom-catalog-manager',
            template: "\n      <div class=\"row\">\n          <div class=\"col-xs-12 col-md-10\">\n              <az-panel [header]=\"'Configuraci\u00F3n y personalizaci\u00F3n de cat\u00E1logos'\">\n            \n                  <az-toolbar (buttonClick)=\"mainToolbarHandler($event)\">\n                      <az-toolbar-button [name]=\"'SAVE'\" [type]=\"'primary'\" [text]=\"'Guardar Cambios'\" [icon]=\"'glyphicon glyphicon-floppy-disk'\"></az-toolbar-button>\n                      <az-toolbar-button [name]=\"'LOAD'\" [text]=\"'Actualizar Lista'\" [icon]=\"'glyphicon glyphicon-refresh'\"></az-toolbar-button>\n                      <az-toolbar-button [name]=\"'CLOSE'\" [text]=\"'Cerrar'\"></az-toolbar-button>\n                  </az-toolbar>\n                  <!--Pool de alertas-->\n                  <alert *ngFor=\"let alert of alerts;let i = index\" [type]=\"alert.type\" dismissible=\"true\" [dismissOnTimeout]=\"alert.dismissOnTimeout\" (close)=\"closeAlert(i)\">\n                      {{ alert?.msg }}\n                  </alert>\n\n                  <div class=\"row\">\n                      <div class=\"col-12\">\n                          <wj-flex-grid #grid style=\"height:550px\"\n                                        [itemsSource]=\"collectionView\">\n\n                              <wj-flex-grid-filter #filter></wj-flex-grid-filter>\n\n                              <wj-flex-grid-column [header]=\"''\" [width]=\"55\" [isReadOnly]=\"true\">\n                                  <ng-template wjFlexGridCellTemplate [cellType]=\"'Cell'\" let-cell=\"cell\">\n                                      <button type=\"button\" class=\"btn btn-default\" (click)=\"onRowEdit(cell.item)\">\n                                          <span class=\"glyphicon glyphicon-pencil\"></span>\n                                      </button>\n                                  </ng-template>\n                              </wj-flex-grid-column>\n\n                              <wj-flex-grid-column [header]=\"'Entidad'\" [binding]=\"'entidad'\" [width]=\"'30*'\" [isReadOnly]=\"true\"></wj-flex-grid-column>\n                              <wj-flex-grid-column [header]=\"'Ensamblado'\" [binding]=\"'idEnsamblado'\" [width]=\"'20*'\" [dataMap]=\"ensambladosMap\"></wj-flex-grid-column>\n                              <wj-flex-grid-column [header]=\"'Clase'\" [binding]=\"'claseAcciones'\" [width]=\"'20*'\"></wj-flex-grid-column>\n                              <wj-flex-grid-column [header]=\"'C\u00F3digo Auto'\" [binding]=\"'codigoAutogenerado'\" dataType=\"Boolean\" [width]=\"'10*'\"></wj-flex-grid-column>\n                              <wj-flex-grid-column [header]=\"'Log'\" [binding]=\"'logCambios'\" dataType=\"Boolean\" [width]=\"'10*'\"></wj-flex-grid-column>\n                          </wj-flex-grid>\n                      </div>\n                  </div>\n                  <!--Pager-->\n                  <div class=\"row\">\n                      <div class=\"col-12 col-md-6\">\n                          <az-pager [totalRows]=\"collectionView.totalItemCount\"\n                                    [pageSize]=\"collectionView.pageSize\"\n                                    [pageIndex]=\"collectionView.pageIndex\"\n                                    (moveToPage)=\"collectionView.moveToPage($event)\">\n\n                          </az-pager>\n                      </div>\n                  </div>\n\n              </az-panel>\n\n          </div>\n      </div>\n\n      <!--Dialogo de edici\u00F3n de datalles-->\n      <div bsModal #detailsDialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"myLargeModalLabel\" aria-hidden=\"true\">\n\n          <div class=\"modal-dialog modal-lg\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-header\">\n                      <button type=\"button\" class=\"close\" aria-label=\"Close\" (click)=\"hideDetailsDialog()\">\n                          <span aria-hidden=\"true\">&times;</span>\n                      </button>\n                      <h4 class=\"modal-title\">Configuraci\u00F3n de entidad - {{currentItem.entidad}}</h4>\n                  </div>\n                  <div class=\"modal-body\">\n                      <div class=\"row\">\n\n                          <div class=\"col-xs-12 col-md-6\">\n                              <az-panel [header]=\"'Opciones de Configuraci\u00F3n'\">\n                                  <div class=\"checkbox\">\n                                      <label>\n                                          <input type=\"checkbox\" [(ngModel)]=\"currentItem.codigoAutogenerado\" />C\u00F3digo Autogenerado\n                                      </label>\n                                  </div>\n\n                                  <div class=\"checkbox\">\n                                      <label>\n                                          <input type=\"checkbox\" [(ngModel)]=\"currentItem.logCambios\" />Habilitar log de cambios\n                                      </label>\n                                  </div>\n\n                                  <div class=\"checkbox\">\n                                      <label>\n                                          <input type=\"checkbox\" [(ngModel)]=\"currentItem.busquedasServidor\" />Realizar b\u00FAsquedas y paginaci\u00F3n del lado del servidor\n                                      </label>\n                                  </div>\n\n                                  <div class=\"checkbox\">\n                                      <label>\n                                          <input type=\"checkbox\" [(ngModel)]=\"currentItem.utilizarCache\" />Guardar cat\u00E1logo en cach\u00E9 para acelerar las b\u00FAsquedas\n                                      </label>\n                                  </div>\n\n                                  <div class=\"form-group\">\n                                      <label class=\"control-label\">Cantidad de registros por p\u00E1gina:</label>\n                                      <input type=\"text\" [(ngModel)]=\"currentItem.tamanioPagina\" />\n                                  </div>                            \n                              </az-panel> <!--Panel-->\n                          </div> <!--Column-->\n\n                          <div class=\"col-xs-12 col-md-6\">\n                        \n                              <az-panel [header]=\"'Clase de personalizaciones'\">\n                                  <div class=\"form-group\">\n                                      <label class=\"control-label\">Ensamblado:</label>\n                                      <wj-combo-box class=\"form-control\"\n                                                    [itemsSource]=\"ensamblados\"\n                                                    [selectedValuePath]=\"'id'\"\n                                                    [displayMemberPath]=\"'nombre'\"\n                                                    [(selectedValue)]=\"currentItem.idEnsamblado\">\n                                      </wj-combo-box>\n                                  </div>\n\n                                  <div class=\"form-group\">\n                                      <label class=\"control-label\">Clase:</label>\n                                      <input type=\"text\" [(ngModel)]=\"currentItem.claseAcciones\" />\n                                  </div>                            \n                              </az-panel> <!--Panel-->\n                          </div> <!--Column-->\n\n                      </div> <!--Row-->\n                \n                      <div class=\"modal-footer\">\n                          <az-toolbar (buttonClick)=\"detailsToolbarHandler($event)\">\n                              <az-toolbar-button [name]=\"'OK'\" [type]=\"'primary'\" [text]=\"'Aceptar'\" [icon]=\"'glyphicon glyphicon-ok'\"></az-toolbar-button>\n                              <az-toolbar-button [name]=\"'CANCEL'\" [type]=\"'warning'\" [text]=\"'Cancelar'\" [icon]=\"'glyphicon glyphicon-remove'\"></az-toolbar-button>\n                          </az-toolbar>\n                      </div> <!--Footer-->\n                  </div> <!--Modal Body-->\n              </div> <!--Modal Content-->\n          </div> <!--Modal-->\n\n      </div>\n    "
        }),
        __metadata("design:paramtypes", [Context, CustomCatalogService, Router, Location,
            EnsambladoService])
    ], CustomCatalogManager);
    return CustomCatalogManager;
}());
export { CustomCatalogManager };
