var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, ViewChild, forwardRef, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators } from '@angular/forms';
import { Location } from '@angular/common';
//Wijmo
import { Control } from 'wijmo/wijmo';
//Azteca Kernel
import { Context } from '../../core/services/context';
import { BaseComponent } from '../../core/models/base-component';
import { CatalogService } from '../../core/services/catalog.service';
import { EnsambladoService } from '../../core/services/ensamblado.service';
import { AztecaValidators } from '../../controls/validators';
import { CatalogEditor } from '../../editors/models/catalog-editor';
import { TrackableCollection } from '../../editors/components/trackable-collection';
import { ChangeState } from '../../core/models/change-tracking';
//Features
import { DocumentTypeService } from '../../core/services/document-type.service';
import { DocumentTypeInfo } from '../../core/models/document-type';
import { Activity } from '../../core/models/activity';
import { ActividadEditor } from './parts/actividad.editor';
var DocumentTypeEditor = /** @class */ (function (_super) {
    __extends(DocumentTypeEditor, _super);
    //
    function DocumentTypeEditor(router, route, formBuilder, changeDetector, context, location, documentTypeService, ensambladoService) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.changeDetector = changeDetector;
        _this.context = context;
        _this.location = location;
        _this.documentTypeService = documentTypeService;
        _this.ensambladoService = ensambladoService;
        _this.documentType = new DocumentTypeInfo();
        _this.ensamblados = [];
        _this.actividadesCollection = new TrackableCollection();
        _this.currentActivity = new Activity();
        _this._lastActivity = 0;
        _this.catalogForm = formBuilder.group({
            'codigo': ['', Validators.required],
            'nombre': ['', Validators.required],
            'idEnsamblado': [0, AztecaValidators.selected],
            'documentClass': ['', Validators.required],
            'idEnsambladoCustom': [0],
            'customClass': ['']
        });
        return _this;
    }
    DocumentTypeEditor_1 = DocumentTypeEditor;
    ///////////////////////// METODOS ///////////////////////////////////////
    DocumentTypeEditor.prototype.cargarEnsamblados = function () {
        var _this = this;
        this.ensambladoService.loadList()
            .then(function (ensamblados) {
            _this.ensamblados = ensamblados;
            _this.ensamblados.unshift({ id: 0, codigo: '', nombre: '[NINGUNO]', activo: true });
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    ///////////////////////// HANDLERS ///////////////////////////////////////
    DocumentTypeEditor.prototype.onConfigureCatalog = function (options) {
        this.autogeneratedCode = options.codigoAutogenerado;
        this.applyPolicies();
        this.cargarEnsamblados();
    };
    DocumentTypeEditor.prototype.onCreatingItem = function () {
    };
    DocumentTypeEditor.prototype.onViewingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.documentTypeService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.documentType = info;
            _this.setReadonlyMode();
            _this.actividadesCollection.sourceCollection = _this.documentType.activities;
            _this._lastActivity = _this.documentType.activities.length;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    DocumentTypeEditor.prototype.onCloningItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        //
        this.documentTypeService.clone(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.documentType = info;
            _this.actividadesCollection.sourceCollection = _this.documentType.activities;
            _this._lastActivity = _this.documentType.activities.length;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    DocumentTypeEditor.prototype.onLoadingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.documentTypeService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.documentType = info;
            _this.actividadesCollection.sourceCollection = _this.documentType.activities;
            _this._lastActivity = _this.documentType.activities.length;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    DocumentTypeEditor.prototype.onSavingItem = function (args) {
        var _this = this;
        this.context.app.showSpinner();
        this.documentTypeService.update(this.documentType)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.reset();
            //Si es un elemento nuevo y no se cerrará el editor, navegar a nueva ruta
            if (!args.closeEditor && _this.documentType.identity == 0) {
                _this.router.navigate(['../', info.identity], { relativeTo: _this.route });
            }
            else {
                if (args.closeEditor)
                    _this.router.navigate(['../'], { relativeTo: _this.route });
                else
                    _this.showAlert('La información ha sido actualizada con éxito', 'success');
            }
            _this.documentType = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    DocumentTypeEditor.prototype.onMenuItemClick = function (option) {
        if (option.name == 'WORKFLOW') {
            this.router.navigate(['workflow'], { relativeTo: this.route });
        }
    };
    /////////////////////////////// ACTIVIDADES /////////////////////////////////
    DocumentTypeEditor.prototype.onActividadesToolbar = function (button) {
        if (button.name == 'ADD') {
            this.currentActivity = new Activity();
            this.activityEditor.show();
        }
    };
    DocumentTypeEditor.prototype.onActivityUpated = function (actividad) {
        var newActivities = this.documentType.activities.slice();
        if (actividad._clientID == 0) {
            var existing = this.documentType.activities.find(function (a) { return a.tag == actividad.tag && a.state != ChangeState.DELETED; });
            if (!existing) {
                this._lastActivity += 1;
                actividad._clientID = this._lastActivity;
                newActivities.push(actividad);
            }
            else {
                this.showAlert('Ya existe una actividad con el mismo ID.', 'warning');
            }
        }
        else {
            var index = newActivities.findIndex(function (a) { return a._clientID == actividad._clientID; });
            newActivities[index] = actividad;
        }
        this.documentType.activities = newActivities;
        this.actividadesCollection.sourceCollection = newActivities;
    };
    DocumentTypeEditor.prototype.onRowDelete = function (actividad) {
        this.actividadesCollection.remove(actividad);
    };
    DocumentTypeEditor.prototype.onTabSelected = function (args) {
        if (args.heading) {
            Control.invalidateAll();
        }
    };
    var DocumentTypeEditor_1;
    __decorate([
        ViewChild(ActividadEditor),
        __metadata("design:type", ActividadEditor)
    ], DocumentTypeEditor.prototype, "activityEditor", void 0);
    DocumentTypeEditor = DocumentTypeEditor_1 = __decorate([
        Component({
            selector: 'custom-tipos-editor',
            template: "\n      <form [formGroup]=\"catalogForm\">\n\n          <azteca-catalog-editor #catalogEditor \n                                 [title]=\"'Tipos de documento'\"\n                                 [info]=\"documentType\"\n                                 [valid]=\"valid\"\n                                 (configureCatalog)=\"onConfigureCatalog($event)\"\n                                 (creatingItem)=\"onCreatingItem()\"\n                                 (viewingItem)=\"onViewingItem($event)\"\n                                 (cloningItem)=\"onCloningItem($event)\"\n                                 (savingItem)=\"onSavingItem($event)\"\n                                 (loadingItem)=\"onLoadingItem($event)\">\n\n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <azteca-form-field [label]=\"'C\u00F3digo:'\">\n                          <catalog-code formControlName=\"codigo\" [(ngModel)]=\"documentType.code\" [automatic]=\"true\"></catalog-code>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Nombre:'\">\n                          <az-textbox formControlName=\"nombre\" [(ngModel)]=\"documentType.nombre\"></az-textbox>\n                      </azteca-form-field>\n\n                  </div>\n              </div>\n\n        \n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <tabset>\n                          <tab heading=\"Generales\" (select)=\"onTabSelected($event)\">\n\n\t\t\t\t\t\t\n                              <div class=\"row\">\n                                  <div class=\"col-12 col-md-10\">\n\n                                      <azteca-form-field [label]=\"'Ensamblado:'\">\n                                          <az-combobox formControlName=\"idEnsamblado\" [(ngModel)]=\"documentType.idEnsamblado\" [items]=\"ensamblados\" [valueMember]=\"'id'\" [displayMember]=\"'nombre'\"></az-combobox>\n                                      </azteca-form-field>\n\n                                      <azteca-form-field [label]=\"'Clase del documento:'\">\n                                          <az-textbox formControlName=\"documentClass\" [(ngModel)]=\"documentType.documentClass\"></az-textbox>\n                                      </azteca-form-field>\n\n                                      <azteca-form-field [label]=\"'Ensamblado de personalizaciones:'\">\n                                          <az-combobox formControlName=\"idEnsambladoCustom\" [(ngModel)]=\"documentType.idEnsambladoCustom\" [items]=\"ensamblados\" [valueMember]=\"'id'\" [displayMember]=\"'nombre'\"></az-combobox>\n                                      </azteca-form-field>\n\n                                      <azteca-form-field [label]=\"'Clase de personalizaciones:'\">\n                                          <az-textbox formControlName=\"customClass\" [(ngModel)]=\"documentType.customClass\"></az-textbox>\n                                      </azteca-form-field>\n\n                                  </div>\n                              </div>\n\t\t\t\t\t\t\n\n                          </tab>\n                          <tab heading=\"Actividades\" (select)=\"onTabSelected($event)\">\n\n                              <az-toolbar (buttonClick)=\"onActividadesToolbar($event)\">\n                                  <az-toolbar-button [name]=\"'ADD'\" [type]=\"'primary'\" [text]=\"'Nueva'\" [icon]=\"'glyphicon glyphicon-plus'\" title=\"Agregar nueva actividad\"></az-toolbar-button>                            \n                              </az-toolbar>\n\n                              <wj-flex-grid style=\"height:300px\" [itemsSource]=\"actividadesCollection\" [isReadOnly]=\"true\">\n\n                                  <wj-flex-grid-column [header]=\"''\" [width]=\"60\" [isReadOnly]=\"true\">\n                                      <ng-template wjFlexGridCellTemplate [cellType]=\"'Cell'\" let-cell=\"cell\">\n                                          <button type=\"button\" class=\"btn btn-default\" (click)=\"onRowDelete(cell.item)\">\n                                              <span class=\"glyphicon glyphicon-trash\"></span>\n                                          </button>\n                                      </ng-template>\n                                  </wj-flex-grid-column>\n\n                                  <wj-flex-grid-column [header]=\"'ID'\" [binding]=\"'tag'\" [width]=\"200\"></wj-flex-grid-column>\n                                  <wj-flex-grid-column [header]=\"'Orden'\" [binding]=\"'orden'\" [width]=\"80\"></wj-flex-grid-column>\n                                  <wj-flex-grid-column [header]=\"'Descripci\u00F3n'\" [binding]=\"'descripcion'\" [width]=\"'*'\"></wj-flex-grid-column>\n                              </wj-flex-grid>\n\n                          </tab>\n                      </tabset>\n                  </div>\n              </div>\n            \n          </azteca-catalog-editor>\n      </form>\n\n      <!------------------------------DIALOGO PARA EDICI\u00D3N DE ACTIVIDADES ------------------------------>\n      <custom-activity-editor\n                              [actividad]=\"currentActivity\"\n                              (activityUpdated)=\"onActivityUpated($event)\">\n\n      </custom-activity-editor>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return DocumentTypeEditor_1; })
                },
                {
                    provide: CatalogService, useExisting: DocumentTypeService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, FormBuilder, ChangeDetectorRef,
            Context, Location, DocumentTypeService, EnsambladoService])
    ], DocumentTypeEditor);
    return DocumentTypeEditor;
}(CatalogEditor));
export { DocumentTypeEditor };
