import { Router, ActivatedRoute } from '@angular/router';
import { Location } from '@angular/common';
import { ModalDirective } from 'ngx-bootstrap';
import { Context } from '../../core/services/context';
import { EmpresaItem } from '../../core/models/empresa';
import { SucursalItem } from '../../core/models/sucursal';
import { ToolbarButton } from '../../controls/models/toolbar-button';
import { MenuItem } from '../../controls/models/menu-item';
import { AzInputNumber } from '../../controls/components/az-input-number.component';
import { AlertsBarComponent } from '../../controls/components/alerts-bar.component';
import { ILink, PaperComponent, PaperEventArgs, ConnectionEventArgs, CellView, ElementView, BBox, LinkDirective } from '../../drawing';
import { DocumentTypeService } from '../../core/services/document-type.service';
import { DocumentTypeInfo } from '../../core/models/document-type';
import { WorkflowStep } from '../../core/models/workflow-step';
import { WorkflowStart } from '../models/workflow-start';
import { WorkflowActivity } from '../models/workflow-activity';
import { WorkflowCondition } from '../models/workflow-condition';
import { WorkflowConditionOption } from '../models/workflow-condition-option';
import { WorkflowElement } from '../models/workflow-element';
import { WorkflowActivityEditor } from './parts/workflow-activity.editor';
import { WorkflowConditionEditor } from './parts/workflow-condition.editor';
import { AccessUserInfo } from '../models/access-user';
import { WorkflowAccessUserEditor } from './parts/workflow-access-user.editor';
import { WorkflowAccessGroupEditor } from './parts/workflow-access-group.editor';
import { AccessGroupInfo } from '../models/access-group';
import { EmpresaService } from '../../core/services/empresa.service';
import { SucursalService } from '../../core/services/sucursal.service';
export declare class WorkflowEditor {
    private context;
    private router;
    private route;
    private location;
    private documentTypeService;
    private empresaSvc;
    private sucursalSvc;
    idTipoDocumento: number;
    documentType: DocumentTypeInfo;
    shapesMenu: MenuItem[];
    start: WorkflowStart;
    conditions: WorkflowCondition[];
    activities: WorkflowActivity[];
    links: ILink[];
    companies: EmpresaItem[];
    branches: SucursalItem[];
    lastStepID: number;
    lastElementID: number;
    lastShapeID: number;
    lastConditionID: number;
    lastLinkID: number;
    lastPosition: {
        x: number;
        y: number;
    };
    currentCell: ElementView;
    currentBox: BBox;
    currentElement: WorkflowElement;
    paper: PaperComponent;
    inputWidth: AzInputNumber;
    inputHeight: AzInputNumber;
    deleteDialog: ModalDirective;
    activityEditor: WorkflowActivityEditor;
    conditionsEditor: WorkflowConditionEditor;
    alertsBar: AlertsBarComponent;
    acessUserEditor: WorkflowAccessUserEditor;
    acessGroupEditor: WorkflowAccessGroupEditor;
    constructor(context: Context, router: Router, route: ActivatedRoute, location: Location, documentTypeService: DocumentTypeService, empresaSvc: EmpresaService, sucursalSvc: SucursalService);
    ngAfterViewInit(): void;
    loadDocumentType(updateDocType: boolean): void;
    loadDataCompanies(): void;
    createDiagram(): void;
    updateNextElement(link: LinkDirective, previousElement: WorkflowElement, workflow: WorkflowStep[]): void;
    updateWorkflow(): void;
    findElementByID(clientID: number): WorkflowElement;
    findElement(shapeID: string): WorkflowElement;
    findLink(linkID: string): ILink;
    setCurrentElement(cell: CellView): void;
    createShapesMenu(): void;
    createElementID(): number;
    createStepID(): number;
    createShapeID(): number;
    getNewElementPosition(): {
        x: number;
        y: number;
    };
    crearActividad(): void;
    crearCondicion(): void;
    setActivityActions(activity: WorkflowActivity): void;
    createNewLink(): void;
    createLink(source: number, target: number, label?: string, vertices?: string): ILink;
    trackShape(index: any, item: any): any;
    isOptionsShape(shapeID: string): boolean;
    removeConditionOption(condition: WorkflowCondition, activityID: number): void;
    createConditionOption(targetActivity: WorkflowActivity, tag?: string, text?: string): WorkflowConditionOption;
    setElementSize(width: number, height: number): void;
    onCellClick(args: PaperEventArgs): void;
    onCellDblClick(args: PaperEventArgs): void;
    onBlankClick(args: PaperEventArgs): void;
    onLinkConnect(args: ConnectionEventArgs): void;
    onLinkDisconnect(args: ConnectionEventArgs): void;
    onLinkDeleted(link: LinkDirective): void;
    shapeMoved(pos: {
        x: number;
        y: number;
    }, element: WorkflowElement): void;
    changeSize(): void;
    onMainToolBar(button: ToolbarButton): void;
    onShapesMenu(option: MenuItem): void;
    onEditActivity(): void;
    onEditOptions(): void;
    onEditUsers(): void;
    onEditGroups(): void;
    onActivityUpdated(activity: WorkflowActivity): void;
    onAccessUsersUpdated(activity: WorkflowActivity): void;
    onAccessGroupUpdated(activity: WorkflowActivity): void;
    onConditionUpdate(condition: WorkflowCondition): void;
    onConfirmDelete(): void;
    handleError(error: any): void;
    copyUsers(activity: AccessUserInfo[]): AccessUserInfo[];
    copyGroups(activity: AccessGroupInfo[]): AccessGroupInfo[];
}
