var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, Input, Output, EventEmitter, ContentChildren, QueryList, NgZone } from '@angular/core';
import { Observable } from 'rxjs';
import * as $ from 'jquery';
//Models
import { Shape } from '../models/shape';
import { LinkDirective } from '../directives/link.directive';
import { RhombusDirective } from '../directives/rhombus.directive';
import { RectangleDirective } from '../directives/rectangle.directive';
import { TextBlockDirective } from '../directives/text-block.directive';
import { ConnectionEventArgs } from '../models/connection-event-args';
//Services
import { DiagramService } from '../services/diagram.service';
import { LinkService } from '../services/link.service';
import { RectangleService } from '../services/rectangle.service';
import { RhombusService } from '../services/rhombus.service';
import { TextBlockService } from '../services/text-block.service';
import { CircleService } from '../services/circle.service';
var PaperComponent = /** @class */ (function () {
    function PaperComponent(diagramService, _zone) {
        this.diagramService = diagramService;
        this._zone = _zone;
        //INPUTS
        this.width = 1000;
        this.height = 800;
        this.gridSize = 10;
        //OUTPUTS
        this.cellClick = new EventEmitter();
        this.cellDblClick = new EventEmitter();
        this.linkConnect = new EventEmitter();
        this.linkDisconnect = new EventEmitter();
        this.linkDeleted = new EventEmitter();
        this.blankClick = new EventEmitter();
    }
    PaperComponent.prototype.ngOnInit = function () {
        this.createPaper();
    };
    PaperComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        if (this.shapes.length > 0)
            this.fitToContent();
        //Crear links
        setTimeout(function (_) { return _this.createLinks(); });
        //Suscribir a cambios posteriores
        this.links.changes.subscribe(function (_) {
            _this.createLinks();
        });
        this.shapes.changes.subscribe(function (_) {
            _this.fitToContent();
        });
    };
    //////////////////////////////// METODOS ////////////////////////////////////////////
    PaperComponent.prototype.clear = function () {
        this.diagramService.clear();
    };
    PaperComponent.prototype.fitToContent = function () {
        var width = this.shapes.first.shape.getBBox().width + this.shapes.first.shape.getBBox().x;
        var height = this.shapes.first.shape.getBBox().height + this.shapes.first.shape.getBBox().y;
        //Determinar el elemento más a la derecha y el más inferior
        this.shapes.forEach(function (s) {
            var currentWidth = s.shape.getBBox().width + s.shape.getBBox().x;
            var currentHeight = s.shape.getBBox().height + s.shape.getBBox().y;
            //
            if (currentWidth > width)
                width = currentWidth;
            if (currentHeight > height)
                height = currentHeight;
        });
        if (width < 450)
            width = 450;
        if (height < 250)
            height = 250;
        this.paper.setDimensions(width + 50, height + 50);
    };
    PaperComponent.prototype.createPaper = function () {
        var gridOpts = { name: 'dot' };
        this.paper = this.diagramService.createDiagram({
            el: $('#paper'),
            width: this.width,
            height: this.height,
            gridSize: this.gridSize,
            drawGrid: true,
            clickThreshold: 1
        });
        //       
        this.paper.setGrid(gridOpts);
        this.paper.drawGrid();
        this.addEventListeners();
    };
    PaperComponent.prototype.checkConnection = function (linkArgs, link) {
        var source = this.shapes.find(function (s) { return s.shape.id == linkArgs.currentConnection.sourceID; });
        var target = this.shapes.find(function (s) { return s.shape.id == linkArgs.currentConnection.targetID; });
        var newArgs = new ConnectionEventArgs();
        newArgs.link = link;
        newArgs.current.source = source;
        newArgs.current.target = target;
        link.sourceID = source.id;
        link.targetID = target.id;
        if (linkArgs.previousConnection.sourceID) {
            newArgs.previous.source = this.shapes.find(function (s) { return s.shape.id == linkArgs.previousConnection.sourceID; });
        }
        if (linkArgs.previousConnection.targetID) {
            newArgs.previous.target = this.shapes.find(function (s) { return s.shape.id == linkArgs.previousConnection.targetID; });
        }
        this.linkConnect.emit(newArgs);
    };
    PaperComponent.prototype.checkDisconnection = function (linkArgs, link) {
        var source = this.shapes.find(function (s) { return s.shape.id == linkArgs.previousConnection.sourceID; });
        var target = this.shapes.find(function (s) { return s.shape.id == linkArgs.previousConnection.targetID; });
        var newArgs = new ConnectionEventArgs();
        newArgs.link = link;
        newArgs.previous.source = source;
        newArgs.previous.target = target;
        if (linkArgs.currentConnection.sourceID) {
            newArgs.current.source = this.shapes.find(function (s) { return s.shape.id == linkArgs.currentConnection.sourceID; });
            link.sourceID = newArgs.current.source.id;
            link.targetID = null;
        }
        if (linkArgs.currentConnection.targetID) {
            newArgs.current.target = this.shapes.find(function (s) { return s.shape.id == linkArgs.currentConnection.targetID; });
            link.targetID = newArgs.current.target.id;
            link.sourceID = null;
        }
        this.linkDisconnect.emit(newArgs);
    };
    PaperComponent.prototype.removeLink = function (link) {
        var linkDir = this.links.find(function (l) { return l.shape.id == link.id; });
        //Si el link estaba conectado, emitir evento de desconexión
        if (linkDir.sourceID && linkDir.targetID) {
            var source = this.shapes.find(function (s) { return s.id == linkDir.sourceID; });
            var target = this.shapes.find(function (s) { return s.id == linkDir.targetID; });
            var newArgs = new ConnectionEventArgs();
            newArgs.link = linkDir;
            newArgs.previous.source = source;
            newArgs.previous.target = target;
            this.linkDisconnect.emit(newArgs);
        }
        this.linkDeleted.emit(linkDir);
    };
    PaperComponent.prototype.createLinks = function () {
        var _this = this;
        this.links.forEach(function (link) {
            //Obtener source y target
            if (!link.drawn) {
                var sourceShape = _this.shapes.find(function (s) { return s.id == link.sourceID; });
                var targetShape = _this.shapes.find(function (s) { return s.id == link.targetID; });
                link.draw(sourceShape, targetShape);
                //Manejo de conexiones
                link.connected.subscribe(function (args) {
                    _this.checkConnection(args, link);
                });
                //Manejo de desconexiones
                link.disconnected.subscribe(function (args) {
                    _this.checkDisconnection(args, link);
                });
            }
        });
    };
    PaperComponent.prototype.addEventListeners = function () {
        var _this = this;
        //Click en una celda
        this.createEventObservable('cell:pointerclick')
            .subscribe(function (cell) {
            _this.cellClick.emit({ cellView: cell });
        });
        //Doble click en una celda
        this.createEventObservable('cell:pointerdblclick')
            .subscribe(function (cell) {
            _this.cellDblClick.emit({ cellView: cell });
        });
        //Click en área sin contenido        
        this.paper.on('blank:pointerclick', function (evt, x, y) {
            var args = { evt: evt, x: x, y: y };
            _this.blankClick.emit(args);
        });
        this.diagramService.graph.on('remove', function (cell) {
            if (cell.isLink()) {
                _this.removeLink(cell);
            }
        });
    };
    PaperComponent.prototype.createEventObservable = function (eventName) {
        var _this = this;
        return Observable.create(function (observer) {
            _this.paper.on(eventName, function (e) { return _this._zone.run(function () { return observer.next(e); }); });
        });
    };
    PaperComponent.prototype.getConnectedLinks = function (element, opt) {
        var _this = this;
        var connectedLinks = this.diagramService.graph.getConnectedLinks(element.shape, { inbound: opt.inbound, outbound: opt.outbound });
        var retLinks = connectedLinks.map(function (l) {
            return _this.links.find(function (ld) { return ld.shape.id == l.id; });
        });
        return retLinks;
    };
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], PaperComponent.prototype, "width", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], PaperComponent.prototype, "height", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], PaperComponent.prototype, "gridSize", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], PaperComponent.prototype, "cellClick", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], PaperComponent.prototype, "cellDblClick", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], PaperComponent.prototype, "linkConnect", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], PaperComponent.prototype, "linkDisconnect", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], PaperComponent.prototype, "linkDeleted", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], PaperComponent.prototype, "blankClick", void 0);
    __decorate([
        ContentChildren(Shape),
        __metadata("design:type", QueryList)
    ], PaperComponent.prototype, "shapes", void 0);
    __decorate([
        ContentChildren(LinkDirective),
        __metadata("design:type", QueryList)
    ], PaperComponent.prototype, "links", void 0);
    __decorate([
        ContentChildren(RectangleDirective),
        __metadata("design:type", QueryList)
    ], PaperComponent.prototype, "rectangles", void 0);
    __decorate([
        ContentChildren(RhombusDirective),
        __metadata("design:type", QueryList)
    ], PaperComponent.prototype, "rhombus", void 0);
    __decorate([
        ContentChildren(TextBlockDirective),
        __metadata("design:type", QueryList)
    ], PaperComponent.prototype, "textBlocks", void 0);
    PaperComponent = __decorate([
        Component({
            selector: 'joint-paper',
            providers: [DiagramService, LinkService, RectangleService, TextBlockService, RhombusService, CircleService],
            template: "\n      <div id=\"paper\"></div>\n    ",
            styles: ['#paper{background:#FFF;width:auto;display:inline-flex;box-shadow:0 3px 5px rgba(0, 0, 0, 0.3);border-top:1px solid #eee;}.joint-element.joint-type-basic-path path{fill:#6a6c8a;stroke-width:0px;}.joint-element.joint-type-basic-path:hover path{fill:#FEC582;}.joint-element.joint-type-basic-path text{fill:#FFF;font-size:12px;font-weight:lighter;}.joint-link .connection{stroke:#6a6c8a;stroke-width:2px;}.joint-link *{pointer-events:none;}.bbox{stroke:#16a085;stroke-width:2;stroke-opacity:0;fill:none;transition-property:stroke-opacity;transition-duration:0.5s;pointer-events:none;}.axis{stroke:#95a5a6;stroke-dasharray:2,4;stroke-width:1;pointer-events:none;}.padding{stroke:#1abc9c;stroke-opacity:0;transition-property:stroke-opacity;transition-duration:1s;pointer-events:none;}.grid{stroke:#16a085;stroke-width:0.5;stroke-opacity:0;transition-property:stroke-opacity;transition-duration:1s;pointer-events:none;}.active{stroke-opacity:0.5;}.padding.active, .bbox.active{stroke-opacity:0.2;}.marker-source, .marker-target{display:none;}']
        }),
        __metadata("design:paramtypes", [DiagramService, NgZone])
    ], PaperComponent);
    return PaperComponent;
}());
export { PaperComponent };
