var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Directive, Input, Output, EventEmitter } from '@angular/core';
import { LinkEventArgs } from '../models/link-event-args';
import { LinkService } from '../services/link.service';
var LinkDirective = /** @class */ (function () {
    function LinkDirective(linkService) {
        this.linkService = linkService;
        this._addedToService = false;
        this.drawn = false;
        this.vertices = [];
        this.label = '';
        //Events
        this.connected = new EventEmitter();
        this.disconnected = new EventEmitter();
        this.verticesChange = new EventEmitter();
    }
    LinkDirective.prototype.ngOnChanges = function (changes) {
        if (this._addedToService) {
            if (changes['vertices']) {
                this.linkService.updateVertices(this);
            }
            if (changes['label']) {
                this.linkService.updateLabel(this);
            }
        }
    };
    LinkDirective.prototype.draw = function (sourceShape, targetShape) {
        if (!this._addedToService) {
            this.linkService.add(this, sourceShape, targetShape);
            this._addedToService = true;
            this.addEventListers();
            this.drawn = true;
        }
    };
    LinkDirective.prototype.ngOnDestroy = function () {
        this.linkService.delete(this);
    };
    LinkDirective.prototype.checkConnection = function () {
        var newArgs = new LinkEventArgs();
        var source = this.shape.getSourceElement();
        var target = this.shape.getTargetElement();
        //Si source y target están definidos, se realizó conexión
        if (source && target) {
            newArgs.currentConnection.sourceID = source.id;
            newArgs.currentConnection.targetID = target.id;
            newArgs.previousConnection.sourceID = this._sourceShapeID;
            newArgs.previousConnection.targetID = this._targetShapeID;
            this._sourceShapeID = source.id;
            this._targetShapeID = target.id;
            this.connected.emit(newArgs);
        }
        else {
            //Si source y target actuales tienen valores, se realizó una desconexión
            if (this._sourceShapeID && this._targetShapeID) {
                newArgs.previousConnection.sourceID = this._sourceShapeID;
                newArgs.previousConnection.targetID = this._targetShapeID;
                this.disconnected.emit(newArgs);
            }
            this._sourceShapeID = source ? source.id : null;
            this._targetShapeID = target ? target.id : null;
        }
    };
    LinkDirective.prototype.addEventListers = function () {
        var _this = this;
        this.linkService.createEventObservable('change:source', this)
            .subscribe(function (args) {
            _this.checkConnection();
        });
        //
        this.linkService.createEventObservable('change:target', this)
            .subscribe(function (args) {
            _this.checkConnection();
        });
        //
        this.linkService.createEventObservable('change:vertices', this)
            .subscribe(function (args) {
            _this.vertices = _this.shape.attributes.vertices;
            _this.verticesChange.emit();
        });
    };
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], LinkDirective.prototype, "id", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], LinkDirective.prototype, "sourceX", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], LinkDirective.prototype, "sourceY", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], LinkDirective.prototype, "sourceID", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], LinkDirective.prototype, "targetX", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], LinkDirective.prototype, "targetY", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], LinkDirective.prototype, "targetID", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], LinkDirective.prototype, "vertices", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], LinkDirective.prototype, "label", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], LinkDirective.prototype, "data", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], LinkDirective.prototype, "connected", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], LinkDirective.prototype, "disconnected", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], LinkDirective.prototype, "verticesChange", void 0);
    LinkDirective = __decorate([
        Directive({
            selector: 'joint-link'
        }),
        __metadata("design:paramtypes", [LinkService])
    ], LinkDirective);
    return LinkDirective;
}());
export { LinkDirective };
