export interface Events {
    on(eventName: string, callback?: Function, context?: any): any;
    on(eventMap: any): any;
    off(eventName?: string, callback?: Function, context?: any): any;
    trigger(eventName: string, ...args: any[]): any;
    bind(eventName: string, callback: Function, context?: any): any;
    unbind(eventName?: string, callback?: Function, context?: any): any;
    once(events: string, callback: Function, context?: any): any;
    listenTo(any: any, events: string, callback: Function): any;
    listenToOnce(any: any, events: string, callback: Function): any;
    stopListening(any?: any, events?: string, callback?: Function): any;
}
export interface ModelBase extends Events {
    url: any;
    parse(response: any, options?: any): any;
    toJSON(options?: any): any;
}
export interface Model extends ModelBase {
    attributes: any;
    changed: any[];
    cidPrefix: string;
    cid: string;
    id: any;
    idAttribute: string;
    validationError: any;
    urlRoot: any;
    constructor(attributes?: any, options?: any): any;
    initialize(attributes?: any, options?: any): void;
    changedAttributes(attributes?: any): any;
    clone(): Model;
    escape(attribute: string): string;
    has(attribute: string): boolean;
    hasChanged(attribute?: string): boolean;
    isNew(): boolean;
    isValid(options?: any): boolean;
    previous(attribute: string): any;
    previousAttributes(): any[];
    validate(attributes: any, options?: any): any;
    keys(): string[];
    values(): any[];
    pairs(): any[];
    invert(): any;
    pick(keys: string[]): any;
    pick(...keys: string[]): any;
    pick(fn: (value: any, key: any, any: any) => any): any;
    omit(keys: string[]): any;
    omit(...keys: string[]): any;
    omit(fn: (value: any, key: any, any: any) => any): any;
    chain(): any;
    isEmpty(): boolean;
    matches(attrs: any): boolean;
}
export interface ViewOptions<TModel extends Model> {
    model?: TModel;
    el?: any;
    events?: any;
    id?: string;
    className?: string;
    tagName?: string;
    attributes?: {
        [id: string]: any;
    };
}
export interface View<TModel extends Model> extends Events {
    constructor(options?: ViewOptions<TModel>): any;
    initialize(options?: ViewOptions<TModel>): void;
    events(): any;
    $(selector: string): JQuery;
    model: TModel;
    setElement(element: HTMLElement | JQuery, delegate?: boolean): View<TModel>;
    id: string;
    cid: string;
    className: string;
    tagName: string;
    el: any;
    $el: JQuery;
    setElement(element: any): View<TModel>;
    attributes: any;
    $(selector: any): JQuery;
    render(): View<TModel>;
    remove(): View<TModel>;
    delegateEvents(events?: any): any;
    delegate(eventName: string, selector: string, listener: Function): View<TModel>;
    undelegateEvents(): any;
    undelegate(eventName: string, selector?: string, listener?: Function): View<TModel>;
    _ensureElement(): void;
}
export interface GenericAttributes<T> extends CellAttributes {
    position?: Point;
    size?: Size;
    angle?: number;
    attrs?: T;
}
export interface ShapeAttrs extends CSSSelector {
    fill?: string;
    stroke?: string;
    r?: string | number;
    rx?: string | number;
    ry?: string | number;
    cx?: string | number;
    cy?: string | number;
    height?: string | number;
    width?: string | number;
    transform?: string;
    points?: string;
    'stroke-width'?: string | number;
    'stroke-linecap'?: string;
    'ref-x'?: string | number;
    'ref-y'?: string | number;
    ref?: string;
}
export interface Generic extends Element {
    constructor(attributes?: GenericAttributes<SVGAttributes>, options?: any): any;
}
export interface RectAttrs extends TextAttrs {
    rect?: ShapeAttrs;
}
export interface Rect extends Generic {
    constructor(attributes?: GenericAttributes<RectAttrs>, options?: any): any;
}
export interface Text extends Generic {
    constructor(attributes?: GenericAttributes<TextAttrs>, options?: any): any;
}
export interface CircleAttrs extends TextAttrs {
    circle?: ShapeAttrs;
}
export interface Circle extends Generic {
    constructor(attributes?: GenericAttributes<CircleAttrs>, options?: any): any;
}
export interface EllipseAttrs extends TextAttrs {
    ellipse?: ShapeAttrs;
}
export interface Ellipse extends Generic {
    constructor(attributes?: GenericAttributes<EllipseAttrs>, options?: any): any;
}
export interface PolygonAttrs extends TextAttrs {
    polygon?: ShapeAttrs;
}
export interface Polygon extends Generic {
    constructor(attributes?: GenericAttributes<PolygonAttrs>, options?: any): any;
}
export interface PolylineAttrs extends TextAttrs {
    polyline?: ShapeAttrs;
}
export interface Polyline extends Generic {
    constructor(attributes?: GenericAttributes<PolylineAttrs>, options?: any): any;
}
export interface Image extends Generic {
    constructor(attributes?: GenericAttributes<TextAttrs>, options?: any): any;
}
export interface PathAttrs extends TextAttrs {
    path?: ShapeAttrs;
}
export interface Path extends Generic {
    constructor(attributes?: GenericAttributes<PathAttrs>, options?: any): any;
}
export interface RhombusAttrs extends TextAttrs {
    path?: ShapeAttrs;
}
export interface Rhombus extends Generic {
    constructor(attributes?: GenericAttributes<RhombusAttrs>, options?: any): any;
}
export interface TextBlockAttrs extends TextAttrs {
    rect?: ShapeAttrs;
}
export interface TextBlock extends Generic {
    constructor(attributes?: GenericAttributes<TextBlockAttrs>, options?: any): any;
    updateSize(cell: Cell, size: Size): void;
    updateContent(cell: Cell, content: string): void;
}
export interface Size {
    width: number;
    height: number;
}
export interface Point {
    x: number;
    y: number;
}
export interface BBox extends Point, Size {
}
export interface TranslateOptions {
    restrictedArea?: BBox;
    transition?: TransitionOptions;
}
export interface TransitionOptions {
    delay?: number;
    duration?: number;
    timingFunction?: (t: number) => number;
    valueFunction?: (a: any, b: any) => (t: number) => any;
}
export interface DfsBfsOptions {
    inbound?: boolean;
    outbound?: boolean;
    deep?: boolean;
}
export interface ExploreOptions {
    breadthFirst?: boolean;
    deep?: boolean;
}
export interface EdgeMap {
    [key: string]: boolean;
}
export interface GridOptions {
    color?: string;
    thickness?: number;
    name?: 'dot' | 'fixedDot' | 'mesh' | 'doubleMesh';
    args?: any[] | any;
}
export interface Graph extends Model {
    constructor(attributes?: any, options?: {
        cellNamespace: any;
        cellModel: any;
    }): any;
    addCell(cell: Cell | Cell[], opt?: any): this;
    addCells(cells: Cell[], opt: any): this;
    resetCells(cells: Cell[], options?: any): this;
    getCell(id: string): Cell;
    getElements(): Element[];
    getLinks(): Link[];
    getCells(): Cell[];
    getFirstCell(): Cell;
    getLastCell(): Cell;
    getConnectedLinks(element: Cell, options?: {
        inbound?: boolean;
        outbound?: boolean;
        deep?: boolean;
    }): Link[];
    disconnectLinks(cell: Cell, options?: any): void;
    removeLinks(cell: Cell, options?: any): void;
    translate(tx: number, ty?: number, options?: TranslateOptions): void;
    cloneCells(cells: Cell[]): {
        [id: string]: Cell;
    };
    getSubgraph(cells: Cell[], options?: {
        deep?: boolean;
    }): Cell[];
    cloneSubgraph(cells: Cell[], options?: {
        deep?: boolean;
    }): {
        [id: string]: Cell;
    };
    dfs(element: Element, iteratee: (element: Element, distance: number) => boolean, options?: DfsBfsOptions, visited?: any, distance?: number): void;
    bfs(element: Element, iteratee: (element: Element, distance: number) => boolean, options?: DfsBfsOptions): void;
    search(element: Element, iteratee: (element: Element, distance: number) => boolean, options?: {
        breadthFirst?: boolean;
    }): void;
    getSuccessors(element: Element, options?: ExploreOptions): Element[];
    getPredecessors(element: Element, options?: ExploreOptions): Element[];
    isSuccessor(elementA: Element, elementB: Element): boolean;
    isPredecessor(elementA: Element, elementB: Element): boolean;
    isSource(element: Element): boolean;
    isSink(element: Element): boolean;
    getSources(): Element[];
    getSinks(): Element[];
    getNeighbors(element: Element, options?: DfsBfsOptions): Element[];
    isNeighbor(elementA: Element, elementB: Element, options?: {
        inbound?: boolean;
        outbound?: boolean;
    }): boolean;
    getCommonAncestor(...cells: Cell[]): Element;
    toJSON(): any;
    fromJSON(json: {
        cells: Cell[];
    }, options?: any): this;
    clear(options?: any): this;
    findModelsFromPoint(p: Point): Element[];
    findModelsUnderElement(element: Element, options?: {
        searchBy?: 'bottomLeft' | 'bottomMiddle' | 'center' | 'corner' | 'leftMiddle' | 'origin' | 'rightMiddle' | 'topMiddle' | 'topRight';
    }): Element[];
    getBBox(elements: Element[], options?: {
        deep?: boolean;
    }): Rect;
    toGraphLib(): any;
    findModelsInArea(rect: Rect | BBox, options?: {
        strict?: boolean;
    }): BBox | boolean;
    getCellsBBox(cells: Cell[], options?: {
        deep?: boolean;
    }): Rect;
    getInboundEdges(node: string): EdgeMap;
    getOutboundEdges(node: string): EdgeMap;
    hasActiveBatch(name?: string): number | boolean;
    maxZIndex(): number;
    removeCells(cells: Cell[], options?: any): this;
    resize(width: number, height: number, options?: any): this;
    resizeCells(width: number, height: number, cells: Cell[], options?: any): this;
    set(key: any | string, value: any, options?: any): this;
    startBatch(name: string, data?: any): any;
    stopBatch(name: string, data?: any): any;
}
export interface Cell extends Model {
    constructor(attributes?: any, options?: any): any;
    id: string;
    toJSON(): any;
    remove(options?: {
        disconnectLinks?: boolean;
    }): this;
    toFront(options?: {
        deep?: boolean;
    }): this;
    toBack(options?: {
        deep?: boolean;
    }): this;
    getAncestors(): Cell[];
    isEmbeddedIn(element: Element, options?: {
        deep: boolean;
    }): boolean;
    prop(key: string | string[]): any;
    prop(any: any): this;
    prop(key: string | string[], value: any, options?: any): this;
    removeProp(path: string | string[], options?: any): this;
    attr(key: string): any;
    attr(any: SVGAttributes): this;
    attr(key: string, value: any): this;
    clone(): Cell;
    clone(opt: {
        deep?: boolean;
    }): Cell | Cell[];
    removeAttr(path: string | string[], options?: any): this;
    transition(path: string, value?: any, options?: TransitionOptions, delim?: string): number;
    getTransitions(): string[];
    stopTransitions(path?: string, delim?: string): this;
    addTo(graph: Graph, options?: any): this;
    isLink(): boolean;
    embed(cell: Cell, options?: any): this;
    findView(paper: Paper): CellView;
    getEmbeddedCells(options?: {
        deep?: boolean;
        breadthFirst?: boolean;
    }): Cell[];
    initialize(options?: {
        id?: string;
    }): void;
    isElement(): boolean;
    isEmbedded(): boolean;
    processPorts(): void;
    startBatch(name: string, options?: any): this;
    stopBatch(name: string, options?: any): this;
    unembed(cell: Cell, options?: any): this;
}
export declare type Padding = number | {
    top?: number;
    right?: number;
    bottom?: number;
    left?: number;
};
export declare type Direction = 'left' | 'right' | 'top' | 'bottom' | 'top-right' | 'top-left' | 'bottom-left' | 'bottom-right';
export interface Port {
    id?: string;
    markup?: string;
    group?: string;
    attrs?: any;
    args?: any;
    size?: Size;
    label: {
        size?: Size;
        markup?: string;
        position?: any;
        args?: any;
    };
    z?: number | 'auto';
}
export interface PortPosition extends Point {
    angle: number;
}
export interface Element extends Cell {
    constructor(attributes?: any, options?: any): any;
    translate(tx: number, ty?: number, options?: TranslateOptions): this;
    position(options?: {
        parentRelative: boolean;
    }): Point;
    position(x: number, y: number, options?: {
        parentRelative?: boolean;
    }): this;
    size(): Size;
    size(width: number, height?: number, options?: {
        direction?: Direction;
    }): this;
    resize(width: number, height: number, options?: {
        direction?: Direction;
    }): this;
    rotate(deg: number, absolute?: boolean, origin?: Point, opt?: {
        parentRelative?: boolean;
    }): this;
    embed(cell: Cell): this;
    unembed(cell: Cell): this;
    getEmbeddedCells(options?: ExploreOptions): Cell[];
    fitEmbeds(options?: {
        deep?: boolean;
        padding?: Padding;
    }): this;
    getBBox(options?: {
        deep?: boolean;
    }): BBox;
    isElement(): boolean;
    scale(scaleX: number, scaleY: number, origin?: Point, options?: {
        direction?: Direction;
        parentRelative?: boolean;
    }): this;
    addPort(port: Port, opt?: any): this;
    addPorts(ports: Port[], opt?: any): this;
    removePort(port: string | Port, opt?: any): this;
    hasPorts(): boolean;
    hasPort(id: string): boolean;
    getPorts(): Port[];
    getPort(id: string): Port;
    getPortsPositions(groupName: string): {
        [id: string]: PortPosition;
    };
    getPortIndex(port: string | Port): number;
    portProp(portId: string, path: any, value?: any, opt?: any): Element;
}
export interface CSSSelector {
    [key: string]: string | number | any;
}
export interface SVGAttributes {
    [selector: string]: CSSSelector;
}
export interface CellAttributes {
    [key: string]: any;
}
export interface TextAttrs extends SVGAttributes {
    text?: {
        [key: string]: string | number;
        text?: string;
        fill?: string;
    };
    textWrap?: {
        text?: string;
        width?: number | string;
        height?: number | string;
    };
}
export interface Label {
    position: number;
    attrs?: TextAttrs;
}
export interface LinkAttributes extends CellAttributes {
    source?: Point | {
        id: string;
        selector?: string;
        port?: string;
    };
    target?: Point | {
        id: string;
        selector?: string;
        port?: string;
    };
    labels?: Label[];
    vertices?: Point[];
    smooth?: boolean;
    attrs?: TextAttrs;
    z?: number;
}
export interface Link extends Cell {
    markup: string;
    labelMarkup: string;
    toolMakup: string;
    vertexMarkup: string;
    arrowHeadMarkup: string;
    constructor(attributes?: LinkAttributes, options?: any): any;
    applyToPoints(fn: (p: Point) => Point, opt?: any): this;
    disconnect(): this;
    label(index?: number): any;
    label(index: number, value: Label, opt?: any): this;
    reparent(options?: any): Element;
    getSourceElement(): undefined | Element | Graph;
    getTargetElement(): undefined | Element | Graph;
    hasLoop(options?: {
        deep?: boolean;
    }): boolean;
    applyToPoints(fn: Function, options?: any): this;
    getRelationshipAncestor(): undefined | Element;
    isLink(): boolean;
    isRelationshipEmbeddedIn(element: Element): boolean;
    scale(sx: number, sy: number, origin: Point | Point | string, opt?: any): this;
    translate(tx: number, ty: number, options?: any): this;
}
export interface ManhattanRouterArgs {
    excludeTypes?: string[];
    excludeEnds?: 'source' | 'target';
    startDirections?: ['left' | 'right' | 'top' | 'bottom'];
    endDirections?: ['left' | 'right' | 'top' | 'bottom'];
}
export interface PaperOptions {
    el?: string | JQuery | HTMLElement;
    width?: number | string;
    height?: number | string;
    origin?: Point;
    gridSize?: number;
    drawGrid?: boolean | GridOptions;
    perpendicularLinks?: boolean;
    snapLinks?: boolean | {
        radius: number;
    };
    linkPinning?: boolean;
    markAvailable?: boolean;
    async?: boolean | {
        batchZise: number;
    };
    embeddingMode?: boolean;
    findParentBy?: 'bbox' | 'center' | 'origin' | 'corner' | 'topRight' | 'bottomLeft';
    multiLinks?: boolean;
    cellViewNamespace?: any;
    highlighterNamespace?: any;
    /** useful undocumented option */
    clickThreshold?: number;
    highlighting?: any;
    preventContextMenu?: boolean;
    model?: Model;
}
export interface Paper {
    constructor(options?: PaperOptions): any;
    options: PaperOptions;
    svg: SVGElement;
    viewport: SVGGElement;
    defs: SVGDefsElement;
    afterRenderViews(): void;
    asyncRenderViews(cells: Cell[], options?: any): void;
    beforeRenderViews(cells: Cell[]): Cell[];
    bindDocumentEvents(): void;
    cellMouseEnter(evt: Event): void;
    cellMouseleave(evt: Event): void;
    cellMouseout(evt: Event): void;
    cellMouseover(evt: Event): void;
    clearGrid(): this;
    clientMatrix(): SVGMatrix;
    clientToLocalPoint(x: number | Point, y?: number): Point;
    clientToLocalRect(x: number | Rect, y?: number, width?: number, height?: number): Rect;
    clientOffset(): Point;
    cloneOptions(): PaperOptions;
    contextmenu(evt: Event): void;
    createViewForModel(cell: Cell): CellView;
    defineFilter(filter: any): string;
    defineGradient(gradient: any): string;
    defineMarker(marker: any): string;
    drawBackground(opt?: {
        color?: string;
        img?: string;
    }): this;
    drawBackgroundImage(img: HTMLImageElement, opt: any): void;
    drawGrid(options?: {
        width?: number;
        height?: number;
        scaleFactor?: number;
        update: any;
        ox?: number;
        oy?: number;
    }): this;
    findView(element: string | JQuery | SVGElement): CellView;
    findViewByModel(model: Cell | string): CellView;
    findViewsFromPoint(point: string | Point | Point): ElementView[];
    findViewsInArea(rect: Rect | BBox, options?: {
        strict?: boolean;
    }): CellView[];
    fitToContent(gridWidth?: number, gridHeight?: number, padding?: number, options?: any): void;
    getArea(): Rect;
    getContentBBox(): Rect;
    getDefaultLink(cellView: CellView, magnet: HTMLElement): Link;
    getModelById(id: string): Cell;
    getRestrictedArea(): Rect | undefined;
    guard(evt: Event, view: CellView): boolean;
    init(): void;
    isDefined(defId: string): boolean;
    linkAllowed(linkViewOrModel: LinkView | Link): boolean;
    localToClientPoint(x: number | Point, y?: number): Point;
    localToClientRect(x: number | Rect, y?: number, width?: number, height?: number): Rect;
    localToPagePoint(x: number | Point, y?: number): Point;
    localToPageRect(x: number | Rect, y?: number, width?: number, height?: number): Rect;
    localToPaperPoint(x: number | Point, y?: number): Point;
    localToPaperRect(x: number | Rect, y?: number, width?: number, height?: number): Rect;
    matrix(): SVGMatrix;
    mouseclick(evt: Event): void;
    mousedblclick(evt: Event): void;
    mousewheel(evt: Event): void;
    on(eventName: string, callback?: Function, context?: any): any;
    onCellAdded(cell: Cell, graph: Graph, options: {
        async?: boolean;
        position?: number;
    }): void;
    onRemove(): void;
    pageOffset(): Point;
    pageToLocalPoint(x: number | Point, y?: number): Point;
    pageToLocalRect(x: number | Rect, y?: number, width?: number, height?: number): Rect;
    paperToLocalPoint(x: number | Point, y?: number): Point;
    paperToLocalRect(x: number | Rect, y?: number, width?: number, height?: number): Rect;
    pointerdown(evt: Event): void;
    pointermove(evt: Event): void;
    pointerup(evt: Event): void;
    remove(): this;
    removeView(cell: Cell): CellView;
    removeViews(): void;
    render(): this;
    renderView(cell: Cell): CellView;
    resetViews(cellsCollection: Cell[], options: any): void;
    rotate(deg: number, ox?: number, oy?: number): this;
    scale(sx: number, sy?: number, ox?: number, oy?: number): this;
    setDimensions(width: number, height: number): void;
    setGrid(drawGrid: GridOptions | GridOptions[]): this;
    setGridSize(gridSize: number): this;
    setInteractivity(value: any): void;
    setOrigin(x: number, y: number): this;
    snapToGrid(x: Point | number, y?: number): Point;
    sortViews(): void;
    translate(tx: number, ty?: number): this;
    unbindDocumentEvents(): void;
    update(): void;
    updateBackgroundColor(color: string): void;
    updateBackgroundImage(opt: {
        position?: any;
        size?: any;
    }): void;
}
export interface CellViewGeneric<T extends Model> extends View<T> {
    constructor(options?: {
        id: string;
    }): any;
    initialize(options?: any): void;
    init(): void;
    getBBox(options?: {
        useModelGeometry?: boolean;
    }): BBox;
    highlight(el?: any, options?: any): this;
    unhighlight(el?: any, options?: any): this;
    addThemeClassName(theme?: string): this;
    applyFilter(selector: string | HTMLElement, filter: any): void;
    can(feature: string): boolean;
    contextmenu(evt: Event, x: number, y: number): void;
    findBySelector(selector: string): JQuery;
    findMagnet(el: SVGElement | JQuery): undefined | JQuery;
    getEventNamespace(): string;
    getSelector(el: HTMLElement, prevSelector: string): string;
    mouseenter(evt: Event): void;
    mouseleave(evt: Event): void;
    mouseout(evt: Event): void;
    mouseover(evt: Event): void;
    mousewheel(evt: Event, x: number, y: number, delta: number): void;
    notify(eventName: string, ...notifyArgs: any[]): void;
    onSetTheme(oldTheme: string, newTheme: string): void;
    onRemove(): void;
    onRender(): void;
    pointerclick(evt: Event, x: number, y: number): void;
    pointerdblclick(evt: Event, x: number, y: number): void;
    pointerdown(evt: Event, x: number, y: number): void;
    pointermove(evt: Event, x: number, y: number): void;
    pointerup(evt: Event, x: number, y: number): void;
    remove(): this;
    removeThemeClassName(theme?: string): this;
    setInteractivity(value: any): void;
    setTheme(theme: string, options?: {
        override?: boolean;
    }): this;
}
export interface CellView extends CellViewGeneric<Cell> {
}
export interface ElementViewAttributes {
    style?: string;
    text?: string;
    html?: string;
    "ref-x"?: string | number;
    "ref-y"?: string | number;
    "ref-dx"?: number;
    "ref-dy"?: number;
    "ref-width"?: string | number;
    "ref-height"?: string | number;
    ref?: string;
    "x-alignment"?: 'middle' | 'right' | number;
    "y-alignment"?: 'middle' | 'bottom' | number;
    port?: string;
}
export interface ElementView extends CellViewGeneric<Element> {
    scale(sx: number, sy: number): void;
    finalizeEmbedding(options?: {
        model?: Model;
        paper?: Paper;
    }): void;
    getBBox(options?: {
        useModelGeometry?: boolean;
    }): BBox;
    mouseenter(evt: Event): void;
    mouseleave(evt: Event): void;
    pointerdown(evt: Event, x: number, y: number): void;
    pointermove(evt: Event, x: number, y: number): void;
    pointerup(evt: Event, x: number, y: number): void;
    positionRelative(vel: any, bbox: BBox, attributes: ElementViewAttributes, nodesBySelector?: any): void;
    prepareEmbedding(options?: {
        model?: Model;
        paper?: Paper;
    }): void;
    processEmbedding(options?: {
        model?: Model;
        paper?: Paper;
    }): void;
    renderMarkup(): void;
    resize(): void;
    resize(cell: any, changed: any, opt: any): void;
    rotate(): void;
    translate(): void;
    translate(model: Model, changes?: any, options?: any): void;
    update(cell: Cell, renderingOnlyAttrs?: any): void;
}
export interface LinkView extends CellViewGeneric<Link> {
    options: {
        shortLinkLength?: number;
        doubleLinkTools?: boolean;
        longLinkLength?: number;
        linkToolsOffset?: number;
        doubleLinkToolsOffset?: number;
        sampleInterval: number;
    };
    getConnectionLength(): number;
    sendToken(token: SVGElement, duration?: number, callback?: () => void): void;
    addVertex(vertex: Point): number;
    getPointAtLength(length: number): Point;
    createWatcher(endType: {
        id: string;
    }): (link: Link, end?: {
        id: string;
    }) => this;
    findRoute(oldVertices: Point[]): Point[];
    getConnectionPoint(end: 'source' | 'target', selectorOrPoint: Element | Point, referenceSelectorOrPoint: Element | Point): Point;
    getPathData(vertices: Point[]): string;
    mouseenter(evt: Event): void;
    mouseleave(evt: Event): void;
    onEndModelChange(endType: 'source' | 'target', endModel?: Element, opt?: {
        cacheOnly?: boolean;
        handleBy?: string;
        translateBy?: boolean;
        tx?: number;
        ty?: number;
    }): void;
    onLabelsChange(): void;
    onSourceChange(cell: Cell, sourceEnd: {
        id: string;
    }, options: any): void;
    onTargetChange(cell: Cell, targetEnd: {
        id: string;
    }, options: any): void;
    onToolsChange(): void;
    onVerticesChange(cell: Cell, changed: any, options: any): void;
    pointerdown(evt: Event, x: number, y: number): void;
    pointermove(evt: Event, x: number, y: number): void;
    pointerup(evt: Event, x: number, y: number): void;
    removeVertex(idx: number): this;
    renderArrowheadMarkers(): this;
    renderLabels(): this;
    renderTools(): this;
    renderVertexMarkers(): this;
    startArrowheadMove(end: 'source' | 'target', options?: {
        whenNotAllowed: 'remove' | 'revert';
    }): void;
    startListening(): void;
    update(model: Cell, attributes: any, options?: any): this;
    updateArrowheadMarkers(): this;
    updateAttributes(): void;
    updateConnection(options?: {
        translateBy?: any;
        tx?: number;
        ty?: number;
    }): void;
    updateLabelPositions(): this;
    updateToolsPosition(): this;
}
