var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, EventEmitter, Input, Output, ViewChild, ContentChildren, QueryList } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
//Bootstrap
import { ModalDirective } from 'ngx-bootstrap';
import { Context } from '../../core/services/context';
import { CatalogService } from '../../core/services/catalog.service';
import { CatalogInfo } from '../../core/models/catalog';
import { Deferred } from '../../core/deferred';
import { MenuItemDirective } from '../../controls/directives/menu-item.directive';
import { AlertsBarComponent } from '../../controls/components/alerts-bar.component';
var CatalogEditorComponent = /** @class */ (function () {
    function CatalogEditorComponent(router, route, context, catalogService) {
        this.router = router;
        this.route = route;
        this.context = context;
        this.catalogService = catalogService;
        this.readonlyMode = false;
        this.widthClass = [];
        this.canceled = false;
        this.defaultOptions = { codigoAutogenerado: false };
        this.enabled = true;
        this.dirty = false;
        //
        this.configureCatalog = new EventEmitter();
        this.creatingItem = new EventEmitter();
        this.viewingItem = new EventEmitter();
        this.loadingItem = new EventEmitter();
        this.cloningItem = new EventEmitter();
        this.savingItem = new EventEmitter();
        this.menuItemClick = new EventEmitter();
        this.cancelingEdit = new EventEmitter();
    }
    CatalogEditorComponent.prototype.ngOnInit = function () {
        //Establecer el ancho establecido para la aplicación
        this.widthClass.push(this.context.app.defaultWidth);
        //               
    };
    CatalogEditorComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        setTimeout(function (_) { return _this.loadConfiguration(); });
    };
    CatalogEditorComponent.prototype.loadConfiguration = function () {
        var _this = this;
        //Cargar configuración del catálogo
        this.context.app.showSpinner();
        this.catalogService.getOptions()
            .then(function (options) {
            if (options != null)
                _this.configureCatalog.emit(options);
            else {
                _this.configureCatalog.emit(_this.defaultOptions);
            }
            setTimeout(function (_) { return _this.triggerOperation(); });
            _this.context.app.hideSpinner();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    CatalogEditorComponent.prototype.triggerOperation = function () {
        var _this = this;
        //
        var cloneId = 0;
        this.route.params.forEach(function (params) {
            _this.identity = +params['id'];
            if (params['cloneId'])
                cloneId = +params['cloneId'];
            if (params['readonly'])
                _this.readonlyMode = params['readonly'] == "true" ? true : false;
        });
        //Si identity es mayor a cero, se solicitará carga de información. Si es cero, se creará un nuevo elemento
        if (this.identity > 0) {
            if (this.readonlyMode)
                this.viewingItem.emit(this.identity);
            else
                this.loadingItem.emit(this.identity);
        }
        else {
            //Determinar si el nuevo elemento será en blanco o se clonará de otro elemento
            if (cloneId == 0)
                this.creatingItem.emit();
            else
                this.cloningItem.emit(cloneId);
        }
    };
    CatalogEditorComponent.prototype.showAlert = function (message, type) {
        this.alerts.showAlert(message, type);
    };
    CatalogEditorComponent.prototype.confirmDiscardChanges = function () {
        this.discardDialog.config.backdrop = false;
        this.discardDialog.config.keyboard = false;
        this.discardDialog.config.ignoreBackdropClick = true;
        this.discardDialog.show();
        this.defDiscardChanges = new Deferred();
        return this.defDiscardChanges.promise;
    };
    CatalogEditorComponent.prototype.discardChanges = function () {
        this.defDiscardChanges.resolve(true);
        this.discardDialog.hide();
    };
    CatalogEditorComponent.prototype.cancelDiscard = function () {
        this.defDiscardChanges.resolve(false);
        this.discardDialog.hide();
    };
    CatalogEditorComponent.prototype.saveHandler = function () {
        this.onSaveItem(false);
    };
    CatalogEditorComponent.prototype.saveCloseHanlder = function () {
        this.onSaveItem(true);
    };
    CatalogEditorComponent.prototype.onSaveItem = function (closeEditor) {
        if (this.valid) {
            var args = { info: this.info, closeEditor: closeEditor };
            this.savingItem.emit(args);
        }
        else {
            this.showAlert("Uno o varios campos no cumplen con las validaciones", "danger");
        }
    };
    CatalogEditorComponent.prototype.reset = function () {
    };
    CatalogEditorComponent.prototype.closeEditor = function () {
        this.canceled = true;
        this.cancelingEdit.emit();
    };
    CatalogEditorComponent.prototype.onMenuItemClicked = function (menu, args) {
        var items = this.menuItems.toArray();
        var item = items[menu.selectedIndex];
        this.menuItemClick.emit(item);
    };
    CatalogEditorComponent.prototype.handleError = function (error) {
        this.context.app.hideSpinner();
    };
    __decorate([
        Input(),
        __metadata("design:type", CatalogInfo)
    ], CatalogEditorComponent.prototype, "info", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], CatalogEditorComponent.prototype, "title", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], CatalogEditorComponent.prototype, "valid", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], CatalogEditorComponent.prototype, "enabled", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], CatalogEditorComponent.prototype, "dirty", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogEditorComponent.prototype, "configureCatalog", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogEditorComponent.prototype, "creatingItem", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogEditorComponent.prototype, "viewingItem", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogEditorComponent.prototype, "loadingItem", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogEditorComponent.prototype, "cloningItem", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogEditorComponent.prototype, "savingItem", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogEditorComponent.prototype, "menuItemClick", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogEditorComponent.prototype, "cancelingEdit", void 0);
    __decorate([
        ContentChildren(MenuItemDirective),
        __metadata("design:type", QueryList)
    ], CatalogEditorComponent.prototype, "menuItems", void 0);
    __decorate([
        ViewChild(AlertsBarComponent),
        __metadata("design:type", AlertsBarComponent)
    ], CatalogEditorComponent.prototype, "alerts", void 0);
    __decorate([
        ViewChild('discardChangesDialog'),
        __metadata("design:type", ModalDirective)
    ], CatalogEditorComponent.prototype, "discardDialog", void 0);
    CatalogEditorComponent = __decorate([
        Component({
            selector: 'azteca-catalog-editor',
            template: "\n      <div class=\"row\">\n          <div [ngClass]=\"widthClass\">\n\n              <az-panel [header]=\"title\">\n            \n                  <!--Barra de alertas-->\n                  <alerts-bar></alerts-bar>\n\n                  <!--Toolbar-->\n                  <div class=\"btn-group\">\n                      <button type=\"submit\" class=\"btn btn-primary\" (click)=\"saveHandler()\" [disabled]=\"!valid\" *ngIf=\"enabled\">\n                          <span class=\"glyphicon glyphicon-floppy-disk\" aria-hidden=\"true\"></span> Guardar\n                      </button>\n                      <!--El boton de guardar y cerrar solo se mostrara en dispositivos grandes-->\n                      <button type=\"button\" class=\"btn btn-default d-none d-lg-block\" (click)=\"saveCloseHanlder()\" [disabled]=\"!valid\" *ngIf=\"enabled\">\n                          <span class=\"glyphicon glyphicon-floppy-remove\" aria-hidden=\"true\"></span> Guardar y cerrar\n                      </button>\n                      <!--En dispositivos peque\u00F1os se mostrar\u00E1 un bot\u00F3n con el \u00EDcono de cerrar, en dispositivos grandes se mostrar\u00E1 con texto-->\n                      <button type=\"button\" class=\"btn btn-default d-none d-lg-block cancel-win\" (click)=\"closeEditor()\">\n                          <span class=\"glyphicon glyphicon-remove\" aria-hidden=\"true\"></span> {{dirty ? 'Cancelar' : 'Cerrar'}}\n                      </button>\n                      <button type=\"button\" class=\"btn btn-default d-lg-none cancel-win\" title=\"Cerrar editor\" (click)=\"closeEditor()\">\n                          <span class=\"glyphicon glyphicon-remove\" aria-hidden=\"true\"></span>\n                      </button>\n\n                      <wj-menu #menu *ngIf=\"menuItems && menuItems.toArray().length > 0 && identity > 0\"\n                               (itemClicked)=\"onMenuItemClicked(menu, $event)\"\n                               [isDisabled]=\"!enabled\"\n                               [header]=\"'Opciones'\">\n\n                          <wj-menu-item *ngFor=\"let item of menuItems\">\n                              <div *ngIf=\"enabled && item.enabled\">\n                                  <span [class]=\"item.icon\"></span>\n                                  <b>{{item.text}}</b>\n                                  <br>\n                                  <small><i>{{item.smallText}}</i></small>\n                              </div>\n                          </wj-menu-item>\n                      </wj-menu>\n                  </div>\n\n                  <!--Controles del formulario-->\n                  <ng-content></ng-content>\n              </az-panel>\n\n          </div>\n      </div>\n\n\n      <div bsModal #discardChangesDialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"mySmallModalLabel\" aria-hidden=\"true\">\n          <div class=\"modal-dialog modal-sm\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-body\">\n                  <div>Existen cambios sin guardar. \u00BFDesea descartarlos?</div>\n                  </div> <!--Modal Body-->\n                  <div class=\"modal-footer\">\n                      <button type=\"button\" class=\"btn btn-primary\" (click)=\"cancelDiscard()\">Cancelar</button>\n                      <button type=\"button\" class=\"btn btn-default\" (click)=\"discardChanges()\">Descartar</button>\n                  </div> <!--Modal Footer-->\n              </div> <!-- Modal Content-->\n          </div> <!--Modal-->\n      </div> <!--Modal directive-->\n    "
        }),
        __metadata("design:paramtypes", [Router,
            ActivatedRoute,
            Context,
            CatalogService])
    ], CatalogEditorComponent);
    return CatalogEditorComponent;
}());
export { CatalogEditorComponent };
