var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, EventEmitter, Input, Output, ContentChildren, ViewChild, QueryList } from '@angular/core';
//
import { ModalDirective } from 'ngx-bootstrap';
//
import { Context } from '../../core/services/context';
import { CatalogService } from '../../core/services/catalog.service';
import { SearchRequest } from '../../search/models/search-request';
import { MenuItemDirective } from '../../controls/directives/menu-item.directive';
import { AlertsBarComponent } from '../../controls/components/alerts-bar.component';
import { GridColumn } from '../../controls/directives/grid-column';
var CatalogManagerComponent = /** @class */ (function () {
    function CatalogManagerComponent(context, catalogService) {
        this.context = context;
        this.catalogService = catalogService;
        this.menuItems = [];
        this.currentItem = null;
        this.widthClass = 'col-12';
        this.defaultOptions = { busquedasServidor: true, tamanioPagina: 10 };
        //
        this.pageSize = 10;
        this.pageIndex = 0;
        this.standAlone = true;
        this.catalogList = [];
        this.serverSide = true;
        this.enabled = true;
        this.allowNew = true;
        this.allowView = true;
        this.allowEdit = true;
        this.allowDelete = true;
        this.allowClone = true;
        this.allowChangeState = true;
        this.allowAudit = true;
        //
        this.configureCatalog = new EventEmitter();
        this.searchRequested = new EventEmitter();
        this.currentItemChanged = new EventEmitter();
        this.addingItem = new EventEmitter();
        this.viewingItem = new EventEmitter();
        this.editingItem = new EventEmitter();
        this.deletingItem = new EventEmitter();
        this.cloningItem = new EventEmitter();
        this.changingItemState = new EventEmitter();
        this.menuItemClick = new EventEmitter();
        this.createMenu();
    }
    CatalogManagerComponent.prototype.ngOnInit = function () {
        if (this.standAlone) {
            this.widthClass = this.context.app.defaultWidth;
        }
    };
    CatalogManagerComponent.prototype.ngOnChanges = function (changes) {
        if (changes['allowView']) {
            this.setMenuItemState("OPEN", this.allowView);
        }
        if (changes['allowEdit']) {
            this.setMenuItemState("EDIT", this.allowEdit);
        }
        if (changes['allowDelete']) {
            this.setMenuItemState("DELETE", this.allowDelete);
        }
        if (changes['allowClone']) {
            this.setMenuItemState("CLONE", this.allowClone);
        }
        if (changes['changeState']) {
            this.setMenuItemState("STATE", this.allowChangeState);
        }
        if (changes['allowAudit']) {
            this.setMenuItemState("AUDIT", this.allowAudit);
        }
    };
    CatalogManagerComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        //Agregar elementos personalizados y suscribir a cambios en coleccion de opciones personalizadas
        setTimeout(function (_) { return _this.updateCustomMenuItems(); });
        this.customMenuItems.changes.subscribe(function (_) {
            setTimeout(function (_) { return _this.updateCustomMenuItems(); });
        });
        setTimeout(function (_) { return _this.loadConfiguration(); });
    };
    CatalogManagerComponent.prototype.loadConfiguration = function () {
        var _this = this;
        //Cargar configuración del catálogo
        this.context.app.showSpinner();
        this.catalogService.getOptions()
            .then(function (options) {
            if (options != null) {
                _this.options = options;
                _this.configureCatalog.emit(options);
            }
            else {
                _this.configureCatalog.emit(_this.defaultOptions);
            }
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    CatalogManagerComponent.prototype.triggerSearch = function () {
        //Disparar búsqueda inicial. Si el manejo se realiza del lado del servidor, obtener sólo la primer página, si es local obtener toda la información disponible
        var request = new SearchRequest();
        request.pageIndex = 0;
        request.pageSize = this.pageSize;
        request.paged = this.serverSide ? true : false;
        //
        this.searchRequested.emit(request);
    };
    CatalogManagerComponent.prototype.showAlert = function (message, type) {
        this.alerts.showAlert(message, type);
    };
    CatalogManagerComponent.prototype.searchRequestedHandler = function (request) {
        //Redireccionar request a componente padre
        this.searchRequested.emit(request);
    };
    CatalogManagerComponent.prototype.isMenuItemEnabled = function (tag) {
        var item = this.getMenuItem(tag);
        if (item != null)
            return item.enabled;
        else
            return false;
    };
    CatalogManagerComponent.prototype.setMenuItemState = function (tag, enabled) {
        var item = this.getMenuItem(tag);
        if (item != null)
            item.enabled = enabled;
    };
    CatalogManagerComponent.prototype.getMenuItem = function (name) {
        var retItem = null;
        this.menuItems.forEach(function (item) {
            if (item.name == name) {
                retItem = item;
            }
        });
        return retItem;
    };
    CatalogManagerComponent.prototype.createMenu = function () {
        //Agregar opciones estándar del catálogo
        var mnuView = { icon: "glyphicon glyphicon-folder-open", text: "Ver", name: "OPEN", smallText: "abrir en modo de sólo lectura" };
        var mnuEdit = { icon: "glyphicon glyphicon-pencil", text: "Editar", name: "EDIT", smallText: "abrir en modo de edición" };
        var mnuState = { icon: "glyphicon glyphicon-lock", text: "Activar/Desactivar", name: "STATE", smallText: "cambiar estatus" };
        var mnuCopy = { icon: "glyphicon glyphicon-duplicate", text: "Duplicar", name: "CLONE", smallText: "crear una copia" };
        var mnuDelete = { icon: "glyphicon glyphicon-trash", text: "Eliminar", name: "DELETE", smallText: "eliminar permanentemente" };
        var mnuAudit = { icon: "glyphicon glyphicon-search", text: "Auditar", name: "AUDIT", smallText: "auditar cambios" };
        this.menuItems.push(mnuView, mnuEdit, mnuState, mnuCopy, mnuDelete, mnuAudit);
        //
        this.menuItems.forEach(function (item) {
            if (item.enabled == undefined)
                item.enabled = true;
        });
    };
    CatalogManagerComponent.prototype.updateCustomMenuItems = function () {
        var _this = this;
        var customOptions = this.customMenuItems.toArray();
        var newItems = customOptions.filter(function (option) { return !_this.menuItems.find(function (item) { return item.name == option.name; }); });
        this.menuItems = this.menuItems.concat(newItems);
        this.menuItems.forEach(function (item) {
            if (item.enabled == undefined)
                item.enabled = true;
        });
    };
    CatalogManagerComponent.prototype.onValidateMenu = function (item) {
        if (item) {
            //Cambiar texto de opción para activar o desactivar registros
            var mnuState = this.menuItems.filter(function (item) { return item.name == "STATE"; })[0];
            if (item.activo) {
                mnuState.text = "Desactivar";
            }
            else {
                mnuState.text = "Activar";
            }
        }
    };
    CatalogManagerComponent.prototype.currentItemChangedHandler = function (item) {
        var _this = this;
        this.currentItem = item;
        this.currentItemChanged.emit(item);
        if (item.data.idAccion >= 0 && this.options) {
            // Ocultamos todas las accones 
            this.menuItems.forEach(function (item) {
                if (item['accion'])
                    item.enabled = false;
            });
            var items_1 = [];
            if (item.data.idAccion == 0) {
                this.options.acciones.forEach(function (accion) {
                    if (accion.isIni === true) {
                        var mnuItem = { icon: accion.icon, text: accion.actionText, name: accion.tag, smallText: accion.actionText };
                        mnuItem['accion'] = true;
                        items_1.push(mnuItem);
                    }
                });
            }
            else {
                var childs_1 = [];
                this.options.accionesFlow.forEach(function (accion) {
                    if (item.data.idAccion === accion.idAccion) {
                        childs_1.push(accion.idAccionChild);
                    }
                });
                childs_1.forEach(function (idAccion) {
                    _this.options.acciones.forEach(function (accion) {
                        if (accion.idAccion === idAccion) {
                            var mnuItem = { icon: accion.icon, text: accion.actionText, name: accion.tag, smallText: accion.actionText };
                            mnuItem['accion'] = true;
                            items_1.push(mnuItem);
                        }
                    });
                });
            }
            var newItems = items_1.filter(function (option) { return !_this.menuItems.find(function (newItem) { return newItem.name == option.name; }); });
            this.menuItems = this.menuItems.concat(newItems);
            var accionItems = this.menuItems.filter(function (option) { return items_1.find(function (newItem) { return newItem.name == option.name; }); });
            accionItems.forEach(function (newItem) {
                newItem.enabled = true;
            });
        }
    };
    CatalogManagerComponent.prototype.onMenuItemClicked = function (menu, args) {
        var item = this.menuItems[menu.selectedIndex];
        this.optionClick(item);
    };
    CatalogManagerComponent.prototype.onIsDroppedDown = function (menu, args) {
        this.onValidateMenu(this.currentItem);
    };
    CatalogManagerComponent.prototype.deleteItem = function () {
        this.deletingItem.emit(this.currentItem);
        this.deleteDialog.hide();
    };
    CatalogManagerComponent.prototype.hideDeleteDialog = function () {
        this.deleteDialog.hide();
    };
    CatalogManagerComponent.prototype.onItemSelected = function (item) {
        if (this.allowEdit) {
            this.editingItem.emit(this.currentItem);
        }
        else if (this.allowView) {
            this.viewingItem.emit(this.currentItem);
        }
    };
    CatalogManagerComponent.prototype.optionClick = function (option) {
        if (option.name == "OPEN")
            this.viewingItem.emit(this.currentItem);
        if (option.name == "EDIT")
            this.editingItem.emit(this.currentItem);
        if (option.name == "DELETE") {
            this.deleteDialog.config.backdrop = false;
            this.deleteDialog.show();
        }
        if (option.name == "CLONE")
            this.cloningItem.emit(this.currentItem);
        if (option.name == "STATE")
            this.changingItemState.emit(this.currentItem);
        //Disparar evento genérico con cualquier opción de menú, principalmente dirigido a notificar acciones personalizadas
        if (this.options.acciones) {
            var accion = this.options.acciones.find(function (item) { return item.tag == option.name; });
            if (accion) {
                option.accion = true;
            }
        }
        this.menuItemClick.emit(option);
    };
    CatalogManagerComponent.prototype.newItemHandler = function () {
        this.addingItem.emit();
    };
    CatalogManagerComponent.prototype.handleError = function (error) {
        this.context.app.hideSpinner();
    };
    __decorate([
        ContentChildren(GridColumn),
        __metadata("design:type", QueryList)
    ], CatalogManagerComponent.prototype, "columns", void 0);
    __decorate([
        ViewChild('confirmDelDialog'),
        __metadata("design:type", ModalDirective)
    ], CatalogManagerComponent.prototype, "deleteDialog", void 0);
    __decorate([
        ContentChildren(MenuItemDirective),
        __metadata("design:type", QueryList)
    ], CatalogManagerComponent.prototype, "customMenuItems", void 0);
    __decorate([
        ViewChild(AlertsBarComponent),
        __metadata("design:type", AlertsBarComponent)
    ], CatalogManagerComponent.prototype, "alerts", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], CatalogManagerComponent.prototype, "pageSize", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], CatalogManagerComponent.prototype, "pageIndex", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], CatalogManagerComponent.prototype, "totalRows", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], CatalogManagerComponent.prototype, "standAlone", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], CatalogManagerComponent.prototype, "catalogList", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], CatalogManagerComponent.prototype, "serverSide", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], CatalogManagerComponent.prototype, "enabled", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], CatalogManagerComponent.prototype, "allowNew", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], CatalogManagerComponent.prototype, "allowView", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], CatalogManagerComponent.prototype, "allowEdit", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], CatalogManagerComponent.prototype, "allowDelete", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], CatalogManagerComponent.prototype, "allowClone", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], CatalogManagerComponent.prototype, "allowChangeState", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], CatalogManagerComponent.prototype, "allowAudit", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogManagerComponent.prototype, "configureCatalog", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogManagerComponent.prototype, "searchRequested", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogManagerComponent.prototype, "currentItemChanged", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogManagerComponent.prototype, "addingItem", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogManagerComponent.prototype, "viewingItem", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogManagerComponent.prototype, "editingItem", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogManagerComponent.prototype, "deletingItem", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogManagerComponent.prototype, "cloningItem", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogManagerComponent.prototype, "changingItemState", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogManagerComponent.prototype, "menuItemClick", void 0);
    CatalogManagerComponent = __decorate([
        Component({
            selector: 'azteca-catalog-manager',
            template: "\n      <!--Barra de alertas-->\n      <alerts-bar></alerts-bar>\n\n      <div class=\"row\">\n          <div [ngClass]=\"{'col-12 col-lg-10': standAlone}\">\n\n              <div class=\"btn-group btn-module-primary\">\n                  <button type=\"button\" class=\"btn btn-primary\" (click)=\"newItemHandler()\" *ngIf=\"enabled && allowNew\">\n                      <span class=\"glyphicon glyphicon-plus\" aria-hidden=\"true\"></span> Nuevo\n                  </button>\n                  <!--Ocultar boton de actualizacion en dispositivos peque\u00F1os-->\n                  <button type=\"button\" class=\"btn btn-default d-none d-md-block\" (click)=\"triggerSearch()\">\n                      <span class=\"glyphicon glyphicon-refresh\" aria-hidden=\"true\"></span> Actualizar\n                  </button>\n                  <wj-menu #menu\n                           class=\"btn btn-default\"\n                           (itemClicked)=\"onMenuItemClicked(menu, $event)\"\n                           (isDroppedDownChanging)=\"onIsDroppedDown(menu, $event)\"\n                           [isDisabled]=\"!enabled\"\n                           [header]=\"'Opciones'\">\n\n                      <wj-menu-item *ngFor=\"let item of menuItems\">\n                          <div *ngIf=\"enabled && item.enabled\">\n                              <span [class]=\"item.icon\"></span>\n                              <b>{{item.text}}</b>\n                              <br>\n                              <small><i>{{item.smallText}}</i></small>\n                          </div>\n                      </wj-menu-item>\n\n                  </wj-menu>\n\n              </div>\n          </div>\n      </div>\n\n      <div class=\"row\">\n          <div [class]=\"widthClass\">\n\n              <azteca-catalog-list [catalogList]=\"catalogList\"\n                                   (searchRequested)=\"searchRequestedHandler($event)\"\n                                   (currentItemChanged)=\"currentItemChangedHandler($event)\"\n                                   (contextMenuClick)=\"optionClick($event)\"\n                                   (contextMenuOpen)=\"onValidateMenu($event)\"\n                                   (itemSelected)=\"onItemSelected($event)\"\n                                   [enabled]=\"enabled\"\n                                   [serverSide]=\"serverSide\"\n                                   [pageSize]=\"pageSize\"\n                                   [totalRows]=\"totalRows\"\n                                   [pageIndex]=\"pageIndex\">\n\n                  <!-- Mapear opciones de men\u00FA de componente padre-->\n                  <azteca-menu-item *ngFor=\"let item of menuItems\" [name]=\"item.name\" [icon]=\"item.icon\" [text]=\"item.text\" [smallText]=\"item.smallText\" [enabled]=\"item.enabled\"></azteca-menu-item>\n\n                  <!-- Mapear columnas definidas en componente padre-->\n                  <azteca-grid-column *ngFor=\"let col of columns\"\n                                      [header]=\"col.header\"\n                                      [binding]=\"col.binding\"\n                                      [dataType]=\"col.dataType ? col.dataType :'String'\"\n                                      [dataMap]=\"col.dataMap\"\n                                      [format]=\"col.format\"\n                                      [width]=\"col.width\">\n\n                      <!-- Add cell template if col.cellTemplate is specified. -->\n                      <ng-template wjFlexGridCellTemplate *ngIf=\"col.cellTemplate\" [cellType]=\"'Cell'\" let-cell=\"cell\">\n                          <!-- Load the component whose type is specified in col.cellTemplate -->\n                          <wj-component-loader [component]=\"col.cellTemplate\" [properties]=\"{cell: cell}\"></wj-component-loader>\n                      </ng-template>\n\n                  </azteca-grid-column>\n\n              </azteca-catalog-list>\n          </div>\n      </div>\n\n\n      <!--DIALOGO DE ELIMINACI\u00D3N-->\n      <div bsModal #confirmDelDialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"mySmallModalLabel\" aria-hidden=\"true\">\n\n          <div class=\"modal-dialog modal-sm\">\n              <div class=\"modal-content\">\n\n                  <div class=\"modal-body\">\n                      <div>\u00BFEst\u00E1 seguro que desea eliminar el elemento seleccionado?</div>\n                  </div>\n                  <div class=\"modal-footer\">\n                      <button type=\"button\" class=\"btn btn-primary\" (click)=\"hideDeleteDialog()\">Cancelar</button>\n                      <button type=\"button\" class=\"btn btn-default\" (click)=\"deleteItem()\">Aceptar</button>\n                  </div>\n\n              </div>\n          </div>\n\n      </div>\n    ",
        }),
        __metadata("design:paramtypes", [Context, CatalogService])
    ], CatalogManagerComponent);
    return CatalogManagerComponent;
}());
export { CatalogManagerComponent };
