var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, EventEmitter, Input, Output, ViewChild, ContentChildren, QueryList } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
//Bootstrap
import { ModalDirective } from 'ngx-bootstrap';
import { Context } from '../../core/services/context';
import { DocumentService } from '../../core/services/document.service';
import { Deferred } from '../../core/deferred';
import { DocumentInfo, DocumentItem } from '../../core/models/document';
import { DocumentStatus } from '../../core/models/document-status';
import { MenuItemDirective } from '../../controls/directives/menu-item.directive';
import { AlertsBarComponent } from '../../controls/components/alerts-bar.component';
var DocumentEditorComponent = /** @class */ (function () {
    function DocumentEditorComponent(router, route, context, documentService) {
        this.router = router;
        this.route = route;
        this.context = context;
        this.documentService = documentService;
        this.readonlyMode = false;
        this.widthClass = [];
        this.canceled = false;
        this.stepOptions = [];
        this.isHeaderCollapsed = true;
        this.enabled = true;
        this.dirty = false;
        //
        this.configureDocument = new EventEmitter();
        this.creatingDocument = new EventEmitter();
        this.viewingDocument = new EventEmitter();
        this.loadingDocument = new EventEmitter();
        this.cloningDocument = new EventEmitter();
        this.savingDocument = new EventEmitter();
        this.applyingNextStep = new EventEmitter();
        this.applyingPreviousStep = new EventEmitter();
        this.menuItemClick = new EventEmitter();
        this.cancelingEdit = new EventEmitter();
        this.validatingMenu = new EventEmitter();
    }
    DocumentEditorComponent.prototype.ngOnInit = function () {
        //Establecer el ancho establecido para la aplicación
        this.widthClass.push(this.context.app.defaultWidth);
        //               
    };
    DocumentEditorComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        setTimeout(function (_) { return _this.loadConfiguration(); });
        setTimeout(function (_) { return _this.triggerOperation(); });
    };
    DocumentEditorComponent.prototype.loadConfiguration = function () {
        var _this = this;
        this.context.app.showSpinner();
        this.documentService.getDocumentType()
            .then(function (docType) {
            _this.documentType = docType;
            _this.configureDocument.emit(docType);
            _this.context.app.hideSpinner();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    DocumentEditorComponent.prototype.triggerOperation = function () {
        var _this = this;
        //
        var cloneId = '';
        this.route.params.forEach(function (params) {
            _this.identity = params['id'];
            if (params['cloneId'])
                cloneId = params['cloneId'];
            if (params['readonly'])
                _this.readonlyMode = params['readonly'] == "true" ? true : false;
        });
        //Si identity tiene contenido, se solicitará carga de información. Si es cero, se creará un nuevo elemento
        if (this.identity && this.identity != '0') {
            if (this.readonlyMode)
                this.viewingDocument.emit(this.identity);
            else
                this.loadingDocument.emit(this.identity);
        }
        else {
            //Determinar si el nuevo elemento será en blanco o se clonará de otro elemento
            if (!cloneId || cloneId == '0')
                this.creatingDocument.emit();
            else
                this.cloningDocument.emit(cloneId);
        }
    };
    DocumentEditorComponent.prototype.nextStep = function () {
        var _this = this;
        //Si el documento se encuentra en borrador, determinar el primer paso del documento
        if (this.document.status == DocumentStatus.DRAFT) {
            //Si no esta definido el paso inicial, mostrar mensaje a usuario
            if (this.documentType.startStep) {
                var args = { document: this.getDocumentItem(), step: this.documentType.startStep };
                this.applyingNextStep.emit(args);
            }
            else {
                this.showAlert('El documento no tiene definido un flujo de trabajo.', 'warning');
            }
        }
        //Si el documento se encuentra activo, determinar el proximo paso
        else if (this.document.status == DocumentStatus.ACTIVE) {
            var step = this.documentType.workflowSteps.find(function (s) { return s.idWorkflowStep == _this.document.currentStep.idWorkflowStep; });
            //Si el paso actual tiene bifuraciones, preguntar al usuario
            if (step.hasOptions) {
                this.stepOptions = step.options;
                this.optionsDialog.config.backdrop = false;
                this.optionsDialog.show();
            }
            //Si el paso actual tiene ligado el siguiente paso directamente
            else if (step.nextStep) {
                this.confirmNextStepDialog.config.backdrop = false;
                this.confirmNextStepDialog.show();
            }
            //Si ya no hay un siguiente paso
            else {
                this.showAlert('El documento se encuentra en el último paso del flujo de trabajo', 'info');
            }
        }
    };
    DocumentEditorComponent.prototype.previousStep = function () {
        this.confirmPrevioustStepDialog.config.backdrop = false;
        this.confirmPrevioustStepDialog.show();
    };
    DocumentEditorComponent.prototype.onConfirmNextStep = function () {
        var _this = this;
        this.confirmNextStepDialog.hide();
        var step = this.documentType.workflowSteps.find(function (s) { return s.idWorkflowStep == _this.document.currentStep.idWorkflowStep; });
        var args = { document: this.getDocumentItem(), step: step.nextStep };
        this.applyingNextStep.emit(args);
    };
    DocumentEditorComponent.prototype.onConfirmPreviousStep = function () {
        this.confirmPrevioustStepDialog.hide();
        var docItem = this.getDocumentItem();
        this.applyingPreviousStep.emit(docItem);
    };
    DocumentEditorComponent.prototype.onWorkflowOptionSelected = function (option) {
        this.optionsDialog.hide();
        var args = { document: this.getDocumentItem(), step: option.nextStep };
        this.applyingNextStep.emit(args);
    };
    DocumentEditorComponent.prototype.showAlert = function (message, type) {
        this.alerts.showAlert(message, type);
    };
    DocumentEditorComponent.prototype.confirmDiscardChanges = function () {
        this.discardDialog.config.backdrop = false;
        this.discardDialog.show();
        this.defDiscardChanges = new Deferred();
        return this.defDiscardChanges.promise;
    };
    DocumentEditorComponent.prototype.discardChanges = function () {
        this.defDiscardChanges.resolve(true);
        this.discardDialog.hide();
    };
    DocumentEditorComponent.prototype.cancelDiscard = function () {
        this.defDiscardChanges.resolve(false);
        this.discardDialog.hide();
    };
    DocumentEditorComponent.prototype.getDocumentItem = function () {
        var docItem = new DocumentItem();
        docItem.id = this.document.identity;
        docItem.fechaCreacion = this.document.fechaCreacion;
        docItem.idStatus = this.document.status;
        docItem.idWorkflowStep = this.document.currentStep ? this.document.currentStep.idWorkflowStep : 0;
        return docItem;
    };
    DocumentEditorComponent.prototype.saveHandler = function () {
        this.onSaveItem(false);
    };
    DocumentEditorComponent.prototype.saveCloseHanlder = function () {
        this.onSaveItem(true);
    };
    DocumentEditorComponent.prototype.onSaveItem = function (closeEditor) {
        if (this.valid) {
            var args = { info: this.document, closeEditor: closeEditor };
            this.savingDocument.emit(args);
        }
        else {
            this.showAlert("Uno o varios campos no cumplen con las validaciones", "danger");
        }
    };
    DocumentEditorComponent.prototype.reset = function () {
    };
    DocumentEditorComponent.prototype.closeEditor = function () {
        this.canceled = true;
        this.cancelingEdit.emit();
    };
    DocumentEditorComponent.prototype.onMenuItemClicked = function (menu, args) {
        var items = this.menuItems.toArray();
        var item = items[menu.selectedIndex];
        this.menuItemClick.emit(item);
    };
    DocumentEditorComponent.prototype.handleError = function (error) {
        this.context.app.hideSpinner();
    };
    __decorate([
        Input(),
        __metadata("design:type", DocumentInfo)
    ], DocumentEditorComponent.prototype, "document", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], DocumentEditorComponent.prototype, "title", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], DocumentEditorComponent.prototype, "valid", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], DocumentEditorComponent.prototype, "enabled", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], DocumentEditorComponent.prototype, "dirty", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], DocumentEditorComponent.prototype, "configureDocument", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], DocumentEditorComponent.prototype, "creatingDocument", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], DocumentEditorComponent.prototype, "viewingDocument", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], DocumentEditorComponent.prototype, "loadingDocument", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], DocumentEditorComponent.prototype, "cloningDocument", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], DocumentEditorComponent.prototype, "savingDocument", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], DocumentEditorComponent.prototype, "applyingNextStep", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], DocumentEditorComponent.prototype, "applyingPreviousStep", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], DocumentEditorComponent.prototype, "menuItemClick", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], DocumentEditorComponent.prototype, "cancelingEdit", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], DocumentEditorComponent.prototype, "validatingMenu", void 0);
    __decorate([
        ContentChildren(MenuItemDirective),
        __metadata("design:type", QueryList)
    ], DocumentEditorComponent.prototype, "menuItems", void 0);
    __decorate([
        ViewChild(AlertsBarComponent),
        __metadata("design:type", AlertsBarComponent)
    ], DocumentEditorComponent.prototype, "alerts", void 0);
    __decorate([
        ViewChild('discardChangesDialog'),
        __metadata("design:type", ModalDirective)
    ], DocumentEditorComponent.prototype, "discardDialog", void 0);
    __decorate([
        ViewChild('optionsDialog'),
        __metadata("design:type", ModalDirective)
    ], DocumentEditorComponent.prototype, "optionsDialog", void 0);
    __decorate([
        ViewChild('confirmNextStepDialog'),
        __metadata("design:type", ModalDirective)
    ], DocumentEditorComponent.prototype, "confirmNextStepDialog", void 0);
    __decorate([
        ViewChild('confirmPrevioustStepDialog'),
        __metadata("design:type", ModalDirective)
    ], DocumentEditorComponent.prototype, "confirmPrevioustStepDialog", void 0);
    DocumentEditorComponent = __decorate([
        Component({
            selector: 'azteca-document-editor',
            template: "\n      <div class=\"row\">\n          <div [ngClass]=\"widthClass\">\n\n              <az-panel [header]=\"title\">\n\n                  <!--Barra de alertas-->\n                  <alerts-bar></alerts-bar>\n\n                  <!--Toolbar-->\n                  <div class=\"btn-group\">\n                      <!--GUARDAR-->\n                      <button type=\"submit\" class=\"btn btn-primary\" (click)=\"saveHandler()\" [disabled]=\"!valid\" *ngIf=\"enabled\">\n                          <span class=\"glyphicon glyphicon-floppy-disk\" aria-hidden=\"true\"></span> Guardar\n                      </button>\n                      <!--GUARDAR Y CERRAR-->\n                      <button type=\"button\" class=\"btn btn-default d-none d-lg-block\" (click)=\"saveCloseHanlder()\" [disabled]=\"!valid\" *ngIf=\"enabled\">\n                          <span class=\"glyphicon glyphicon-floppy-remove\" aria-hidden=\"true\"></span> Guardar y cerrar\n                      </button>\n\n                      <!--SIGUIENTE-->\n                      <button *ngIf=\"document.identity != '' && document.status > 0\" type=\"button\" class=\"btn btn-default d-none d-lg-block\" (click)=\"nextStep()\">\n                          <span class=\"glyphicon glyphicon-arrow-right\" aria-hidden=\"true\"></span> Continuar\n                      </button>\n                      <button *ngIf=\"document.identity != '' && document.status > 0\" type=\"button\" class=\"btn btn-default d-lg-none\" title=\"Ir al siguiente paso\" (click)=\"nextStep()\">\n                          <span class=\"glyphicon glyphicon-arrow-right\" aria-hidden=\"true\"></span>\n                      </button>\n\n                      <!--ANTERIOR-->\n                      <button *ngIf=\"document.status == 2\" type=\"button\" class=\"btn btn-default d-none d-lg-block\" (click)=\"previousStep()\">\n                          <span class=\"glyphicon glyphicon-arrow-left\" aria-hidden=\"true\"></span> Retroceder\n                      </button>\n                      <button *ngIf=\"document.status == 2\" type=\"button\" class=\"btn btn-default d-lg-none\" title=\"Regresar al paso anterior\" (click)=\"previousStep()\">\n                          <span class=\"glyphicon glyphicon-arrow-left\" aria-hidden=\"true\"></span>\n                      </button>\n\n                      <!--CERRAR EDITOR-->\n                      <button type=\"button\" class=\"btn btn-default d-none d-lg-block cancel-win\" (click)=\"closeEditor()\">\n                          <span class=\"glyphicon glyphicon-remove\" aria-hidden=\"true\"></span> {{dirty ? 'Cancelar' : 'Cerrar'}}\n                      </button>\n                      <button type=\"button\" class=\"btn btn-default d-lg-none cancel-win\" title=\"Cerrar editor\" (click)=\"closeEditor()\">\n                          <span class=\"glyphicon glyphicon-remove\" aria-hidden=\"true\"></span>\n                      </button>\n\n                      <!--OPCIONES-->\n                      <wj-menu #menu *ngIf=\"menuItems && menuItems.toArray().length > 0 && identity > 0\"\n                               (itemClicked)=\"onMenuItemClicked(menu, $event)\"\n                               [isDisabled]=\"!enabled\"\n                               [header]=\"'Opciones'\">\n\n                          <wj-menu-item *ngFor=\"let item of menuItems\">\n                              <div *ngIf=\"enabled && item.enabled\">\n                                  <span [class]=\"item.icon\"></span>\n                                  <b>{{item.text}}</b>\n                                  <br>\n                                  <small><i>{{item.smallText}}</i></small>\n                              </div>\n                          </wj-menu-item>\n                      </wj-menu>\n                  </div>\n\n                  <!-- Encabezado del documento-->\n                  <div class=\"card card-outline-info\">\n                      <div class=\"card-header\">\n                          <h6 class=\"modal-title pull-left\">Folio: {{document.identity}}</h6>\n                          <button type=\"button\" class=\"btn btn-default pull-right\" [title]=\"(isHeaderCollapsed ? 'Mostrar' : 'Ocultar') + ' detalle del documento'\" (click)=\"isHeaderCollapsed=!isHeaderCollapsed\">\n                              <span [class]=\"isHeaderCollapsed ? 'glyphicon glyphicon-chevron-down': 'glyphicon glyphicon-chevron-up'\"></span>\n                          </button>\n                      </div>\n                      <div class=\"card-body\" [collapse]=\"isHeaderCollapsed\">\n                          <div class=\"row\">\n                              <div class=\"col-12 col-md-6 col-lg-4\">\n                                  <label class=\"form-control-label\">Fecha de captura:</label>\n                                  <az-label [text]=\"document.fechaCreacion | dateFormat:'DD/MM/YYYY HH:mm'\"></az-label>\n                              </div>\n                              <div class=\"col-12 col-md-6 col-lg-4\">\n                                  <label class=\"form-control-label\">Estatus:</label>\n                                  <az-label [text]=\"document.statusDescription\"></az-label>\n                              </div>\n                              <div class=\"col-12 col-md-6 col-lg-4\">\n                                  <label class=\"form-control-label\">Paso del flujo:</label>\n                                  <az-label [text]=\"document.currentStep ? document.currentStep.statusText : 'N/A' \"></az-label>\n                              </div>\n                          </div>\n                      </div>\n                  </div>\n\n                  <!--Controles del formulario-->\n                  <ng-content></ng-content>\n              </az-panel>\n\n          </div>\n      </div>\n\n      <!--DIALOGO DE CAMBIOS SIN GUARDAR-->\n      <div bsModal #discardChangesDialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"mySmallModalLabel\" aria-hidden=\"true\">\n          <div class=\"modal-dialog modal-sm\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-body\">\n                      <div>Existen cambios sin guardar. \u00BFDesea descartarlos?</div>\n                  </div> <!--Modal Body-->\n                  <div class=\"modal-footer\">\n                      <button type=\"button\" class=\"btn btn-primary\" (click)=\"cancelDiscard()\">Cancelar</button>\n                      <button type=\"button\" class=\"btn btn-default\" (click)=\"discardChanges()\">Descartar</button>\n                  </div> <!--Modal Footer-->\n              </div> <!-- Modal Content-->\n          </div> <!--Modal-->\n      </div> <!--Modal directive-->\n\n\n      <!--DIALOGO DE BIFURCACIONES-->\n      <div bsModal #optionsDialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"mySmallModalLabel\" aria-hidden=\"true\">\n          <div class=\"modal-dialog modal-sm\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-header\">\n                      <h5>Elegir el siguiente paso</h5>\n                  </div>\n                  <div class=\"modal-body\">\n                      <ul class=\"list-group\">\n                          <button *ngFor=\"let option of stepOptions\" class=\"list-group-item list-group-item-action\" (click)=\"onWorkflowOptionSelected(option)\">\n                              <span class=\"glyphicon glyphicon-arrow-right\" style=\"margin-right:5px;\"></span>{{option.text}}\n                          </button>\n                      </ul>\n                  </div> <!--Modal Body-->\n                  <div class=\"modal-footer\">\n                      <button type=\"button\" class=\"btn btn-danger\" (click)=\"optionsDialog.hide()\">Cancelar</button>\n                  </div> <!--Modal Footer-->\n\n              </div> <!-- Modal Content-->\n          </div> <!--Modal-->\n      </div> <!--Modal directive-->\n\n\n      <!--DIALOGO DE CONFIRMACION NEXT STEP-->\n      <div bsModal #confirmNextStepDialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"mySmallModalLabel\" aria-hidden=\"true\">\n          <div class=\"modal-dialog modal-sm\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-body\">\n                      <h5>\u00BFEst\u00E1 seguro que desea ir al siguiente paso?</h5>\n                  </div> <!--Modal Body-->\n                  <div class=\"modal-footer\">\n                      <button type=\"button\" class=\"btn btn-primary\" (click)=\"onConfirmNextStep()\">Aceptar</button>\n                      <button type=\"button\" class=\"btn btn-danger\" (click)=\"confirmNextStepDialog.hide()\">Cancelar</button>\n                  </div> <!--Modal Footer-->\n\n              </div> <!-- Modal Content-->\n          </div> <!--Modal-->\n      </div> <!--Modal directive-->\n\n      <!--DIALOGO DE CONFIRMACION PREVIOUS STEP-->\n\n      <div bsModal #confirmPrevioustStepDialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"mySmallModalLabel\" aria-hidden=\"true\">\n          <div class=\"modal-dialog modal-sm\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-body\">\n                      <h5>\u00BFEst\u00E1 seguro que desea regresar al paso anterior?</h5>\n                  </div> <!--Modal Body-->\n                  <div class=\"modal-footer\">\n                      <button type=\"button\" class=\"btn btn-primary\" (click)=\"onConfirmPreviousStep()\">Aceptar</button>\n                      <button type=\"button\" class=\"btn btn-danger\" (click)=\"confirmPrevioustStepDialog.hide()\">Cancelar</button>\n                  </div> <!--Modal Footer-->\n\n              </div> <!-- Modal Content-->\n          </div> <!--Modal-->\n      </div> <!--Modal directive-->\n    "
        }),
        __metadata("design:paramtypes", [Router,
            ActivatedRoute,
            Context,
            DocumentService])
    ], DocumentEditorComponent);
    return DocumentEditorComponent;
}());
export { DocumentEditorComponent };
