import { EventEmitter, QueryList } from '@angular/core';
import { FormGroup, FormBuilder } from '@angular/forms';
import { ModalDirective } from 'ngx-bootstrap';
import { Menu } from 'wijmo/wijmo.input';
import { Context } from '../../core/services/context';
import { DocumentService } from '../../core/services/document.service';
import { DocumentInfo, DocumentItem } from '../../core/models/document';
import { DocumentDetail } from '../../core/models/document-detail';
import { DocumentTypeInfo } from '../../core/models/document-type';
import { WorkflowOption } from '../../core/models/workflow-option';
import { SearchRequest } from '../../search/models/search-request';
import { FilterGroup } from '../../search/models/filter-group';
import { DocumentListComponent } from '../../search/components/document-list.component';
import { MenuItem } from '../../controls/models/menu-item';
import { MenuItemDirective } from '../../controls/directives/menu-item.directive';
import { GridColumn } from '../../controls/directives/grid-column';
import { Alert } from '../../controls/models/alert';
import { AlertsBarComponent } from '../../controls/components/alerts-bar.component';
import { ToolbarButton } from '../../controls/models/toolbar-button';
import { WorkflowEventArgs } from '../models/workflow-event-args';
export declare class DocumentManagerComponent {
    private context;
    private documentService;
    private formBuilder;
    form: FormGroup;
    menuItems: MenuItem[];
    currentDocument: DocumentItem;
    documentType: DocumentTypeInfo;
    currentOptions: WorkflowOption[];
    alerts: Alert[];
    widthClass: string;
    fechaInicial: Date;
    fechaFinal: Date;
    selectedGroup: FilterGroup;
    filterPanelCollapsed: boolean;
    columns: QueryList<GridColumn>;
    deleteDialog: ModalDirective;
    optionsDialog: ModalDirective;
    confirmNextStepDialog: ModalDirective;
    confirmPrevioustStepDialog: ModalDirective;
    alertsBar: AlertsBarComponent;
    baseList: DocumentListComponent;
    customMenuItems: QueryList<MenuItemDirective>;
    pageSize: number;
    maxRows: number;
    totalRows: number;
    standAlone: boolean;
    startPeriod: number;
    documentList: DocumentItem[];
    filterGroups: FilterGroup[];
    showFilterPanel: boolean;
    enabled: boolean;
    allowNew: boolean;
    allowView: boolean;
    allowEdit: boolean;
    allowDelete: boolean;
    allowClone: boolean;
    allowNext: boolean;
    allowPrevious: boolean;
    allowAudit: boolean;
    allowExport: boolean;
    readonly classGridPanel: string;
    configureDocument: EventEmitter<DocumentTypeInfo>;
    searchRequested: EventEmitter<SearchRequest>;
    currentItemChanged: EventEmitter<DocumentItem>;
    addingItem: EventEmitter<void>;
    viewingItem: EventEmitter<DocumentItem>;
    editingItem: EventEmitter<DocumentItem>;
    exportingItem: EventEmitter<DocumentItem>;
    deletingItem: EventEmitter<DocumentItem>;
    cloningItem: EventEmitter<DocumentItem>;
    applyingNextStep: EventEmitter<WorkflowEventArgs>;
    applyingPreviousStep: EventEmitter<DocumentItem>;
    menuItemClick: EventEmitter<MenuItem>;
    validatingMenu: EventEmitter<DocumentItem>;
    constructor(context: Context, documentService: DocumentService<DocumentDetail, DocumentInfo<DocumentDetail>>, formBuilder: FormBuilder);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    loadConfiguration(): void;
    showAlert(message: string, type: string): void;
    nextStep(): void;
    previousStep(): void;
    onConfirmNextStep(): void;
    onConfirmPreviousStep(): void;
    onWorkflowOptionSelected(option: WorkflowOption): void;
    onDocumentSelected(document: DocumentItem): void;
    triggerSearch(): void;
    onParamsToolbar(button: ToolbarButton): void;
    private isMenuItemEnabled;
    private setMenuItemState;
    getMenuItem(name: string): MenuItem;
    createMenu(): void;
    updateCustomMenuItems(): void;
    onValidateMenu(document: DocumentItem): void;
    currentItemChangedHandler(document: DocumentItem): void;
    onMenuItemClicked(menu: Menu, args: any): void;
    onIsDroppedDown(menu: Menu, args: any): void;
    deleteItem(): void;
    hideDeleteDialog(): void;
    optionClick(option: MenuItem): void;
    newItemHandler(): void;
    onFilterGroupChanged(group: FilterGroup): void;
    toggleCollapse(): void;
    private handleError;
}
