var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, EventEmitter, Input, Output, ContentChildren, ViewChild, QueryList } from '@angular/core';
import { FormBuilder } from '@angular/forms';
//
import { ModalDirective } from 'ngx-bootstrap';
import * as moment from 'moment';
//
import { Context } from '../../core/services/context';
import { DocumentService } from '../../core/services/document.service';
import { DocumentStatus } from '../../core/models/document-status';
import { SearchRequest } from '../../search/models/search-request';
import { ConditionValueType } from '../../search/models/condition-value-type';
import { DocumentListComponent } from '../../search/components/document-list.component';
import { MenuItemDirective } from '../../controls/directives/menu-item.directive';
import { GridColumn } from '../../controls/directives/grid-column';
import { AlertsBarComponent } from '../../controls/components/alerts-bar.component';
var DocumentManagerComponent = /** @class */ (function () {
    function DocumentManagerComponent(context, documentService, formBuilder) {
        this.context = context;
        this.documentService = documentService;
        this.formBuilder = formBuilder;
        this.menuItems = [];
        this.currentDocument = null;
        this.currentOptions = [];
        this.alerts = [];
        this.widthClass = 'col-12';
        this.fechaInicial = new Date();
        this.fechaFinal = new Date();
        this.filterPanelCollapsed = false;
        //
        this.pageSize = 20;
        this.maxRows = 5000;
        this.standAlone = true;
        //Cantidad de días que se consultarán al abrirse por primera vez el admin. de documentos (desde la fecha actual y la cantidad de días atrás especificados)
        this.startPeriod = 30;
        this.documentList = [];
        this.filterGroups = [];
        this.showFilterPanel = true;
        this.enabled = true;
        this.allowNew = true;
        //
        this.configureDocument = new EventEmitter();
        this.searchRequested = new EventEmitter();
        this.currentItemChanged = new EventEmitter();
        this.addingItem = new EventEmitter();
        this.viewingItem = new EventEmitter();
        this.editingItem = new EventEmitter();
        this.exportingItem = new EventEmitter();
        this.deletingItem = new EventEmitter();
        this.cloningItem = new EventEmitter();
        this.applyingNextStep = new EventEmitter();
        this.applyingPreviousStep = new EventEmitter();
        this.menuItemClick = new EventEmitter();
        this.validatingMenu = new EventEmitter();
        //Crear formulario de parámetros
        this.form = formBuilder.group({
            'fechaInicial': [new Date()],
            'fechaFinal': [new Date()]
        });
        this.createMenu();
    }
    Object.defineProperty(DocumentManagerComponent.prototype, "allowView", {
        get: function () {
            return this.isMenuItemEnabled("OPEN");
        },
        set: function (value) {
            this.setMenuItemState("OPEN", value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DocumentManagerComponent.prototype, "allowEdit", {
        get: function () {
            return this.isMenuItemEnabled("EDIT");
        },
        set: function (value) {
            this.setMenuItemState("EDIT", value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DocumentManagerComponent.prototype, "allowDelete", {
        get: function () {
            return this.isMenuItemEnabled('DELETE');
        },
        set: function (value) {
            this.setMenuItemState('DELETE', value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DocumentManagerComponent.prototype, "allowClone", {
        get: function () {
            return this.isMenuItemEnabled('CLONE');
        },
        set: function (value) {
            this.setMenuItemState('CLONE', value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DocumentManagerComponent.prototype, "allowNext", {
        get: function () {
            return this.isMenuItemEnabled('NEXT');
        },
        set: function (value) {
            this.setMenuItemState('NEXT', value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DocumentManagerComponent.prototype, "allowPrevious", {
        get: function () {
            return this.isMenuItemEnabled('PREVIOUS');
        },
        set: function (value) {
            this.setMenuItemState('PREVIOUS', value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DocumentManagerComponent.prototype, "allowAudit", {
        get: function () {
            return this.isMenuItemEnabled('AUDIT');
        },
        set: function (value) {
            this.setMenuItemState('AUDIT', value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DocumentManagerComponent.prototype, "allowExport", {
        get: function () {
            return this.isMenuItemEnabled('EXPORT');
        },
        set: function (value) {
            this.setMenuItemState('EXPORT', value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DocumentManagerComponent.prototype, "classGridPanel", {
        /*Permite tomar todo el espacio disponible cuando el panel de filtro no está visible y 75% cuando lo está*/
        get: function () {
            return !this.showFilterPanel || this.filterPanelCollapsed ? 'col-12' : 'col-12 col-lg-9';
        },
        enumerable: true,
        configurable: true
    });
    DocumentManagerComponent.prototype.ngOnInit = function () {
        if (this.standAlone) {
            this.widthClass = this.context.app.defaultWidth;
        }
    };
    DocumentManagerComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        //Agregar elementos personalizados y suscribir a cambios en coleccion de opciones personalizadas
        setTimeout(function (_) { return _this.updateCustomMenuItems(); });
        this.customMenuItems.changes.subscribe(function (_) {
            setTimeout(function (_) { return _this.updateCustomMenuItems(); });
        });
        setTimeout(function (_) { return _this.loadConfiguration(); });
    };
    DocumentManagerComponent.prototype.loadConfiguration = function () {
        var _this = this;
        this.fechaInicial = moment().subtract(this.startPeriod, 'day').toDate();
        this.fechaFinal = moment().add(1, 'day').toDate();
        //
        this.context.app.showSpinner();
        this.documentService.getDocumentType()
            .then(function (docType) {
            _this.documentType = docType;
            _this.configureDocument.emit(docType);
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    DocumentManagerComponent.prototype.showAlert = function (message, type) {
        this.alertsBar.showAlert(message, type);
    };
    DocumentManagerComponent.prototype.nextStep = function () {
        var _this = this;
        //Si el documento se encuentra en borrador, determinar el primer paso del documento
        if (this.currentDocument.idStatus == DocumentStatus.DRAFT) {
            //Si no esta definido el paso inicial, mostrar mensaje a usuario
            if (this.documentType.startStep) {
                var args = { document: this.currentDocument, step: this.documentType.startStep };
                this.applyingNextStep.emit(args);
            }
            else {
                this.showAlert('El documento no tiene definido un flujo de trabajo.', 'warning');
            }
        }
        //Si el documento se encuentra activo, determinar el proximo paso
        else if (this.currentDocument.idStatus == DocumentStatus.ACTIVE) {
            var step = this.documentType.workflowSteps.find(function (s) { return s.idWorkflowStep == _this.currentDocument.idWorkflowStep; });
            //Si el paso actual tiene bifuraciones, preguntar al usuario
            if (step.hasOptions) {
                this.currentOptions = step.options;
                this.optionsDialog.config.backdrop = false;
                this.optionsDialog.show();
            }
            //Si el paso actual tiene ligado el siguiente paso directamente
            else if (step.nextStep) {
                this.confirmNextStepDialog.config.backdrop = false;
                this.confirmNextStepDialog.show();
            }
            //Si ya no hay un siguiente paso
            else {
                this.showAlert('El documento se encuentra en el último paso del flujo de trabajo', 'info');
            }
        }
    };
    DocumentManagerComponent.prototype.previousStep = function () {
        this.confirmPrevioustStepDialog.config.backdrop = false;
        this.confirmPrevioustStepDialog.show();
    };
    DocumentManagerComponent.prototype.onConfirmNextStep = function () {
        var _this = this;
        this.confirmNextStepDialog.hide();
        var step = this.documentType.workflowSteps.find(function (s) { return s.idWorkflowStep == _this.currentDocument.idWorkflowStep; });
        var args = { document: this.currentDocument, step: step.nextStep };
        this.applyingNextStep.emit(args);
    };
    DocumentManagerComponent.prototype.onConfirmPreviousStep = function () {
        this.confirmPrevioustStepDialog.hide();
        this.applyingPreviousStep.emit(this.currentDocument);
    };
    DocumentManagerComponent.prototype.onWorkflowOptionSelected = function (option) {
        this.optionsDialog.hide();
        var args = { document: this.currentDocument, step: option.nextStep };
        this.applyingNextStep.emit(args);
    };
    DocumentManagerComponent.prototype.onDocumentSelected = function (document) {
        this.editingItem.emit(this.currentDocument);
    };
    DocumentManagerComponent.prototype.triggerSearch = function () {
        //Disparar búsqueda inicial. Si el manejo se realiza del lado del servidor, obtener sólo la primer página, si es local obtener toda la información disponible
        var request = new SearchRequest();
        request.pageIndex = 0;
        request.pageSize = this.pageSize;
        request.paged = false;
        request.maxRows = this.maxRows;
        //Agregar condiciones de fecha
        var condicionFechaIni = { field: 'fechaCreacion', operator: '>=', valueType: ConditionValueType.DATE_TIME, value: moment(this.fechaInicial).format() };
        var condicionFechaFin = { field: 'fechaCreacion', operator: '<=', valueType: ConditionValueType.DATE_TIME, value: moment(this.fechaFinal).format() };
        var condicionSysIni = { field: 'fechaSys', operator: '>=', valueType: ConditionValueType.DATE_TIME, value: moment(this.fechaInicial).subtract(8, 'day').format() };
        var condicionSysFin = { field: 'fechaSys', operator: '<=', valueType: ConditionValueType.DATE_TIME, value: moment(this.fechaFinal).add(8, 'day').format() };
        request.conditions.push(condicionFechaIni, condicionFechaFin, condicionSysIni, condicionSysFin);
        //
        this.searchRequested.emit(request);
    };
    DocumentManagerComponent.prototype.onParamsToolbar = function (button) {
        if (button.name == 'REFRESH') {
            this.triggerSearch();
        }
    };
    DocumentManagerComponent.prototype.isMenuItemEnabled = function (tag) {
        var item = this.getMenuItem(tag);
        if (item != null)
            return item.enabled;
        else
            return false;
    };
    DocumentManagerComponent.prototype.setMenuItemState = function (tag, enabled) {
        var item = this.getMenuItem(tag);
        if (item != null)
            item.enabled = enabled;
    };
    DocumentManagerComponent.prototype.getMenuItem = function (name) {
        var retItem = null;
        this.menuItems.forEach(function (item) {
            if (item.name == name) {
                retItem = item;
            }
        });
        return retItem;
    };
    DocumentManagerComponent.prototype.createMenu = function () {
        //Agregar opciones estándar del catálogo
        var mnuView = { icon: "glyphicon glyphicon-folder-open", text: "Abrir", name: "OPEN", smallText: "abrir en modo de sólo lectura" };
        var mnuEdit = { icon: "glyphicon glyphicon-pencil", text: "Editar", name: "EDIT", smallText: "abrir en modo de edición" };
        var mnuNext = { icon: "glyphicon glyphicon-arrow-right", text: "Continuar", name: "NEXT", smallText: "ir a siguiente paso" };
        var mnuPrevious = { icon: "glyphicon glyphicon-arrow-left", text: "Retroceder", name: "PREVIOUS", smallText: "regresar a paso anterior" };
        var mnuCopy = { icon: "glyphicon glyphicon-duplicate", text: "Duplicar", name: "CLONE", smallText: "crear una copia" };
        var mnuDelete = { icon: "glyphicon glyphicon-trash", text: "Eliminar", name: "DELETE", smallText: "eliminar permanentemente" };
        var mnuExport = { icon: "glyphicon glyphicon-export", text: "Exportar", name: "EXPORT", smallText: "exportar información del documento", enabled: false };
        var mnuAudit = { icon: "glyphicon glyphicon-search", text: "Auditar", name: "AUDIT", smallText: "auditar cambios" };
        this.menuItems.push(mnuView, mnuEdit, mnuNext, mnuPrevious, mnuCopy, mnuDelete, mnuExport, mnuAudit);
        //
        this.menuItems.forEach(function (item) {
            if (item.enabled == undefined)
                item.enabled = true;
        });
    };
    DocumentManagerComponent.prototype.updateCustomMenuItems = function () {
        var _this = this;
        var customOptions = this.customMenuItems.toArray();
        var newItems = customOptions.filter(function (option) { return !_this.menuItems.find(function (item) { return item.name == option.name; }); });
        this.menuItems = this.menuItems.concat(newItems);
        this.menuItems.forEach(function (item) {
            if (item.enabled == undefined)
                item.enabled = true;
        });
    };
    DocumentManagerComponent.prototype.onValidateMenu = function (document) {
        if (document) {
            var mnuEdit = this.getMenuItem('EDIT');
            var mnuDelete = this.getMenuItem('DELETE');
            var mnuNext = this.getMenuItem('NEXT');
            var mnuPrevious = this.getMenuItem('PREVIOUS');
            //Habilitar opciones del estatus Borrador
            if (document.idStatus == DocumentStatus.DRAFT) {
                if (this.allowEdit)
                    mnuEdit.enabled = true;
                if (this.allowDelete)
                    mnuDelete.enabled = true;
                if (this.allowNext)
                    mnuNext.enabled = true;
                if (this.allowPrevious)
                    mnuPrevious.enabled = false;
            }
            //Habilitar opciones del estatus Activo
            if (document.idStatus == DocumentStatus.ACTIVE) {
                mnuEdit.enabled = false;
                mnuDelete.enabled = false;
                if (this.allowNext)
                    mnuNext.enabled = true;
                if (this.allowPrevious)
                    mnuPrevious.enabled = true;
            }
            //Habilitar opciones del estatus Cancelado
            if (document.idStatus == DocumentStatus.CANCELED) {
                mnuEdit.enabled = false;
                mnuDelete.enabled = false;
                mnuNext.enabled = false;
                mnuPrevious.enabled = false;
            }
            this.validatingMenu.emit(document);
        }
    };
    DocumentManagerComponent.prototype.currentItemChangedHandler = function (document) {
        this.currentDocument = document;
        this.currentItemChanged.emit(document);
    };
    DocumentManagerComponent.prototype.onMenuItemClicked = function (menu, args) {
        var item = this.menuItems[menu.selectedIndex];
        this.optionClick(item);
    };
    DocumentManagerComponent.prototype.onIsDroppedDown = function (menu, args) {
        this.onValidateMenu(this.currentDocument);
    };
    DocumentManagerComponent.prototype.deleteItem = function () {
        this.deletingItem.emit(this.currentDocument);
        this.deleteDialog.hide();
    };
    DocumentManagerComponent.prototype.hideDeleteDialog = function () {
        this.deleteDialog.hide();
    };
    DocumentManagerComponent.prototype.optionClick = function (option) {
        if (option.name == 'OPEN')
            this.viewingItem.emit(this.currentDocument);
        if (option.name == 'EDIT')
            this.editingItem.emit(this.currentDocument);
        if (option.name == 'DELETE') {
            this.deleteDialog.config.backdrop = false;
            this.deleteDialog.show();
        }
        if (option.name == 'CLONE')
            this.cloningItem.emit(this.currentDocument);
        if (option.name == 'NEXT')
            this.nextStep();
        if (option.name == 'PREVIOUS')
            this.previousStep();
        if (option.name == 'EXPORT')
            this.exportingItem.emit(this.currentDocument);
        //Disparar evento genérico con cualquier opción de menú, principalmente dirigido a notificar acciones personalizadas
        this.menuItemClick.emit(option);
    };
    DocumentManagerComponent.prototype.newItemHandler = function () {
        this.addingItem.emit();
    };
    DocumentManagerComponent.prototype.onFilterGroupChanged = function (group) {
        this.selectedGroup = group;
    };
    DocumentManagerComponent.prototype.toggleCollapse = function () {
        this.filterPanelCollapsed = !this.filterPanelCollapsed;
        this.baseList.grid.invalidate();
    };
    DocumentManagerComponent.prototype.handleError = function (error) {
        this.context.app.hideSpinner();
    };
    __decorate([
        ContentChildren(GridColumn),
        __metadata("design:type", QueryList)
    ], DocumentManagerComponent.prototype, "columns", void 0);
    __decorate([
        ViewChild('confirmDelDialog'),
        __metadata("design:type", ModalDirective)
    ], DocumentManagerComponent.prototype, "deleteDialog", void 0);
    __decorate([
        ViewChild('optionsDialog'),
        __metadata("design:type", ModalDirective)
    ], DocumentManagerComponent.prototype, "optionsDialog", void 0);
    __decorate([
        ViewChild('confirmNextStepDialog'),
        __metadata("design:type", ModalDirective)
    ], DocumentManagerComponent.prototype, "confirmNextStepDialog", void 0);
    __decorate([
        ViewChild('confirmPrevioustStepDialog'),
        __metadata("design:type", ModalDirective)
    ], DocumentManagerComponent.prototype, "confirmPrevioustStepDialog", void 0);
    __decorate([
        ViewChild(AlertsBarComponent),
        __metadata("design:type", AlertsBarComponent)
    ], DocumentManagerComponent.prototype, "alertsBar", void 0);
    __decorate([
        ViewChild(DocumentListComponent),
        __metadata("design:type", DocumentListComponent)
    ], DocumentManagerComponent.prototype, "baseList", void 0);
    __decorate([
        ContentChildren(MenuItemDirective),
        __metadata("design:type", QueryList)
    ], DocumentManagerComponent.prototype, "customMenuItems", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], DocumentManagerComponent.prototype, "pageSize", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], DocumentManagerComponent.prototype, "maxRows", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], DocumentManagerComponent.prototype, "totalRows", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], DocumentManagerComponent.prototype, "standAlone", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], DocumentManagerComponent.prototype, "startPeriod", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], DocumentManagerComponent.prototype, "documentList", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], DocumentManagerComponent.prototype, "filterGroups", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], DocumentManagerComponent.prototype, "showFilterPanel", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], DocumentManagerComponent.prototype, "enabled", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], DocumentManagerComponent.prototype, "allowNew", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean),
        __metadata("design:paramtypes", [Boolean])
    ], DocumentManagerComponent.prototype, "allowView", null);
    __decorate([
        Input(),
        __metadata("design:type", Boolean),
        __metadata("design:paramtypes", [Boolean])
    ], DocumentManagerComponent.prototype, "allowEdit", null);
    __decorate([
        Input(),
        __metadata("design:type", Boolean),
        __metadata("design:paramtypes", [Boolean])
    ], DocumentManagerComponent.prototype, "allowDelete", null);
    __decorate([
        Input(),
        __metadata("design:type", Boolean),
        __metadata("design:paramtypes", [Boolean])
    ], DocumentManagerComponent.prototype, "allowClone", null);
    __decorate([
        Input(),
        __metadata("design:type", Boolean),
        __metadata("design:paramtypes", [Boolean])
    ], DocumentManagerComponent.prototype, "allowNext", null);
    __decorate([
        Input(),
        __metadata("design:type", Boolean),
        __metadata("design:paramtypes", [Boolean])
    ], DocumentManagerComponent.prototype, "allowPrevious", null);
    __decorate([
        Input(),
        __metadata("design:type", Boolean),
        __metadata("design:paramtypes", [Boolean])
    ], DocumentManagerComponent.prototype, "allowAudit", null);
    __decorate([
        Input(),
        __metadata("design:type", Boolean),
        __metadata("design:paramtypes", [Boolean])
    ], DocumentManagerComponent.prototype, "allowExport", null);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DocumentManagerComponent.prototype, "configureDocument", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DocumentManagerComponent.prototype, "searchRequested", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DocumentManagerComponent.prototype, "currentItemChanged", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DocumentManagerComponent.prototype, "addingItem", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DocumentManagerComponent.prototype, "viewingItem", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DocumentManagerComponent.prototype, "editingItem", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DocumentManagerComponent.prototype, "exportingItem", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DocumentManagerComponent.prototype, "deletingItem", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DocumentManagerComponent.prototype, "cloningItem", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], DocumentManagerComponent.prototype, "applyingNextStep", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DocumentManagerComponent.prototype, "applyingPreviousStep", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DocumentManagerComponent.prototype, "menuItemClick", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], DocumentManagerComponent.prototype, "validatingMenu", void 0);
    DocumentManagerComponent = __decorate([
        Component({
            selector: 'azteca-document-manager',
            template: "\n      <!--Pool de alertas-->\n      <alerts-bar></alerts-bar>\n\n      <form [formGroup]=\"form\">\n\n          <!--PANEL DE PERIODO Y RESUMEN DE ESTATUS-->\n          <div class=\"row\">\n              <div *ngIf=\"showFilterPanel\" class=\"col-12 col-lg-3\" [collapse]=\"filterPanelCollapsed\">\n                  <div class=\"row\">\n                      <div class=\"col-12\">\n                          <az-panel [header]=\"'Per\u00EDodo'\">\n                              <azteca-form-field [label]=\"'Fecha inicial:'\">\n                                  <az-input-date formControlName=\"fechaInicial\" [(ngModel)]=\"fechaInicial\"></az-input-date>\n                              </azteca-form-field>\n\n                              <azteca-form-field [label]=\"'Fecha final:'\">\n                                  <az-input-date formControlName=\"fechaFinal\" [(ngModel)]=\"fechaFinal\"></az-input-date>\n                              </azteca-form-field>\n\n                              <br />\n\n                              <az-toolbar (buttonClick)=\"onParamsToolbar($event)\">\n                                  <az-toolbar-button [name]=\"'REFRESH'\" [type]=\"'primary'\" [text]=\"'Actualizar listado'\" [icon]=\"'glyphicon glyphicon-refresh'\" [enabled]=\"form.valid\"></az-toolbar-button>\n                              </az-toolbar>\n\n                          </az-panel>\n                      </div>\n                      <div class=\"col-12 d-none d-lg-block\">\n\n                          <az-panel [header]=\"'Resumen de estados'\" [type]=\"'info'\">\n                              <document-groups [groups]=\"filterGroups\" \n                                               [selectedGroup]=\"selectedGroup\"\n                                               (selectedGroupChanged)=\"onFilterGroupChanged($event)\"></document-groups>\n                          </az-panel>\n\n                      </div>\n                  </div> <!--ROW PANEL-->\n              </div> <!--COL PANEL-->\n\n              <div [class]=\"classGridPanel\">\n\n                  <!--MEN\u00DA PRINCIPAL-->\n                  <div class=\"row\">\n                      <div class=\"col-12\">\n\n                          <div class=\"btn-group btn-module-primary\">\n                              <button type=\"button\" class=\"btn btn-default\" [title]=\"(filterPanelCollapsed ? 'Mostrar' : 'Ocultar') + ' panel de filtro'\" (click)=\"toggleCollapse()\">\n                                  <span [class]=\"filterPanelCollapsed ? 'glyphicon glyphicon-chevron-right': 'glyphicon glyphicon-chevron-left'\"></span>\n                              </button>\n                              <button type=\"button\" class=\"btn btn-primary\" (click)=\"newItemHandler()\" *ngIf=\"enabled && allowNew\">\n                                  <span class=\"glyphicon glyphicon-plus\" aria-hidden=\"true\"></span> Nuevo\n                              </button>\n                              <wj-menu #menu\n                                       (itemClicked)=\"onMenuItemClicked(menu, $event)\"\n                                       (isDroppedDownChanging)=\"onIsDroppedDown(menu, $event)\"\n                                       [isDisabled]=\"!enabled\"\n                                       [header]=\"'Opciones'\">\n\n                                  <wj-menu-item *ngFor=\"let item of menuItems\">\n                                      <div *ngIf=\"enabled && item.enabled\">\n                                          <span [class]=\"item.icon\"></span>\n                                          <b>{{item.text}}</b>\n                                          <br>\n                                          <small><i>{{item.smallText}}</i></small>\n                                      </div>\n                                  </wj-menu-item>\n\n                              </wj-menu>\n\n                          </div> <!--TOOLBAR-->\n                      </div> <!--COL MENU-->\n                  </div> <!--ROW MENU-->\n\n                  <!--GRID DE DOCUMENTOS-->\n                  <div class=\"row\">\n                      <div class=\"col-12\">\n\n                          <azteca-document-list [documentList]=\"documentList\"\n                                                [filterGroup]=\"selectedGroup\"\n                                                (currentItemChanged)=\"currentItemChangedHandler($event)\"\n                                                (contextMenuClick)=\"optionClick($event)\"\n                                                (contextMenuOpen)=\"onValidateMenu($event)\"\n                                                (itemSelected)=\"onDocumentSelected($event)\"\n                                                [enabled]=\"enabled\"\n                                                [pageSize]=\"pageSize\">\n\n\n                              <!-- Mapear opciones de men\u00FA de componente padre-->\n                              <azteca-menu-item *ngFor=\"let item of menuItems\" [name]=\"item.name\" [icon]=\"item.icon\" [text]=\"item.text\" [smallText]=\"item.smallText\" [enabled]=\"item.enabled\"></azteca-menu-item>\n\n                              <!-- Mapear columnas definidas en componente padre-->\n                              <azteca-grid-column *ngFor=\"let col of columns\"\n                                                  [header]=\"col.header\"\n                                                  [binding]=\"col.binding\"\n                                                  [dataType]=\"col.dataType ? col.dataType :'String'\"\n                                                  [dataMap]=\"col.dataMap\"\n                                                  [format]=\"col.format\"\n                                                  [width]=\"col.width\">\n\n                                  <!-- Add cell template if col.cellTemplate is specified. -->\n                                  <ng-template wjFlexGridCellTemplate *ngIf=\"col.cellTemplate\" [cellType]=\"'Cell'\" let-cell=\"cell\">\n                                      <!-- Load the component whose type is specified in col.cellTemplate -->\n                                      <wj-component-loader [component]=\"col.cellTemplate\" [properties]=\"{cell: cell}\"></wj-component-loader>\n                                  </ng-template>\n\n                              </azteca-grid-column>\n\n                          </azteca-document-list>\n\n                      </div> <!--COL GRID-->\n                  </div> <!--ROW GRID-->\n\n              </div> <!--COL LIST-->\n\n          </div> <!--ROW-->\n\n   \n\n      </form>\n\n\n      <!--DIALOGO DE ELIMINACI\u00D3N-->\n      <div bsModal #confirmDelDialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"mySmallModalLabel\" aria-hidden=\"true\">\n\n          <div class=\"modal-dialog modal-sm\">\n              <div class=\"modal-content\">\n\n                  <div class=\"modal-body\">\n                      <div>\u00BFEst\u00E1 seguro que desea eliminar el documento seleccionado?</div>\n                  </div>\n                  <div class=\"modal-footer\">\n                      <button type=\"button\" class=\"btn btn-primary\" (click)=\"hideDeleteDialog()\">Cancelar</button>\n                      <button type=\"button\" class=\"btn btn-default\" (click)=\"deleteItem()\">Aceptar</button>\n                  </div>\n\n              </div>\n          </div>\n\n      </div>\n\n      <!--DIALOGO DE BIFURCACIONES-->\n      <div bsModal #optionsDialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"mySmallModalLabel\" aria-hidden=\"true\">\n          <div class=\"modal-dialog modal-sm\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-header\">\n                      <h5>Elegir el siguiente paso</h5>\n                  </div>\n                  <div class=\"modal-body\">\n                      <ul class=\"list-group\">\n                          <button *ngFor=\"let option of currentOptions\" class=\"list-group-item list-group-item-action\" (click)=\"onWorkflowOptionSelected(option)\">\n                              <span class=\"glyphicon glyphicon-arrow-right\" style=\"margin-right:5px;\"></span>{{option.text}}\n                          </button>\n                      </ul>\n                  </div> <!--Modal Body-->\n                  <div class=\"modal-footer\">                \n                      <button type=\"button\" class=\"btn btn-danger\" (click)=\"optionsDialog.hide()\">Cancelar</button>\n                  </div> <!--Modal Footer-->\n\n              </div> <!-- Modal Content-->\n          </div> <!--Modal-->\n      </div> <!--Modal directive-->\n\n\n      <!--DIALOGO DE CONFIRMACION NEXT STEP-->\n\n      <div bsModal #confirmNextStepDialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"mySmallModalLabel\" aria-hidden=\"true\">\n          <div class=\"modal-dialog modal-sm\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-body\">\n                      <h5>\u00BFEst\u00E1 seguro que desea avanzar al siguiente paso?</h5>\n                  </div> <!--Modal Body-->\n                  <div class=\"modal-footer\">\n                      <button type=\"button\" class=\"btn btn-primary\" (click)=\"onConfirmNextStep()\">Aceptar</button>\n                      <button type=\"button\" class=\"btn btn-danger\" (click)=\"confirmNextStepDialog.hide()\">Cancelar</button>\n                  </div> <!--Modal Footer-->\n\n              </div> <!-- Modal Content-->\n          </div> <!--Modal-->\n      </div> <!--Modal directive-->\n\n\n      <!--DIALOGO DE CONFIRMACION PREVIOUS STEP-->\n\n      <div bsModal #confirmPrevioustStepDialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"mySmallModalLabel\" aria-hidden=\"true\">\n          <div class=\"modal-dialog modal-sm\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-body\">\n                      <h5>\u00BFEst\u00E1 seguro que desea regresar al paso anterior?</h5>\n                  </div> <!--Modal Body-->\n                  <div class=\"modal-footer\">\n                      <button type=\"button\" class=\"btn btn-primary\" (click)=\"onConfirmPreviousStep()\">Aceptar</button>\n                      <button type=\"button\" class=\"btn btn-danger\" (click)=\"confirmPrevioustStepDialog.hide()\">Cancelar</button>\n                  </div> <!--Modal Footer-->\n\n              </div> <!-- Modal Content-->\n          </div> <!--Modal-->\n      </div> <!--Modal directive-->\n    "
        }),
        __metadata("design:paramtypes", [Context, DocumentService,
            FormBuilder])
    ], DocumentManagerComponent);
    return DocumentManagerComponent;
}());
export { DocumentManagerComponent };
