var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, Input, Output, ViewChild, EventEmitter, ContentChildren, QueryList, forwardRef } from '@angular/core';
//Wijmo
import { Control } from 'wijmo/wijmo';
import { FlexGrid, CellType, CellRange } from 'wijmo/wijmo.grid';
//Kernel
import { BaseComponent } from '../../core/models/base-component';
import { BaseControl } from '../../controls/models/base-control';
import { ChangeState } from '../../core/models/change-tracking';
import { TrackableCollection } from './trackable-collection';
import { GridColumn } from '../../controls/directives/grid-column';
import { MenuItemDirective } from '../../controls/directives/menu-item.directive';
var EditableListComponent = /** @class */ (function (_super) {
    __extends(EditableListComponent, _super);
    function EditableListComponent() {
        var _this = _super.call(this) || this;
        _this.collectionView = new TrackableCollection();
        _this._listItems = [];
        _this.allowNew = true;
        _this.allowEdit = true;
        _this.allowDelete = true;
        //Outputs
        _this.contextMenuOpen = new EventEmitter();
        _this.currentItemChanged = new EventEmitter();
        _this.addingItem = new EventEmitter();
        _this.editingItem = new EventEmitter();
        _this.deletingItem = new EventEmitter();
        _this.listItemsUpdated = new EventEmitter();
        _this.menuItemClick = new EventEmitter();
        _this.cellUpdated = new EventEmitter();
        return _this;
    }
    EditableListComponent_1 = EditableListComponent;
    Object.defineProperty(EditableListComponent.prototype, "listItems", {
        //Inputs
        get: function () {
            return this._listItems;
        },
        set: function (value) {
            this._listItems = value;
            this.collectionView.sourceCollection = value;
        },
        enumerable: true,
        configurable: true
    });
    EditableListComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        setTimeout(function (_) { return _this.validateColumns(); });
        this.columns.changes.subscribe(function (_) {
            setTimeout(function (_) { return _this.validateColumns(); });
        });
    };
    EditableListComponent.prototype.ngOnChanges = function (changes) {
        if (changes['enabled'] || changes['allowEdit'] || changes['allowDelete']) {
            this.validateMenu();
        }
    };
    /////////////////////// METODOS ////////////////////////////////////
    EditableListComponent.prototype.validateColumns = function () {
        //Si no se especifico si la columna es de solo lectura o no, especificar como de solo lectura
        this.columns.forEach(function (col) {
            if (col.isReadOnly == undefined)
                col.isReadOnly = true;
        });
    };
    EditableListComponent.prototype.validateMenu = function () {
        //Validar opciones básicas del menú en relación a los inputs globales del componente
        var mnuEdit = this.findMenuItem('EDIT');
        if (mnuEdit) {
            mnuEdit.enabled = mnuEdit.enabled && this.allowEdit && this.enabled;
        }
        var mnuDelete = this.findMenuItem('DELETE');
        if (mnuDelete) {
            mnuDelete.enabled = mnuDelete.enabled && this.allowDelete && this.enabled;
        }
    };
    EditableListComponent.prototype.findMenuItem = function (name) {
        if (this.menuItems)
            return this.menuItems.find(function (item) { return item.name == name; });
    };
    EditableListComponent.prototype.deleteItem = function (item) {
        this.collectionView.remove(item);
    };
    EditableListComponent.prototype.updateItem = function (item) {
        var newItems = this.listItems.slice();
        //Si el elemento es nuevo, agregar. Si no, buscar su índice dentro de la colección y reemplazar
        var index = newItems.findIndex(function (i) { return i._clientID == item._clientID; });
        if (index == -1) {
            item.state = ChangeState.ADDED;
            newItems.push(item);
        }
        else {
            item.state = ChangeState.MODIFIED;
            newItems[index] = item;
        }
        this.listItemsUpdated.emit(newItems);
    };
    EditableListComponent.prototype.updateItems = function (items) {
        var newItems = this.listItems.slice();
        //Si el elemento es nuevo, agregar. Si no, buscar su índice dentro de la colección y reemplazar
        items.forEach(function (item) {
            var index = newItems.findIndex(function (i) { return i._clientID == item._clientID; });
            if (index == -1) {
                item.state = ChangeState.ADDED;
                newItems.push(item);
            }
            else {
                item.state = ChangeState.MODIFIED;
                newItems[index] = item;
            }
        });
        this.listItemsUpdated.emit(newItems);
    };
    EditableListComponent.prototype.refresh = function () {
        var _this = this;
        setTimeout(function (_) { return _this.collectionView.refresh(); });
        Control.invalidateAll();
    };
    /////////////////////// HANDLERS //////////////////////////////////
    EditableListComponent.prototype.contextMenuClick = function (menu) {
        var options = this.menuItems.toArray();
        var option = options[menu.selectedIndex];
        this.onMenuItemClick(option);
    };
    EditableListComponent.prototype.onToolbarClick = function (button) {
        if (button.name == 'ADD') {
            this.addingItem.emit();
        }
    };
    EditableListComponent.prototype.onMenuItemClick = function (option) {
        if (this.currentItem) {
            if (option.name == 'EDIT' && this.allowEdit) {
                this.editingItem.emit(this.currentItem);
            }
            if (option.name == 'DELETE' && this.allowDelete) {
                this.deletingItem.emit(this.currentItem);
            }
            this.menuItemClick.emit(option);
        }
    };
    EditableListComponent.prototype.initialized = function (sender, args) {
        var _this = this;
        var self = this;
        //Agregar manejador para menú contextual        
        sender.addEventListener(sender.hostElement, "contextmenu", function (e) {
            var ht = sender.hitTest(e);
            sender.select(new CellRange(ht.row, ht.col), true);
            self.validateMenu();
            self.contextMenuOpen.emit(self.currentItem);
        });
        //Manejo de doble click
        sender.addEventListener(sender.hostElement, "dblclick", function (e) {
            var ht = sender.hitTest(e);
            if (ht.cellType == CellType.Cell) {
                if (_this.enabled && _this.allowEdit) {
                    _this.editingItem.emit(_this.currentItem);
                }
            }
        });
        //        
        this.collectionView.currentChanged.addHandler(function (args) {
            _this.currentItem = self.collectionView.currentItem;
            self.currentItemChanged.emit(self.currentItem);
        }, self);
    };
    EditableListComponent.prototype.onCellUpdated = function (args) {
        this.cellUpdated.emit(args);
    };
    var EditableListComponent_1;
    __decorate([
        ViewChild('grid'),
        __metadata("design:type", FlexGrid)
    ], EditableListComponent.prototype, "gridDetail", void 0);
    __decorate([
        ContentChildren(GridColumn),
        __metadata("design:type", QueryList)
    ], EditableListComponent.prototype, "columns", void 0);
    __decorate([
        ContentChildren(MenuItemDirective),
        __metadata("design:type", QueryList)
    ], EditableListComponent.prototype, "menuItems", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Array),
        __metadata("design:paramtypes", [Array])
    ], EditableListComponent.prototype, "listItems", null);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], EditableListComponent.prototype, "allowNew", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], EditableListComponent.prototype, "allowEdit", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], EditableListComponent.prototype, "allowDelete", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], EditableListComponent.prototype, "contextMenuOpen", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], EditableListComponent.prototype, "currentItemChanged", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], EditableListComponent.prototype, "addingItem", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], EditableListComponent.prototype, "editingItem", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], EditableListComponent.prototype, "deletingItem", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], EditableListComponent.prototype, "listItemsUpdated", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], EditableListComponent.prototype, "menuItemClick", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], EditableListComponent.prototype, "cellUpdated", void 0);
    EditableListComponent = EditableListComponent_1 = __decorate([
        Component({
            selector: 'azteca-editable-list',
            template: "\n\n      <az-toolbar *ngIf=\"allowNew || menuItems.toArray().length > 0\" (buttonClick)=\"onToolbarClick($event)\" (menuItemClick)=\"onMenuItemClick($event)\">\n          <az-toolbar-button *ngIf=\"allowNew\" [name]=\"'ADD'\" [type]=\"'primary'\" [text]=\"'Agregar'\" [icon]=\"'glyphicon glyphicon-plus'\" [enabled]=\"enabled\"></az-toolbar-button>\n          <az-toolbar-menu [name]=\"'OPTIONS'\" [header]=\"'Opciones'\" [menuItems]=\"menuItems.toArray()\" [enabled]=\"enabled\"></az-toolbar-menu>\n      </az-toolbar>\n\n\n      <wj-flex-grid   #grid\n                      style=\"height:550px\"\n                      (initialized)=\"initialized(grid, $event)\"\n                      (cellEditEnded)=\"onCellUpdated($event)\"\n                      [isReadOnly]=\"!enabled || !allowEdit\"\n                      [wjContextMenu]=\"ctxMenu\"              \n                      [itemsSource]=\"collectionView\">\n\n          <!--Agregar las columnas definidas en el template-->\n          <wj-flex-grid-column *ngFor=\"let col of columns\"\n                               [header]=\"col.header\"\n                               [binding]=\"col.binding\"\n                               [name]=\"col.name\"\n                               [isReadOnly]=\"col.isReadOnly\"\n                               [format]=\"col.format\"\n                               [dataType]=\"col.dataType\"\n                               [dataMap]=\"col.dataMap\"\n                               [width]=\"col.width\">\n              <!-- Add cell template if col.cellTemplate is specified. -->\n              <ng-template wjFlexGridCellTemplate *ngIf=\"col.cellTemplate\" [cellType]=\"'Cell'\" let-cell=\"cell\">\n                  <!-- Load the component whose type is specified in col.cellTemplate -->\n                  <wj-component-loader [component]=\"col.cellTemplate\" [properties]=\"{cell: cell}\"></wj-component-loader>\n              </ng-template>\n          </wj-flex-grid-column>\n      </wj-flex-grid>\n\n\n      <wj-menu #ctxMenu (itemClicked)=\"contextMenuClick(ctxMenu)\" style=\"display:none\">\n          <wj-menu-item *ngFor=\"let item of menuItems\">\n              <div *ngIf=\"item.enabled\">\n                  <span [class]=\"item.icon\"></span>\n                  <b>{{item.text}}</b>\n                  <br>\n                  <small><i>{{item.smallText}}</i></small>\n              </div>\n          </wj-menu-item>\n      </wj-menu>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return EditableListComponent_1; })
                }
            ]
        }),
        __metadata("design:paramtypes", [])
    ], EditableListComponent);
    return EditableListComponent;
}(BaseControl));
export { EditableListComponent };
