var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Angular
import { Component, EventEmitter, Input, Output, ContentChildren, ViewChild, QueryList, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { Location } from '@angular/common';
//Tree
import { TreeComponent, TreeNode } from 'angular-tree-component';
//Bootstrap
import { ModalDirective } from 'ngx-bootstrap';
//Azteca Kernel
import { Context } from '../../core/services/context';
import { CatalogService } from '../../core/services/catalog.service';
import { Deferred } from '../../core/deferred';
import { HierarchyChanges } from '../../core/models/hierarchy';
import { MenuItemDirective } from '../../controls/directives/menu-item.directive';
//
var HierarchyManagerComponent = /** @class */ (function () {
    function HierarchyManagerComponent(context, catalogService, router, route, location, changeDetector) {
        var _this = this;
        this.context = context;
        this.catalogService = catalogService;
        this.router = router;
        this.route = route;
        this.location = location;
        this.changeDetector = changeDetector;
        this.alerts = [];
        this.defaultOptions = { codigoAutogenerado: true };
        this.menuItems = [];
        this.lastCreated = null;
        this.deletedNodes = [];
        this.clipboardNode = null;
        this.canceled = false;
        this.title = 'Administrador de jerarquía';
        this.editorTitle = 'Editando información del nodo';
        this.enabled = true;
        this.displayField = 'nombre';
        //Outputs
        this.configureCatalog = new EventEmitter();
        this.menuItemClick = new EventEmitter();
        this.currentNodeChanged = new EventEmitter();
        this.creatingNode = new EventEmitter();
        this.editingNode = new EventEmitter();
        this.savingNode = new EventEmitter();
        this.deletingNode = new EventEmitter();
        this.copyingNode = new EventEmitter();
        this.pastingNode = new EventEmitter();
        this.savingHierarchy = new EventEmitter();
        this.nodesChanged = new EventEmitter();
        this.validatingMenu = new EventEmitter();
        //Configuración del árbol
        this.actionMapping = {
            mouse: {
                contextMenu: function (tree, node, $event) {
                    $event.preventDefault();
                    node.setActiveAndVisible(false);
                    _this.validatingMenu.emit(node);
                },
                dblClick: function (tree, node, $event) { return _this.editingNode.emit(_this.currentNode); }
            }
        };
        this.treeOptions = {
            displayField: this.displayField, idField: 'clientID', allowDrag: true, actionMapping: this.actionMapping, allowDrop: function (element, to) {
                if (_this.allowDropHandler) {
                    return _this.allowDropHandler(element, to);
                }
                else {
                    return true;
                }
            }
        };
    }
    HierarchyManagerComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        setTimeout(function (_) { return _this.loadConfiguration(); });
        setTimeout(function (_) { return _this.createMenu(); });
    };
    HierarchyManagerComponent.prototype.loadConfiguration = function () {
        var _this = this;
        this.catalogService.getOptions()
            .then(function (options) {
            if (options != null)
                _this.configureCatalog.emit(options);
            else {
                _this.configureCatalog.emit(_this.defaultOptions);
            }
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    HierarchyManagerComponent.prototype.createMenu = function () {
        var mnuAddChild = { icon: "glyphicon glyphicon-plus", text: "Crear hijo", name: "CHILD", smallText: "crear nodo hijo" };
        var mnuAddSibling = { icon: "glyphicon glyphicon-plus", text: "Crear hermano", name: "SIBLING", smallText: "crear nodo hermano" };
        var mnuEdit = { icon: "glyphicon glyphicon-edit", text: "Editar", name: "EDIT", smallText: "editar nodo" };
        var mnuCopy = { icon: "glyphicon glyphicon-duplicate", text: "Copiar", name: "COPY", smallText: "copiar nodo y descendientes" };
        var mnuPaste = { icon: "glyphicon glyphicon-paste", text: "Pegar", name: "PASTE", smallText: "pegar nodos en memoria" };
        var mnuDelete = { icon: "glyphicon glyphicon-trash", text: "Eliminar", name: "DELETE", smallText: "eliminar nodo" };
        this.menuItems.push(mnuAddChild, mnuAddSibling, mnuEdit, mnuCopy, mnuPaste, mnuDelete);
        //Marcar como habilitadas todas las opciones
        this.menuItems.forEach(function (item) {
            if (item.enabled == undefined)
                item.enabled = true;
        });
    };
    HierarchyManagerComponent.prototype.mainToolbarHandler = function (button) {
        if (button.name == "SAVE") {
            var changes = new HierarchyChanges();
            changes.nodes = this.nodes;
            changes.deletedNodes = this.deletedNodes;
            this.savingHierarchy.emit(changes);
        }
        if (button.name == "ROOT") {
            this.creatingNode.emit(null);
        }
        if (button.name == "CLOSE") {
            this.canceled = true;
            this.location.back();
        }
    };
    HierarchyManagerComponent.prototype.getLastClientID = function (nodes) {
        var _this = this;
        var lastID = 0;
        nodes.forEach(function (node) {
            if (node.clientID > lastID)
                lastID = node.clientID;
            if (node.children.length > 0) {
                var maxChildrenID = _this.getLastClientID(node.children);
                if (maxChildrenID > lastID)
                    lastID = maxChildrenID;
            }
        });
        return lastID;
    };
    HierarchyManagerComponent.prototype.selectAction = function (item) {
        if (item.name == "CHILD") {
            this.creatingNode.emit(this.currentNode);
        }
        if (item.name == "SIBLING") {
            this.creatingNode.emit(this.currentNode.parent);
        }
        if (item.name == "EDIT") {
            this.editingNode.emit(this.currentNode);
        }
        if (item.name == "DELETE") {
            this.deleteDialog.config.backdrop = false;
            this.deleteDialog.show();
        }
        if (item.name == "COPY") {
            this.clipboardNode = this.currentNode;
            this.copyingNode.emit(this.clipboardNode);
        }
        if (item.name == "PASTE") {
            if (this.clipboardNode == null) {
                this.showAlert('No hay información en el portapapeles', 'warning');
            }
            else if (this.clipboardNode === this.currentNode) {
                this.showAlert('El nodo en el portapapeles y el nodo destino son el mismo', 'warning');
            }
            else {
                this.pastingNode.emit(this.clipboardNode);
                if (this.currentNode) {
                    this.pasteNode(this.clipboardNode, this.currentNode);
                }
                else {
                    this.pasteNode(this.clipboardNode, null);
                }
            }
        }
        //Notificar a componente padre
        this.menuItemClick.emit(item);
    };
    HierarchyManagerComponent.prototype.onMenuItemClick = function (menu, args) {
        var item = null;
        //Si el indice es menor a la cantidad de opciones estándar, buscar en array local (ya que primero se agregan las opciones estándar)
        if (menu.selectedIndex < this.menuItems.length) {
            item = this.menuItems[menu.selectedIndex];
        }
        //Si es mayor, buscar en array de opciones personalizadas
        else {
            var customItems = this.customMenuItems.toArray();
            var customIndex = menu.selectedIndex - (this.menuItems.length + 1); //Se determina el indice dentro del array de custom options restando las opciones estándar
            item = customItems[customIndex];
        }
        this.selectAction(item);
    };
    HierarchyManagerComponent.prototype.showEditor = function () {
        this.editDialog.config.backdrop = false;
        this.editDialog.show();
    };
    HierarchyManagerComponent.prototype.hideEditor = function () {
        this.editDialog.hide();
    };
    HierarchyManagerComponent.prototype.showAlert = function (message, type) {
        var newAlert = { msg: message, type: type, dismissOnTimeout: 5000, closable: true };
        this.alerts.push(newAlert);
    };
    HierarchyManagerComponent.prototype.closeAlert = function (i) {
        this.alerts.splice(i, 1);
    };
    HierarchyManagerComponent.prototype.findInfoByClientID = function (clientID, nodes) {
        var _this = this;
        var retNode = null;
        nodes.forEach(function (node) {
            if (node.clientID == clientID) {
                retNode = node;
            }
            else {
                if (!retNode && node.children && node.children.length > 0) {
                    retNode = _this.findInfoByClientID(clientID, node.children);
                }
            }
        });
        return retNode;
    };
    HierarchyManagerComponent.prototype.addNode = function (info, parentNode) {
        var newNodes = this.nodes.slice();
        if (info.clientID == 0)
            info.clientID = this.getLastClientID(this.nodes) + 1;
        //Si no se especificó un nodo padre, agregar como nodo raíz
        if (parentNode == null || parentNode.data.identity == undefined) {
            newNodes.push(info);
        }
        //Si se especificó el padre, buscar nodo y agregar a su colección de hijos
        else {
            var parentInfo = this.findInfoByClientID(parentNode.data.clientID, newNodes);
            if (parentInfo) {
                parentInfo.children.push(info);
            }
            else {
                console.error('No se encontró un nodo con client ID: ' + parentNode.data.clientID);
            }
        }
        this.lastCreated = info;
        if (parentNode)
            parentNode.setIsExpanded(true);
        this.nodesChanged.emit(newNodes);
    };
    HierarchyManagerComponent.prototype.updateNode = function (info) {
        var newNodes = this.nodes.slice();
        var nodeToUpdate = this.tree.treeModel.getNodeById(info.clientID);
        //Si es un nodo raíz, reemplazar directamente
        if (nodeToUpdate.isRoot) {
            var nodeIndex = newNodes.indexOf(nodeToUpdate.data);
            if (nodeIndex != -1)
                newNodes[nodeIndex] = info;
        }
        //Buscar el info padre para reemplazar en colección children
        else {
            var infoPadre = this.findInfoByClientID(nodeToUpdate.parent.data.clientID, newNodes);
            var nodeIndex = infoPadre.children.indexOf(nodeToUpdate.data);
            if (nodeIndex != -1)
                infoPadre.children[nodeIndex] = info;
        }
        this.nodesChanged.emit(newNodes);
    };
    HierarchyManagerComponent.prototype.deleteNode = function (node) {
        var newNodes = this.nodes.slice();
        var deletedNode;
        //Si es un nodo raíz, eliminar directamente
        if (node.isRoot) {
            var nodeIndex = newNodes.indexOf(node.data);
            if (nodeIndex != -1) {
                deletedNode = newNodes.splice(nodeIndex, 1)[0];
            }
        }
        //Buscar el info padre para eliminar en colección children
        else {
            var infoPadre = this.findInfoByClientID(node.parent.data.clientID, newNodes);
            var nodeIndex = infoPadre.children.indexOf(node.data);
            if (nodeIndex != -1) {
                deletedNode = infoPadre.children.splice(nodeIndex, 1)[0];
            }
        }
        this.deletedNodes.push(deletedNode);
        this.nodesChanged.emit(newNodes);
    };
    HierarchyManagerComponent.prototype.pasteNode = function (node, target) {
        var newNodes = this.nodes.slice();
        var copy = JSON.parse(JSON.stringify(node.data));
        copy.nombre += ' (copia)';
        //Reestablecer campos para que se tomen como nuevos nodos
        copy.clientID = this.getLastClientID(this.nodes) + 1;
        copy.identity = 0;
        copy.code = '';
        this.resetNodeData(copy.children);
        //Si se especificó el nodo destino, pegar sobre él, si no, pegar como nodo raíz
        if (target) {
            var infoTarget = this.findInfoByClientID(target.data.clientID, newNodes);
            infoTarget.children.push(copy);
            target.setIsExpanded(true);
        }
        else {
            newNodes.push(copy);
        }
        this.lastCreated = copy;
        this.nodesChanged.emit(newNodes);
    };
    HierarchyManagerComponent.prototype.reset = function () {
        this.lastCreated = null;
        this.deletedNodes = [];
        this.clipboardNode = null;
    };
    HierarchyManagerComponent.prototype.resetNodeData = function (nodes) {
        var _this = this;
        nodes.forEach(function (node) {
            node.clientID = _this.getLastClientID(_this.nodes) + 1;
            node.identity = 0;
            node.code = '';
            _this.resetNodeData(node.children);
        });
    };
    HierarchyManagerComponent.prototype.confirmDelete = function () {
        this.deletingNode.emit(this.currentNode);
        this.deleteDialog.hide();
    };
    HierarchyManagerComponent.prototype.onTreeUpdated = function () {
        var _this = this;
        //Si se acaba de crear un nuevo nodo, buscarlo y establecerlo como el nodo activo
        if (this.lastCreated != null) {
            setTimeout(function (_) { return _this.activateLastCreated(); });
        }
    };
    HierarchyManagerComponent.prototype.activateLastCreated = function () {
        var node = this.tree.treeModel.getNodeById(this.lastCreated.clientID);
        node.setIsActive(true, false);
        this.lastCreated = null;
    };
    HierarchyManagerComponent.prototype.onCurrentNodeChanged = function (args) {
        var node = args.node;
        this.currentNodeChanged.emit(node);
    };
    HierarchyManagerComponent.prototype.onMoveNode = function (args) {
    };
    HierarchyManagerComponent.prototype.onCommitEdit = function () {
        this.savingNode.emit();
    };
    HierarchyManagerComponent.prototype.onCancelEdit = function () {
        this.editDialog.hide();
    };
    HierarchyManagerComponent.prototype.confirmDiscardChanges = function () {
        this.discardDialog.config.backdrop = false;
        this.discardDialog.show();
        this.defDiscardChanges = new Deferred();
        return this.defDiscardChanges.promise;
    };
    HierarchyManagerComponent.prototype.cancelDiscard = function () {
        this.defDiscardChanges.resolve(false);
        this.discardDialog.hide();
    };
    HierarchyManagerComponent.prototype.discardChanges = function () {
        this.discardDialog.hide();
        this.defDiscardChanges.resolve(true);
    };
    HierarchyManagerComponent.prototype.onOpeningMenu = function (menu) {
        this.validatingMenu.emit(this.currentNode);
    };
    HierarchyManagerComponent.prototype.handleError = function (error) {
        this.context.app.hideSpinner();
    };
    __decorate([
        ContentChildren(MenuItemDirective),
        __metadata("design:type", QueryList)
    ], HierarchyManagerComponent.prototype, "customMenuItems", void 0);
    __decorate([
        ViewChild(TreeComponent),
        __metadata("design:type", TreeComponent)
    ], HierarchyManagerComponent.prototype, "tree", void 0);
    __decorate([
        ViewChild('editDialog'),
        __metadata("design:type", ModalDirective)
    ], HierarchyManagerComponent.prototype, "editDialog", void 0);
    __decorate([
        ViewChild('confirmDelDialog'),
        __metadata("design:type", ModalDirective)
    ], HierarchyManagerComponent.prototype, "deleteDialog", void 0);
    __decorate([
        ViewChild('discardChangesDialog'),
        __metadata("design:type", ModalDirective)
    ], HierarchyManagerComponent.prototype, "discardDialog", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], HierarchyManagerComponent.prototype, "nodes", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], HierarchyManagerComponent.prototype, "title", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], HierarchyManagerComponent.prototype, "editorTitle", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], HierarchyManagerComponent.prototype, "enabled", void 0);
    __decorate([
        Input(),
        __metadata("design:type", TreeNode)
    ], HierarchyManagerComponent.prototype, "currentNode", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], HierarchyManagerComponent.prototype, "validForm", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Function)
    ], HierarchyManagerComponent.prototype, "allowDropHandler", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], HierarchyManagerComponent.prototype, "displayField", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], HierarchyManagerComponent.prototype, "configureCatalog", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], HierarchyManagerComponent.prototype, "menuItemClick", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], HierarchyManagerComponent.prototype, "currentNodeChanged", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], HierarchyManagerComponent.prototype, "creatingNode", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], HierarchyManagerComponent.prototype, "editingNode", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], HierarchyManagerComponent.prototype, "savingNode", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], HierarchyManagerComponent.prototype, "deletingNode", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], HierarchyManagerComponent.prototype, "copyingNode", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], HierarchyManagerComponent.prototype, "pastingNode", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], HierarchyManagerComponent.prototype, "savingHierarchy", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], HierarchyManagerComponent.prototype, "nodesChanged", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], HierarchyManagerComponent.prototype, "validatingMenu", void 0);
    HierarchyManagerComponent = __decorate([
        Component({
            selector: 'azteca-hierarchy-manager',
            template: "\n      <div class=\"row\">\n          <div class=\"col-12 col-md-10 col-lg-10\">\n              <az-panel [header]=\"title\">\n\n                  <!--Pool de alertas-->\n                  <alert *ngFor=\"let alert of alerts;let i = index\" [type]=\"alert.type\" dismissible=\"true\" [dismissOnTimeout]=\"alert.dismissOnTimeout\" (close)=\"closeAlert(i)\">\n                      {{ alert?.msg }}\n                  </alert>\n\n\n                  <div class=\"row\">\n                      <div class=\"col-12 col-md-10 col-lg-10\">\n                          <az-toolbar (buttonClick)=\"mainToolbarHandler($event)\" (menuItemClick)=\"selectAction($event)\" (openingMenu)=\"onOpeningMenu($event)\">\n                              <!--Mostrar boton con text en dipositivos grandes, solo con icono en peque\u00F1os-->\n                              <az-toolbar-button [name]=\"'SAVE'\" [type]=\"'primary'\" [text]=\"'Guardar'\" [icon]=\"'glyphicon glyphicon-floppy-disk'\" [class]=\"'d-none d-lg-block'\"></az-toolbar-button>\n                              <az-toolbar-button [name]=\"'SAVE'\" [type]=\"'primary'\" [toolTip]=\"'Guardar'\" [icon]=\"'glyphicon glyphicon-floppy-disk'\" [class]=\"'d-lg-none'\"></az-toolbar-button>\n                              <!--Mostrar boton con text en dipositivos grandes, solo con icono en peque\u00F1os-->\n                              <az-toolbar-button [name]=\"'ROOT'\" [text]=\"'Crear ra\u00EDz'\" [icon]=\"'glyphicon glyphicon-plus'\" [class]=\"'d-none d-lg-block'\"></az-toolbar-button>\n                              <az-toolbar-button [name]=\"'ROOT'\" [toolTip]=\"'Crear ra\u00EDz'\" [icon]=\"'glyphicon glyphicon-plus'\" [class]=\"'d-lg-none'\"></az-toolbar-button>\n                              <!--Mostrar boton con text en dipositivos grandes, solo con icono en peque\u00F1os-->\n                              <az-toolbar-button [name]=\"'CLOSE'\" [text]=\"'Cerrar'\" [icon]=\"'glyphicon glyphicon-remove'\" [class]=\"'d-none d-lg-block'\"></az-toolbar-button>\n                              <az-toolbar-button [name]=\"'CLOSE'\" [toolTip]=\"'Cerrar'\" [icon]=\"'glyphicon glyphicon-remove'\" [class]=\"'d-lg-none'\"></az-toolbar-button>\n\n                              <az-toolbar-menu *ngIf=\"currentNode\" [name]=\"'NODE'\" [header]=\"'Nodo'\" [menuItems]=\"menuItems\"></az-toolbar-menu>\n                              <az-toolbar-menu *ngIf=\"currentNode && customMenuItems.toArray().length > 0\" [name]=\"'OPTS'\" [header]=\"'Opciones'\" [menuItems]=\"customMenuItems.toArray()\"></az-toolbar-menu>\n                          </az-toolbar>\n                      </div>\n                  </div>\n\n                  <div class=\"row\">\n                      <div class=\"col-12\" style=\"height: 500px; overflow:auto;\">\n                          <tree-root [nodes]=\"nodes\" \n                                [options]=\"treeOptions\"\n                                (updateData)=\"onTreeUpdated($event)\"\n                                (activate)=\"onCurrentNodeChanged($event)\"\n                                (moveNode)=\"onMoveNode($event)\">\n\n                              <ng-template #treeNodeTemplate let-node=\"node\" let-index=\"index\">\n                                  <span [class]=\"node.data.icon\"></span>\n                                  <span [wjContextMenu]=\"ctxMenu\">{{ node.data.nombre }}</span>\n                              </ng-template>\n                          </tree-root>\n\n                      </div>\n                  </div>\n\n              </az-panel>\n          </div>\n      </div>\n\n      <!-- Men\u00FA Contextual-->\n      <wj-menu #ctxMenu style=\"display:none\"\n                      (itemClicked)=\"onMenuItemClick(ctxMenu, $event)\"                \n                      [isDisabled]=\"!enabled\">\n\n          <!-- Opciones est\u00E1ndar de la jerarqu\u00EDa-->\n          <wj-menu-item *ngFor=\"let item of menuItems\">\n              <div *ngIf=\"enabled && item.enabled\">\n                  <span [class]=\"item.icon\"></span>\n                  <b>{{item.text}}</b>\n                  <br>\n                  <small><i>{{item.smallText}}</i></small>\n              </div>\n          </wj-menu-item>\n    \n          <wj-menu-separator *ngIf=\"customMenuItems && customMenuItems.toArray().length > 0\"></wj-menu-separator>\n    \n          <!--Opciones personalizadas del componente padre-->\n          <wj-menu-item *ngFor=\"let item of customMenuItems\">\n              <div *ngIf=\"enabled && item.enabled\">\n                  <span [class]=\"item.icon\"></span>\n                  <b>{{item.text}}</b>\n                  <br>\n                  <small><i>{{item.smallText}}</i></small>\n              </div>\n          </wj-menu-item>\n\n      </wj-menu>\n\n\n      <div bsModal #editDialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"myLargeModalLabel\" aria-hidden=\"true\">\n          <div class=\"modal-dialog modal-lg\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-body\">\n\n                      <az-panel [header]=\"editorTitle\">\n                              <ng-content></ng-content>\n                      </az-panel> \n\n                  </div> <!--Modal Body-->\n                  <div class=\"modal-footer\">\n                      <button type=\"button\" class=\"btn btn-primary\" (click)=\"onCommitEdit()\" [disabled]=\"!validForm\">Aceptar</button>\n                      <button type=\"button\" class=\"btn btn-danger\" (click)=\"onCancelEdit()\">Cancelar</button>\n                  </div> <!--Modal Footer-->\n\n              </div> <!-- Modal Content-->\n          </div> <!--Modal-->\n      </div> <!--Modal directive-->\n\n\n      <div bsModal #confirmDelDialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"mySmallModalLabel\" aria-hidden=\"true\">\n          <div class=\"modal-dialog modal-sm\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-body\">\n                      <div>\u00BFEst\u00E1 seguro que desea eliminar el nodo seleccionado?</div>\n                  </div> <!--Modal Body-->\n                  <div class=\"modal-footer\">\n                      <button type=\"button\" class=\"btn btn-primary\" (click)=\"confirmDelete()\">Aceptar</button>\n                      <button type=\"button\" class=\"btn btn-default\" (click)=\"confirmDelDialog.hide()\">Cancelar</button>                \n                  </div> <!--Modal Footer-->\n\n              </div> <!-- Modal Content-->\n          </div> <!--Modal-->\n      </div> <!--Modal directive-->\n\n      <div bsModal #discardChangesDialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"mySmallModalLabel\" aria-hidden=\"true\">\n          <div class=\"modal-dialog modal-sm\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-body\">\n                      <div>Existen cambios sin guardar. \u00BFDesea descartarlos?</div>\n                  </div> <!--Modal Body-->\n                  <div class=\"modal-footer\">\n                      <button type=\"button\" class=\"btn btn-primary\" (click)=\"cancelDiscard()\">Cancelar</button>\n                      <button type=\"button\" class=\"btn btn-default\" (click)=\"discardChanges()\">Descartar</button>\n                  </div> <!--Modal Footer-->\n              </div> <!-- Modal Content-->\n          </div> <!--Modal-->\n      </div> <!--Modal directive-->\n    "
        }),
        __metadata("design:paramtypes", [Context, CatalogService, Router,
            ActivatedRoute, Location, ChangeDetectorRef])
    ], HierarchyManagerComponent);
    return HierarchyManagerComponent;
}());
export { HierarchyManagerComponent };
