var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, ViewChild, forwardRef, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators } from '@angular/forms';
import { Location } from '@angular/common';
//Azteca Kernel
import { Context, BaseComponent, CatalogService } from '../../core';
import { CatalogEditor } from '../../editors';
//Features
import { CalendarioService } from '../services/calendario.service';
import { CalendarioInfo } from '../models/calendario';
import { CalendarioCreateComponent } from '../components/calendarios-create.component';
var CalendariosEditor = /** @class */ (function (_super) {
    __extends(CalendariosEditor, _super);
    //
    function CalendariosEditor(router, route, formBuilder, changeDetector, context, location, calendarioService) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.changeDetector = changeDetector;
        _this.context = context;
        _this.location = location;
        _this.calendarioService = calendarioService;
        _this.calendario = new CalendarioInfo();
        _this.catalogForm = formBuilder.group({
            'codigo': ['', Validators.required],
            'nombre': ['', Validators.required],
            'sample_field': ['']
        });
        return _this;
    }
    CalendariosEditor_1 = CalendariosEditor;
    ///////////////////////// METODOS ///////////////////////////////////////
    ///////////////////////// HANDLERS ///////////////////////////////////////
    CalendariosEditor.prototype.onConfigureCatalog = function (options) {
        this.autogeneratedCode = options.codigoAutogenerado;
        this.applyPolicies();
    };
    CalendariosEditor.prototype.onCreatingItem = function () {
    };
    CalendariosEditor.prototype.onViewingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.calendarioService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.calendario = info;
            _this.setReadonlyMode();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    CalendariosEditor.prototype.onCloningItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        //
        this.calendarioService.clone(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.calendario = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    CalendariosEditor.prototype.onLoadingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.calendarioService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.calendario = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    CalendariosEditor.prototype.onSavingItem = function (args) {
        var _this = this;
        this.context.app.showSpinner();
        this.calendarioService.update(this.calendario)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.reset();
            //Si es un elemento nuevo y no se cerrará el editor, navegar a nueva ruta
            if (!args.closeEditor && _this.calendario.identity == 0) {
                _this.router.navigate(['../', info.identity], { relativeTo: _this.route });
            }
            else {
                if (args.closeEditor)
                    _this.router.navigate(['../'], { relativeTo: _this.route });
                else
                    _this.showAlert('La información ha sido actualizada con éxito', 'success');
            }
            _this.calendario = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    CalendariosEditor.prototype.onMenuItemClick = function (item) {
        if (item.name == 'CREATE') {
            this.dlgCalendarCreate.showCreate(this.calendario.identity);
        }
        if (item.name == 'FREE') {
            this.router.navigate(['dias-festivos'], { relativeTo: this.route });
        }
        else if (item.name == 'HABILES') {
            this.router.navigate(['dias-habiles'], { relativeTo: this.route });
        }
    };
    var CalendariosEditor_1;
    __decorate([
        ViewChild('dlgCalendarCreate'),
        __metadata("design:type", CalendarioCreateComponent)
    ], CalendariosEditor.prototype, "dlgCalendarCreate", void 0);
    CalendariosEditor = CalendariosEditor_1 = __decorate([
        Component({
            selector: 'general-calendario-editor',
            template: "\n      <form [formGroup]=\"catalogForm\">\n\n          <azteca-catalog-editor #catalogEditor\n                                 [title]=\"'Calendario'\"\n                                 [info]=\"calendario\"\n                                 [valid]=\"valid\"\n                                 (configureCatalog)=\"onConfigureCatalog($event)\"\n                                 (creatingItem)=\"onCreatingItem()\"\n                                 (viewingItem)=\"onViewingItem($event)\"\n                                 (cloningItem)=\"onCloningItem($event)\"\n                                 (savingItem)=\"onSavingItem($event)\"\n                                 (loadingItem)=\"onLoadingItem($event)\"\n                                 (menuItemClick)=\"onMenuItemClick($event)\">\n\n\n              <!------------------- Menu de acciones adicionales --------------------->\n              <azteca-menu-item [name]=\"'CREATE'\" [icon]=\"'glyphicon glyphicon-cog'\" [text]=\"'Generar'\" [smallText]=\"'generar el calendario'\"></azteca-menu-item>\n              <azteca-menu-item [name]=\"'FREE'\" [icon]=\"'glyphicon glyphicon-certificate'\" [text]=\"'Dias festivos'\" [smallText]=\"'editar dias festivos'\"></azteca-menu-item>\n              <azteca-menu-item [name]=\"'HABILES'\" [icon]=\"'glyphicon glyphicon-cog'\" [text]=\"'Dias habiles'\" [smallText]=\"'editar dias habiles'\"></azteca-menu-item>\n              <!------------------- Controles del editor ----------------------------->\n\n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <azteca-form-field [label]=\"'C\u00F3digo:'\">\n                          <catalog-code formControlName=\"codigo\" [(ngModel)]=\"calendario.code\" [automatic]=\"autogeneratedCode\"></catalog-code>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Nombre:'\">\n                          <az-textbox formControlName=\"nombre\" [(ngModel)]=\"calendario.nombre\"></az-textbox>\n                      </azteca-form-field>\n\n                  </div>\n              </div>\n\n              <!--<azteca-schedule></azteca-schedule>-->\n\n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <tabset>\n                          <!--<tab heading=\"Tab1\">\n\n\n                          <div class=\"row\">\n\n                          </div>\n\n\n                      </tab>\n                      <tab heading=\"Tab2\">\n\n                      </tab>-->\n                      </tabset>\n                  </div>\n              </div>\n\n\n          </azteca-catalog-editor>\n      </form>\n\n      <calendario-create #dlgCalendarCreate\n                         (calendarCreated)=\"onCalendarioCreated($event)\">\n\n      </calendario-create>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return CalendariosEditor_1; })
                },
                {
                    provide: CatalogService, useExisting: CalendarioService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, FormBuilder, ChangeDetectorRef,
            Context, Location, CalendarioService])
    ], CalendariosEditor);
    return CalendariosEditor;
}(CatalogEditor));
export { CalendariosEditor };
