var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, Input, forwardRef, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators } from '@angular/forms';
import { Location } from '@angular/common';
import { Control } from 'wijmo/wijmo';
//Azteca Kernel
import { Context, BaseComponent, CatalogService } from '../../core';
import { CatalogEditor } from '../../editors';
import { SearchRequest } from '../../search';
//Features
import { EstadoService } from '../services/estado.service';
import { EstadoInfo } from '../models/estado';
import { MunicipioService } from '../services/municipio.service';
import { CodigoPostalService } from '../services/codigo-postal.service';
var EstadosEditor = /** @class */ (function (_super) {
    __extends(EstadosEditor, _super);
    //
    function EstadosEditor(router, route, formBuilder, changeDetector, context, location, estadoService, municipioService, codigoPostalService) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.changeDetector = changeDetector;
        _this.context = context;
        _this.location = location;
        _this.estadoService = estadoService;
        _this.municipioService = municipioService;
        _this.codigoPostalService = codigoPostalService;
        _this.estado = new EstadoInfo();
        _this.municipios = [];
        _this.codigosPostales = [];
        _this.catalogForm = formBuilder.group({
            'codigo': ['', Validators.required],
            'nombre': ['', Validators.required],
            'referencia': ['']
        });
        return _this;
    }
    EstadosEditor_1 = EstadosEditor;
    ///////////////////////// METODOS ///////////////////////////////////////
    ///////////////////////// HANDLERS ///////////////////////////////////////
    EstadosEditor.prototype.onConfigureCatalog = function (options) {
        var _this = this;
        this.route.params.forEach(function (params) {
            _this.idPais = +params['idPais'];
        });
        this.autogeneratedCode = options.codigoAutogenerado;
    };
    EstadosEditor.prototype.onCreatingItem = function () {
        //Asignar y cargar datos de la empresa que dependerá la sucursal
        this.estado.idPais = this.idPais;
    };
    EstadosEditor.prototype.onViewingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.estadoService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.estado = info;
            _this.setReadonlyMode();
            _this.loadMunicipios();
            _this.loadCodigosPostales();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    EstadosEditor.prototype.onCloningItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        //
        this.estadoService.clone(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.estado = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    EstadosEditor.prototype.onLoadingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.estadoService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.estado = info;
            _this.loadMunicipios();
            _this.loadCodigosPostales();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    EstadosEditor.prototype.onSavingItem = function (args) {
        var _this = this;
        this.context.app.showSpinner();
        this.estadoService.update(this.estado)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.estado = info;
            _this.reset();
            if (args.closeEditor)
                _this.location.back();
            else
                _this.showAlert('La información ha sido actualizada con éxito', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    EstadosEditor.prototype.onCancelingEdit = function () {
        this.location.back();
    };
    //Manejo de Estados
    EstadosEditor.prototype.selectMunicipiosTab = function () {
        Control.invalidateAll();
    };
    EstadosEditor.prototype.selectCodigosPostalesTab = function () {
        Control.invalidateAll();
    };
    EstadosEditor.prototype.loadMunicipios = function () {
        var _this = this;
        var request = new SearchRequest();
        request.paged = false;
        //Agregar condición de empresa actual
        var condicionEstado = { field: "idEstado", operator: "=", valueType: "int", value: this.estado.identity.toString() };
        request.conditions.push(condicionEstado);
        //
        this.context.app.showSpinner();
        this.municipioService.search(this.context.app.defaultSite.identity, request)
            .then(function (response) {
            _this.context.app.hideSpinner();
            //
            _this.municipios = response.rows;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    EstadosEditor.prototype.loadCodigosPostales = function () {
        var _this = this;
        var request = new SearchRequest();
        request.paged = false;
        //Agregar condición de empresa actual
        var condicionEstado = { field: "idEstado", operator: "=", valueType: "int", value: this.estado.identity.toString() };
        request.conditions.push(condicionEstado);
        //
        this.context.app.showSpinner();
        this.codigoPostalService.search(this.context.app.defaultSite.identity, request)
            .then(function (response) {
            _this.context.app.hideSpinner();
            //
            _this.codigosPostales = response.rows;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    var EstadosEditor_1;
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], EstadosEditor.prototype, "municipios", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], EstadosEditor.prototype, "codigosPostales", void 0);
    EstadosEditor = EstadosEditor_1 = __decorate([
        Component({
            selector: 'general-estados-editor',
            template: "\n      <form [formGroup]=\"catalogForm\">\n\n          <azteca-catalog-editor #catalogEditor \n                                 [title]=\"'Entidades geogr\u00E1ficas - Estado'\"\n                                 [info]=\"estado\"\n                                 [valid]=\"valid\"\n                                 (configureCatalog)=\"onConfigureCatalog($event)\"\n                                 (creatingItem)=\"onCreatingItem()\"\n                                 (viewingItem)=\"onViewingItem($event)\"\n                                 (cloningItem)=\"onCloningItem($event)\"\n                                 (savingItem)=\"onSavingItem($event)\"\n                                 (loadingItem)=\"onLoadingItem($event)\">\n\n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <azteca-form-field [label]=\"'C\u00F3digo:'\">\n                          <catalog-code formControlName=\"codigo\" [(ngModel)]=\"estado.code\" [automatic]=\"autogeneratedCode\"></catalog-code>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Nombre:'\">\n                          <az-textbox formControlName=\"nombre\" [(ngModel)]=\"estado.nombre\"></az-textbox>\n                      </azteca-form-field>\n                      <azteca-form-field [label]=\"'Referencia:'\">\n                          <az-textbox formControlName=\"referencia\" [(ngModel)]=\"estado.referencia\"></az-textbox>\n                      </azteca-form-field>\n                  </div>\n              </div>\n\n        \n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <tabset>\n                          <tab heading=\"Municipios\" [disabled]=\"estado.identity == 0\" (select)=\"selectMunicipiosTab()\">\n                              <div class=\"row\">\n                                  <div class=\"col-12\">\n                                      <general-municipios-manager [name]=\"'municipios'\"\n                                                                  [municipios]=\"municipios\"\n                                                                  [idEstado]=\"estado.identity\"\n                                                                  (refreshListParent)=\"loadMunicipios()\">\n                                      </general-municipios-manager>\n                                  </div>\n                              </div>\n                          </tab>\n                          <tab heading=\"Codigos Postales\" [disabled]=\"estado.identity == 0\" (select)=\"selectCodigosPostalesTab()\">\n                              <div class=\"row\">\n                                  <div class=\"col-12\">\n                                      <general-codigos-postales-manager [name]=\"'codigospostales'\"\n                                                                       [codigospostales]=\"codigosPostales\"\n                                                                       [idEstado]=\"estado.identity\"\n                                                                       (refreshListParent)=\"loadCodigosPostales()\">\n                                      </general-codigos-postales-manager>\n                                  </div>\n                              </div>\n                          </tab>\n                      </tabset>\n\n                  </div>\n              </div>\n     \n\n          </azteca-catalog-editor>\n      </form>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return EstadosEditor_1; })
                },
                {
                    provide: CatalogService, useExisting: EstadoService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, FormBuilder, ChangeDetectorRef,
            Context, Location, EstadoService, MunicipioService, CodigoPostalService])
    ], EstadosEditor);
    return EstadosEditor;
}(CatalogEditor));
export { EstadosEditor };
