var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, forwardRef, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators } from '@angular/forms';
import { Location } from '@angular/common';
//Azteca Kernel
import { Context, BaseComponent, CatalogService } from '../../core';
import { CatalogEditor } from '../../editors';
//Features
import { FormatoService } from '../services/formato.service';
import { FormatoInfo } from '../models/formato';
var FormatosEditor = /** @class */ (function (_super) {
    __extends(FormatosEditor, _super);
    //
    function FormatosEditor(router, route, formBuilder, changeDetector, context, location, formatoService) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.changeDetector = changeDetector;
        _this.context = context;
        _this.location = location;
        _this.formatoService = formatoService;
        _this.formato = new FormatoInfo();
        _this.catalogForm = formBuilder.group({
            'codigo': [''],
            'nombre': ['', Validators.required],
            'archivo': [null]
        });
        return _this;
    }
    FormatosEditor_1 = FormatosEditor;
    ///////////////////////// METODOS ///////////////////////////////////////
    ///////////////////////// HANDLERS ///////////////////////////////////////
    FormatosEditor.prototype.onConfigureCatalog = function (options) {
        var _this = this;
        this.route.params.forEach(function (params) {
            _this.idFormatoTipo = +params['idFormatoTipo'];
        });
        this.autogeneratedCode = options.codigoAutogenerado;
    };
    FormatosEditor.prototype.onCreatingItem = function () {
        //Asignar y cargar datos de la empresa que dependerá el formato
        this.formato.idFormatoTipo = this.idFormatoTipo;
    };
    FormatosEditor.prototype.onViewingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.formatoService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.formato = info;
            _this.setReadonlyMode();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    FormatosEditor.prototype.onCloningItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        //
        this.formatoService.clone(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.formato = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    FormatosEditor.prototype.onLoadingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.formatoService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.formato = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    FormatosEditor.prototype.onSavingItem = function (args) {
        var _this = this;
        this.context.app.showSpinner();
        this.formatoService.update(this.formato)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.formato = info;
            _this.reset();
            if (args.closeEditor)
                _this.location.back();
            else
                _this.showAlert('La información ha sido actualizada con éxito', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    FormatosEditor.prototype.onCancelingEdit = function () {
        this.location.back();
    };
    var FormatosEditor_1;
    FormatosEditor = FormatosEditor_1 = __decorate([
        Component({
            selector: 'general-formatos-editor',
            template: "\n      <form [formGroup]=\"catalogForm\">\n\n          <azteca-catalog-editor #catalogEditor \n                                 [title]=\"'Formato'\"\n                                 [info]=\"formato\"\n                                 [valid]=\"valid\"\n                                 (configureCatalog)=\"onConfigureCatalog($event)\"\n                                 (creatingItem)=\"onCreatingItem()\"\n                                 (viewingItem)=\"onViewingItem($event)\"\n                                 (cloningItem)=\"onCloningItem($event)\"\n                                 (savingItem)=\"onSavingItem($event)\"\n                                 (loadingItem)=\"onLoadingItem($event)\">\n\n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <azteca-form-field [label]=\"'C\u00F3digo:'\">\n                          <catalog-code formControlName=\"codigo\" [(ngModel)]=\"formato.code\" [automatic]=\"autogeneratedCode\"></catalog-code>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Nombre:'\">\n                          <az-textbox formControlName=\"nombre\" [(ngModel)]=\"formato.nombre\"></az-textbox>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Archivo del formato:'\">\n                          <azteca-file-box formControlName=\"archivo\" [(ngModel)]=\"formato.archivo\"></azteca-file-box>\n                      </azteca-form-field>\n\n                  </div>\n              </div>\n\n          </azteca-catalog-editor>\n      </form>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return FormatosEditor_1; })
                },
                {
                    provide: CatalogService, useExisting: FormatoService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, FormBuilder, ChangeDetectorRef,
            Context, Location, FormatoService])
    ], FormatosEditor);
    return FormatosEditor;
}(CatalogEditor));
export { FormatosEditor };
