var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, forwardRef, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators } from '@angular/forms';
import { Location } from '@angular/common';
//Azteca Kernel
import { Context, BaseComponent, CatalogService } from '../../core';
import { CatalogEditor } from '../../editors';
//Features
import { IdiomaService } from '../services/idioma.service';
import { IdiomaInfo } from '../models/idioma';
var IdiomasEditor = /** @class */ (function (_super) {
    __extends(IdiomasEditor, _super);
    //
    function IdiomasEditor(router, route, formBuilder, changeDetector, context, location, idiomaService) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.changeDetector = changeDetector;
        _this.context = context;
        _this.location = location;
        _this.idiomaService = idiomaService;
        _this.idioma = new IdiomaInfo();
        _this.catalogForm = formBuilder.group({
            'codigo': ['', Validators.required],
            'nombre': ['', Validators.required],
            'sample_field': ['']
        });
        return _this;
    }
    IdiomasEditor_1 = IdiomasEditor;
    ///////////////////////// METODOS ///////////////////////////////////////
    ///////////////////////// HANDLERS ///////////////////////////////////////
    IdiomasEditor.prototype.onConfigureCatalog = function (options) {
        this.autogeneratedCode = options.codigoAutogenerado;
        this.applyPolicies();
    };
    IdiomasEditor.prototype.onCreatingItem = function () {
    };
    IdiomasEditor.prototype.onViewingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.idiomaService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.idioma = info;
            _this.setReadonlyMode();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    IdiomasEditor.prototype.onCloningItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        //
        this.idiomaService.clone(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.idioma = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    IdiomasEditor.prototype.onLoadingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.idiomaService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.idioma = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    IdiomasEditor.prototype.onSavingItem = function (args) {
        var _this = this;
        this.context.app.showSpinner();
        this.idiomaService.update(this.idioma)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.reset();
            //Si es un elemento nuevo y no se cerrará el editor, navegar a nueva ruta
            if (!args.closeEditor && _this.idioma.identity == 0) {
                _this.router.navigate(['../', info.identity], { relativeTo: _this.route });
            }
            else {
                if (args.closeEditor)
                    _this.router.navigate(['../'], { relativeTo: _this.route });
                else
                    _this.showAlert('La información ha sido actualizada con éxito', 'success');
            }
            _this.idioma = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    var IdiomasEditor_1;
    IdiomasEditor = IdiomasEditor_1 = __decorate([
        Component({
            selector: 'general-idioma-editor',
            template: "\n      <form [formGroup]=\"catalogForm\">\n\n          <azteca-catalog-editor #catalogEditor \n                                 [title]=\"'Idioma'\"\n                                 [info]=\"idioma\"\n                                 [valid]=\"valid\"\n                                 (configureCatalog)=\"onConfigureCatalog($event)\"\n                                 (creatingItem)=\"onCreatingItem()\"\n                                 (viewingItem)=\"onViewingItem($event)\"\n                                 (cloningItem)=\"onCloningItem($event)\"\n                                 (savingItem)=\"onSavingItem($event)\"\n                                 (loadingItem)=\"onLoadingItem($event)\">\n\n\n              <!------------------- Menu de acciones adicionales --------------------->\n\n              <!------------------- Controles del editor ----------------------------->\n\n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <azteca-form-field [label]=\"'C\u00F3digo:'\">\n                          <catalog-code formControlName=\"codigo\" [(ngModel)]=\"idioma.code\" [automatic]=\"autogeneratedCode\"></catalog-code>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Nombre:'\">\n                          <az-textbox formControlName=\"nombre\" [(ngModel)]=\"idioma.nombre\"></az-textbox>\n                      </azteca-form-field>\n\n                  </div>\n              </div>\n\n        \n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <tabset>\n                   \n                      </tabset>\n                  </div>\n              </div>\n            \n\n          </azteca-catalog-editor>\n      </form>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return IdiomasEditor_1; })
                },
                {
                    provide: CatalogService, useExisting: IdiomaService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, FormBuilder, ChangeDetectorRef,
            Context, Location, IdiomaService])
    ], IdiomasEditor);
    return IdiomasEditor;
}(CatalogEditor));
export { IdiomasEditor };
