var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, forwardRef, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators } from '@angular/forms';
import { Location } from '@angular/common';
//Azteca Kernel
import { Context, BaseComponent, CatalogService } from '../../core';
import { CatalogEditor } from '../../editors';
//Features
import { ImpresoraService } from '../services/impresora.service';
import { ImpresoraInfo } from '../models/impresora';
var ImpresorasEditor = /** @class */ (function (_super) {
    __extends(ImpresorasEditor, _super);
    //
    function ImpresorasEditor(router, route, formBuilder, changeDetector, context, location, impresoraService) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.changeDetector = changeDetector;
        _this.context = context;
        _this.location = location;
        _this.impresoraService = impresoraService;
        _this.impresora = new ImpresoraInfo();
        _this.catalogForm = formBuilder.group({
            'codigo': ['', Validators.required],
            'nombre': ['', Validators.required],
            'ruta': ['', Validators.required]
        });
        return _this;
    }
    ImpresorasEditor_1 = ImpresorasEditor;
    ///////////////////////// METODOS ///////////////////////////////////////
    ///////////////////////// HANDLERS ///////////////////////////////////////
    ImpresorasEditor.prototype.onConfigureCatalog = function (options) {
        this.autogeneratedCode = options.codigoAutogenerado;
    };
    ImpresorasEditor.prototype.onCreatingItem = function () {
    };
    ImpresorasEditor.prototype.onViewingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.impresoraService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.impresora = info;
            _this.setReadonlyMode();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    ImpresorasEditor.prototype.onCloningItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        //
        this.impresoraService.clone(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.impresora = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    ImpresorasEditor.prototype.onLoadingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.impresoraService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.impresora = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    ImpresorasEditor.prototype.onSavingItem = function (args) {
        var _this = this;
        this.context.app.showSpinner();
        this.impresoraService.update(this.impresora)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.impresora = info;
            _this.reset();
            if (args.closeEditor)
                _this.location.back();
            else
                _this.showAlert('La información ha sido actualizada con éxito', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    var ImpresorasEditor_1;
    ImpresorasEditor = ImpresorasEditor_1 = __decorate([
        Component({
            selector: 'general-impresoras-editor',
            template: "\n      <form [formGroup]=\"catalogForm\">\n\n          <azteca-catalog-editor #catalogEditor \n                                 [title]=\"'Impresora'\"\n                                 [info]=\"impresora\"\n                                 [valid]=\"valid\"\n                                 (configureCatalog)=\"onConfigureCatalog($event)\"\n                                 (creatingItem)=\"onCreatingItem()\"\n                                 (viewingItem)=\"onViewingItem($event)\"\n                                 (cloningItem)=\"onCloningItem($event)\"\n                                 (savingItem)=\"onSavingItem($event)\"\n                                 (loadingItem)=\"onLoadingItem($event)\">\n\n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <azteca-form-field [label]=\"'C\u00F3digo:'\">\n                          <catalog-code formControlName=\"codigo\" [(ngModel)]=\"impresora.code\" [automatic]=\"autogeneratedCode\"></catalog-code>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Nombre:'\">\n                          <az-textbox formControlName=\"nombre\" [(ngModel)]=\"impresora.nombre\"></az-textbox>\n                      </azteca-form-field>\n\n                  </div>\n              </div>\n\n        \n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <tabset>\n                          <tab heading=\"Generales\">\n\t\t\t\t\t\t\n                              <div class=\"row\">\n                                  <div class=\"col-12 col-md-10\">\n\n                                      <azteca-form-field [label]=\"'Ruta:'\">\n                                          <az-textbox formControlName=\"ruta\" [(ngModel)]=\"impresora.ruta\"></az-textbox>\n                                      </azteca-form-field>\n\n                                  </div>\n                              </div>\t\t\t\t\t\n\n                          </tab>\n                    \n                      </tabset>\n                  </div>\n              </div>\n            \n\n          </azteca-catalog-editor>\n      </form>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return ImpresorasEditor_1; })
                },
                {
                    provide: CatalogService, useExisting: ImpresoraService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, FormBuilder, ChangeDetectorRef,
            Context, Location, ImpresoraService])
    ], ImpresorasEditor);
    return ImpresorasEditor;
}(CatalogEditor));
export { ImpresorasEditor };
