var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, Input, forwardRef, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators } from '@angular/forms';
import { Location } from '@angular/common';
import { Control } from 'wijmo/wijmo';
//Azteca Kernel
import { Context, BaseComponent, CatalogService } from '../../core';
import { CatalogEditor } from '../../editors';
import { SearchRequest } from '../../search';
//Features
import { MunicipioService } from '../services/municipio.service';
import { MunicipioInfo } from '../models/municipio';
import { PoblacionService } from '../services/poblacion.service';
import { AsentamientoHumanoService } from '../services/asentamiento-humano.service';
var MunicipiosEditor = /** @class */ (function (_super) {
    __extends(MunicipiosEditor, _super);
    //
    function MunicipiosEditor(router, route, formBuilder, changeDetector, context, location, municipioService, poblacionService, asentamientoHumanoService) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.changeDetector = changeDetector;
        _this.context = context;
        _this.location = location;
        _this.municipioService = municipioService;
        _this.poblacionService = poblacionService;
        _this.asentamientoHumanoService = asentamientoHumanoService;
        _this.municipio = new MunicipioInfo();
        _this.poblaciones = [];
        _this.asentamientosHumanos = [];
        _this.catalogForm = formBuilder.group({
            'codigo': ['', Validators.required],
            'nombre': ['', Validators.required],
            'referencia': ['']
        });
        return _this;
    }
    MunicipiosEditor_1 = MunicipiosEditor;
    ///////////////////////// METODOS ///////////////////////////////////////
    ///////////////////////// HANDLERS ///////////////////////////////////////
    MunicipiosEditor.prototype.onConfigureCatalog = function (options) {
        var _this = this;
        this.route.params.forEach(function (params) {
            _this.idEstado = +params['idEstado'];
        });
        this.autogeneratedCode = options.codigoAutogenerado;
    };
    MunicipiosEditor.prototype.onCreatingItem = function () {
        this.municipio.idEstado = this.idEstado;
    };
    MunicipiosEditor.prototype.onViewingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.municipioService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.municipio = info;
            _this.setReadonlyMode();
            _this.loadPoblaciones();
            _this.loadAsentamientosHumanos();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    MunicipiosEditor.prototype.onCloningItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        //
        this.municipioService.clone(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.municipio = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    MunicipiosEditor.prototype.onLoadingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.municipioService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.municipio = info;
            _this.loadPoblaciones();
            _this.loadAsentamientosHumanos();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    MunicipiosEditor.prototype.onSavingItem = function (args) {
        var _this = this;
        this.context.app.showSpinner();
        this.municipioService.update(this.municipio)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.municipio = info;
            _this.reset();
            if (args.closeEditor)
                _this.location.back();
            else
                _this.showAlert('La información ha sido actualizada con éxito', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    MunicipiosEditor.prototype.onCancelingEdit = function () {
        this.location.back();
    };
    //Manejo de Estados
    MunicipiosEditor.prototype.selectPoblacionesTab = function () {
        Control.invalidateAll();
    };
    MunicipiosEditor.prototype.selectAsentamientosTab = function () {
        Control.invalidateAll();
    };
    MunicipiosEditor.prototype.loadPoblaciones = function () {
        var _this = this;
        var request = new SearchRequest();
        request.paged = false;
        //Agregar condición de empresa actual
        var condicionMunicipio = { field: "idMunicipio", operator: "=", valueType: "int", value: this.municipio.identity.toString() };
        request.conditions.push(condicionMunicipio);
        //
        this.context.app.showSpinner();
        this.poblacionService.search(this.context.app.defaultSite.identity, request)
            .then(function (response) {
            _this.context.app.hideSpinner();
            //
            _this.poblaciones = response.rows;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    MunicipiosEditor.prototype.loadAsentamientosHumanos = function () {
        var _this = this;
        var request = new SearchRequest();
        request.paged = false;
        //Agregar condición de empresa actual
        var condicionMunicipio = { field: "IdMunicipio", operator: "=", valueType: "int", value: this.municipio.identity.toString() };
        request.conditions.push(condicionMunicipio);
        //
        this.context.app.showSpinner();
        this.asentamientoHumanoService.search(this.context.app.defaultSite.identity, request)
            .then(function (response) {
            _this.context.app.hideSpinner();
            //
            _this.asentamientosHumanos = response.rows;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    var MunicipiosEditor_1;
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], MunicipiosEditor.prototype, "poblaciones", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], MunicipiosEditor.prototype, "asentamientosHumanos", void 0);
    MunicipiosEditor = MunicipiosEditor_1 = __decorate([
        Component({
            selector: 'general-municipios-editor',
            template: "\n      <form [formGroup]=\"catalogForm\">\n\n          <azteca-catalog-editor #catalogEditor \n                                 [title]=\"'Entidades geogr\u00E1ficas - Municipio'\"\n                                 [info]=\"municipio\"\n                                 [valid]=\"valid\"\n                                 (configureCatalog)=\"onConfigureCatalog($event)\"\n                                 (creatingItem)=\"onCreatingItem()\"\n                                 (viewingItem)=\"onViewingItem($event)\"\n                                 (cloningItem)=\"onCloningItem($event)\"\n                                 (savingItem)=\"onSavingItem($event)\"\n                                 (loadingItem)=\"onLoadingItem($event)\">\n\n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <azteca-form-field [label]=\"'C\u00F3digo:'\">\n                          <catalog-code formControlName=\"codigo\" [(ngModel)]=\"municipio.code\" [automatic]=\"autogeneratedCode\"></catalog-code>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Nombre:'\">\n                          <az-textbox formControlName=\"nombre\" [(ngModel)]=\"municipio.nombre\"></az-textbox>\n                      </azteca-form-field>\n                      <azteca-form-field [label]=\"'Referencia:'\">\n                          <az-textbox formControlName=\"referencia\" [(ngModel)]=\"municipio.referencia\"></az-textbox>\n                      </azteca-form-field>\n                  </div>\n              </div>\n\n        \n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <tabset>\n                          <tab heading=\"Poblaciones\" [disabled]=\"municipio.identity == 0\" (select)=\"selectPoblacionesTab()\">\n                              <div class=\"row\">\n                                  <div class=\"col-12\">\n                                      <general-poblaciones-manager [name]=\"'poblaciones'\"\n                                                                   [poblaciones]=\"poblaciones\"\n                                                                   [idMunicipio]=\"municipio.identity\"\n                                                                   (refreshListParent)=\"loadPoblaciones()\">\n                                      </general-poblaciones-manager>\n                                  </div>\n                              </div>\n                          </tab>\n\n                          <tab heading=\"Asentamientos Humanos\" [disabled]=\"municipio.identity == 0\" (select)=\"selectAsentamientosTab()\">\n                              <div class=\"row\">\n                                  <div class=\"col-12\">\n                                      <general-asentamiento-humano-manager [name]=\"'asentamientoHumano'\"\n                                                                       [asentamientosHumanos]=\"asentamientosHumanos\"\n                                                                       [idMunicipio]=\"municipio.identity\"\n                                                                       (refreshListParent)=\"loadAsentamientosHumanos()\">\n                                      </general-asentamiento-humano-manager>\n                                  </div>\n                              </div>\n                          </tab>\n                      </tabset>\n                  </div>\n              </div>\n            \n\n          </azteca-catalog-editor>\n      </form>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return MunicipiosEditor_1; })
                },
                {
                    provide: CatalogService, useExisting: MunicipioService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, FormBuilder, ChangeDetectorRef,
            Context, Location, MunicipioService, PoblacionService, AsentamientoHumanoService])
    ], MunicipiosEditor);
    return MunicipiosEditor;
}(CatalogEditor));
export { MunicipiosEditor };
