var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, Input, forwardRef, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators } from '@angular/forms';
import { Location } from '@angular/common';
import { Control } from 'wijmo/wijmo';
//Azteca Kernel
import { Context, BaseComponent, CatalogService } from '../../core';
import { CatalogEditor } from '../../editors';
import { SearchRequest } from '../../search';
//Features
import { PaisService } from '../services/pais.service';
import { PaisInfo } from '../models/pais';
import { EstadoService } from '../services/estado.service';
var PaisesEditor = /** @class */ (function (_super) {
    __extends(PaisesEditor, _super);
    //
    function PaisesEditor(router, route, formBuilder, changeDetector, context, location, paisService, estadoService) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.changeDetector = changeDetector;
        _this.context = context;
        _this.location = location;
        _this.paisService = paisService;
        _this.estadoService = estadoService;
        _this.pais = new PaisInfo();
        _this.estados = [];
        _this.catalogForm = formBuilder.group({
            'codigo': ['', Validators.required],
            'nombre': ['', Validators.required],
            'referencia': ['']
        });
        return _this;
    }
    PaisesEditor_1 = PaisesEditor;
    ///////////////////////// METODOS ///////////////////////////////////////
    ///////////////////////// HANDLERS ///////////////////////////////////////
    PaisesEditor.prototype.onConfigureCatalog = function (options) {
        this.autogeneratedCode = options.codigoAutogenerado;
    };
    PaisesEditor.prototype.onCreatingItem = function () {
    };
    PaisesEditor.prototype.onViewingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.paisService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.pais = info;
            _this.setReadonlyMode();
            _this.loadEstados();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    PaisesEditor.prototype.onCloningItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        //
        this.paisService.clone(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.pais = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    PaisesEditor.prototype.onLoadingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.paisService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.pais = info;
            _this.loadEstados();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    PaisesEditor.prototype.onSavingItem = function (args) {
        var _this = this;
        this.context.app.showSpinner();
        this.paisService.update(this.pais)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.pais = info;
            _this.reset();
            if (args.closeEditor)
                _this.location.back();
            else
                _this.showAlert('La información ha sido actualizada con éxito', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    //Manejo de Estados
    PaisesEditor.prototype.selectEstadosTab = function () {
        Control.invalidateAll();
    };
    PaisesEditor.prototype.loadEstados = function () {
        var _this = this;
        var request = new SearchRequest();
        request.paged = false;
        //Agregar condición de empresa actual
        var condicionServidorSMTP = { field: "idPais", operator: "=", valueType: "int", value: this.pais.identity.toString() };
        request.conditions.push(condicionServidorSMTP);
        //
        this.context.app.showSpinner();
        this.estadoService.search(this.context.app.defaultSite.identity, request)
            .then(function (response) {
            _this.context.app.hideSpinner();
            //
            _this.estados = response.rows;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    var PaisesEditor_1;
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], PaisesEditor.prototype, "estados", void 0);
    PaisesEditor = PaisesEditor_1 = __decorate([
        Component({
            selector: 'general-paises-editor',
            template: "\n      <form [formGroup]=\"catalogForm\">\n\n          <azteca-catalog-editor #catalogEditor \n                                 [title]=\"'Entidades geogr\u00E1ficas - Editando pais'\"\n                                 [info]=\"pais\"\n                                 [valid]=\"valid\"\n                                 (configureCatalog)=\"onConfigureCatalog($event)\"\n                                 (creatingItem)=\"onCreatingItem()\"\n                                 (viewingItem)=\"onViewingItem($event)\"\n                                 (cloningItem)=\"onCloningItem($event)\"\n                                 (savingItem)=\"onSavingItem($event)\"\n                                 (loadingItem)=\"onLoadingItem($event)\">\n\n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <azteca-form-field [label]=\"'C\u00F3digo:'\">\n                          <catalog-code formControlName=\"codigo\" [(ngModel)]=\"pais.code\" [automatic]=\"autogeneratedCode\"></catalog-code>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Nombre:'\">\n                          <az-textbox formControlName=\"nombre\" [(ngModel)]=\"pais.nombre\"></az-textbox>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Referencia:'\">\n                          <az-textbox formControlName=\"referencia\" [(ngModel)]=\"pais.referencia\"></az-textbox>\n                      </azteca-form-field>\n                  </div>\n              </div>\n\n        \n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <tabset>\n                          <tab heading=\"Estados\" [disabled]=\"pais.identity == 0\" (select)=\"selectEstadosTab()\">\n                              <div class=\"row\">\n                                  <div class=\"col-12\">\n                                      <general-estados-manager [name]=\"'estados'\"\n                                                               [estados]=\"estados\"\n                                                               [idPais]=\"pais.identity\"\n                                                               (refreshListParent)=\"loadEstados()\">\n                                      </general-estados-manager>\n                                  </div>\n                              </div>\n                          </tab>\n                      </tabset>\n                  </div>\n              </div>\n            \n\n          </azteca-catalog-editor>\n      </form>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return PaisesEditor_1; })
                },
                {
                    provide: CatalogService, useExisting: PaisService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, FormBuilder, ChangeDetectorRef,
            Context, Location, PaisService, EstadoService])
    ], PaisesEditor);
    return PaisesEditor;
}(CatalogEditor));
export { PaisesEditor };
