var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, forwardRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
//Azteca Kernel
import { Context, BaseComponent, CatalogService } from '../../core';
import { CatalogManager } from '../../editors';
//Features
import { PaisService } from '../services/pais.service';
var PaisesManager = /** @class */ (function (_super) {
    __extends(PaisesManager, _super);
    //    
    function PaisesManager(router, route, context, paisService) {
        var _this = _super.call(this, context, router, route) || this;
        _this.router = router;
        _this.route = route;
        _this.context = context;
        _this.paisService = paisService;
        _this.paises = [];
        return _this;
    }
    PaisesManager_1 = PaisesManager;
    ///////////////////////// METODOS ///////////////////////////////////////
    ///////////////////////// HANDLERS ///////////////////////////////////////
    PaisesManager.prototype.onConfigureCatalog = function (options) {
        this.manager.serverSide = options.busquedasServidor;
        this.manager.pageSize = options.tamanioPagina;
        this.refreshList();
    };
    PaisesManager.prototype.doSearch = function (request) {
        var _this = this;
        this.context.app.showSpinner();
        this.paisService.search(this.context.app.defaultSite.identity, request)
            .then(function (response) {
            _this.context.app.hideSpinner();
            //
            _this.paises = response.rows;
            _this.totalRows = response.totalRows;
            _this.pageIndex = request.pageIndex;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    PaisesManager.prototype.onAddingItem = function () {
        this.router.navigate([0], { relativeTo: this.route });
    };
    PaisesManager.prototype.onViewingItem = function (item) {
        this.router.navigate([item.id, { readonly: true }], { relativeTo: this.route });
    };
    PaisesManager.prototype.onEditingItem = function (item) {
        this.router.navigate([item.id], { relativeTo: this.route });
    };
    PaisesManager.prototype.onDeletingItem = function (item) {
        var _this = this;
        this.paisService.delete(item.id)
            .then(function (success) {
            _this.refreshList();
            _this.showAlert('El registro ha sido eliminado con éxito.', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    PaisesManager.prototype.onCloningItem = function (item) {
        this.router.navigate([0, { cloneId: item.id }], { relativeTo: this.route });
    };
    PaisesManager.prototype.onChangingItemState = function (item) {
        var _this = this;
        this.paisService.changeStatus(item.id, !item.activo)
            .then(function (success) {
            _this.refreshList();
            _this.showAlert('El estatus del registro ha sido actualizado con éxito.', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    var PaisesManager_1;
    PaisesManager = PaisesManager_1 = __decorate([
        Component({
            selector: 'general-paises-manager',
            template: "\n      <div class=\"card\">\n          <div class=\"card-header\">Entidades geogr\u00E1ficas - Lista de pa\u00EDses</div>\n          <div class=\"card-body\">\n              <azteca-catalog-manager (searchRequested)=\"doSearch($event)\"\n                                      (addingItem)=\"onAddingItem()\"\n                                      (viewingItem)=\"onViewingItem($event)\"\n                                      (editingItem)=\"onEditingItem($event)\"\n                                      (deletingItem)=\"onDeletingItem($event)\"\n                                      (cloningItem)=\"onCloningItem($event)\"\n                                      (changingItemState)=\"onChangingItemState($event)\"\n                                      (configureCatalog)=\"onConfigureCatalog($event)\"\n                                      [enabled]=\"enabled\"\n                                      [allowNew]=\"allowNew\"\n                                      [allowView]=\"allowView\"\n                                      [allowEdit]=\"allowEdit\"\n                                      [allowDelete]=\"allowDelete\"\n                                      [allowClone]=\"allowClone\"\n                                      [allowChangeState]=\"allowChangeState\"\n                                      [catalogList]=\"paises\"\n                                      [totalRows]=\"totalRows\"\n                                      [pageIndex]=\"pageIndex\">\n\n\n                  <azteca-grid-column [header]=\"'ID'\" [binding]=\"'id'\" dataType=\"Number\" [width]=\"'10*'\"></azteca-grid-column>\n                  <azteca-grid-column [header]=\"'Codigo'\" [binding]=\"'codigo'\" [width]=\"'10*'\"></azteca-grid-column>\n                  <azteca-grid-column [header]=\"'Nombre'\" [binding]=\"'nombre'\" [width]=\"'60*'\"></azteca-grid-column>\n            \n\n              </azteca-catalog-manager>\n          </div>\n      </div>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return PaisesManager_1; })
                },
                {
                    provide: CatalogService, useExisting: PaisService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, Context, PaisService])
    ], PaisesManager);
    return PaisesManager;
}(CatalogManager));
export { PaisesManager };
