var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, ViewChild, forwardRef, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators } from '@angular/forms';
import { Location } from '@angular/common';
//Azteca Kernel
import { Context, BaseComponent, CatalogService } from '../../core';
import { AzAutocompleteComponent } from '../../controls';
import { CatalogEditor } from '../../editors';
//Features
import { GrupoClasificacionService } from '../services/grupo-clasificacion.service';
import { ParametroService } from '../services/parametro.service';
import { ParametroInfo } from '../models/parametro';
var ParametrosEditor = /** @class */ (function (_super) {
    __extends(ParametrosEditor, _super);
    function ParametrosEditor(router, route, formBuilder, changeDetector, context, location, parametroService, grupoClasificacionService) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.changeDetector = changeDetector;
        _this.context = context;
        _this.location = location;
        _this.parametroService = parametroService;
        _this.grupoClasificacionService = grupoClasificacionService;
        _this.parametro = new ParametroInfo();
        _this.entidades = [];
        _this.entidad = '';
        _this.catalogForm = formBuilder.group({
            'codigo': ['', Validators.required],
            'nombre': ['', Validators.required],
            //'entidad': ['', (control) => this.validaEntidad()],
            'entidad': [''],
            'requerido': [''],
            'validar': [''],
            'expresion': [''],
            'sample_field': ['']
        });
        return _this;
    }
    ParametrosEditor_1 = ParametrosEditor;
    ///////////////////////// METODOS ///////////////////////////////////////
    ///////////////////////// HANDLERS ///////////////////////////////////////
    ParametrosEditor.prototype.onConfigureCatalog = function (options) {
        var _this = this;
        this.loadEntidades();
        this.autogeneratedCode = options.codigoAutogenerado;
        this.applyPolicies();
        this.route.params.forEach(function (param) {
            _this.entidad = param['entidad'];
            _this.parametro.entidad = _this.entidad;
            _this.entidadAutoComplete.text = _this.entidad;
        });
    };
    ParametrosEditor.prototype.onCreatingItem = function () {
    };
    ParametrosEditor.prototype.validaEntidad = function () {
        if (this.entidad != '')
            return this.entidad;
        else
            return null;
    };
    ParametrosEditor.prototype.onViewingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.parametroService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.parametro = info;
            _this.setReadonlyMode();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    ParametrosEditor.prototype.onCloningItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        //
        this.parametroService.clone(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.parametro = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    ParametrosEditor.prototype.onLoadingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.parametroService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.parametro = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    ParametrosEditor.prototype.onSavingItem = function (args) {
        var _this = this;
        this.context.app.showSpinner();
        this.parametroService.update(this.parametro)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.reset();
            //Si es un elemento nuevo y no se cerrará el editor, navegar a nueva ruta
            if (!args.closeEditor && _this.parametro.identity == 0) {
                _this.router.navigate(['../', info.identity], { relativeTo: _this.route });
            }
            else {
                if (args.closeEditor)
                    _this.router.navigate(['../'], { relativeTo: _this.route });
                else
                    _this.showAlert('La información ha sido actualizada con éxito', 'success');
            }
            _this.parametro = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    ParametrosEditor.prototype.loadEntidades = function () {
        var _this = this;
        this.grupoClasificacionService.loadEntidades()
            .then(function (entidades) { return _this.entidades = entidades; })
            .catch(function (error) { return _this.handleError(error); });
    };
    var ParametrosEditor_1;
    __decorate([
        ViewChild(AzAutocompleteComponent),
        __metadata("design:type", AzAutocompleteComponent)
    ], ParametrosEditor.prototype, "entidadAutoComplete", void 0);
    ParametrosEditor = ParametrosEditor_1 = __decorate([
        Component({
            selector: 'general-parametro-editor',
            template: "\n      <form [formGroup]=\"catalogForm\">\n\n          <azteca-catalog-editor #catalogEditor \n                                 [title]=\"'Parametro'\"\n                                 [info]=\"parametro\"\n                                 [valid]=\"valid\"\n                                 (configureCatalog)=\"onConfigureCatalog($event)\"\n                                 (creatingItem)=\"onCreatingItem()\"\n                                 (viewingItem)=\"onViewingItem($event)\"\n                                 (cloningItem)=\"onCloningItem($event)\"\n                                 (savingItem)=\"onSavingItem($event)\"\n                                 (loadingItem)=\"onLoadingItem($event)\">\n\n\n              <!------------------- Menu de acciones adicionales --------------------->\n\n              <!------------------- Controles del editor ----------------------------->\n\n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <azteca-form-field [label]=\"'C\u00F3digo:'\">\n                          <catalog-code formControlName=\"codigo\" [(ngModel)]=\"parametro.code\" [automatic]=\"autogeneratedCode\"></catalog-code>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Nombre:'\">\n                          <az-textbox formControlName=\"nombre\" [(ngModel)]=\"parametro.nombre\"></az-textbox>\n                      </azteca-form-field>\n\n                  </div>\n              </div>\n\n        \n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <tabset>\n                          <tab heading=\"Generales\">\n\n                              <div class=\"row\">\n                                  <div class=\"col-12 col-md-10\">\n\n                                      <azteca-form-field [label]=\"'Entidad:'\">\n                                          <az-autocomplete #entidadAutoComplete\n                                                           formControlName=\"entidad\"\n                                                           [(ngModel)]=\"parametro.entidad\"\n                                                           [items]=\"entidades\"\n                                                           [displayMember]=\"'nombre'\"\n                                                           [enabled]=\"entidad == ''\">\n                                          </az-autocomplete>\n\n                                      </azteca-form-field>\n\n                                      <az-checkbox formControlName=\"requerido\" [label]=\"'Requerido'\" [(ngModel)]=\"parametro.requerido\"></az-checkbox>\n                                      <az-checkbox formControlName=\"validar\" [label]=\"'Validar'\" [(ngModel)]=\"parametro.validar\"></az-checkbox>\n\n                                      <azteca-form-field [label]=\"'Expresion:'\">\n                                          <az-textbox formControlName=\"expresion\" [(ngModel)]=\"parametro.expresion\"></az-textbox>\n                                      </azteca-form-field>\n\n\n                                  </div>\n                              </div>\n\n\n                          </tab>\n                      </tabset>\n                  </div>\n              </div>\n            \n\n          </azteca-catalog-editor>\n      </form>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return ParametrosEditor_1; })
                },
                {
                    provide: CatalogService, useExisting: ParametroService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, FormBuilder, ChangeDetectorRef,
            Context, Location, ParametroService, GrupoClasificacionService])
    ], ParametrosEditor);
    return ParametrosEditor;
}(CatalogEditor));
export { ParametrosEditor };
