var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, forwardRef, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators } from '@angular/forms';
import { Location } from '@angular/common';
//Azteca Kernel
import { Context, BaseComponent, CatalogService } from '../../core';
import { CatalogEditor } from '../../editors';
//Features
import { PersonaService } from '../services/persona.service';
import { PersonaInfo } from '../models/persona';
var PersonasEditor = /** @class */ (function (_super) {
    __extends(PersonasEditor, _super);
    //
    function PersonasEditor(router, route, formBuilder, changeDetector, context, location, personaService) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.changeDetector = changeDetector;
        _this.context = context;
        _this.location = location;
        _this.personaService = personaService;
        _this.persona = new PersonaInfo();
        _this.catalogForm = formBuilder.group({
            'codigo': ['', Validators.required],
            'nombre': ['', Validators.required],
            'apellidoPaterno': [''],
            'apellidoMaterno': [''],
            'telefonoCasa': [''],
            'telefonoOficina': [''],
            'celular': [''],
            'correo': [''],
            'domicilio': ['']
        });
        return _this;
    }
    PersonasEditor_1 = PersonasEditor;
    ///////////////////////// METODOS ///////////////////////////////////////
    ///////////////////////// HANDLERS ///////////////////////////////////////
    PersonasEditor.prototype.onConfigureCatalog = function (options) {
        this.autogeneratedCode = options.codigoAutogenerado;
    };
    PersonasEditor.prototype.onCreatingItem = function () {
    };
    PersonasEditor.prototype.onViewingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.personaService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.persona = info;
            _this.setReadonlyMode();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    PersonasEditor.prototype.onCloningItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        //
        this.personaService.clone(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.persona = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    PersonasEditor.prototype.onLoadingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.personaService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.persona = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    PersonasEditor.prototype.onSavingItem = function (args) {
        var _this = this;
        this.context.app.showSpinner();
        this.personaService.update(this.persona)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.persona = info;
            _this.reset();
            if (args.closeEditor)
                _this.location.back();
            else
                _this.showAlert('La información ha sido actualizada con éxito', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    PersonasEditor.prototype.onCancelingEdit = function () {
        this.location.back();
    };
    PersonasEditor.prototype.onDomicilioValidChange = function () {
        this.changeDetector.detectChanges();
    };
    var PersonasEditor_1;
    PersonasEditor = PersonasEditor_1 = __decorate([
        Component({
            selector: 'general-personas-editor',
            template: "\n      <form [formGroup]=\"catalogForm\">\n\n          <azteca-catalog-editor #catalogEditor \n                                 [title]=\"'Persona'\"\n                                 [info]=\"persona\"\n                                 [valid]=\"valid && domicilioEditor.valid\"\n                                 (configureCatalog)=\"onConfigureCatalog($event)\"\n                                 (creatingItem)=\"onCreatingItem()\"\n                                 (viewingItem)=\"onViewingItem($event)\"\n                                 (cloningItem)=\"onCloningItem($event)\"\n                                 (savingItem)=\"onSavingItem($event)\"\n                                 (loadingItem)=\"onLoadingItem($event)\">\n\n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <azteca-form-field [label]=\"'C\u00F3digo:'\">\n                          <catalog-code formControlName=\"codigo\" [(ngModel)]=\"persona.code\" [automatic]=\"autogeneratedCode\"></catalog-code>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Nombre:'\">\n                          <az-textbox formControlName=\"nombre\" [(ngModel)]=\"persona.nombre\"></az-textbox>\n                      </azteca-form-field>\n                  </div>\n              </div>\n\n              <!--Apellido paterno y materno-->\n              <div class=\"row\">\n                  <div class=\"col-12 col-md-6\">\n                      <azteca-form-field  [label]=\"'Apellido paterno:'\">\n                          <az-textbox formControlName=\"apellidoPaterno\" [(ngModel)]=\"persona.apellidoPaterno\" ></az-textbox>\n                      </azteca-form-field>\n                  </div>\n                  <div class=\"col-12 col-md-6\">\n                      <azteca-form-field *ngIf=\"apellidoMaternoVisible\" [label]=\"'Apellido materno:'\">\n                          <az-textbox formControlName=\"apellidoMaterno\" [(ngModel)]=\"persona.apellidoMaterno\" ></az-textbox>\n                      </azteca-form-field>\n                  </div>\n              </div>\n\n        \n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <tabset>\n                          <tab heading=\"Generales\">\n                      \n                              <!--Tel Casa y Oficina-->\n                              <div class=\"row\">\n                                  <div class=\"col-12 col-md-6\">\n                                      <azteca-form-field  [label]=\"'Tel\u00E9fono de casa:'\">\n                                          <az-textbox formControlName=\"telefonoCasa\" [(ngModel)]=\"persona.telefonoCasa\" ></az-textbox>\n                                      </azteca-form-field>\n                                  </div>\n                                  <div class=\"col-12 col-md-6\">\n                                      <azteca-form-field  [label]=\"'Tel\u00E9fono de oficina:'\">\n                                          <az-textbox formControlName=\"telefonoOficina\" [(ngModel)]=\"persona.telefonoOficina\" ></az-textbox>\n                                      </azteca-form-field>\n                                  </div>\n                              </div>\n\n                              <!--Celular y correo-->\n                              <div class=\"row\">\n                                  <div class=\"col-12 col-md-6\">\n                                      <azteca-form-field [label]=\"'Celular:'\">\n                                          <az-textbox formControlName=\"celular\" [(ngModel)]=\"persona.celular\"></az-textbox>\n                                      </azteca-form-field>\n                                  </div>\n                                  <div class=\"col-12 col-md-6\">\n                                      <azteca-form-field  [label]=\"'Correo electr\u00F3nico:'\">\n                                          <az-textbox formControlName=\"correo\" [(ngModel)]=\"persona.correo\"></az-textbox>\n                                      </azteca-form-field>\n                                  </div>\n                              </div>\n                          </tab>\n                          <tab heading=\"Domicilio\">\n                              <general-domicilio-editor #domicilioEditor\n                                                 formControlName=\"domicilio\"\n                                                 [(ngModel)]=\"persona.domicilio\"\n                                                 [calleRequired]=\"true\"\n                                                 (validChange)=\"onDomicilioValidChange($event)\">\n\n                              </general-domicilio-editor>\n                          </tab>\n                      </tabset>\n                  </div>\n              </div>\n            \n\n          </azteca-catalog-editor>\n      </form>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return PersonasEditor_1; })
                },
                {
                    provide: CatalogService, useExisting: PersonaService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, FormBuilder, ChangeDetectorRef,
            Context, Location, PersonaService])
    ], PersonasEditor);
    return PersonasEditor;
}(CatalogEditor));
export { PersonasEditor };
