var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, forwardRef, Output, Input, EventEmitter } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
//Azteca Kernel
import { Context, BaseComponent, CatalogService } from '../../core';
import { CatalogManager } from '../../editors';
//Features
import { PersonaService } from '../services/persona.service';
var PersonasManager = /** @class */ (function (_super) {
    __extends(PersonasManager, _super);
    //    
    function PersonasManager(router, route, context, personaService) {
        var _this = _super.call(this, context, router, route) || this;
        _this.router = router;
        _this.route = route;
        _this.context = context;
        _this.personaService = personaService;
        _this.personas = [];
        _this.refreshListParent = new EventEmitter();
        _this.deletedPersona = new EventEmitter();
        return _this;
    }
    PersonasManager_1 = PersonasManager;
    ///////////////////////// METODOS ///////////////////////////////////////
    ///////////////////////// HANDLERS ///////////////////////////////////////
    PersonasManager.prototype.onConfigureCatalog = function (options) {
        if (this.manager.standAlone) {
            this.manager.serverSide = options.busquedasServidor;
            this.manager.pageSize = options.tamanioPagina;
            this.refreshList();
        }
    };
    PersonasManager.prototype.doSearch = function (request) {
        var _this = this;
        if (this.manager.standAlone) {
            this.context.app.showSpinner();
            this.personaService.search(this.context.app.defaultSite.identity, request)
                .then(function (response) {
                _this.context.app.hideSpinner();
                //
                _this.personas = response.rows;
                _this.totalRows = response.totalRows;
                _this.pageIndex = request.pageIndex;
            })
                .catch(function (error) { return _this.handleError(error); });
        }
    };
    PersonasManager.prototype.onAddingItem = function () {
        this.router.navigate([0], { relativeTo: this.route });
    };
    PersonasManager.prototype.onViewingItem = function (item) {
        this.router.navigate([item.id, { readonly: true }], { relativeTo: this.route });
    };
    PersonasManager.prototype.onEditingItem = function (item) {
        this.router.navigate([item.id], { relativeTo: this.route });
    };
    PersonasManager.prototype.onDeletingItem = function (item) {
        var _this = this;
        this.personaService.delete(item.id)
            .then(function (success) {
            _this.deletedPersona.emit(item.id);
            _this.refreshList();
            _this.showAlert('El registro ha sido eliminado con éxito.', 'success');
            if (!_this.manager.standAlone)
                _this.refreshListParent.emit();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    PersonasManager.prototype.onCloningItem = function (item) {
        this.router.navigate([0, { cloneId: item.id }], { relativeTo: this.route });
    };
    PersonasManager.prototype.onChangingItemState = function (item) {
        var _this = this;
        this.personaService.changeStatus(item.id, !item.activo)
            .then(function (success) {
            _this.refreshList();
            if (!_this.manager.standAlone)
                _this.refreshListParent.emit();
            _this.showAlert('El estatus del registro ha sido actualizado con éxito.', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    var PersonasManager_1;
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], PersonasManager.prototype, "personas", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], PersonasManager.prototype, "standAlone", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], PersonasManager.prototype, "refreshListParent", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], PersonasManager.prototype, "deletedPersona", void 0);
    PersonasManager = PersonasManager_1 = __decorate([
        Component({
            selector: 'general-personas-manager',
            template: "\n      <azteca-catalog-manager (searchRequested)=\"doSearch($event)\"\n                              (addingItem)=\"onAddingItem()\"\n                              (viewingItem)=\"onViewingItem($event)\"\n                              (editingItem)=\"onEditingItem($event)\"\n                              (deletingItem)=\"onDeletingItem($event)\"\n                              (cloningItem)=\"onCloningItem($event)\"\n                              (changingItemState)=\"onChangingItemState($event)\"\n      \t\t\t\t\t\t(configureCatalog)=\"onConfigureCatalog($event)\"\n                              [enabled]=\"enabled\"\n                              [allowNew]=\"allowNew\"\n                              [allowView]=\"allowView\"\n                              [allowEdit]=\"allowEdit\"\n                              [allowDelete]=\"allowDelete\"\n                              [allowClone]=\"allowClone\"\n                              [allowChangeState]=\"allowChangeState\"\n                              [catalogList]=\"personas\"\n                              [totalRows]=\"totalRows\"\n                              [pageIndex]=\"pageIndex\">\n\n    \n          <azteca-grid-column [header]=\"'C\u00F3digo'\" [binding]=\"'codigo'\" [width]=\"'10*'\"></azteca-grid-column>\n          <azteca-grid-column [header]=\"'Nombre'\" [binding]=\"'nombre'\" [width]=\"'60*'\"></azteca-grid-column>\n    \n\n      </azteca-catalog-manager>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return PersonasManager_1; })
                },
                {
                    provide: CatalogService, useExisting: PersonaService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, Context, PersonaService])
    ], PersonasManager);
    return PersonasManager;
}(CatalogManager));
export { PersonasManager };
