var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, forwardRef, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators } from '@angular/forms';
import { Location } from '@angular/common';
//Azteca Kernel
import { Context, BaseComponent, CatalogService } from '../../core';
import { CatalogEditor } from '../../editors';
//Features
import { PoblacionService } from '../services/poblacion.service';
import { PoblacionInfo } from '../models/poblacion';
var PoblacionesEditor = /** @class */ (function (_super) {
    __extends(PoblacionesEditor, _super);
    //
    function PoblacionesEditor(router, route, formBuilder, changeDetector, context, location, poblacionService) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.changeDetector = changeDetector;
        _this.context = context;
        _this.location = location;
        _this.poblacionService = poblacionService;
        _this.poblacion = new PoblacionInfo();
        _this.ambitos = [{ id: 'U', nombre: 'Urbano' }, { id: 'R', nombre: 'Rural' }];
        _this.catalogForm = formBuilder.group({
            'codigo': ['', Validators.required],
            'nombre': ['', Validators.required],
            'ubicacion': [null],
            'ambito': [''],
            'referencia': ['']
        });
        return _this;
    }
    PoblacionesEditor_1 = PoblacionesEditor;
    ///////////////////////// METODOS ///////////////////////////////////////
    ///////////////////////// HANDLERS ///////////////////////////////////////
    PoblacionesEditor.prototype.onConfigureCatalog = function (options) {
        var _this = this;
        this.route.params.forEach(function (params) {
            _this.idMunicipio = +params['idMunicipio'];
        });
        this.autogeneratedCode = options.codigoAutogenerado;
    };
    PoblacionesEditor.prototype.onCreatingItem = function () {
        this.poblacion.idMunicipio = this.idMunicipio;
    };
    PoblacionesEditor.prototype.onViewingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.poblacionService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.poblacion = info;
            _this.setReadonlyMode();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    PoblacionesEditor.prototype.onCloningItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        //
        this.poblacionService.clone(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.poblacion = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    PoblacionesEditor.prototype.onLoadingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.poblacionService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.poblacion = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    PoblacionesEditor.prototype.onSavingItem = function (args) {
        var _this = this;
        this.context.app.showSpinner();
        this.poblacionService.update(this.poblacion)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.poblacion = info;
            _this.reset();
            if (args.closeEditor)
                _this.location.back();
            else
                _this.showAlert('La información ha sido actualizada con éxito', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    PoblacionesEditor.prototype.onCancelingEdit = function () {
        this.location.back();
    };
    var PoblacionesEditor_1;
    PoblacionesEditor = PoblacionesEditor_1 = __decorate([
        Component({
            selector: 'general-poblaciones-editor',
            template: "\n      <form [formGroup]=\"catalogForm\">\n\n          <azteca-catalog-editor #catalogEditor \n                                 [title]=\"'Poblacion'\"\n                                 [info]=\"poblacion\"\n                                 [valid]=\"valid\"\n                                 (configureCatalog)=\"onConfigureCatalog($event)\"\n                                 (creatingItem)=\"onCreatingItem()\"\n                                 (viewingItem)=\"onViewingItem($event)\"\n                                 (cloningItem)=\"onCloningItem($event)\"\n                                 (savingItem)=\"onSavingItem($event)\"\n                                 (loadingItem)=\"onLoadingItem($event)\">\n\n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <azteca-form-field [label]=\"'C\u00F3digo:'\">\n                          <catalog-code formControlName=\"codigo\" [(ngModel)]=\"poblacion.code\" [automatic]=\"autogeneratedCode\"></catalog-code>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Nombre:'\">\n                          <az-textbox formControlName=\"nombre\" [(ngModel)]=\"poblacion.nombre\"></az-textbox>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Referencia:'\">\n                          <az-textbox formControlName=\"referencia\" [(ngModel)]=\"poblacion.referencia\"></az-textbox>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'\u00C1mbito:'\">\n                          <az-combobox formControlName=\"ambito\" [(ngModel)]=\"poblacion.ambito\" [items]=\"ambitos\" [valueMember]=\"'id'\" [displayMember]=\"'nombre'\"></az-combobox>\n                      </azteca-form-field>\n\n\n                      <azteca-position formControlName=\"ubicacion\" [(ngModel)]=\"poblacion.ubicacion\" [zoom]=\"12\">\n\n                      </azteca-position>\n                  </div>\n              </div>\n\n        \n                    \n\n          </azteca-catalog-editor>\n      </form>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return PoblacionesEditor_1; })
                },
                {
                    provide: CatalogService, useExisting: PoblacionService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, FormBuilder, ChangeDetectorRef,
            Context, Location, PoblacionService])
    ], PoblacionesEditor);
    return PoblacionesEditor;
}(CatalogEditor));
export { PoblacionesEditor };
