var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, Input, Output, EventEmitter, forwardRef } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { Observable } from 'rxjs';
import { mergeMap } from 'rxjs/operators';
//
import { Context, BaseComponent } from '../../core';
import { CatalogSelector } from '../../search/index';
import { MunicipioService } from '../services/municipio.service';
var MunicipioSelectorComponent = /** @class */ (function (_super) {
    __extends(MunicipioSelectorComponent, _super);
    function MunicipioSelectorComponent(context, municipioService) {
        var _this = _super.call(this, context) || this;
        _this.context = context;
        _this.municipioService = municipioService;
        _this.selectedItem = null;
        //Outputs
        _this.selectedItemChanged = new EventEmitter();
        _this.keywordSearchSource = Observable.create(function (observer) {
            observer.next(_this.innerSelector.displayValue);
        })
            .pipe(mergeMap(function (keyword) { return _this.findKeyword(keyword); }));
        return _this;
    }
    MunicipioSelectorComponent_1 = MunicipioSelectorComponent;
    MunicipioSelectorComponent.prototype.loadItem = function (itemID) {
        var _this = this;
        if (itemID > 0) {
            this.municipioService.getDetailByID(itemID)
                .then(function (info) {
                _this.selectedItem = info;
                _this.displayValue = info.nombre;
                _this.selectedItemChanged.emit(_this.selectedItem);
            })
                .catch(function (error) { return _this.handleError(error); });
        }
        else {
            this.selectedItem = null;
            this.displayValue = "";
            this.selectedItemChanged.emit(this.selectedItem);
        }
    };
    MunicipioSelectorComponent.prototype.doSearch = function (request) {
        var _this = this;
        this.context.app.showSpinner();
        //Agregar condición de estado
        var condicionEstado = { field: "idEstado", operator: "=", valueType: "int", value: this.idEstado.toString() };
        request.conditions.push(condicionEstado);
        //
        this.municipioService.search(this.context.app.defaultSite.identity, request)
            .then(function (response) {
            _this.context.app.hideSpinner();
            //
            _this.municipios = response.rows;
            _this.totalRows = response.totalRows;
            _this.pageIndex = request.pageIndex;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    MunicipioSelectorComponent.prototype.findKeyword = function (keyword) {
        return this.municipioService.searchKeyword(this.context.app.defaultSite.identity, keyword);
    };
    MunicipioSelectorComponent.prototype.onKeywordSearch = function (keyword) {
        this.markUnselected();
    };
    var MunicipioSelectorComponent_1;
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], MunicipioSelectorComponent.prototype, "idEstado", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], MunicipioSelectorComponent.prototype, "selectedItemChanged", void 0);
    MunicipioSelectorComponent = MunicipioSelectorComponent_1 = __decorate([
        Component({
            selector: 'municipio-selector',
            template: "\n      <azteca-catalog-selector [catalogList]=\"municipios\"\n                               [dialogTitle]=\"'Lista de municipios'\"\n                               [displayValue]=\"displayValue\"\n                               [serverSide]=\"true\"\n                               [selectedItem]=\"selectedItem\"\n                               [pageIndex]=\"pageIndex\"\n                               [pageSize]=\"pageSize\"\n                               [totalRows]=\"totalRows\"\n                               [enabled]=\"enabled\"\n                               [visible]=\"visible\"\n                               [dataSource]=\"keywordSearchSource\"\n                               [showListButton]=\"showListButton\"\n                               (selectedItemChanged)=\"itemChangedHandler($event)\"\n                               (keywordSearch)=\"onKeywordSearch($event)\"\n                               (searchRequested)=\"doSearch($event)\">\n\n          <azteca-grid-column [header]=\"'Codigo'\" [binding]=\"'codigo'\" [width]=\"'1*'\"></azteca-grid-column>\n          <azteca-grid-column [header]=\"'Nombre'\" [binding]=\"'nombre'\" [width]=\"'3*'\"></azteca-grid-column>\n    \n\n      </azteca-catalog-selector>\n    ",
            providers: [{
                    provide: BaseComponent,
                    useExisting: forwardRef(function () { return MunicipioSelectorComponent_1; })
                },
                {
                    provide: NG_VALUE_ACCESSOR,
                    useExisting: forwardRef(function () { return MunicipioSelectorComponent_1; }),
                    multi: true
                }]
        }),
        __metadata("design:paramtypes", [Context, MunicipioService])
    ], MunicipioSelectorComponent);
    return MunicipioSelectorComponent;
}(CatalogSelector));
export { MunicipioSelectorComponent };
