var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, Input, Output, EventEmitter, forwardRef } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { Observable } from 'rxjs';
import { mergeMap } from 'rxjs/operators';
//
import { Context, BaseComponent } from '../../core';
import { CatalogSelector } from '../../search/index';
import { PersonaService } from '../services/persona.service';
var PersonaSelectorComponent = /** @class */ (function (_super) {
    __extends(PersonaSelectorComponent, _super);
    function PersonaSelectorComponent(context, personaService) {
        var _this = _super.call(this, context) || this;
        _this.context = context;
        _this.personaService = personaService;
        _this.selectedItem = null;
        //Outputs
        _this.selectedItemChanged = new EventEmitter();
        _this.keywordSearchSource = Observable.create(function (observer) {
            observer.next(_this.innerSelector.displayValue);
        })
            .pipe(mergeMap(function (keyword) { return _this.findKeyword(keyword); }));
        return _this;
    }
    PersonaSelectorComponent_1 = PersonaSelectorComponent;
    PersonaSelectorComponent.prototype.loadItem = function (itemID) {
        var _this = this;
        if (itemID > 0) {
            this.personaService.getDetailByID(itemID)
                .then(function (info) {
                _this.selectedItem = info;
                _this.displayValue = info.nombre + ' ' + info.apellidoPaterno + ' ' + info.apellidoMaterno;
                _this.selectedItemChanged.emit(_this.selectedItem);
            })
                .catch(function (error) { return _this.handleError(error); });
        }
        else {
            this.selectedItem = null;
            this.displayValue = "";
            this.selectedItemChanged.emit(this.selectedItem);
        }
    };
    PersonaSelectorComponent.prototype.doSearch = function (request) {
        var _this = this;
        this.context.app.showSpinner();
        this.personaService.search(this.context.app.defaultSite.identity, request)
            .then(function (response) {
            _this.context.app.hideSpinner();
            //
            _this.personas = response.rows;
            _this.totalRows = response.totalRows;
            _this.pageIndex = request.pageIndex;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    PersonaSelectorComponent.prototype.findKeyword = function (keyword) {
        return this.personaService.searchKeyword(this.context.app.defaultSite.identity, keyword);
    };
    PersonaSelectorComponent.prototype.onKeywordSearch = function (keyword) {
        this.markUnselected();
    };
    var PersonaSelectorComponent_1;
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], PersonaSelectorComponent.prototype, "idPais", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], PersonaSelectorComponent.prototype, "selectedItemChanged", void 0);
    PersonaSelectorComponent = PersonaSelectorComponent_1 = __decorate([
        Component({
            selector: 'persona-selector',
            template: "\n      <azteca-catalog-selector [catalogList]=\"personas\"\n                               [dialogTitle]=\"'Lista de personas'\"\n                               [displayValue]=\"displayValue\"\n                               [serverSide]=\"true\"\n                               [selectedItem]=\"selectedItem\"\n                               [pageIndex]=\"pageIndex\"\n                               [pageSize]=\"pageSize\"\n                               [totalRows]=\"totalRows\"\n                               [enabled]=\"enabled\"\n                               [visible]=\"visible\"\n                               [dataSource]=\"keywordSearchSource\"\n                               [showListButton]=\"showListButton\"\n                               (selectedItemChanged)=\"itemChangedHandler($event)\"\n                               (keywordSearch)=\"onKeywordSearch($event)\"\n                               (searchRequested)=\"doSearch($event)\">\n\n          <azteca-grid-column [header]=\"'Codigo'\" [binding]=\"'codigo'\" [width]=\"'1*'\"></azteca-grid-column>\n          <azteca-grid-column [header]=\"'Nombre'\" [binding]=\"'nombre'\" [width]=\"'3*'\"></azteca-grid-column>\n          <azteca-grid-column [header]=\"'Apellido Pat.'\" [binding]=\"'apellidoPaterno'\" [width]=\"'3*'\"></azteca-grid-column>\n          <azteca-grid-column [header]=\"'Apellido Mat.'\" [binding]=\"'apellidoMaterno'\" [width]=\"'3*'\"></azteca-grid-column>\n    \n      </azteca-catalog-selector>\n    ",
            providers: [{
                    provide: BaseComponent,
                    useExisting: forwardRef(function () { return PersonaSelectorComponent_1; })
                },
                {
                    provide: NG_VALUE_ACCESSOR,
                    useExisting: forwardRef(function () { return PersonaSelectorComponent_1; }),
                    multi: true
                }]
        }),
        __metadata("design:paramtypes", [Context, PersonaService])
    ], PersonaSelectorComponent);
    return PersonaSelectorComponent;
}(CatalogSelector));
export { PersonaSelectorComponent };
