var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Directive, Input, Output, EventEmitter } from '@angular/core';
import { DrawingService } from '../providers/drawing.service';
import * as Google from '../models/google-maps-types';
var DrawingDirective = /** @class */ (function () {
    function DrawingDirective(drawingService) {
        this.drawingService = drawingService;
        this._observableSubscriptions = [];
        this.defaultLineOptions = {
            strokeWeight: 1,
            editable: true
        };
        this.defaultPolyOptions = {
            strokeWeight: 0,
            fillOpacity: 0.45,
            fillColor: '#1E90FF',
            editable: true
        };
        this.drawingControl = true;
        this.polylineOptions = this.defaultLineOptions;
        this.rectangleOptions = null;
        this.circleOptions = null;
        this.polygonOptions = this.defaultPolyOptions;
        //
        this.polygonComplete = new EventEmitter();
        this.polylineComplete = new EventEmitter();
        this.rectangleComplete = new EventEmitter();
        this.circleComplete = new EventEmitter();
        this.overlayComplete = new EventEmitter();
    }
    DrawingDirective.prototype.ngOnChanges = function (changes) {
        this.drawingService.createManager(this);
        this.addListeners();
        if (changes['drawingMode']) {
            this.drawingService.updateDrawingMode(this);
        }
        if (changes['drawingControl']) {
            this.drawingService.updateDrawingControl(this);
        }
        if (changes['polylineOptions']) {
            this.drawingService.updatePolylineOptions(this);
        }
        if (changes['rectangleOptions']) {
            this.drawingService.updateRectangleOptions(this);
        }
        if (changes['circleOptions']) {
            this.drawingService.updateCircleOptions(this);
        }
        if (changes['polygonOptions']) {
            this.drawingService.updatePolygonOptions(this);
        }
    };
    DrawingDirective.prototype.addListeners = function () {
        var _this = this;
        var polygonSub = this.drawingService.createEventObservable('polygoncomplete', this).subscribe(function (polygon) {
            _this.polygonComplete.emit(polygon);
        });
        this._observableSubscriptions.push(polygonSub);
        //
        var rectSub = this.drawingService.createEventObservable('rectanglecomplete', this).subscribe(function (rectangle) {
            _this.rectangleComplete.emit(rectangle);
        });
        this._observableSubscriptions.push(rectSub);
        //
        var polylineSub = this.drawingService.createEventObservable('polylinecomplete', this).subscribe(function (polyline) {
            _this.polylineComplete.emit(polyline);
        });
        this._observableSubscriptions.push(polylineSub);
        //
        var circleSub = this.drawingService.createEventObservable('circlecomplete', this).subscribe(function (circle) {
            _this.circleComplete.emit(circle);
        });
        this._observableSubscriptions.push(circleSub);
        //
        var overlaySub = this.drawingService.createEventObservable('overlaycomplete', this).subscribe(function (overlay) {
            _this.overlayComplete.emit(overlay);
        });
        this._observableSubscriptions.push(overlaySub);
    };
    DrawingDirective.prototype.ngOnDestroy = function () {
        this._observableSubscriptions.forEach(function (s) {
            s.unsubscribe();
        });
    };
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], DrawingDirective.prototype, "drawingMode", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], DrawingDirective.prototype, "drawingControl", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], DrawingDirective.prototype, "polylineOptions", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], DrawingDirective.prototype, "rectangleOptions", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], DrawingDirective.prototype, "circleOptions", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], DrawingDirective.prototype, "polygonOptions", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], DrawingDirective.prototype, "polygonComplete", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], DrawingDirective.prototype, "polylineComplete", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], DrawingDirective.prototype, "rectangleComplete", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], DrawingDirective.prototype, "circleComplete", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], DrawingDirective.prototype, "overlayComplete", void 0);
    DrawingDirective = __decorate([
        Directive({
            selector: 'google-map-drawing'
        }),
        __metadata("design:paramtypes", [DrawingService])
    ], DrawingDirective);
    return DrawingDirective;
}());
export { DrawingDirective };
