var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, ElementRef, EventEmitter, Output, Input } from '@angular/core';
import { InfoWindowService } from '../providers/info-window.service';
var infoWindowId = 0;
/**
 * GoogleInfoWindow renders a info window inside a {@link AgmMarker} or standalone.
 *
 */
var InfoWindowDirective = /** @class */ (function () {
    function InfoWindowDirective(_infoWindowManager, _el) {
        this._infoWindowManager = _infoWindowManager;
        this._el = _el;
        /**
         * Sets the open state for the InfoWindow. You can also call the open() and close() methods.
         */
        this.isOpen = false;
        /**
         * Emits an event when the info window is closed.
         */
        this.infoWindowClose = new EventEmitter();
        this._infoWindowAddedToManager = false;
        this._id = (infoWindowId++).toString();
    }
    InfoWindowDirective_1 = InfoWindowDirective;
    InfoWindowDirective.prototype.ngOnInit = function () {
        this.content = this._el.nativeElement.querySelector('.google-info-window-content');
        this._infoWindowManager.addInfoWindow(this);
        this._infoWindowAddedToManager = true;
        this._updateOpenState();
        this._registerEventListeners();
    };
    /** @internal */
    InfoWindowDirective.prototype.ngOnChanges = function (changes) {
        if (!this._infoWindowAddedToManager) {
            return;
        }
        if ((changes['latitude'] || changes['longitude']) && typeof this.latitude === 'number' &&
            typeof this.longitude === 'number') {
            this._infoWindowManager.setPosition(this);
        }
        if (changes['zIndex']) {
            this._infoWindowManager.setZIndex(this);
        }
        if (changes['isOpen']) {
            this._updateOpenState();
        }
        this._setInfoWindowOptions(changes);
    };
    InfoWindowDirective.prototype._registerEventListeners = function () {
        var _this = this;
        this._infoWindowManager.createEventObservable('closeclick', this).subscribe(function () {
            _this.isOpen = false;
            _this.infoWindowClose.emit();
        });
    };
    InfoWindowDirective.prototype._updateOpenState = function () {
        this.isOpen ? this.open() : this.close();
    };
    InfoWindowDirective.prototype._setInfoWindowOptions = function (changes) {
        var options = {};
        var optionKeys = Object.keys(changes).filter(function (k) { return InfoWindowDirective_1._infoWindowOptionsInputs.indexOf(k) !== -1; });
        optionKeys.forEach(function (k) { options[k] = changes[k].currentValue; });
        this._infoWindowManager.setOptions(this, options);
    };
    /**
     * Opens the info window.
     */
    InfoWindowDirective.prototype.open = function () { return this._infoWindowManager.open(this); };
    /**
     * Closes the info window.
     */
    InfoWindowDirective.prototype.close = function () {
        var _this = this;
        return this._infoWindowManager.close(this).then(function () { _this.infoWindowClose.emit(); });
    };
    /** @internal */
    InfoWindowDirective.prototype.id = function () { return this._id; };
    /** @internal */
    InfoWindowDirective.prototype.toString = function () { return 'GoogleInfoWindow-' + this._id.toString(); };
    /** @internal */
    InfoWindowDirective.prototype.ngOnDestroy = function () { this._infoWindowManager.deleteInfoWindow(this); };
    var InfoWindowDirective_1;
    InfoWindowDirective._infoWindowOptionsInputs = ['disableAutoPan', 'maxWidth'];
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], InfoWindowDirective.prototype, "latitude", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], InfoWindowDirective.prototype, "longitude", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], InfoWindowDirective.prototype, "disableAutoPan", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], InfoWindowDirective.prototype, "zIndex", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], InfoWindowDirective.prototype, "maxWidth", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], InfoWindowDirective.prototype, "isOpen", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], InfoWindowDirective.prototype, "infoWindowClose", void 0);
    InfoWindowDirective = InfoWindowDirective_1 = __decorate([
        Component({
            selector: 'google-map-info-window',
            template: "\n    <div class='google-info-window-content'>\n      <ng-content></ng-content>\n    </div>\n  "
        }),
        __metadata("design:paramtypes", [InfoWindowService, ElementRef])
    ], InfoWindowDirective);
    return InfoWindowDirective;
}());
export { InfoWindowDirective };
