var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Directive, Input, Output, EventEmitter, ContentChildren, QueryList } from '@angular/core';
import { MarkerService } from '../providers/marker.service';
import { InfoWindowDirective } from './info-window.directive';
var MarkerDirective = /** @class */ (function () {
    function MarkerDirective(markerService) {
        this.markerService = markerService;
        this._observableSubscriptions = [];
        this.label = '';
        this.draggable = false;
        this.iconUrl = '';
        this.visible = true;
        this.title = '';
        this.opacity = 1;
        /**
         * This event emitter gets emitted when the user clicks on the marker.
         */
        this.markerClick = new EventEmitter();
        /**
         * This event is fired when the user stops dragging the marker.
         */
        this.dragEnd = new EventEmitter();
        /**
         * This event is fired when the user mouses over the marker.
         */
        this.mouseOver = new EventEmitter();
        /**
         * This event is fired when the user mouses outside the marker.
         */
        this.mouseOut = new EventEmitter();
        /**
         * @internal
         */
        /**
           * Whether to automatically open the child info window when the marker is clicked.
           */
        this.openInfoWindow = true;
        this.infoWindow = new QueryList();
    }
    MarkerDirective.prototype.ngOnChanges = function (changes) {
        if (typeof this.latitude !== 'number' || typeof this.longitude !== 'number') {
            return;
        }
        if (!this.markerAddedToService) {
            this.markerService.addMarker(this);
            this.markerAddedToService = true;
            this.addEventListeners();
            return;
        }
        if (changes['latitude'] || changes['longitude']) {
            this.markerService.updatePosition(this);
        }
        if (changes['title']) {
            this.markerService.updateTitle(this);
        }
        if (changes['label']) {
            this.markerService.updateLabel(this);
        }
        if (changes['draggable']) {
            this.markerService.updateDraggable(this);
        }
        if (changes['iconUrl']) {
            this.markerService.updateIcon(this);
        }
        if (changes['opacity']) {
            this.markerService.updateOpacity(this);
        }
        if (changes['visible']) {
            this.markerService.updateVisible(this);
        }
        if (changes['zIndex']) {
            //this.markerService.updateZIndex(this);
        }
    };
    MarkerDirective.prototype.ngAfterContentInit = function () {
        var _this = this;
        this.handleInfoWindowUpdate();
        this.infoWindow.changes.subscribe(function () { return _this.handleInfoWindowUpdate(); });
    };
    MarkerDirective.prototype.handleInfoWindowUpdate = function () {
        var _this = this;
        if (this.infoWindow.length > 1) {
            throw new Error('Expected no more than one info window.');
        }
        this.infoWindow.forEach(function (marker) {
            marker.hostMarker = _this;
        });
    };
    MarkerDirective.prototype.addEventListeners = function () {
        var _this = this;
        var cs = this.markerService.createEventObservable('click', this).subscribe(function () {
            if (_this.openInfoWindow) {
                _this.infoWindow.forEach(function (infoWindow) { return infoWindow.open(); });
            }
            _this.markerClick.emit(null);
        });
        this._observableSubscriptions.push(cs);
        var ds = this.markerService.createEventObservable('dragend', this)
            .subscribe(function (e) {
            _this.dragEnd.emit({ coords: { lat: e.latLng.lat(), lng: e.latLng.lng() } });
        });
        this._observableSubscriptions.push(ds);
        var mover = this.markerService.createEventObservable('mouseover', this)
            .subscribe(function (e) {
            _this.mouseOver.emit({ coords: { lat: e.latLng.lat(), lng: e.latLng.lng() } });
        });
        this._observableSubscriptions.push(mover);
        var mout = this.markerService.createEventObservable('mouseout', this)
            .subscribe(function (e) {
            _this.mouseOut.emit({ coords: { lat: e.latLng.lat(), lng: e.latLng.lng() } });
        });
        this._observableSubscriptions.push(mout);
    };
    MarkerDirective.prototype.ngOnDestroy = function () {
        this.markerService.deleteMarker(this);
        this._observableSubscriptions.forEach(function (s) {
            s.unsubscribe();
        });
    };
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], MarkerDirective.prototype, "latitude", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], MarkerDirective.prototype, "longitude", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], MarkerDirective.prototype, "label", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], MarkerDirective.prototype, "draggable", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], MarkerDirective.prototype, "iconUrl", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], MarkerDirective.prototype, "visible", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], MarkerDirective.prototype, "title", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], MarkerDirective.prototype, "opacity", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], MarkerDirective.prototype, "data", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], MarkerDirective.prototype, "markerClick", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], MarkerDirective.prototype, "dragEnd", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], MarkerDirective.prototype, "mouseOver", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], MarkerDirective.prototype, "mouseOut", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], MarkerDirective.prototype, "openInfoWindow", void 0);
    __decorate([
        ContentChildren(InfoWindowDirective),
        __metadata("design:type", QueryList)
    ], MarkerDirective.prototype, "infoWindow", void 0);
    MarkerDirective = __decorate([
        Directive({
            selector: 'google-map-marker',
        }),
        __metadata("design:paramtypes", [MarkerService])
    ], MarkerDirective);
    return MarkerDirective;
}());
export { MarkerDirective };
