var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Directive, Input, Output, EventEmitter } from '@angular/core';
import { PolygonService } from '../providers/polygon.service';
import { Position } from '../models/position';
var PolygonDirective = /** @class */ (function () {
    function PolygonDirective(polygonService) {
        this.polygonService = polygonService;
        this._observableSubscriptions = [];
        this.path = [];
        this.strokeColor = '#1E90FF';
        this.strokeOpacity = 0.45;
        this.strokeWeight = 0;
        this.fillColor = '#1E90FF';
        this.fillOpacity = 0.45;
        this.editable = false;
        this.visible = true;
        this.clickable = true;
        this.draggable = false;
        this.click = new EventEmitter();
        this.dblClick = new EventEmitter();
        this.dragStart = new EventEmitter();
        this.dragEnd = new EventEmitter();
        this.changed = new EventEmitter();
    }
    PolygonDirective.prototype.ngOnChanges = function (changes) {
        if (this.path.length < 3) {
            return;
        }
        if (!this.polygonAddedToService) {
            this.polygonService.addPolygon(this);
            this.polygonAddedToService = true;
            this.addEventListeners();
            return;
        }
        if (changes['path']) {
            this.polygonService.updatePolygon(this);
        }
        if (changes['strokeColor']) {
            this.polygonService.updateStrokeColor(this);
        }
        if (changes['strokeOpacity']) {
            this.polygonService.updateStrokeOpacity(this);
        }
        if (changes['strokeWeight']) {
            this.polygonService.updateStrokeWeight(this);
        }
        if (changes['fillColor']) {
            this.polygonService.updateFillColor(this);
        }
        if (changes['fillOpacity']) {
            this.polygonService.updateFillOpacity(this);
        }
        if (changes['clickable']) {
            this.polygonService.updateClickable(this);
        }
        if (changes['editable']) {
            this.polygonService.updateEditable(this);
        }
        if (changes['visible']) {
            this.polygonService.updateVisible(this);
        }
        if (changes['draggable']) {
            this.polygonService.updateDraggable(this);
        }
    };
    PolygonDirective.prototype.mapDrawnPolygon = function (polygon) {
        if (!this.polygonAddedToService) {
            this.polygonService.addPolygon(this, polygon);
            this.polygonAddedToService = true;
            this.addEventListeners();
            var polyPath = polygon.getPath().getArray();
            this.path = polyPath.map(function (p) { return new Position(p.lat(), p.lng()); });
            return;
        }
    };
    PolygonDirective.prototype.clear = function () {
        if (this.polygonAddedToService) {
            this.polygonService.deletePolygon(this);
            this.polygonAddedToService = false;
            this._observableSubscriptions.forEach(function (s) {
                s.unsubscribe();
            });
            this.path = [];
        }
    };
    PolygonDirective.prototype.addEventListeners = function () {
        var _this = this;
        var clickSub = this.polygonService.createEventObservable('click', this).subscribe(function () {
            _this.click.emit(null);
        });
        this._observableSubscriptions.push(clickSub);
        //
        var dblClickSub = this.polygonService.createEventObservable('dblClick', this).subscribe(function () {
            _this.dblClick.emit(null);
        });
        this._observableSubscriptions.push(dblClickSub);
        //
        var dragStartSub = this.polygonService.createEventObservable('dragstart', this).subscribe(function () {
            _this.dragStart.emit(null);
        });
        this._observableSubscriptions.push(dragStartSub);
        //
        var dragEndSub = this.polygonService.createEventObservable('dragend', this).subscribe(function () {
            var pathPromise = _this.polygonService.getPath(_this);
            pathPromise.then(function (path) {
                var positionPath = path.map(function (p) { return new Position(p.lat(), p.lng()); });
                _this.dragEnd.emit(positionPath);
            });
        });
        this._observableSubscriptions.push(dragEndSub);
        //
        var mvcArraySub = this.polygonService.createPathEventObservable(this).subscribe(function (path) {
            var positionPath = path.map(function (p) { return new Position(p.lat(), p.lng()); });
            _this.changed.emit(positionPath);
        });
        this._observableSubscriptions.push(mvcArraySub);
    };
    PolygonDirective.prototype.ngOnDestroy = function () {
        this.polygonService.deletePolygon(this);
        this._observableSubscriptions.forEach(function (s) {
            s.unsubscribe();
        });
    };
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], PolygonDirective.prototype, "path", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], PolygonDirective.prototype, "strokeColor", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], PolygonDirective.prototype, "strokeOpacity", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], PolygonDirective.prototype, "strokeWeight", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], PolygonDirective.prototype, "fillColor", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], PolygonDirective.prototype, "fillOpacity", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], PolygonDirective.prototype, "editable", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], PolygonDirective.prototype, "visible", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], PolygonDirective.prototype, "clickable", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], PolygonDirective.prototype, "draggable", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], PolygonDirective.prototype, "data", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], PolygonDirective.prototype, "click", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], PolygonDirective.prototype, "dblClick", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], PolygonDirective.prototype, "dragStart", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], PolygonDirective.prototype, "dragEnd", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], PolygonDirective.prototype, "changed", void 0);
    PolygonDirective = __decorate([
        Directive({
            selector: 'google-map-polygon',
        }),
        __metadata("design:paramtypes", [PolygonService])
    ], PolygonDirective);
    return PolygonDirective;
}());
export { PolygonDirective };
