var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Injectable, NgZone } from '@angular/core';
import { MapService } from './map.service';
import { Observable } from 'rxjs';
import 'rxjs/add/operator/toPromise';
var PolygonService = /** @class */ (function () {
    function PolygonService(mapService, _zone) {
        this.mapService = mapService;
        this._zone = _zone;
        this.polygons = new Map();
    }
    PolygonService.prototype.addPolygon = function (polygonDirective, polygon) {
        var polygonPromise = null;
        if (!polygon) {
            polygonPromise = this.mapService.createPolygon({
                paths: polygonDirective.path,
                strokeColor: polygonDirective.strokeColor,
                strokeOpacity: polygonDirective.strokeOpacity,
                strokeWeight: polygonDirective.strokeWeight,
                fillColor: polygonDirective.fillColor,
                fillOpacity: polygonDirective.fillOpacity,
                editable: polygonDirective.editable
            });
        }
        else {
            polygonPromise = Promise.resolve(polygon);
        }
        this.polygons.set(polygonDirective, polygonPromise);
    };
    PolygonService.prototype.updatePolygon = function (polygon) {
        var _this = this;
        var p = this.polygons.get(polygon);
        if (p == null) {
            return Promise.resolve();
        }
        return p.then(function (l) { return _this._zone.run(function () { l.setPaths(polygon.path); }); });
    };
    PolygonService.prototype.updateClickable = function (polygon) {
        var _this = this;
        var p = this.polygons.get(polygon);
        if (p == null) {
            return Promise.resolve();
        }
        return p.then(function (p) { return _this._zone.run(function () { return p.setClickable(polygon.clickable); }); });
    };
    PolygonService.prototype.updateVisible = function (polygon) {
        var _this = this;
        var p = this.polygons.get(polygon);
        if (p == null) {
            return Promise.resolve();
        }
        return p.then(function (p) { return _this._zone.run(function () { return p.setVisible(polygon.visible); }); });
    };
    PolygonService.prototype.updateEditable = function (polygon) {
        var _this = this;
        var p = this.polygons.get(polygon);
        if (p == null) {
            return Promise.resolve();
        }
        return p.then(function (p) { return _this._zone.run(function () { return p.setEditable(polygon.editable); }); });
    };
    PolygonService.prototype.updateFillColor = function (polygon) {
        var _this = this;
        var p = this.polygons.get(polygon);
        if (p == null) {
            return Promise.resolve();
        }
        return p.then(function (p) { return _this._zone.run(function () { return p.setOptions({ fillColor: polygon.fillColor }); }); });
    };
    PolygonService.prototype.updateFillOpacity = function (polygon) {
        var _this = this;
        var p = this.polygons.get(polygon);
        if (p == null) {
            return Promise.resolve();
        }
        return p.then(function (p) { return _this._zone.run(function () { return p.setOptions({ fillOpacity: polygon.fillOpacity }); }); });
    };
    PolygonService.prototype.updateStrokeColor = function (polygon) {
        var _this = this;
        var p = this.polygons.get(polygon);
        if (p == null) {
            return Promise.resolve();
        }
        return p.then(function (p) { return _this._zone.run(function () { return p.setOptions({ strokeColor: polygon.strokeColor }); }); });
    };
    PolygonService.prototype.updateStrokeOpacity = function (polygon) {
        var _this = this;
        var p = this.polygons.get(polygon);
        if (p == null) {
            return Promise.resolve();
        }
        return p.then(function (p) { return _this._zone.run(function () { return p.setOptions({ strokeOpacity: polygon.strokeOpacity }); }); });
    };
    PolygonService.prototype.updateStrokeWeight = function (polygon) {
        var _this = this;
        var p = this.polygons.get(polygon);
        if (p == null) {
            return Promise.resolve();
        }
        return p.then(function (p) { return _this._zone.run(function () { return p.setOptions({ strokeWeight: polygon.strokeWeight }); }); });
    };
    PolygonService.prototype.updateDraggable = function (polygon) {
        var _this = this;
        var p = this.polygons.get(polygon);
        if (p == null) {
            return Promise.resolve();
        }
        return p.then(function (p) { return _this._zone.run(function () { return p.setDraggable(polygon.draggable); }); });
    };
    PolygonService.prototype.setPolygonOptions = function (polygon, options) {
        return this.polygons.get(polygon).then(function (l) { l.setOptions(options); });
    };
    PolygonService.prototype.getPath = function (polygon) {
        return this.polygons.get(polygon).then(function (p) { return p.getPath().getArray(); });
    };
    PolygonService.prototype.deletePolygon = function (polygon) {
        var _this = this;
        var m = this.polygons.get(polygon);
        if (m == null) {
            return Promise.resolve();
        }
        return m.then(function (l) {
            return _this._zone.run(function () {
                l.setMap(null);
                _this.polygons.delete(polygon);
            });
        });
    };
    PolygonService.prototype.createEventObservable = function (eventName, polygon) {
        var _this = this;
        return Observable.create(function (observer) {
            _this.polygons.get(polygon).then(function (l) {
                l.addListener(eventName, function (e) { return _this._zone.run(function () { return observer.next(e); }); });
            });
        });
    };
    PolygonService.prototype.createPathEventObservable = function (polygon) {
        var _this = this;
        return Observable.create(function (observer) {
            _this.polygons.get(polygon).then(function (p) {
                var path = p.getPath();
                google.maps.event.addListener(path, 'insert_at', function () { return _this._zone.run(function () { return observer.next(path.getArray()); }); });
                google.maps.event.addListener(path, 'remove_at', function () { return _this._zone.run(function () { return observer.next(path.getArray()); }); });
                google.maps.event.addListener(path, 'set_at', function () { return _this._zone.run(function () { return observer.next(path.getArray()); }); });
            });
        });
    };
    PolygonService = __decorate([
        Injectable(),
        __metadata("design:paramtypes", [MapService, NgZone])
    ], PolygonService);
    return PolygonService;
}());
export { PolygonService };
