var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, forwardRef, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators } from '@angular/forms';
import { Location } from '@angular/common';
//Azteca Kernel
import { Context, BaseComponent, CatalogService, EnsambladoService } from '../../core';
import { AztecaValidators } from '../../controls';
import { CatalogEditor } from '../../editors';
//Features
import { JobSourceService } from '../services/job-source.service';
import { JobSourceInfo } from '../models/job-source';
var JobOrigenesEditor = /** @class */ (function (_super) {
    __extends(JobOrigenesEditor, _super);
    //
    function JobOrigenesEditor(router, route, formBuilder, changeDetector, context, location, jobSourceService, ensambladoService) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.changeDetector = changeDetector;
        _this.context = context;
        _this.location = location;
        _this.jobSourceService = jobSourceService;
        _this.ensambladoService = ensambladoService;
        _this.jobSource = new JobSourceInfo();
        _this.ensamblados = [];
        _this.catalogForm = formBuilder.group({
            'codigo': ['', Validators.required],
            'nombre': ['', Validators.required],
            'idEnsamblado': [0, AztecaValidators.selected],
            'clase': ['', Validators.required],
            'maxReintentos': [0]
        });
        return _this;
    }
    JobOrigenesEditor_1 = JobOrigenesEditor;
    ///////////////////////// METODOS ///////////////////////////////////////
    JobOrigenesEditor.prototype.loadEnsamblados = function () {
        var _this = this;
        this.context.app.showSpinner();
        this.ensambladoService.loadList()
            .then(function (ensamblados) {
            _this.ensamblados = ensamblados;
            _this.context.app.hideSpinner();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    ///////////////////////// HANDLERS ///////////////////////////////////////
    JobOrigenesEditor.prototype.onConfigureCatalog = function (options) {
        this.autogeneratedCode = options.codigoAutogenerado;
        this.applyPolicies();
        this.loadEnsamblados();
    };
    JobOrigenesEditor.prototype.onCreatingItem = function () {
    };
    JobOrigenesEditor.prototype.onViewingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.jobSourceService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.jobSource = info;
            _this.setReadonlyMode();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    JobOrigenesEditor.prototype.onCloningItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        //
        this.jobSourceService.clone(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.jobSource = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    JobOrigenesEditor.prototype.onLoadingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.jobSourceService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.jobSource = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    JobOrigenesEditor.prototype.onSavingItem = function (args) {
        var _this = this;
        this.context.app.showSpinner();
        this.jobSourceService.update(this.jobSource)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.reset();
            //Si es un elemento nuevo y no se cerrará el editor, navegar a nueva ruta
            if (!args.closeEditor && _this.jobSource.identity == 0) {
                _this.router.navigate(['../', info.identity], { relativeTo: _this.route });
            }
            else {
                if (args.closeEditor)
                    _this.router.navigate(['../'], { relativeTo: _this.route });
                else
                    _this.showAlert('La información ha sido actualizada con éxito', 'success');
            }
            _this.jobSource = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    var JobOrigenesEditor_1;
    JobOrigenesEditor = JobOrigenesEditor_1 = __decorate([
        Component({
            selector: 'kernel.queue-job-source-editor',
            template: "\n      <form [formGroup]=\"catalogForm\">\n\n          <azteca-catalog-editor #catalogEditor \n                                 [title]=\"'JobSource'\"\n                                 [info]=\"jobSource\"\n                                 [valid]=\"valid\"\n                                 (configureCatalog)=\"onConfigureCatalog($event)\"\n                                 (creatingItem)=\"onCreatingItem()\"\n                                 (viewingItem)=\"onViewingItem($event)\"\n                                 (cloningItem)=\"onCloningItem($event)\"\n                                 (savingItem)=\"onSavingItem($event)\"\n                                 (loadingItem)=\"onLoadingItem($event)\">\n\n\n              <!------------------- Menu de acciones adicionales --------------------->\n\n              <!------------------- Controles del editor ----------------------------->\n\n              <div class=\"row\">\n                  <div class=\"col-12 col-lg-10\">\n\n                      <div class=\"row\">\n                          <div class=\"col-12 col-lg-6\">\n                              <azteca-form-field [label]=\"'C\u00F3digo:'\">\n                                  <catalog-code formControlName=\"codigo\" [(ngModel)]=\"jobSource.code\" [automatic]=\"autogeneratedCode\"></catalog-code>\n                              </azteca-form-field>\n                          </div>\n                          <div class=\"col-12 col-lg-6\">\n                              <azteca-form-field [label]=\"'Nombre:'\">\n                                  <az-textbox formControlName=\"nombre\" [(ngModel)]=\"jobSource.nombre\"></az-textbox>\n                              </azteca-form-field>\n                          </div>\n                      </div>\n\n                      <div class=\"row\">\n                          <div class=\"col-12 col-lg-6\">\n                              <azteca-form-field [label]=\"'Ensamblado:'\">\n                                  <az-combobox formControlName=\"idEnsamblado\"\n                                               [(ngModel)]=\"jobSource.idEnsamblado\"\n                                               [items]=\"ensamblados\"\n                                               [valueMember]=\"'id'\"\n                                               [displayMember]=\"'nombre'\">\n                                  </az-combobox>\n                              </azteca-form-field>\n                          </div>\n                          <div class=\"col-12 col-lg-6\">\n                              <azteca-form-field [label]=\"'Clase:'\">\n                                  <az-textbox formControlName=\"clase\" [(ngModel)]=\"jobSource.clase\"></az-textbox>\n                              </azteca-form-field>\n                          </div>\n                      </div>\n\n\n                      <div class=\"row\">\n                          <div class=\"col-12 col-lg-6\">\n                              <azteca-form-field [label]=\"'Cantidad de reintentos:'\">\n                                  <az-input-number formControlName=\"maxReintentos\" [(ngModel)]=\"jobSource.maxReintentos\" [min]=\"0\"></az-input-number>\n                              </azteca-form-field>\n                          </div>\n                      </div>\n\n                  </div>\n              </div>\n\n          </azteca-catalog-editor>\n      </form>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return JobOrigenesEditor_1; })
                },
                {
                    provide: CatalogService, useExisting: JobSourceService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, FormBuilder, ChangeDetectorRef,
            Context, Location, JobSourceService, EnsambladoService])
    ], JobOrigenesEditor);
    return JobOrigenesEditor;
}(CatalogEditor));
export { JobOrigenesEditor };
