var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, forwardRef, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators } from '@angular/forms';
import { Location } from '@angular/common';
//Azteca Kernel
import { Context, BaseComponent, CatalogService } from '../../core';
import { CatalogEditor } from '../../editors';
//Features
import { ScheduleService } from '../services/schedule.service';
import { ScheduleInfo } from '../models/schedule';
var SchedulesEditor = /** @class */ (function (_super) {
    __extends(SchedulesEditor, _super);
    //
    function SchedulesEditor(router, route, formBuilder, changeDetector, context, location, scheduleService) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.changeDetector = changeDetector;
        _this.context = context;
        _this.location = location;
        _this.scheduleService = scheduleService;
        _this.schedule = new ScheduleInfo();
        _this.frecuencias = [
            { 'name': 'Diaria', 'value': 'D' },
            { 'name': 'Semanal', 'value': 'S' },
            { 'name': 'Mensual', 'value': 'M' }
        ];
        _this.ocurrencias = [
            { "id": true, "nombre": "ocurre una vez a las" },
            { "id": false, "nombre": "Ocurre cada (minutos)" }
        ];
        _this.ocurrenciaMes = "PERIOD";
        _this.ocurrenciasMes = [
            { "id": "DAY", "nombre": "por dia especifico de mes" },
            { "id": "PERIOD", "nombre": "por el limite de mes" }
        ];
        _this.periodoMes = "FIRST";
        _this.periodosMes = [
            { "id": "FIRST", "nombre": "primer dia del mes" },
            { "id": "LAST", "nombre": "ultimo dia del mes" }
        ];
        _this.catalogForm = formBuilder.group({
            'codigo': ['', Validators.required],
            'nombre': ['', Validators.required],
            'frecuencia': ['', Validators.required],
            'intervaloFrecuencia': [0],
            'lunes': [false],
            'martes': [false],
            'miercoles': [false],
            'jueves': [false],
            'viernes': [false],
            'sabado': [false],
            'domingo': [false],
            'horaEjecucion': [new Date()],
            'fechaIni': [new Date()],
            'fechaFin': [new Date()],
            'horaIni': [new Date()],
            'horaFin': [new Date()],
            'evaluarHoraEjecucion': [true],
            'evaluarFechaFinal': [true],
            'ocurrenciaMes': ['PERIOD'],
            'diaMes': [0],
            'periodoMes': ['LAST'],
        });
        return _this;
    }
    SchedulesEditor_1 = SchedulesEditor;
    ///////////////////////// METODOS ///////////////////////////////////////
    ///////////////////////// HANDLERS ///////////////////////////////////////
    SchedulesEditor.prototype.onConfigureCatalog = function (options) {
        this.autogeneratedCode = options.codigoAutogenerado;
        this.applyPolicies();
    };
    SchedulesEditor.prototype.onCreatingItem = function () {
        this.schedule.horaEjecucion = new Date(1901, 1, 1, 0, 0, 0, 0);
    };
    SchedulesEditor.prototype.onViewingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.scheduleService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.schedule = info;
            _this.setReadonlyMode();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    SchedulesEditor.prototype.onCloningItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        //
        this.scheduleService.clone(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.schedule = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    SchedulesEditor.prototype.onLoadingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.scheduleService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.schedule = info;
            if (info.frecuencia == 'M') {
                //Fue por dia del mes
                if (info.diaMes > 0) {
                    _this.ocurrenciaMes = "DAY";
                }
                else if (info.primerDiaMes || info.ultimoDiaMes) { //Si es por periodo del mes
                    _this.ocurrenciaMes = "PERIOD";
                    //
                    info.diaMes = 0;
                    if (info.primerDiaMes)
                        _this.periodoMes = "FIRST";
                    if (info.ultimoDiaMes)
                        _this.periodoMes = "LAST";
                }
            }
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    SchedulesEditor.prototype.onSavingItem = function (args) {
        var _this = this;
        this.context.app.showSpinner();
        if (this.schedule.frecuencia == 'M') {
            if (this.ocurrenciaMes = 'DAY') {
                this.schedule.primerDiaMes = false;
                this.schedule.ultimoDiaMes = false;
            }
            else
                (this.ocurrenciaMes = 'PERIOD');
            {
                this.schedule.diaMes = 0;
                this.schedule.primerDiaMes = this.periodoMes == "FIRST" ? true : false;
                this.schedule.ultimoDiaMes = this.periodoMes == "LAST" ? true : false;
            }
        }
        this.scheduleService.update(this.schedule)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.reset();
            //Si es un elemento nuevo y no se cerrará el editor, navegar a nueva ruta
            if (!args.closeEditor && _this.schedule.identity == 0) {
                _this.router.navigate(['../', info.identity], { relativeTo: _this.route });
            }
            else {
                if (args.closeEditor)
                    _this.router.navigate(['../'], { relativeTo: _this.route });
                else
                    _this.showAlert('La información ha sido actualizada con éxito', 'success');
            }
            _this.schedule = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    var SchedulesEditor_1;
    SchedulesEditor = SchedulesEditor_1 = __decorate([
        Component({
            selector: 'kernel/queue-schedule-editor',
            template: "\n      <form [formGroup]=\"catalogForm\">\n\n          <azteca-catalog-editor #catalogEditor \n                                 [title]=\"'Schedule'\"\n                                 [info]=\"schedule\"\n                                 [valid]=\"valid\"\n                                 (configureCatalog)=\"onConfigureCatalog($event)\"\n                                 (creatingItem)=\"onCreatingItem()\"\n                                 (viewingItem)=\"onViewingItem($event)\"\n                                 (cloningItem)=\"onCloningItem($event)\"\n                                 (savingItem)=\"onSavingItem($event)\"\n                                 (loadingItem)=\"onLoadingItem($event)\">\n\n\n              <!------------------- Menu de acciones adicionales --------------------->\n\n              <!------------------- Controles del editor ----------------------------->\n\n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <azteca-form-field [label]=\"'C\u00F3digo:'\">\n                          <catalog-code formControlName=\"codigo\" [(ngModel)]=\"schedule.code\" [automatic]=\"autogeneratedCode\"></catalog-code>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Nombre:'\">\n                          <az-textbox formControlName=\"nombre\" [(ngModel)]=\"schedule.nombre\"></az-textbox>\n                      </azteca-form-field>\n\n                  </div>\n              </div>\n\n        \n              <div class=\"row\">\n                  <div class=\"col-12\">\n                      <tabset>\n                          <tab heading=\"Programaci&oacute;n\">\n\n                              <az-panel [header]=\"'Frecuencia'\">\n\n                                  <div class=\"row\">\n                                      <div class=\"col-12 col-md-6\">\n                                          <azteca-form-field [label]=\"'Frecuencia:'\">\n                                              <az-combobox formControlName=\"frecuencia\"\n                                                           [(ngModel)]=\"schedule.frecuencia\"\n                                                           [items]=\"frecuencias\"\n                                                           [displayMember]=\"'name'\"\n                                                           [valueMember]=\"'value'\">\n                                              </az-combobox>\n                                          </azteca-form-field>\n                                      </div>\n                                  </div>\n                            \n                                  <!--Diario-->\n                                  <div class=\"row\" *ngIf=\"schedule.frecuencia == 'D'\">\n                                      <div class=\"col-12 col-md-6\">\n                                          <azteca-form-field [label]=\"'ocurre cada:'\">\n                                              <az-input-number formControlName=\"intervaloFrecuencia\"\n                                                               [(ngModel)]=\"schedule.intervaloFrecuencia\"\n                                                               [min]=\"1\"\n                                                               [max]=\"100\">\n                                              </az-input-number>\n                                          </azteca-form-field>\n                                      </div>\n                                  </div>\n\n                                  <!--Mensual-->\n                                  <div class=\"row\" *ngIf=\"schedule.frecuencia == 'M'\">\n                                      <div class=\"col-12 col-md-6\">\n                                          <azteca-form-field [label]=\"'periodo del mes:'\">\n                                              <az-combobox formControlName=\"ocurrenciaMes\"\n                                                           [(ngModel)]=\"ocurrenciaMes\"\n                                                           [items]=\"ocurrenciasMes\"\n                                                           [displayMember]=\"'nombre'\"\n                                                           [valueMember]=\"'id'\">\n                                              </az-combobox>\n                                          </azteca-form-field>\n                                      </div>\n\n                                      <div class=\"col-12 col-md-6\" *ngIf=\"ocurrenciaMes == 'DAY'\">\n                                          <azteca-form-field [label]=\"'ocurre el dia (del mes):'\">\n                                              <az-input-number formControlName=\"diaMes\"\n                                                               [(ngModel)]=\"schedule.diaMes\"\n                                                               [min]=\"1\"\n                                                               [max]=\"31\">\n                                              </az-input-number>\n                                          </azteca-form-field>\n                                      </div>\n\n                                      <div class=\"col-12 col-md-6\" *ngIf=\"ocurrenciaMes == 'PERIOD'\">\n                                          <azteca-form-field [label]=\"'ocurre el:'\">\n                                              <az-combobox formControlName=\"periodoMes\"\n                                                           [(ngModel)]=\"periodoMes\"\n                                                           [items]=\"periodosMes\"\n                                                           [displayMember]=\"'nombre'\"\n                                                           [valueMember]=\"'id'\">\n                                              </az-combobox>\n                                          </azteca-form-field>\n                                      </div>\n\n                                  </div>\n\n\n                                  <div class=\"row\">\n                                      <!-- Si la frecuencia es semanal, poder indicar entre (Lun, Mar, Mie, Jue, Vie, Sab, Dom) -->\n                                      <ng-container *ngIf=\"schedule.frecuencia == 'S'\">\n                                          <div class=\"row\">\n                                              <div class=\"col-12 col-md-2\">\n                                                  <az-checkbox formControlName=\"lunes\"\n                                                               [label]=\"'Lunes'\"\n                                                               [(ngModel)]=\"schedule.lunes\">\n                                                  </az-checkbox>\n                                              </div>\n                                              <div class=\"col-12 col-md-2\">\n                                                  <az-checkbox formControlName=\"martes\"\n                                                               [label]=\"'Martes'\"\n                                                               [(ngModel)]=\"schedule.martes\">\n                                                  </az-checkbox>\n                                              </div>\n                                              <div class=\"col-12 col-md-2\">\n                                                  <az-checkbox formControlName=\"miercoles\"\n                                                               [label]=\"'Miercoles'\"\n                                                               [(ngModel)]=\"schedule.miercoles\">\n                                                  </az-checkbox>\n                                              </div>\n                                              <div class=\"col-12 col-md-2\">\n                                                  <az-checkbox formControlName=\"jueves\"\n                                                               [label]=\"'Jueves'\"\n                                                               [(ngModel)]=\"schedule.jueves\">\n                                                  </az-checkbox>\n                                              </div>\n                                              <div class=\"col-12 col-md-2\">\n                                                  <az-checkbox formControlName=\"viernes\"\n                                                               [label]=\"'Viernes'\"\n                                                               [(ngModel)]=\"schedule.viernes\">\n                                                  </az-checkbox>\n                                              </div>\n\n                                              <div class=\"col-12 col-md-2\">\n                                                  <az-checkbox formControlName=\"sabado\"\n                                                               [label]=\"'S&aacute;bado'\"\n                                                               [(ngModel)]=\"schedule.sabado\">\n                                                  </az-checkbox>\n                                              </div>\n                                              <div class=\"col-12 col-md-2\">\n                                                  <az-checkbox formControlName=\"domingo\"\n                                                               [label]=\"'Domingo'\"\n                                                               [(ngModel)]=\"schedule.domingo\">\n                                                  </az-checkbox>\n                                              </div>\n                                          </div>\n\n                                      </ng-container>\n\n                                  </div>\n\n                              </az-panel>\n\n                              <az-panel [header]=\"'Recurrencia'\">\n\n                                  <div class=\"row\">\n                            \n                                      <div class=\"col-12 col-md-4\">\n                                          <azteca-form-field [label]=\"'Ocurrencia'\">\n                                              <az-combobox formControlName=\"evaluarHoraEjecucion\"\n                                                           [(ngModel)]=\"schedule.evaluarHoraEjecucion\"\n                                                           [items]=\"ocurrencias\"\n                                                           [displayMember]=\"'nombre'\"\n                                                           [valueMember]=\"'id'\">\n                                              </az-combobox>\n                                          </azteca-form-field>\n                                      </div>\n\n                                      <div class=\"col-12 col-md-4\" *ngIf=\"schedule.evaluarHoraEjecucion==true\">\n                                          <ng-container *ngIf=\"schedule.evaluarHoraEjecucion==true\">\n                                              <azteca-form-field [label]=\"'Hora ejecuci&oacute;n:'\">\n                                                  <az-input-time formControlName=\"horaEjecucion\"\n                                                                      [(ngModel)]=\"schedule.horaEjecucion\"></az-input-time>\n                                              </azteca-form-field>\n                                          </ng-container>\n                                      </div>\n\n                                      <div class=\"col-12 col-md-4\">\n                                          <ng-container *ngIf=\"schedule.evaluarHoraEjecucion==false\">\n                                              <azteca-form-field [label]=\"'Intervalo ejecuci&oacute;n:'\">\n                                                  <az-input-number formControlName=\"intervaloEjecucion\"\n                                                                   [(ngModel)]=\"schedule.intervaloEjecucion\"\n                                                                   [min]=\"1\"\n                                                                   [max]=\"100\">\n                                                  </az-input-number>\n                                              </azteca-form-field>\n                                          </ng-container>                                    \n                                      </div>\n\n                                  </div>\n                                                                                   \n\n                              </az-panel>\n               \n                       \n                              <ng-container *ngIf=\"schedule.evaluarIntervaloEspecifico\">\n                                  <div class=\"row\">\n                               \n                                  </div>\n                                  <div class=\"row\">\n                                      <div class=\"col-12 col-md-5\">\n                                          <azteca-form-field [label]=\"'Hora inicial:'\">\n                                              <az-input-date-time formControlName=\"horaIni\"\n                                                                  [(ngModel)]=\"schedule.horaIni\"></az-input-date-time>\n                                          </azteca-form-field>\n                                      </div>\n                                      <div class=\"col-12 col-md-5\">\n                                          <!--Fecha Inicial-->\n                                          <azteca-form-field [label]=\"'Hora final:'\">\n                                              <az-input-date-time formControlName=\"horaFin\"\n                                                                  [(ngModel)]=\"schedule.horaFin\"></az-input-date-time>\n                                          </azteca-form-field>\n                                      </div>\n                                  </div>\n                              </ng-container>\n\n                              <az-panel [header]=\"'Duraci&oacute;n'\">\n                                  <div class=\"row\">\n                                      <div class=\"col-12 col-md-4\">\n                                          <azteca-form-field [label]=\"'Fecha inicial:'\">\n                                              <az-input-date formControlName=\"fechaIni\"\n                                                             [(ngModel)]=\"schedule.fechaIni\"></az-input-date>\n                                          </azteca-form-field>\n                                      </div>\n\n                                      <div class=\"col-12 col-md-4\">\n                                          <az-checkbox formControlName=\"evaluarFechaFinal\"\n                                                       [label]=\"'Fecha final'\"\n                                                       [(ngModel)]=\"schedule.evaluarFechaFinal\">\n                                          </az-checkbox>\n\n                                          <ng-container *ngIf=\"schedule.evaluarFechaFinal\">\n                                              <azteca-form-field [label]=\"''\">\n                                                  <az-input-date formControlName=\"fechaFin\"\n                                                                 [(ngModel)]=\"schedule.fechaFin\"></az-input-date>\n                                              </azteca-form-field>\n                                          </ng-container>\n                                      </div>\n\n                                  </div>\n                              </az-panel>\n\n                          </tab>\n                      </tabset>\n                  </div>\n              </div>\n            \n\n          </azteca-catalog-editor>\n      </form>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return SchedulesEditor_1; })
                },
                {
                    provide: CatalogService, useExisting: ScheduleService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, FormBuilder, ChangeDetectorRef,
            Context, Location, ScheduleService])
    ], SchedulesEditor);
    return SchedulesEditor;
}(CatalogEditor));
export { SchedulesEditor };
