var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, EventEmitter, Input, Output, ViewChild, ContentChildren, QueryList } from '@angular/core';
//
import * as wijmo from 'wijmo/wijmo';
//
import { ModalDirective } from 'ngx-bootstrap';
import { GridColumn } from '../../controls/directives/grid-column';
import { SearchRequest } from '../models/search-request';
var CatalogListDialogComponent = /** @class */ (function () {
    function CatalogListDialogComponent() {
        this.selectedItems = [];
        this.selectedItem = null;
        this.list = [];
        this.multiSelect = false;
        this.excludedItems = [];
        //Outputs
        this.searchRequested = new EventEmitter();
        this.selectedItemChanged = new EventEmitter();
        this.selectedItemsChanged = new EventEmitter();
    }
    CatalogListDialogComponent.prototype.ngOnChanges = function (changes) {
        if (changes['catalogList']) {
            //Si se habilitó selección múltiple, crear una copia de la colección y marcar los registros seleccionados
            if (this.multiSelect) {
                this.updateSelected();
            }
            //Si está configurado con selección simple, utilizar la misma colección de entrada
            else {
                this.list = this.catalogList;
            }
        }
    };
    CatalogListDialogComponent.prototype.updateSelected = function () {
        var _this = this;
        if (this.catalogList == undefined)
            return;
        //Crear copia local de la colección y quitar los elementos excluidos
        this.list = this.catalogList.slice();
        if (this.excludedItems.length > 0) {
            this.list = this.list.filter(function (fitem) { return !_this.excludedItems.find(function (sitem) { return sitem.id == fitem.id; }); });
        }
        //Marcar los elementos seleccionados
        this.list.forEach(function (item) {
            if (item.selected == undefined)
                item.selected = false;
            //Si el elemento se encuentra dentro de la colección de elementos seleccionados, cambiar estatus
            if (_this.selectedItems.find(function (selItem) { return selItem.id == item.id; })) {
                item.selected = true;
            }
        });
    };
    CatalogListDialogComponent.prototype.onSearchRequested = function (request) {
        this.searchRequested.emit(request);
    };
    CatalogListDialogComponent.prototype.onCurrentItemChanged = function (item) {
        this.selectedItem = item;
    };
    CatalogListDialogComponent.prototype.onItemSelected = function (item) {
        //Sólo aplica cuando es de selección simple (doble click)
        if (!this.multiSelect) {
            this.selectedItemChanged.emit(item);
            this.listDialog.hide();
        }
    };
    CatalogListDialogComponent.prototype.onItemCheckedChanged = function (item) {
        if (item.selected) {
            this.selectedItems.push(item);
        }
        else {
            this.selectedItems = this.selectedItems.filter(function (fItem) { return item.id != fItem.id; });
        }
    };
    CatalogListDialogComponent.prototype.onConfirmClick = function () {
        if (this.multiSelect) {
            this.selectedItemsChanged.emit(this.selectedItems);
        }
        else {
            this.selectedItemChanged.emit(this.selectedItem);
        }
        this.listDialog.hide();
    };
    CatalogListDialogComponent.prototype.onCancelClick = function () {
        this.listDialog.hide();
    };
    CatalogListDialogComponent.prototype.triggerSearch = function () {
        var request = new SearchRequest();
        request.pageIndex = 0;
        request.pageSize = this.pageSize;
        request.paged = this.serverSide ? true : false;
        //
        this.searchRequested.emit(request);
    };
    CatalogListDialogComponent.prototype.show = function () {
        this.selectedItems = [];
        this.selectedItem = null;
        this.listDialog.config.backdrop = false;
        this.listDialog.show();
    };
    CatalogListDialogComponent.prototype.isValid = function () {
        if (this.multiSelect) {
            return this.selectedItems.length > 0;
        }
        else {
            return this.selectedItem != null;
        }
    };
    CatalogListDialogComponent.prototype.refreshControls = function () {
        wijmo.Control.invalidateAll();
    };
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], CatalogListDialogComponent.prototype, "catalogList", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], CatalogListDialogComponent.prototype, "serverSide", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], CatalogListDialogComponent.prototype, "pageIndex", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], CatalogListDialogComponent.prototype, "pageSize", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], CatalogListDialogComponent.prototype, "totalRows", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], CatalogListDialogComponent.prototype, "multiSelect", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], CatalogListDialogComponent.prototype, "excludedItems", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], CatalogListDialogComponent.prototype, "title", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogListDialogComponent.prototype, "searchRequested", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogListDialogComponent.prototype, "selectedItemChanged", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogListDialogComponent.prototype, "selectedItemsChanged", void 0);
    __decorate([
        ViewChild('listDialog'),
        __metadata("design:type", ModalDirective)
    ], CatalogListDialogComponent.prototype, "listDialog", void 0);
    __decorate([
        ContentChildren(GridColumn),
        __metadata("design:type", QueryList)
    ], CatalogListDialogComponent.prototype, "columns", void 0);
    CatalogListDialogComponent = __decorate([
        Component({
            selector: 'catalog-list-dialog',
            template: "\n      <div bsModal #listDialog=\"bs-modal\" (onShown)=\"refreshControls()\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"myLargeModalLabel\" aria-hidden=\"true\">\n\n          <div class=\"modal-dialog modal-lg\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-header\" *ngIf=\"title\">{{title}}</div>\n                  <div class=\"modal-body\">\n                      <azteca-catalog-list [catalogList]=\"list\"\n                                           (searchRequested)=\"onSearchRequested($event)\"\n                                           (currentItemChanged)=\"onCurrentItemChanged($event)\"\n                                           (itemSelected)=\"onItemSelected($event)\"\n                                           (itemCheckedChanged)=\"onItemCheckedChanged($event)\"\n                                           [showSelectColumn]=\"multiSelect\"\n                                           [serverSide]=\"serverSide\"\n                                           [pageSize]=\"pageSize\"\n                                           [totalRows]=\"totalRows\"\n                                           [pageIndex]=\"pageIndex\">\n\n                          <!-- Mapear columnas definidas en componente padre-->\n                          <azteca-grid-column *ngFor=\"let col of columns\"\n                                              [header]=\"col.header\"\n                                              [binding]=\"col.binding\"\n                                              [dataType]=\"col.dataType ? col.dataType :'String'\"\n                                              [dataMap]=\"col.dataMap\"\n                                              [width]=\"col.width\">\n\n                              <!-- Add cell template if col.cellTemplate is specified. -->\n                              <ng-template wjFlexGridCellTemplate *ngIf=\"col.cellTemplate\" [cellType]=\"'Cell'\" let-cell=\"cell\">\n                                  <!-- Load the component whose type is specified in col.cellTemplate -->\n                                  <wj-component-loader [component]=\"col.cellTemplate\" [properties]=\"{cell: cell}\"></wj-component-loader>\n                              </ng-template>\n\n                          </azteca-grid-column>\n\n                      </azteca-catalog-list>\n                \n\n                  </div> <!-- Modal Body-->\n                  <div class=\"modal-footer\">\n                      <button type=\"button\" class=\"btn btn-primary\" (click)=\"onConfirmClick()\" [disabled]=\"!isValid()\">Aceptar</button>\n                      <button type=\"button\" class=\"btn btn-default\" (click)=\"onCancelClick()\">Cancelar</button>\n                  </div> <!-- Modal Footer-->\n\n              </div> <!--Modal Content-->\n          </div> <!-- Modal-->\n      </div> <!-- Modal Directive-->\n    "
        }),
        __metadata("design:paramtypes", [])
    ], CatalogListDialogComponent);
    return CatalogListDialogComponent;
}());
export { CatalogListDialogComponent };
