var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, EventEmitter, Input, Output, ViewChild, ContentChildren, QueryList } from '@angular/core';
//
import { CollectionView, DataType } from 'wijmo/wijmo';
import { FlexGrid, CellRange, CellType } from 'wijmo/wijmo.grid';
import { FlexGridFilter, FilterType, Operator } from 'wijmo/wijmo.grid.filter';
import { Menu } from 'wijmo/wijmo.input';
import { SearchRequest, SortOrder } from '../models/search-request';
import { GridColumn } from '../../controls/directives/grid-column';
import { MenuItemDirective } from '../../controls/directives/menu-item.directive';
import { GridFilter } from '../../utils/grid-filter';
var CatalogListComponent = /** @class */ (function () {
    function CatalogListComponent() {
        this._emptyFilter = "{\"defaultFilterType\":3, \"filters\":[]}";
        this._catalogList = [];
        this._currentFilter = this._emptyFilter;
        this._currentSortedColumn = -1;
        this._pageSize = 20;
        this._serverSide = true;
        //
        this.currentItem = null;
        this.catalogView = new CollectionView();
        //
        this.enabled = true;
        this.showSelectColumn = false;
        this.showStatusColumn = true;
        this.showRowButton = false;
        this.pageIndex = 0;
        this.totalRows = 0;
        //
        this.searchRequested = new EventEmitter();
        this.contextMenuClick = new EventEmitter();
        this.currentItemChanged = new EventEmitter();
        this.itemSelected = new EventEmitter();
        this.contextMenuOpen = new EventEmitter();
        this.rowButtonClick = new EventEmitter();
        this.itemCheckedChanged = new EventEmitter();
    }
    Object.defineProperty(CatalogListComponent.prototype, "pageCount", {
        get: function () {
            if (this.serverSide)
                return Math.ceil(this.totalRows / this.pageSize);
            else
                return this.catalogView.pageCount;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CatalogListComponent.prototype, "catalogList", {
        get: function () {
            return this._catalogList;
        },
        set: function (value) {
            if (value) {
                this._catalogList = value;
                this.catalogView.sourceCollection = value;
                this.catalogView.moveCurrentToFirst();
                if (this.catalogView.currentItem != null) {
                    this.currentItem = { id: this.catalogView.currentItem.id, codigo: this.catalogView.currentItem.codigo, activo: this.catalogView.currentItem.activo, estatus: this.catalogView.currentItem.estatus, data: this.catalogView.currentItem };
                    this.currentItemChanged.emit(this.currentItem);
                }
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CatalogListComponent.prototype, "pageSize", {
        get: function () {
            return this._pageSize;
        },
        set: function (value) {
            this._pageSize = value;
            this.catalogView.pageSize = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CatalogListComponent.prototype, "serverSide", {
        get: function () {
            return this._serverSide;
        },
        set: function (value) {
            this._serverSide = value;
            if (this.filter) {
                this.setFilterType();
            }
        },
        enumerable: true,
        configurable: true
    });
    CatalogListComponent.prototype.setFilterType = function () {
        if (this._serverSide) {
            this.filter.defaultFilterType = FilterType.Condition;
            this._currentFilter = this.filter.filterDefinition;
        }
        else {
            this.filter.defaultFilterType = FilterType.Both;
            this._currentFilter = this._emptyFilter;
        }
        this.setDefaultFilterOperator();
    };
    CatalogListComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.catalogView.currentChanged.addHandler(function (args) {
            _this.refreshCurrenItem();
        });
    };
    CatalogListComponent.prototype.ngAfterViewInit = function () {
        this.setFilterType();
    };
    CatalogListComponent.prototype.initialized = function (sender, args) {
        var _this = this;
        var self = this;
        //Agregar manejador para menú contextual        
        sender.addEventListener(sender.hostElement, "contextmenu", function (e) {
            var ht = sender.hitTest(e);
            sender.select(new CellRange(ht.row, ht.col), true);
            self.contextMenuOpen.emit(self.currentItem);
        });
        //Manejo de doble click
        sender.addEventListener(sender.hostElement, "dblclick", function (e) {
            var ht = sender.hitTest(e);
            if (ht.cellType == CellType.Cell) {
                _this.itemSelected.emit(_this.currentItem);
            }
        });
        //Establecer el operador "comienza con" para todas cadenas
        this.setDefaultFilterOperator();
        //        
    };
    CatalogListComponent.prototype.setDefaultFilterOperator = function () {
        for (var i = 0; i < this.grid.columns.length; i++) {
            var col = this.grid.columns[i];
            var colFilter = this.filter.getColumnFilter(col);
            if (colFilter != null) {
                if (col.dataType == undefined || col.dataType == DataType.String) {
                    colFilter.conditionFilter.condition1.operator = Operator.BW;
                }
            }
        }
    };
    CatalogListComponent.prototype.moveFirst = function () {
        if (this.serverSide)
            this.createSearchRequest(0);
        else {
            this.catalogView.moveToFirstPage();
            this.pageIndex = this.catalogView.pageIndex;
            this.refreshCurrenItem();
        }
    };
    CatalogListComponent.prototype.movePrevious = function () {
        if (this.serverSide)
            this.createSearchRequest(this.pageIndex - 1);
        else {
            this.catalogView.moveToPreviousPage();
            this.pageIndex = this.catalogView.pageIndex;
            this.refreshCurrenItem();
        }
    };
    CatalogListComponent.prototype.moveNext = function () {
        if (this.serverSide)
            this.createSearchRequest(this.pageIndex + 1);
        else {
            this.catalogView.moveToNextPage();
            this.pageIndex = this.catalogView.pageIndex;
            this.refreshCurrenItem();
        }
    };
    CatalogListComponent.prototype.moveLast = function () {
        if (this.serverSide)
            this.createSearchRequest(this.pageCount - 1);
        else {
            this.catalogView.moveToLastPage();
            this.pageIndex = this.catalogView.pageIndex;
            this.refreshCurrenItem();
        }
    };
    CatalogListComponent.prototype.getStatusColor = function (activo) {
        if (activo)
            return '#298A08';
        else
            return 'orangered';
    };
    CatalogListComponent.prototype.filterChanged = function (e, args) {
        if (this.serverSide) {
            this._currentFilter = this.filter.filterDefinition;
            this.createSearchRequest(0);
        }
        else {
            this.pageIndex = 0;
        }
    };
    CatalogListComponent.prototype.sortChanged = function (sender, args) {
        if (this.serverSide) {
            var col = sender.columns[args.col];
            this._currentSortedColumn = args.col;
            this._currentSortOrder = col.currentSort;
            this.createSearchRequest(this.pageIndex);
        }
    };
    CatalogListComponent.prototype.createSearchRequest = function (pageIndex) {
        //Crear objeto con la representación del filtro actual del grid
        var gridFilter = new GridFilter();
        gridFilter.fromJSON(this._currentFilter);
        //Crear search request a partir de los filtros y orden del grid
        var request = new SearchRequest();
        request.SetGridConditions(gridFilter);
        request.pageIndex = pageIndex;
        request.pageSize = this.pageSize;
        request.paged = this.serverSide ? true : false;
        //Iterar sobre las columnas del grid para determinar el orden
        for (var i = 0; i < this.grid.columns.length; i++) {
            var col = this.grid.columns[i];
            if (col.currentSort != null) {
                var SortExp = new SortOrder();
                SortExp.field = col.binding;
                SortExp.direction = col.currentSort == "+" ? "asc" : "desc";
                request.order.push(SortExp);
            }
        }
        //
        this.searchRequested.emit(request);
        return request;
    };
    CatalogListComponent.prototype.menuItemClicked = function (menu, args) {
        if (this.currentItem != null) {
            var menuItems = this.contextMenuItems.toArray();
            var item = menuItems[menu.selectedIndex];
            this.contextMenuClick.emit(item);
        }
    };
    CatalogListComponent.prototype.onRowButtonClick = function (row) {
        this.rowButtonClick.emit(row);
    };
    CatalogListComponent.prototype.onCellUpdated = function (args) {
        //Si se editó la columna de selección
        if (args.col == 0) {
            this.itemCheckedChanged.emit(this.catalogView.currentItem);
        }
    };
    CatalogListComponent.prototype.refreshCurrenItem = function () {
        var row = this.catalogView.currentItem;
        if (row != null)
            this.currentItem = { id: row.id, codigo: row.codigo, activo: row.activo, estatus: row.estatus, data: row };
        else
            this.currentItem = null;
        //
        this.currentItemChanged.emit(this.currentItem);
    };
    __decorate([
        ContentChildren(GridColumn),
        __metadata("design:type", QueryList)
    ], CatalogListComponent.prototype, "columns", void 0);
    __decorate([
        ViewChild('filter'),
        __metadata("design:type", FlexGridFilter)
    ], CatalogListComponent.prototype, "filter", void 0);
    __decorate([
        ViewChild('grid'),
        __metadata("design:type", FlexGrid)
    ], CatalogListComponent.prototype, "grid", void 0);
    __decorate([
        ViewChild('smallGrid'),
        __metadata("design:type", FlexGrid)
    ], CatalogListComponent.prototype, "smallGrid", void 0);
    __decorate([
        ViewChild('ctxMenu'),
        __metadata("design:type", Menu)
    ], CatalogListComponent.prototype, "contextMenu", void 0);
    __decorate([
        ContentChildren(MenuItemDirective),
        __metadata("design:type", QueryList)
    ], CatalogListComponent.prototype, "contextMenuItems", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], CatalogListComponent.prototype, "enabled", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Array),
        __metadata("design:paramtypes", [Array])
    ], CatalogListComponent.prototype, "catalogList", null);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], CatalogListComponent.prototype, "showSelectColumn", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], CatalogListComponent.prototype, "showStatusColumn", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], CatalogListComponent.prototype, "showRowButton", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], CatalogListComponent.prototype, "rowButtonIcon", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], CatalogListComponent.prototype, "pageIndex", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number),
        __metadata("design:paramtypes", [Number])
    ], CatalogListComponent.prototype, "pageSize", null);
    __decorate([
        Input(),
        __metadata("design:type", Boolean),
        __metadata("design:paramtypes", [Boolean])
    ], CatalogListComponent.prototype, "serverSide", null);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], CatalogListComponent.prototype, "totalRows", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogListComponent.prototype, "searchRequested", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogListComponent.prototype, "contextMenuClick", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogListComponent.prototype, "currentItemChanged", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogListComponent.prototype, "itemSelected", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogListComponent.prototype, "contextMenuOpen", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogListComponent.prototype, "rowButtonClick", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], CatalogListComponent.prototype, "itemCheckedChanged", void 0);
    CatalogListComponent = __decorate([
        Component({
            selector: 'azteca-catalog-list',
            template: "\n      <wj-menu #ctxMenu (itemClicked)=\"menuItemClicked(ctxMenu, $event)\" style=\"display:none\">\n          <wj-menu-item *ngFor=\"let item of contextMenuItems\">\n              <div *ngIf=\"enabled && item.enabled\">\n                  <span [class]=\"item.icon\"></span>\n                  <b>{{item.text}}</b>\n                  <br>\n                  <small><i>{{item.smallText}}</i></small>\n              </div>\n          </wj-menu-item>\n      </wj-menu>\n\n      <!------------------------------------------- GRID PARA DISPOSITIVOS GRANDES ---------------------------------------------->\n      <div class=\"row d-none d-lg-block\">\n\n          <div class=\"col-12\">\n              <wj-flex-grid #grid style=\"height:500px\"\n                            [itemsSource]=\"catalogView\"\n                            (initialized)=\"initialized(grid, $event)\"\n                            (sortedColumn)=\"sortChanged(grid, $event)\"\n                            (cellEditEnded)=\"onCellUpdated($event)\"\n                            [selectionMode]=\"'Row'\"\n                            [wjContextMenu]=\"ctxMenu\">\n\n                  <!--Selection Column-->\n                  <wj-flex-grid-column *ngIf=\"showSelectColumn\" [header]=\"''\" [allowResizing]=\"false\" [binding]=\"'selected'\" dataType=\"Boolean\" [width]=\"45\"></wj-flex-grid-column>\n\n                  <!--Row Button-->\n                  <wj-flex-grid-column *ngIf=\"showRowButton\" [header]=\"''\" [width]=\"55\" [isReadOnly]=\"true\">\n                      <ng-template wjFlexGridCellTemplate [cellType]=\"'Cell'\" let-cell=\"cell\">\n                          <button type=\"button\" class=\"btn btn-default\" (click)=\"onRowButtonClick(cell.item)\">\n                              <span [ngClass]=\"rowButtonIcon\"></span>\n                          </button>\n                      </ng-template>\n                  </wj-flex-grid-column>\n\n\n                  <wj-flex-grid-filter #filter (filterChanged)=\"filterChanged(filter, $event)\"></wj-flex-grid-filter>\n                  <!--Agregar las columnas definidas en el template-->\n                  <wj-flex-grid-column *ngFor=\"let col of columns\"\n                                       [header]=\"col.header\"\n                                       [binding]=\"col.binding\"\n                                       [name]=\"col.name\"\n                                       [isReadOnly]=\"true\"\n                                       [format]=\"col.format\"\n                                       [dataType]=\"col.dataType\"\n                                       [dataMap]=\"col.dataMap\"\n                                       [width]=\"col.width\">\n\n                      <ng-template wjFlexGridCellTemplate *ngIf=\"col.cellTemplate\" [cellType]=\"'Cell'\" let-cell=\"cell\">\n                          <!-- Load the component whose type is specified in col.cellTemplate -->\n                          <wj-component-loader [component]=\"col.cellTemplate\" [properties]=\"{cell: cell}\"></wj-component-loader>\n                      </ng-template>\n                  </wj-flex-grid-column>\n\n                  <!--COLUMNA DE ESTATUS-->\n                  <wj-flex-grid-column *ngIf=\"showStatusColumn\" [header]=\"'Estatus'\" [binding]=\"'estatus'\" [width]=\"120\">\n                      <ng-template wjFlexGridCellTemplate [cellType]=\"'Cell'\" let-cell=\"cell\">\n                          <div [ngStyle]=\"{'background-color': getStatusColor(cell.item.activo), 'color': 'white'}\">\n                              {{cell.item.estatus}}\n                          </div>\n                      </ng-template>\n                  </wj-flex-grid-column>\n\n              </wj-flex-grid>\n          </div>\n      </div>\n\n\n      <!--------------------------------------- GRID PARA DISPOSITIVOS PEQUE\u00D1OS ------------------------------------------------->\n      <div class=\"row d-lg-none \">\n          <div class=\"col-12\">\n\n              <wj-flex-grid #smallGrid style=\"height:400px\"\n                            [itemsSource]=\"catalogView\"\n                            (initialized)=\"initialized(smallGrid, $event)\"\n                            (sortedColumn)=\"sortChanged(smallGrid, $event)\"\n                            (cellEditEnded)=\"onCellUpdated($event)\"\n                            [selectionMode]=\"'Row'\"\n                            [wjContextMenu]=\"ctxMenu\">\n\n                  <!--Selection Column-->\n                  <wj-flex-grid-column *ngIf=\"showSelectColumn\" [header]=\"''\" [allowResizing]=\"false\" [binding]=\"'selected'\" dataType=\"Boolean\" [width]=\"45\"></wj-flex-grid-column>\n\n                  <!--Row Button-->\n                  <wj-flex-grid-column *ngIf=\"showRowButton\" [header]=\"''\" [width]=\"55\" [isReadOnly]=\"true\">\n                      <ng-template wjFlexGridCellTemplate [cellType]=\"'Cell'\" let-cell=\"cell\">\n                          <button type=\"button\" class=\"btn btn-default\" (click)=\"onRowButtonClick(cell.item)\">\n                              <span [ngClass]=\"rowButtonIcon\"></span>\n                          </button>\n                      </ng-template>\n                  </wj-flex-grid-column>\n\n                  <!--COLUMNA DE ESTATUS-->\n                  <wj-flex-grid-column [header]=\"'Registro'\" [binding]=\"'estatus'\" [isReadOnly]=\"true\" [width]=\"'*'\">\n                      <ng-template wjFlexGridCellTemplate [cellType]=\"'Cell'\" let-cell=\"cell\">\n                          <div>\n                              <div class=\"row\">\n                                  <div class=\"col-6\">\n                                      {{cell.item.codigo}}\n                                  </div>\n                                  <div class=\"col-6\" [ngStyle]=\"{'background-color': getStatusColor(cell.item.activo), 'color': 'white'}\">\n                                      {{cell.item.estatus}}\n                                  </div>\n                              </div>\n                              <div class=\"row\">\n                                  <div class=\"col-12\">\n                                      {{cell.item.nombre}}\n                                  </div>\n                              </div>\n                          </div>\n                      </ng-template>\n                  </wj-flex-grid-column>\n              </wj-flex-grid>\n\n          </div>\n      </div>\n\n      <div class=\"row\">\n          <div class=\"col-xs-12 col-md-6\">\n              <div class=\"btn-group\">\n                  <button type=\"button\" class=\"btn btn-default\"\n                          (click)=\"moveFirst()\"\n                          [disabled]=\"pageIndex <= 0\">\n                      <span class=\"glyphicon glyphicon-fast-backward\"></span>\n                  </button>\n                  <button type=\"button\" class=\"btn btn-default\"\n                          (click)=\"movePrevious()\"\n                          [disabled]=\"pageIndex <= 0\">\n                      <span class=\"glyphicon glyphicon-step-backward\"></span>\n                  </button>\n                  <button type=\"button\" class=\"btn btn-default\" disabled style=\"width:100px\">\n                      {{pageIndex + 1}} de {{pageCount}}\n                  </button>\n                  <button type=\"button\" class=\"btn btn-default\"\n                          (click)=\"moveNext()\"\n                          [disabled]=\"pageIndex >= pageCount -1\">\n                      <span class=\"glyphicon glyphicon-step-forward\"></span>\n                  </button>\n                  <button type=\"button\" class=\"btn btn-default\"\n                          (click)=\"moveLast()\"\n                          [disabled]=\"pageIndex >= pageCount -1\">\n                      <span class=\"glyphicon glyphicon-fast-forward\"></span>\n                  </button>\n              </div>\n          </div>\n      </div>\n    "
        })
    ], CatalogListComponent);
    return CatalogListComponent;
}());
export { CatalogListComponent };
