var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, EventEmitter, Input, Output, ViewChild, ContentChildren, QueryList } from '@angular/core';
//
import * as wijmo from 'wijmo/wijmo';
import * as moment from 'moment';
//
import { ModalDirective } from 'ngx-bootstrap';
import { GridColumn } from '../../controls/directives/grid-column';
import { SearchRequest } from '../models/search-request';
import { ConditionValueType } from '../models/condition-value-type';
var DocumentListDialogComponent = /** @class */ (function () {
    function DocumentListDialogComponent() {
        this.selectedItems = [];
        this.selectedItem = null;
        this.list = [];
        this.fechaInicial = new Date();
        this.fechaFinal = new Date();
        this.multiSelect = false;
        this.excludedItems = [];
        this.startPeriod = 2;
        this.endPeriod = 2;
        //Outputs
        this.searchRequested = new EventEmitter();
        this.selectedItemChanged = new EventEmitter();
        this.selectedItemsChanged = new EventEmitter();
    }
    DocumentListDialogComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        setTimeout(function (_) { return _this.loadConfiguration(); });
    };
    DocumentListDialogComponent.prototype.loadConfiguration = function () {
        this.fechaInicial = moment().subtract(this.startPeriod, 'day').toDate();
        this.fechaFinal = moment().add(this.endPeriod, 'day').toDate();
    };
    DocumentListDialogComponent.prototype.ngOnChanges = function (changes) {
        if (changes['documentList']) {
            //Si se habilitó selección múltiple, crear una copia de la colección y marcar los registros seleccionados
            if (this.multiSelect) {
                this.updateSelected();
            }
            //Si está configurado con selección simple, utilizar la misma colección de entrada
            else {
                this.list = this.documentList;
            }
        }
    };
    DocumentListDialogComponent.prototype.updateSelected = function () {
        var _this = this;
        if (this.documentList == undefined)
            return;
        //Crear copia local de la colección y quitar los elementos excluidos
        this.list = this.documentList.slice();
        if (this.excludedItems.length > 0) {
            this.list = this.list.filter(function (fitem) { return !_this.excludedItems.find(function (sitem) { return sitem.id == fitem.id; }); });
        }
        //Marcar los elementos seleccionados
        this.list.forEach(function (item) {
            if (item.selected == undefined)
                item.selected = false;
            //Si el elemento se encuentra dentro de la colección de elementos seleccionados, cambiar estatus
            if (_this.selectedItems.find(function (selItem) { return selItem.id == item.id; })) {
                item.selected = true;
            }
        });
    };
    DocumentListDialogComponent.prototype.onSearchRequested = function (request) {
        this.searchRequested.emit(request);
    };
    DocumentListDialogComponent.prototype.onCurrentItemChanged = function (item) {
        this.selectedItem = item;
    };
    DocumentListDialogComponent.prototype.currentItemChangedHandler = function (item) {
        //this.selectedItemChanged.emit(item);
        this.selectedItem = item;
    };
    DocumentListDialogComponent.prototype.onItemSelected = function (item) {
        //Sólo aplica cuando es de selección simple (doble click)
        if (!this.multiSelect) {
            this.selectedItemChanged.emit(item);
            this.listDialog.hide();
        }
    };
    DocumentListDialogComponent.prototype.onItemCheckedChanged = function (item) {
        if (item.selected) {
            this.selectedItems.push(item);
        }
        else {
            this.selectedItems = this.selectedItems.filter(function (fItem) { return item.id != fItem.id; });
        }
    };
    DocumentListDialogComponent.prototype.selectItem = function (item) {
        this.selectedItemChanged.emit(item);
        this.listDialog.hide();
    };
    DocumentListDialogComponent.prototype.onConfirmClick = function () {
        if (this.multiSelect) {
            this.selectedItemsChanged.emit(this.selectedItems);
        }
        else {
            this.selectedItemChanged.emit(this.selectedItem);
        }
        this.listDialog.hide();
    };
    DocumentListDialogComponent.prototype.onCancelClick = function () {
        this.listDialog.hide();
    };
    DocumentListDialogComponent.prototype.triggerSearch = function () {
        var request = new SearchRequest();
        request.pageIndex = 0;
        request.pageSize = this.pageSize;
        request.paged = false;
        //request.maxRows = this.maxRows;
        //Agregar condiciones de fecha
        var condicionFechaIni = { field: 'FechaSys', operator: '>=', valueType: ConditionValueType.DATE_TIME, value: moment(this.fechaInicial).format() };
        var condicionFechaFin = { field: 'FechaSys', operator: '<=', valueType: ConditionValueType.DATE_TIME, value: moment(this.fechaFinal).format() };
        request.conditions.push(condicionFechaIni, condicionFechaFin);
        //
        this.searchRequested.emit(request);
    };
    DocumentListDialogComponent.prototype.show = function () {
        this.fechaInicial = moment().subtract(this.startPeriod, 'day').toDate();
        this.fechaFinal = moment().add(2, 'day').toDate();
        this.selectedItems = [];
        this.selectedItem = null;
        this.listDialog.config.backdrop = false;
        this.listDialog.show();
    };
    DocumentListDialogComponent.prototype.isValid = function () {
        if (this.multiSelect) {
            return this.selectedItems.length > 0;
        }
        else {
            return this.selectedItem != null;
        }
    };
    DocumentListDialogComponent.prototype.refreshControls = function () {
        wijmo.Control.invalidateAll();
    };
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], DocumentListDialogComponent.prototype, "documentList", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], DocumentListDialogComponent.prototype, "serverSide", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], DocumentListDialogComponent.prototype, "pageIndex", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], DocumentListDialogComponent.prototype, "pageSize", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], DocumentListDialogComponent.prototype, "totalRows", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], DocumentListDialogComponent.prototype, "multiSelect", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], DocumentListDialogComponent.prototype, "excludedItems", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], DocumentListDialogComponent.prototype, "title", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], DocumentListDialogComponent.prototype, "startPeriod", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], DocumentListDialogComponent.prototype, "endPeriod", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DocumentListDialogComponent.prototype, "searchRequested", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DocumentListDialogComponent.prototype, "selectedItemChanged", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DocumentListDialogComponent.prototype, "selectedItemsChanged", void 0);
    __decorate([
        ViewChild('listDialog'),
        __metadata("design:type", ModalDirective)
    ], DocumentListDialogComponent.prototype, "listDialog", void 0);
    __decorate([
        ContentChildren(GridColumn),
        __metadata("design:type", QueryList)
    ], DocumentListDialogComponent.prototype, "columns", void 0);
    DocumentListDialogComponent = __decorate([
        Component({
            selector: 'document-list-dialog',
            template: "\n      <div bsModal #listDialog=\"bs-modal\" (onShown)=\"refreshControls()\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"myLargeModalLabel\" aria-hidden=\"true\">\n          <div class=\"modal-dialog modal-lg\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-header\">\n                      <h4 class=\"modal-title\">{{title}}</h4>\n                  </div>\n                  <div class=\"modal-body\">\n                      <!--FILTRO DE PERIODO-->\n                      <div class=\"row\">\n                          <div class=\"col-12 col-lg-6\">\n                              <label class=\"form-control-label\">Fecha inicial:</label>\n                              <az-input-date [(ngModel)]=\"fechaInicial\"></az-input-date>\n                          </div>\n                          <div class=\"col-12 col-lg-6\">\n                              <label class=\"form-control-label\">Fecha final:</label>\n                              <az-input-date [(ngModel)]=\"fechaFinal\"></az-input-date>\n                          </div>\n                      </div>\n                      <div class=\"row\">\n                          <div class=\"col-12\">\n                              <button class=\"btn btn-default\" (click)=\"triggerSearch()\">Actualizar listado</button>\n                          </div>\n                      </div>\n\n                      <!--LISTADO DE DOCUMENTOS-->\n                      <div class=\"row\">\n                          <div class=\"col-12\">\n\n                              <azteca-document-list [documentList]=\"documentList\"\n                                                    (currentItemChanged)=\"currentItemChangedHandler($event)\"\n                                                    (itemSelected)=\"selectItem($event)\"\n                                                    (itemCheckedChanged)=\"onItemCheckedChanged($event)\"\n                                                    [showSelectColumn]=\"multiSelect\"\n                                                    [enabled]=\"enabled\"\n                                                    [pageSize]=\"pageSize\">\n\n                                  <!-- Mapear columnas definidas en componente padre-->\n                                  <azteca-grid-column *ngFor=\"let col of columns\"\n                                                      [header]=\"col.header\"\n                                                      [binding]=\"col.binding\"\n                                                      [dataType]=\"col.dataType ? col.dataType :'String'\"\n                                                      [dataMap]=\"col.dataMap\"\n                                                      [format]=\"col.format\"\n                                                      [width]=\"col.width\">\n\n                                      <!-- Add cell template if col.cellTemplate is specified. -->\n                                      <ng-template wjFlexGridCellTemplate *ngIf=\"col.cellTemplate\" [cellType]=\"'Cell'\" let-cell=\"cell\">\n                                          <!-- Load the component whose type is specified in col.cellTemplate -->\n                                          <wj-component-loader [component]=\"col.cellTemplate\" [properties]=\"{cell: cell}\"></wj-component-loader>\n                                      </ng-template>\n\n                                  </azteca-grid-column>\n\n                              </azteca-document-list>\n\n                          </div>\n                      </div>\n\n                  </div><!--Modal Body-->\n                  <div class=\"modal-footer\">\n                      <button type=\"button\" class=\"btn btn-primary\" (click)=\"onConfirmClick()\" [disabled]=\"!isValid()\">Aceptar</button>\n                      <button type=\"button\" class=\"btn btn-default\" (click)=\"onCancelClick()\">Cancelar</button>\n                  </div> <!-- Modal Footer-->\n              </div>\n          </div> <!--Modal Content-->\n      </div> <!--Modal-->\n    "
        }),
        __metadata("design:paramtypes", [])
    ], DocumentListDialogComponent);
    return DocumentListDialogComponent;
}());
export { DocumentListDialogComponent };
