var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, EventEmitter, Input, Output, ViewChild, ContentChildren, QueryList } from '@angular/core';
//
import { CollectionView, DataType } from 'wijmo/wijmo';
import { FlexGrid, CellRange, CellType } from 'wijmo/wijmo.grid';
import { FlexGridFilter, Operator } from 'wijmo/wijmo.grid.filter';
import { Menu } from 'wijmo/wijmo.input';
import { DocumentStatus } from '../../core/models/document-status';
import { FilterGroup } from '../models/filter-group';
import { GridColumn } from '../../controls/directives/grid-column';
import { MenuItemDirective } from '../../controls/directives/menu-item.directive';
var DocumentListComponent = /** @class */ (function () {
    function DocumentListComponent() {
        this._pageSize = 20;
        //
        this.currentDocument = null;
        this.documentsView = new CollectionView();
        //
        this.enabled = true;
        this.documentList = [];
        this.showSelectColumn = false;
        this.showRowButton = false;
        this.showStatusColumn = true;
        this.pageIndex = 0;
        //    
        this.contextMenuClick = new EventEmitter();
        this.currentItemChanged = new EventEmitter();
        this.itemSelected = new EventEmitter();
        this.contextMenuOpen = new EventEmitter();
        this.rowButtonClick = new EventEmitter();
        this.itemCheckedChanged = new EventEmitter();
    }
    Object.defineProperty(DocumentListComponent.prototype, "pageCount", {
        get: function () {
            return this.documentsView.pageCount;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DocumentListComponent.prototype, "pageSize", {
        get: function () {
            return this._pageSize;
        },
        set: function (value) {
            this._pageSize = value;
            this.documentsView.pageSize = value;
        },
        enumerable: true,
        configurable: true
    });
    //Implementación 
    DocumentListComponent.prototype.ngAfterViewInit = function () {
        this.setDefaultFilterOperator();
    };
    DocumentListComponent.prototype.ngOnChanges = function (changes) {
        if (changes['documentList'] && this.documentList) {
            this.updateCollectionView();
            this.documentsView.moveCurrentToFirst();
            if (this.documentsView.currentItem != null) {
                this.currentDocument = { id: this.documentsView.currentItem.id, fechaCreacion: this.documentsView.currentItem.fechaCreacion, status: this.documentsView.currentItem.status, idStatus: this.documentsView.currentItem.idStatus, idWorkflowStep: this.documentsView.currentItem.idWorkflowStep, workflowStep: this.documentsView.currentItem.workflowStep };
                this.currentItemChanged.emit(this.currentDocument);
            }
        }
        if (changes['filterGroup']) {
            this.updateCollectionView();
        }
    };
    DocumentListComponent.prototype.initialized = function (sender, args) {
        var _this = this;
        var self = this;
        //Agregar manejador para menú contextual        
        sender.addEventListener(sender.hostElement, "contextmenu", function (e) {
            var ht = sender.hitTest(e);
            sender.select(new CellRange(ht.row, ht.col), true);
            self.contextMenuOpen.emit(self.currentDocument);
        });
        //Manejo de doble click
        sender.addEventListener(sender.hostElement, "dblclick", function (e) {
            var ht = sender.hitTest(e);
            if (ht.cellType == CellType.Cell) {
                _this.itemSelected.emit(_this.currentDocument);
            }
        });
        //Establecer el operador "comienza con" para todas cadenas
        this.setDefaultFilterOperator();
        //        
        this.documentsView.currentChanged.addHandler(function (args) {
            var row = self.documentsView.currentItem;
            if (row != null)
                _this.currentDocument = { id: row.id, fechaCreacion: row.fechaCreacion, status: row.status, idStatus: row.idStatus, idWorkflowStep: row.idWorkflowStep, workflowStep: row.workflowStep };
            else
                _this.currentDocument = null;
            //
            self.currentItemChanged.emit(self.currentDocument);
        }, self);
    };
    DocumentListComponent.prototype.updateCollectionView = function () {
        var _this = this;
        if (!this.documentList)
            return;
        if (this.filterGroup && this.filterGroup.id > 0) {
            if (this.filterGroup.tag == 'STATUS') {
                this.documentsView.sourceCollection = this.documentList.filter(function (doc) { return doc.idStatus == _this.filterGroup.id; });
            }
            else if (this.filterGroup.tag == 'STEP') {
                this.documentsView.sourceCollection = this.documentList.filter(function (doc) { return doc.idWorkflowStep == _this.filterGroup.id; });
            }
            else {
                this.documentsView.sourceCollection = this.documentList;
            }
        }
        else {
            this.documentsView.sourceCollection = this.documentList;
        }
    };
    DocumentListComponent.prototype.setDefaultFilterOperator = function () {
        for (var i = 0; i < this.grid.columns.length; i++) {
            var col = this.grid.columns[i];
            var colFilter = this.filter.getColumnFilter(col);
            if (colFilter != null) {
                if (col.dataType == undefined || col.dataType == DataType.String) {
                    colFilter.conditionFilter.condition1.operator = Operator.BW;
                }
            }
        }
    };
    DocumentListComponent.prototype.moveFirst = function () {
        this.documentsView.moveToFirstPage();
        this.pageIndex = this.documentsView.pageIndex;
    };
    DocumentListComponent.prototype.movePrevious = function () {
        this.documentsView.moveToPreviousPage();
        this.pageIndex = this.documentsView.pageIndex;
    };
    DocumentListComponent.prototype.moveNext = function () {
        this.documentsView.moveToNextPage();
        this.pageIndex = this.documentsView.pageIndex;
    };
    DocumentListComponent.prototype.moveLast = function () {
        this.documentsView.moveToLastPage();
        this.pageIndex = this.documentsView.pageIndex;
    };
    DocumentListComponent.prototype.getStatusColor = function (idStatus) {
        if (idStatus == DocumentStatus.DRAFT)
            return '#6E6E6E';
        else if (idStatus == DocumentStatus.ACTIVE)
            return '#298A08';
        else if (idStatus == DocumentStatus.QUEUED)
            return '#AEB404';
        else
            return 'orangered';
    };
    DocumentListComponent.prototype.filterChanged = function (e, args) {
        this.pageIndex = 0;
    };
    DocumentListComponent.prototype.sortChanged = function (sender, args) {
    };
    DocumentListComponent.prototype.menuItemClicked = function (menu, args) {
        if (this.currentDocument != null) {
            var menuItems = this.contextMenuItems.toArray();
            var item = menuItems[menu.selectedIndex];
            this.contextMenuClick.emit(item);
        }
    };
    DocumentListComponent.prototype.onRowButtonClick = function (row) {
        this.rowButtonClick.emit(row);
    };
    DocumentListComponent.prototype.onCellUpdated = function (args) {
        //Si se editó la columna de selección
        if (args.col == 0) {
            this.itemCheckedChanged.emit(this.documentsView.currentItem);
        }
    };
    __decorate([
        ContentChildren(GridColumn),
        __metadata("design:type", QueryList)
    ], DocumentListComponent.prototype, "columns", void 0);
    __decorate([
        ViewChild('grid'),
        __metadata("design:type", FlexGrid)
    ], DocumentListComponent.prototype, "grid", void 0);
    __decorate([
        ViewChild('filter'),
        __metadata("design:type", FlexGridFilter)
    ], DocumentListComponent.prototype, "filter", void 0);
    __decorate([
        ViewChild('ctxMenu'),
        __metadata("design:type", Menu)
    ], DocumentListComponent.prototype, "contextMenu", void 0);
    __decorate([
        ContentChildren(MenuItemDirective),
        __metadata("design:type", QueryList)
    ], DocumentListComponent.prototype, "contextMenuItems", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], DocumentListComponent.prototype, "enabled", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], DocumentListComponent.prototype, "documentList", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], DocumentListComponent.prototype, "showSelectColumn", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], DocumentListComponent.prototype, "showRowButton", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], DocumentListComponent.prototype, "showStatusColumn", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], DocumentListComponent.prototype, "rowButtonIcon", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], DocumentListComponent.prototype, "pageIndex", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number),
        __metadata("design:paramtypes", [Number])
    ], DocumentListComponent.prototype, "pageSize", null);
    __decorate([
        Input(),
        __metadata("design:type", FilterGroup)
    ], DocumentListComponent.prototype, "filterGroup", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DocumentListComponent.prototype, "contextMenuClick", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DocumentListComponent.prototype, "currentItemChanged", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DocumentListComponent.prototype, "itemSelected", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DocumentListComponent.prototype, "contextMenuOpen", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DocumentListComponent.prototype, "rowButtonClick", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], DocumentListComponent.prototype, "itemCheckedChanged", void 0);
    DocumentListComponent = __decorate([
        Component({
            selector: 'azteca-document-list',
            template: "\n      <wj-menu #ctxMenu (itemClicked)=\"menuItemClicked(ctxMenu, $event)\" style=\"display:none\">\n          <wj-menu-item *ngFor=\"let item of contextMenuItems\">\n              <div *ngIf=\"enabled && item.enabled\">\n                  <span [class]=\"item.icon\"></span>\n                  <b>{{item.text}}</b>\n                  <br>\n                  <small><i>{{item.smallText}}</i></small>\n              </div>\n          </wj-menu-item>\n      </wj-menu>\n\n      <div class=\"row\">\n\n          <div class=\"col-12\">\n              <wj-flex-grid #grid style=\"height:500px\"\n                            [itemsSource]=\"documentsView\"\n                            (initialized)=\"initialized(grid, $event)\"\n                            (sortedColumn)=\"sortChanged(grid, $event)\"\n                            (cellEditEnded)=\"onCellUpdated($event)\"\n                            [selectionMode]=\"'Row'\"\n                            [wjContextMenu]=\"ctxMenu\">\n\n                  <!--Selection Column-->\n                  <wj-flex-grid-column *ngIf=\"showSelectColumn\" [header]=\"''\" [allowResizing]=\"false\" [binding]=\"'selected'\" dataType=\"Boolean\" [width]=\"45\"></wj-flex-grid-column>\n\n                  <!--Row Button-->\n                  <wj-flex-grid-column *ngIf=\"showRowButton\" [header]=\"''\" [width]=\"55\" [isReadOnly]=\"true\">\n                      <ng-template wjFlexGridCellTemplate [cellType]=\"'Cell'\" let-cell=\"cell\">\n                          <button type=\"button\" class=\"btn btn-default\" (click)=\"onRowButtonClick(cell.item)\">\n                              <span [ngClass]=\"rowButtonIcon\"></span>\n                          </button>\n                      </ng-template>\n                  </wj-flex-grid-column>\n\n\n                  <wj-flex-grid-filter #filter (filterChanged)=\"filterChanged(filter, $event)\"></wj-flex-grid-filter>\n                  <!--Agregar las columnas definidas en el template-->\n                  <wj-flex-grid-column *ngFor=\"let col of columns\"\n                                       [header]=\"col.header\"\n                                       [binding]=\"col.binding\"\n                                       [name]=\"col.name\"\n                                       [isReadOnly]=\"true\"\n                                       [format]=\"col.format\"\n                                       [dataType]=\"col.dataType\"\n                                       [dataMap]=\"col.dataMap\"\n                                       [width]=\"col.width\">\n                      <!-- Add cell template if col.cellTemplate is specified. -->\n                      <ng-template wjFlexGridCellTemplate *ngIf=\"col.cellTemplate\" [cellType]=\"'Cell'\" let-cell=\"cell\">\n                          <!-- Load the component whose type is specified in col.cellTemplate -->\n                          <wj-component-loader [component]=\"col.cellTemplate\" [properties]=\"{cell: cell}\"></wj-component-loader>\n                      </ng-template>\n                  </wj-flex-grid-column>\n\n                  <!--COLUMNA DE ESTATUS-->\n                  <wj-flex-grid-column *ngIf=\"showStatusColumn\" [header]=\"'Estatus'\" [binding]=\"'status'\" [width]=\"120\">\n                      <ng-template wjFlexGridCellTemplate [cellType]=\"'Cell'\" let-cell=\"cell\">\n                          <div [ngStyle]=\"{'background-color': getStatusColor(cell.item.idStatus), 'color':'white'}\">\n                              {{cell.item.status}}\n                          </div>\n                      </ng-template>\n                  </wj-flex-grid-column>\n\n              </wj-flex-grid>\n          </div>\n      </div>\n\n      <div class=\"row\">\n          <div class=\"col-xs-12 col-md-6\">\n              <div class=\"btn-group\">\n                  <button type=\"button\" class=\"btn btn-default\"\n                          (click)=\"moveFirst()\"\n                          [disabled]=\"pageIndex <= 0\">\n                      <span class=\"glyphicon glyphicon-fast-backward\"></span>\n                  </button>\n                  <button type=\"button\" class=\"btn btn-default\"\n                          (click)=\"movePrevious()\"\n                          [disabled]=\"pageIndex <= 0\">\n                      <span class=\"glyphicon glyphicon-step-backward\"></span>\n                  </button>\n                  <button type=\"button\" class=\"btn btn-default\" disabled style=\"width:100px\">\n                      {{pageIndex + 1}} de {{pageCount}}\n                  </button>\n                  <button type=\"button\" class=\"btn btn-default\"\n                          (click)=\"moveNext()\"\n                          [disabled]=\"pageIndex >= pageCount -1\">\n                      <span class=\"glyphicon glyphicon-step-forward\"></span>\n                  </button>\n                  <button type=\"button\" class=\"btn btn-default\"\n                          (click)=\"moveLast()\"\n                          [disabled]=\"pageIndex >= pageCount -1\">\n                      <span class=\"glyphicon glyphicon-fast-forward\"></span>\n                  </button>\n              </div>\n          </div>\n      </div>\n    "
        })
    ], DocumentListComponent);
    return DocumentListComponent;
}());
export { DocumentListComponent };
