var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, forwardRef } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { Observable } from 'rxjs';
import { mergeMap } from 'rxjs/operators';
//
import { Context, BaseComponent, ModuloService } from '../../../core';
import { HierarchySelector, ITreeHost } from '../../../search/index';
//
var ModuloSelectorComponent = /** @class */ (function (_super) {
    __extends(ModuloSelectorComponent, _super);
    function ModuloSelectorComponent(context, moduloService) {
        var _this = _super.call(this, context) || this;
        _this.context = context;
        _this.moduloService = moduloService;
        _this.selectedItem = null;
        _this.keywordSearchSource = Observable.create(function (observer) {
            observer.next(_this.innerSelector.displayValue);
        })
            .pipe(mergeMap(function (keyword) { return _this.findKeyword(keyword); }));
        return _this;
    }
    ModuloSelectorComponent_1 = ModuloSelectorComponent;
    ModuloSelectorComponent.prototype.loadItem = function (itemID) {
        var _this = this;
        if (itemID > 0) {
            this.moduloService.getDetailByID(itemID)
                .then(function (info) {
                _this.selectedItem = info;
                _this.displayValue = info.namedPath;
            })
                .catch(function (error) { return _this.handleError(error); });
        }
        else {
            this.selectedItem = null;
            this.displayValue = "";
        }
    };
    ModuloSelectorComponent.prototype.doSearch = function (request) {
        var _this = this;
        this.context.app.showSpinner();
        this.moduloService.search(this.context.app.defaultSite.identity, request)
            .then(function (response) {
            _this.context.app.hideSpinner();
            //
            _this.modulos = response.rows;
            _this.totalRows = response.totalRows;
            _this.pageIndex = request.pageIndex;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    ModuloSelectorComponent.prototype.findKeyword = function (keyword) {
        return this.moduloService.searchKeyword(this.context.app.defaultSite.identity, keyword);
    };
    ModuloSelectorComponent.prototype.onKeywordSearch = function (keyword) {
        this.markUnselected();
    };
    ModuloSelectorComponent.prototype.onLoadingHierarchy = function () {
        var _this = this;
        //Cargar nodos raíz al abrir diálogo de jerarquía
        this.moduloService.loadChildren(this.context.app.defaultCompany.identity, 0)
            .then(function (rootNodes) { return _this.nodes = rootNodes; })
            .catch(function (error) { return _this.handleError(error); });
    };
    ModuloSelectorComponent.prototype.loadChildren = function (parent) {
        return this.moduloService.loadChildren(this.context.app.defaultCompany.identity, parent.identity);
    };
    var ModuloSelectorComponent_1;
    ModuloSelectorComponent = ModuloSelectorComponent_1 = __decorate([
        Component({
            selector: 'security-modulo-selector',
            template: "\n      <azteca-hierarchy-selector [hierarchyList]=\"modulos\"\n                                 [nodes]=\"nodes\"\n                                 [dialogTitle]=\"'M\u00F3dulos del sistema'\"\n                                 [displayValue]=\"displayValue\"\n                                 [serverSide]=\"true\"\n                                 [selectedItem]=\"selectedItem\"\n                                 [pageIndex]=\"pageIndex\"\n                                 [pageSize]=\"pageSize\"\n                                 [totalRows]=\"totalRows\"\n                                 [enabled]=\"enabled\"\n                                 [visible]=\"visible\"\n                                 [dataSource]=\"keywordSearchSource\"\n                                 [showListButton]=\"showListButton\"\n                                 [showTreeButton]=\"showTreeButton\"\n                                 (selectedItemChanged)=\"itemChangedHandler($event)\"\n                                 (keywordSearch)=\"onKeywordSearch($event)\"\n                                 (loadingHierarchy)=\"onLoadingHierarchy($event)\"\n                                 (searchRequested)=\"doSearch($event)\">\n\n          <azteca-grid-column [header]=\"'ID'\" [binding]=\"'id'\" [dataType]=\"Number\" [width]=\"45\"></azteca-grid-column>\n          <azteca-grid-column [header]=\"'Codigo'\" [binding]=\"'codigo'\" [width]=\"'10*'\"></azteca-grid-column>\n          <azteca-grid-column [header]=\"'Ruta'\" [binding]=\"'ruta'\" [width]=\"'50*'\"></azteca-grid-column>\n          <azteca-grid-column [header]=\"'Categor\u00EDa'\" [binding]=\"'categoria'\" [width]=\"'20*'\"></azteca-grid-column>\n    \n\n      </azteca-hierarchy-selector>\n    ",
            providers: [
                {
                    provide: BaseComponent,
                    useExisting: forwardRef(function () { return ModuloSelectorComponent_1; })
                },
                {
                    provide: ITreeHost,
                    useExisting: forwardRef(function () { return ModuloSelectorComponent_1; })
                },
                {
                    provide: NG_VALUE_ACCESSOR,
                    useExisting: forwardRef(function () { return ModuloSelectorComponent_1; }),
                    multi: true
                }
            ]
        }),
        __metadata("design:paramtypes", [Context, ModuloService])
    ], ModuloSelectorComponent);
    return ModuloSelectorComponent;
}(HierarchySelector));
export { ModuloSelectorComponent };
