var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, ViewChild, forwardRef, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators } from '@angular/forms';
import { Location } from '@angular/common';
//
import { Control } from 'wijmo/wijmo';
//Azteca Kernel
import { Context, BaseComponent, CatalogService, EmpresaInfo, EmpresaService, SucursalService } from '../../core';
import { AztecaValidators } from '../../controls';
import { CatalogEditor } from '../../editors';
import { SearchRequest } from '../../search';
//Locales
import { SucursalesManager } from './sucursales.manager';
var EmpresasEditor = /** @class */ (function (_super) {
    __extends(EmpresasEditor, _super);
    //        
    function EmpresasEditor(router, route, formBuilder, changeDetector, context, empresaService, sucursalService, location) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.changeDetector = changeDetector;
        _this.context = context;
        _this.empresaService = empresaService;
        _this.sucursalService = sucursalService;
        _this.location = location;
        _this.empresa = new EmpresaInfo();
        _this.sucursales = [];
        _this.catalogForm = formBuilder.group({
            'codigo': ['', Validators.required],
            'nombre': ['', Validators.required],
            'logo': [null, AztecaValidators.validFile],
            'domicilio': ['']
        });
        return _this;
    }
    EmpresasEditor_1 = EmpresasEditor;
    EmpresasEditor.prototype.onConfigureCatalog = function (options) {
        this.autogeneratedCode = options.codigoAutogenerado;
        this.applyPolicies();
    };
    EmpresasEditor.prototype.onCreatingItem = function () {
    };
    EmpresasEditor.prototype.onViewingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.empresaService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.empresa = info;
            _this.setReadonlyMode();
            _this.loadSucursales();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    EmpresasEditor.prototype.onCloningItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        //
        this.empresaService.clone(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.empresa = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    EmpresasEditor.prototype.onLoadingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.empresaService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.empresa = info;
            _this.loadSucursales();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    EmpresasEditor.prototype.onSavingItem = function (args) {
        var _this = this;
        this.context.app.showSpinner();
        this.empresaService.update(this.empresa)
            .then(function (info) {
            _this.context.app.hideSpinner();
            //Si es un elemento nuevo y no se cerrará el editor, navegar a nueva ruta
            _this.reset();
            if (!args.closeEditor && _this.empresa.identity == 0) {
                _this.router.navigate(['../', info.identity], { relativeTo: _this.route });
            }
            else {
                if (args.closeEditor)
                    _this.router.navigate(['../'], { relativeTo: _this.route });
                else
                    _this.showAlert('La información ha sido actualizada con éxito', 'success');
            }
            _this.empresa = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    //Manejo de sucursales
    EmpresasEditor.prototype.selectSucursalesTab = function (args) {
        if (args.heading) {
            Control.invalidateAll();
        }
    };
    EmpresasEditor.prototype.onSucursalesListUpdated = function () {
        this.loadSucursales();
    };
    EmpresasEditor.prototype.loadSucursales = function () {
        var _this = this;
        var request = new SearchRequest();
        request.paged = false;
        //Agregar condición de empresa actual
        var condicionEmpresa = { field: "idEmpresa", operator: "=", valueType: "int", value: this.empresa.identity.toString() };
        request.conditions.push(condicionEmpresa);
        //
        this.context.app.showSpinner();
        this.sucursalService.search(this.context.app.defaultSite.identity, request)
            .then(function (response) {
            _this.context.app.hideSpinner();
            //
            _this.sucursales = response.rows;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    EmpresasEditor.prototype.onDomicilioValidChange = function () {
        this.changeDetector.detectChanges();
    };
    var EmpresasEditor_1;
    __decorate([
        ViewChild(SucursalesManager),
        __metadata("design:type", SucursalesManager)
    ], EmpresasEditor.prototype, "siteManager", void 0);
    EmpresasEditor = EmpresasEditor_1 = __decorate([
        Component({
            selector: 'security-empresas-editor',
            template: "\n      <form [formGroup]=\"catalogForm\">\n\n          <azteca-catalog-editor #catalogEditor \n                                 [title]=\"'Empresa'\"\n                                 [info]=\"empresa\"   \n                                 [valid]=\"valid && domicilioEditor.valid\"\n                                 (configureCatalog)=\"onConfigureCatalog($event)\"\n                                 (creatingItem)=\"onCreatingItem()\"\n                                 (viewingItem)=\"onViewingItem($event)\"\n                                 (cloningItem)=\"onCloningItem($event)\"\n                                 (savingItem)=\"onSavingItem($event)\"\n                                 (loadingItem)=\"onLoadingItem($event)\">\n\n              <div class=\"row\">\n                  <div class=\"col-4 col-lg-2\">\n                      <azteca-form-field>\n                          <azteca-image-box formControlName=\"logo\" [(ngModel)]=\"empresa.logo\"></azteca-image-box>\n                      </azteca-form-field>                    \n                  </div>\n\n                  <div class=\"col-8 col-lg-8\">\n                      <azteca-form-field [label]=\"'C\u00F3digo:'\">                    \n                          <catalog-code formControlName=\"codigo\" [(ngModel)]=\"empresa.code\" [automatic]=\"autogeneratedCode\"></catalog-code>                    \n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Nombre:'\">\n                          <az-textbox formControlName=\"nombre\" [(ngModel)]=\"empresa.nombre\"></az-textbox>\n                      </azteca-form-field>\n\n                  </div>\n              </div>\n\n        \n              <div class=\"row\">\n                  <div class=\"col-12 col-lg-10\">\n                      <tabset>\n                          <tab heading=\"Domicilio\">\n\n                              <general-domicilio-editor #domicilioEditor\n                                                        formControlName=\"domicilio\"\n                                                        [(ngModel)]=\"empresa.domicilio\"\n                                                        [poblacionRequired]=\"true\"\n                                                        [cruceUnoVisible]=\"false\"\n                                                        [cruceDosVisible]=\"false\"\n                                                        (validChange)=\"onDomicilioValidChange($event)\">\n\n                              </general-domicilio-editor>\n\n                          </tab>\n                          <tab heading=\"Sucursales\" [disabled]=\"empresa.identity == 0\" (select)=\"selectSucursalesTab($event)\">\n\n                              <div class=\"row\">\n                                  <div class=\"col-12\">\n                                      <azteca-sucursales-manager #sites\n                                                                 [name]=\"'sucursales'\"\n                                                                 [sucursales]=\"sucursales\"\n                                                                 [idEmpresa]=\"empresa.identity\"\n                                                                 (listUpdated)=\"onSucursalesListUpdated()\">\n                                      </azteca-sucursales-manager>\n                                  </div>\n                              </div>\n                          </tab>\n                      </tabset>\n                  </div>\n              </div>\n            \n\n          </azteca-catalog-editor>\n      </form>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return EmpresasEditor_1; })
                },
                {
                    provide: CatalogService, useExisting: EmpresaService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, FormBuilder, ChangeDetectorRef,
            Context, EmpresaService, SucursalService, Location])
    ], EmpresasEditor);
    return EmpresasEditor;
}(CatalogEditor));
export { EmpresasEditor };
