var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, forwardRef, ChangeDetectorRef } from '@angular/core';
import { FormBuilder, Validators } from '@angular/forms';
import { Router, ActivatedRoute } from '@angular/router';
//
import { Context, BaseComponent, CatalogService, ModuloInfo, ModuloService } from '../../core';
import { HierarchyManager } from '../../editors/index';
import { AztecaValidators } from '../../controls/index';
//
var ModulosManager = /** @class */ (function (_super) {
    __extends(ModulosManager, _super);
    function ModulosManager(context, changeDetector, moduloService, formBuilder, router, route) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.context = context;
        _this.changeDetector = changeDetector;
        _this.moduloService = moduloService;
        _this.formBuilder = formBuilder;
        _this.router = router;
        _this.route = route;
        _this.moduloEdicion = new ModuloInfo();
        _this.categorias = [];
        _this.nodeForm = formBuilder.group({
            'codigo': ['', Validators.required],
            'nombre': ['', Validators.required],
            'imagen': [''],
            'idCategoria': [0, AztecaValidators.selected],
            'descripcion': ['']
        });
        return _this;
    }
    ModulosManager_1 = ModulosManager;
    ModulosManager.prototype.onConfigureCatalog = function (options) {
        this.autogeneratedCode = options.codigoAutogenerado;
        this.loadHierarchy();
        this.loadCategorias();
        this.applyPolicies();
    };
    ModulosManager.prototype.loadHierarchy = function () {
        var _this = this;
        this.context.app.showSpinner();
        this.moduloService.loadHierarchy(this.context.app.defaultCompany.identity, 0)
            .then(function (nodes) {
            _this.context.app.hideSpinner();
            _this.modulos = nodes;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    ModulosManager.prototype.onNodesChanged = function (modulos) {
        this.modulos = modulos;
    };
    ModulosManager.prototype.onCurrentNodeChanged = function (node) {
        this.currentNode = node;
    };
    ModulosManager.prototype.onCreatingNode = function (parentNode) {
        this.moduloEdicion = new ModuloInfo(); //Crear nueva instancia para evitar que reset modifique la información del último nodo en edición
        this.nodeForm.reset();
        this.moduloEdicion = new ModuloInfo(); //Se vuelve a crear instancia para evitar valores nulos creados por reset
        this.currentParent = parentNode;
        this.showEditor();
    };
    ModulosManager.prototype.onEditingNode = function (node) {
        this.moduloEdicion = this.moduloService.copy(node.data);
        this.showEditor();
    };
    ModulosManager.prototype.onSavingNode = function () {
        //Si es un nuevo nodo
        if (this.moduloEdicion.clientID == 0) {
            this.addNode(this.moduloEdicion, this.currentParent);
        }
        //Si se estaba editando un nodo existente
        else {
            this.updateNode(this.moduloEdicion);
        }
        this.moduloEdicion = new ModuloInfo();
        this.hideEditor();
    };
    ModulosManager.prototype.onDeletingNode = function (node) {
        this.deleteNode(node);
    };
    ModulosManager.prototype.onSavingHierarchy = function (changes) {
        var _this = this;
        this.context.app.showSpinner();
        this.moduloService.saveHierarchy(changes)
            .then(function (modulos) {
            _this.modulos = modulos;
            _this.reset();
            _this.context.app.hideSpinner();
            _this.showAlert('Los cambios han sido guardados con éxito.', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    ModulosManager.prototype.loadCategorias = function () {
        var _this = this;
        this.moduloService.loadCategories()
            .then(function (categorias) {
            categorias.unshift({ idCategoria: 0, nombre: '[Seleccione]', rootModules: [] });
            _this.categorias = categorias;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    ModulosManager.prototype.onMenuItemClick = function (menuItem) {
        if (menuItem.name == 'PROCESOS') {
            if (this.currentNode.data.identity > 0) {
                this.router.navigate(['kernel/security/procesos', this.process.id, { idModulo: this.currentNode.data.identity }]);
            }
            else {
                this.showAlert('El módulo no ha sido guardado. Primero guarde los cambios hasta el momento', 'warning');
            }
        }
    };
    var ModulosManager_1;
    ModulosManager = ModulosManager_1 = __decorate([
        Component({
            selector: 'security-modulos-manager',
            template: "\n      <azteca-hierarchy-manager (configureCatalog)=\"onConfigureCatalog($event)\"\n                                (currentNodeChanged)=\"onCurrentNodeChanged($event)\"\n                                (creatingNode)=\"onCreatingNode($event)\"\n                                (editingNode)=\"onEditingNode($event)\"\n                                (savingNode)=\"onSavingNode()\"\n                                (deletingNode)=\"onDeletingNode($event)\"\n                                (savingHierarchy)=\"onSavingHierarchy($event)\"\n                                (nodesChanged)=\"onNodesChanged($event)\"\n                                (menuItemClick)=\"onMenuItemClick($event)\"\n                                [title]=\"'Administraci\u00F3n de m\u00F3dulos del sistema'\"\n                                [validForm]=\"nodeForm.valid\"\n                                [currentNode]=\"currentNode\"                          \n                                [nodes]=\"modulos\">\n\n          <!------------------- Menu de acciones adicionales --------------------->\n          <azteca-menu-item [name]=\"'PROCESOS'\" [icon]=\"'glyphicon glyphicon-cog'\" [text]=\"'Procesos'\" [smallText]=\"'editar procesos del m\u00F3dulo'\"></azteca-menu-item>\n\n          <!------------------- Formulario de edici\u00F3n  --------------------->\n          <form [formGroup]=\"nodeForm\">\n              <div class=\"row\">\n\n                  <div class=\"col-xs-12 col-md-10\">\n                      <azteca-form-field [label]=\"'C\u00F3digo:'\">\n                          <catalog-code formControlName=\"codigo\" [(ngModel)]=\"moduloEdicion.code\" [automatic]=\"autogeneratedCode\"></catalog-code>\n                      </azteca-form-field>\n\n                      <label class=\"control-label\">Ruta:</label>\n                      <az-label [text]=\"moduloEdicion.namedPath\"></az-label>\n\n                      <azteca-form-field [label]=\"'Nombre:'\">\n                          <az-textbox formControlName=\"nombre\" [(ngModel)]=\"moduloEdicion.nombre\"></az-textbox>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Im\u00E1gen:'\">\n                          <az-textbox formControlName=\"imagen\" [(ngModel)]=\"moduloEdicion.imageFile\"></az-textbox>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Categor\u00EDa:'\">\n                          <az-combobox formControlName=\"idCategoria\" [(ngModel)]=\"moduloEdicion.idModuloCategoria\" [items]=\"categorias\" [displayMember]=\"'nombre'\" [valueMember]=\"'idCategoria'\"></az-combobox>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Descripci\u00F3n:'\">\n                          <az-textarea formControlName=\"descripcion\" [(ngModel)]=\"moduloEdicion.descripcion\"></az-textarea>\n                      </azteca-form-field>\n\n                  </div>\n              </div>\n          </form>\n\n      </azteca-hierarchy-manager>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return ModulosManager_1; })
                },
                {
                    provide: CatalogService, useExisting: ModuloService
                }
            ]
        }),
        __metadata("design:paramtypes", [Context, ChangeDetectorRef, ModuloService,
            FormBuilder, Router, ActivatedRoute])
    ], ModulosManager);
    return ModulosManager;
}(HierarchyManager));
export { ModulosManager };
