var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, ViewChild, forwardRef, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators } from '@angular/forms';
import { Location } from '@angular/common';
//Wijmo
import { Control } from 'wijmo/wijmo';
import { CellRange, DataMap } from 'wijmo/wijmo.grid';
//ng2 bootstrap
import { ModalDirective } from 'ngx-bootstrap';
//Azteca Kernel
import { Context, BaseComponent, CatalogService, ProcesoService, ProcesoInfo, PolicyInfo, PolicyScope, SubProceso } from '../../core';
import { AztecaValidators } from '../../controls';
import { CatalogEditor, TrackableCollection, ChangeState } from '../../editors';
//Features
import { PoliticasEditor } from './parts/politicas.editor';
import { SubProcesosEditor } from './parts/sub-procesos.editor';
var ProcesosEditor = /** @class */ (function (_super) {
    __extends(ProcesosEditor, _super);
    function ProcesosEditor(router, route, formBuilder, changeDetector, context, location, procesoService) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.changeDetector = changeDetector;
        _this.context = context;
        _this.location = location;
        _this.procesoService = procesoService;
        _this.proceso = new ProcesoInfo();
        _this.tipos = [];
        _this.currentPolitica = new PolicyInfo();
        _this.politicasMenu = [];
        _this.ambitosMap = new DataMap(PolicyScope.list, 'id', 'nombre');
        _this.currentSubProceso = new SubProceso();
        //
        _this._lastPolID = 0;
        _this._lastSubProcID = 0;
        _this.catalogForm = formBuilder.group({
            'codigo': ['', Validators.required],
            'nombre': ['', Validators.required],
            'idModulo': ['', AztecaValidators.selected],
            'url': ['', Validators.required],
            'parametros': [''],
            'idProcesoTipo': [0, AztecaValidators.selected],
            'orden': [0],
            'imageFile': [''],
            'descripcion': [''],
        });
        //
        _this.createPoliticasMenu();
        return _this;
    }
    ProcesosEditor_1 = ProcesosEditor;
    //////////////////////// METODOS ///////////////////////////////////
    ProcesosEditor.prototype.createPoliticasMenu = function () {
        this.politicasMenu.push({ name: 'EDIT', icon: 'glyphicon glyphicon-pencil', text: 'Editar', smallText: 'editar política', enabled: true });
        this.politicasMenu.push({ name: 'DELETE', icon: 'glyphicon glyphicon-trash', text: 'Eliminar', smallText: 'eliminar política', enabled: true });
    };
    ProcesosEditor.prototype.loadTiposProceso = function () {
        var _this = this;
        this.procesoService.loadTiposProceso()
            .then(function (tipos) { return _this.tipos = tipos; })
            .catch(function (error) { return _this.handleError(error); });
    };
    ProcesosEditor.prototype.clonePolicy = function (original) {
        return JSON.parse(JSON.stringify(original));
    };
    ////////////////////// HANDLERS ////////////////////////
    ProcesosEditor.prototype.onConfigureCatalog = function (options) {
        this.autogeneratedCode = options.codigoAutogenerado;
        this.loadTiposProceso();
        this.applyPolicies();
    };
    ProcesosEditor.prototype.onCreatingItem = function () {
        this.politicasCollection = new TrackableCollection(this.proceso.politicas);
        this.subProcesosCollection = new TrackableCollection(this.proceso.subProcesos);
    };
    ProcesosEditor.prototype.onViewingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.procesoService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.proceso = info;
            _this.setReadonlyMode();
            _this.politicasCollection = new TrackableCollection(_this.proceso.politicas);
            _this.subProcesosCollection = new TrackableCollection(_this.proceso.subProcesos);
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    ProcesosEditor.prototype.onCloningItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        //
        this.procesoService.clone(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.proceso = info;
            _this.politicasCollection = new TrackableCollection(_this.proceso.politicas);
            _this.subProcesosCollection = new TrackableCollection(_this.proceso.subProcesos);
            _this._lastPolID = _this.proceso.politicas.length;
            _this._lastSubProcID = _this.proceso.subProcesos.length;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    ProcesosEditor.prototype.onLoadingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.procesoService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.proceso = info;
            _this.politicasCollection = new TrackableCollection(_this.proceso.politicas);
            _this.subProcesosCollection = new TrackableCollection(_this.proceso.subProcesos);
            _this._lastPolID = _this.proceso.politicas.length;
            _this._lastSubProcID = _this.proceso.subProcesos.length;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    ProcesosEditor.prototype.onSavingItem = function (args) {
        var _this = this;
        this.context.app.showSpinner();
        this.procesoService.update(this.proceso)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.proceso = info;
            _this.reset();
            if (args.closeEditor)
                _this.location.back();
            else
                _this.showAlert('La información ha sido actualizada con éxito', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    ProcesosEditor.prototype.onProcesoMenuClick = function (item) {
        if (item.name == 'USERS') {
        }
        else if (item.name == 'GROUPS') {
        }
    };
    ////////////////////// SUB PROCESOS /////////////////////////////////////////////////////////////////
    ProcesosEditor.prototype.onSubProcesosToolbar = function (button) {
        if (button.name == 'ADD') {
            this.currentSubProceso = new SubProceso();
            this.editorSubProcesos.show();
        }
    };
    ProcesosEditor.prototype.onSubProcesoAdded = function (subProceso) {
        var newSubProcesos = this.proceso.subProcesos.slice();
        newSubProcesos.push(subProceso);
        this.proceso.subProcesos = newSubProcesos;
        this.subProcesosCollection = new TrackableCollection(this.proceso.subProcesos);
    };
    ProcesosEditor.prototype.onDeleteSubProceso = function (subProceso) {
        this.deleteSubProcesoDialog.show();
    };
    ProcesosEditor.prototype.onConfirmDeleteSubProceso = function () {
        this.subProcesosCollection.remove(this.subProcesosCollection.currentItem);
        this.deleteSubProcesoDialog.hide();
    };
    ////////////////////////////// POLITICAS ///////////////////////////////////////////////////////////
    ProcesosEditor.prototype.politicasGridInitialized = function (sender, args) {
        var self = this;
        //Agregar manejador para menú contextual        
        sender.addEventListener(sender.hostElement, "contextmenu", function (e) {
            var ht = sender.hitTest(e);
            sender.select(new CellRange(ht.row, ht.col), true);
        });
    };
    ProcesosEditor.prototype.onPoliticasToolbar = function (button) {
        if (button.name == 'ADD') {
            this.currentPolitica = new PolicyInfo();
            this.editorPoliticas.show();
        }
    };
    ProcesosEditor.prototype.politicasMenuClick = function (menu) {
        var item = this.politicasMenu[menu.selectedIndex];
        this.selectPoliticasAction(item);
    };
    ProcesosEditor.prototype.selectPoliticasAction = function (item) {
        if (!this.politicasCollection.currentItem)
            return;
        //
        if (item.name == 'EDIT') {
            this.currentPolitica = this.clonePolicy(this.politicasCollection.currentItem);
            this.editorPoliticas.show();
        }
        if (item.name == 'DELETE') {
            this.deletePolicyDialog.config.backdrop = false;
            this.deletePolicyDialog.show();
        }
    };
    ProcesosEditor.prototype.onPoliticaUpdated = function (politica) {
        var newPoliticas = this.proceso.politicas.slice();
        //Si no tiene un client id, es un elemento nuevo. 
        if (politica._clientID == 0) {
            //Verificar que no exista otra política con el mismo nombre y para el mismo componente
            var existing = this.proceso.politicas.find(function (pol) { return pol.nombre == politica.nombre && pol.componente == politica.componente && pol.state != ChangeState.DELETED; });
            if (!existing) {
                //Asignar consecutivo de client id y agregar al nuevo array
                this._lastPolID += 1;
                politica._clientID = this._lastPolID;
                newPoliticas.push(politica);
            }
            else {
                this.showAlert('Ya existe una política con el mismo nombre para el mismo campo', 'warning');
            }
        }
        else {
            politica.state = ChangeState.MODIFIED;
            var index = newPoliticas.findIndex(function (c) { return c._clientID == politica._clientID; });
            newPoliticas[index] = politica;
        }
        this.proceso.politicas = newPoliticas;
        this.politicasCollection = new TrackableCollection(this.proceso.politicas);
    };
    ProcesosEditor.prototype.onDeletePolicy = function () {
        this.politicasCollection.remove(this.politicasCollection.currentItem);
        this.deletePolicyDialog.hide();
    };
    //
    ProcesosEditor.prototype.tabSelected = function (args) {
        if (args.heading) {
            Control.invalidateAll();
        }
    };
    var ProcesosEditor_1;
    __decorate([
        ViewChild(PoliticasEditor),
        __metadata("design:type", PoliticasEditor)
    ], ProcesosEditor.prototype, "editorPoliticas", void 0);
    __decorate([
        ViewChild(SubProcesosEditor),
        __metadata("design:type", SubProcesosEditor)
    ], ProcesosEditor.prototype, "editorSubProcesos", void 0);
    __decorate([
        ViewChild('deletePolicyDialog'),
        __metadata("design:type", ModalDirective)
    ], ProcesosEditor.prototype, "deletePolicyDialog", void 0);
    __decorate([
        ViewChild('deleteSubProcesoDialog'),
        __metadata("design:type", ModalDirective)
    ], ProcesosEditor.prototype, "deleteSubProcesoDialog", void 0);
    ProcesosEditor = ProcesosEditor_1 = __decorate([
        Component({
            selector: 'security-procesos-editor',
            template: "\n      <wj-menu #ctxPoliticasMenu (itemClicked)=\"politicasMenuClick(ctxPoliticasMenu, $event)\" style=\"display:none\">\n          <wj-menu-item *ngFor=\"let item of politicasMenu\">\n              <div *ngIf=\"item.enabled\">\n                  <span [class]=\"item.icon\"></span>\n                  <b>{{item.text}}</b>\n                  <br>\n                  <small><i>{{item.smallText}}</i></small>\n              </div>\n          </wj-menu-item>\n      </wj-menu>\n\n\n\n      <form [formGroup]=\"catalogForm\">\n\n          <azteca-catalog-editor #catalogEditor \n                                 [title]=\"'Proceso'\"\n                                 [info]=\"proceso\"\n                                 [valid]=\"valid\"\n                                 (menuItemClick)=\"onProcesoMenuClick($event)\"\n                                 (configureCatalog)=\"onConfigureCatalog($event)\"\n                                 (creatingItem)=\"onCreatingItem()\"\n                                 (viewingItem)=\"onViewingItem($event)\"\n                                 (cloningItem)=\"onCloningItem($event)\"\n                                 (savingItem)=\"onSavingItem($event)\"\n                                 (loadingItem)=\"onLoadingItem($event)\">\n\n              <!------------------- Menu de acciones adicionales --------------------->\n              <azteca-menu-item [name]=\"'USERS'\" [icon]=\"'glyphicon glyphicon-user'\" [text]=\"'Usuarios'\" [smallText]=\"'editar usuarios con acceso'\"></azteca-menu-item>\n              <azteca-menu-item [name]=\"'GROUPS'\" [icon]=\"'fa fa-users'\" [text]=\"'Grupos'\" [smallText]=\"'editar grupos con acceso'\"></azteca-menu-item>\n\n              <!------------------- Controles del editor ----------------------------->\n\n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <azteca-form-field [label]=\"'C\u00F3digo:'\">\n                          <catalog-code formControlName=\"codigo\" [(ngModel)]=\"proceso.code\" [automatic]=\"autogeneratedCode\"></catalog-code>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Nombre:'\">\n                          <az-textbox formControlName=\"nombre\" [(ngModel)]=\"proceso.nombre\"></az-textbox>\n                      </azteca-form-field>\n\n                  </div>\n              </div>\n        \n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10\">\n                      <tabset>\n                          <!-------------- GENERALES --------------------------------->\n                          <tab heading=\"General\" (select)=\"tabSelected($event)\">\n\t\t\t\t\t\t\n                              <div class=\"row\">\n                                  <div class=\"col-12 col-md-10\">\n\n                                      <azteca-form-field [label]=\"'M\u00F3dulo:'\">\n                                          <security-modulo-selector formControlName=\"idModulo\" [(ngModel)]=\"proceso.idModulo\"></security-modulo-selector>\n                                      </azteca-form-field>\n\n                                  </div>\n                              </div>\t\t\t\t\t\t\n                              <div class=\"row\">\n                                  <div class=\"col-12 col-md-5\">\n                                      <azteca-form-field [label]=\"'Tipo de proceso:'\">\n                                          <az-combobox formControlName=\"idProcesoTipo\" [(ngModel)]=\"proceso.idTipoProceso\" [items]=\"tipos\" [displayMember]=\"'tipo'\" [valueMember]=\"'idProcesoTipo'\"></az-combobox>\n                                      </azteca-form-field>\n                                  </div>\n                                  <div class=\"col-12 col-md-5\">\n                                      <azteca-form-field [label]=\"'Orden:'\">\n                                          <az-input-number formControlName=\"orden\" [(ngModel)]=\"proceso.orden\"></az-input-number>\n                                      </azteca-form-field>\n                                  </div>\n                              </div>\n                              <div class=\"row\">\n                                  <div class=\"col-12 col-md-10\">\n                                      <azteca-form-field [label]=\"'Url:'\">\n                                          <az-textbox formControlName=\"url\" [(ngModel)]=\"proceso.url\"></az-textbox>\n                                      </azteca-form-field>\n\n                                      <azteca-form-field [label]=\"'Par\u00E1metros:'\">\n                                          <az-textbox formControlName=\"parametros\" [(ngModel)]=\"proceso.parametros\"></az-textbox>\n                                      </azteca-form-field>\n\n                                      <azteca-form-field [label]=\"'Im\u00E1gen:'\">\n                                          <az-textbox formControlName=\"imageFile\" [(ngModel)]=\"proceso.imageFile\"></az-textbox>\n                                      </azteca-form-field>\n\n                                      <azteca-form-field [label]=\"'Descripci\u00F3n:'\">\n                                          <az-textarea formControlName=\"descripcion\" [(ngModel)]=\"proceso.descripcion\" [rows]=\"4\" ></az-textarea>\n                                      </azteca-form-field>\n\n                                  </div>\n                              </div>\n                          </tab>\n\n                          <!--------------SUB PROCESOS --------------------------------->\n                          <tab heading=\"Sub procesos\" (select)=\"tabSelected($event)\">\n\n                              <az-toolbar (buttonClick)=\"onSubProcesosToolbar($event)\">\n                                  <az-toolbar-button [name]=\"'ADD'\" [type]=\"'primary'\" [text]=\"'Nuevo'\" [title]=\"'Agregar sub proceso'\" [icon]=\"'glyphicon glyphicon-plus'\"></az-toolbar-button>                            \n                              </az-toolbar>\n\n                              <wj-flex-grid style=\"height:550px\" [itemsSource]=\"subProcesosCollection\" [isReadOnly]=\"true\">                            \n\n                                  <wj-flex-grid-column [header]=\"''\" [width]=\"60\" [isReadOnly]=\"true\">\n                                      <ng-template wjFlexGridCellTemplate [cellType]=\"'Cell'\" let-cell=\"cell\">\n                                          <button type=\"button\" class=\"btn btn-default\" (click)=\"onDeleteSubProceso(cell.item)\">\n                                              <span class=\"glyphicon glyphicon-trash\"></span>\n                                          </button>\n                                      </ng-template>\n                                  </wj-flex-grid-column>\n\n                                  <wj-flex-grid-column [header]=\"'Nombre'\" [binding]=\"'nombre'\" [width]=\"'15*'\"></wj-flex-grid-column>\n                                  <wj-flex-grid-column [header]=\"'Url'\" [binding]=\"'url'\" [width]=\"'35*'\"></wj-flex-grid-column>\n                              </wj-flex-grid>\n\n                          </tab>\n\n                          <!--------------POL\u00CDTICAS ------------------------------------>\n                          <tab heading=\"Pol\u00EDticas\" (select)=\"tabSelected($event)\">\n                              <az-toolbar (buttonClick)=\"onPoliticasToolbar($event)\" (menuItemClick)=\"selectPoliticasAction($event)\">\n                                  <az-toolbar-button [name]=\"'ADD'\" [type]=\"'primary'\" [text]=\"'Nueva'\" [icon]=\"'glyphicon glyphicon-plus'\"></az-toolbar-button>\n                                  <az-toolbar-menu *ngIf=\"politicasCollection && politicasCollection.currentItem\" [name]=\"'OPTIONS'\" [header]=\"'Opciones'\" [menuItems]=\"politicasMenu\"></az-toolbar-menu>\n                              </az-toolbar>\n\n                              <wj-flex-grid #politicasGrid\n                                            style=\"height:500px\" \n                                            [selectionMode]=\"'Row'\"\n                                            [isReadOnly]=\"true\"\n                                            (initialized)=\"politicasGridInitialized(politicasGrid, $event)\"\n                                            [itemsSource]=\"politicasCollection\" \n                                            [wjContextMenu]=\"ctxPoliticasMenu\">\n\n                                  <wj-flex-grid-column [header]=\"'Nombre'\" [binding]=\"'nombre'\" [width]=\"'40*'\"></wj-flex-grid-column>\n                                  <wj-flex-grid-column [header]=\"'Aplica a'\" [binding]=\"'url'\" [width]=\"'20*'\"></wj-flex-grid-column>\n                                  <wj-flex-grid-column [header]=\"'Componente'\" [binding]=\"'componente'\" [width]=\"'20*'\"></wj-flex-grid-column>                            \n                                  <wj-flex-grid-column [header]=\"'\u00C1mbito'\" [binding]=\"'ambito'\" [width]=\"'20*'\" [dataMap]=\"ambitosMap\"></wj-flex-grid-column>\n                              </wj-flex-grid>\n\n                          </tab>\n\n                      </tabset>\n                  </div>\n              </div>\n            \n          </azteca-catalog-editor>\n      </form>\n\n      <!--------------EDITOR DE POLITICAS --------------------------------->\n      <security-politicas-editor [politica]=\"currentPolitica\" [subProcesos]=\"proceso.subProcesos\" (policyUpdated)=\"onPoliticaUpdated($event)\" >\n\n      </security-politicas-editor>\n\n      <!--------------EDITOR DE SUB PROCESOS --------------------------------->\n      <security-sub-procesos-editor [subProceso]=\"\" (updated)=\"onSubProcesoAdded($event)\">\n\n      </security-sub-procesos-editor>\n\n      <!-------------- DIALOGO DE CONFIRMACI\u00D3N AL ELIMINAR POL\u00CDTICAS --------------------------------->\n      <div bsModal #deletePolicyDialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"mySmallModalLabel\" aria-hidden=\"true\">\n          <div class=\"modal-dialog modal-sm\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-body\">\n                      <p>\u00BFEst\u00E1 seguro que desea eliminar la pol\u00EDtica seleccionada?</p>\n                  </div> <!--Modal Body-->\n                  <div class=\"modal-footer\">\n                      <button type=\"button\" class=\"btn btn-primary\" (click)=\"deletePolicyDialog.hide()\">Cancelar</button>\n                      <button type=\"button\" class=\"btn btn-danger\" (click)=\"onDeletePolicy()\">Aceptar</button>\n                  </div> <!--Modal Footer-->\n\n              </div> <!-- Modal Content-->\n          </div> <!--Modal-->\n      </div> <!--Modal directive-->\n\n      <!-------------- DIALOGO DE CONFIRMACI\u00D3N AL ELIMINAR SUB PROCESOS --------------------------------->\n      <div bsModal #deleteSubProcesoDialog=\"bs-modal\" class=\"modal fade\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"mySmallModalLabel\" aria-hidden=\"true\">\n          <div class=\"modal-dialog modal-sm\">\n              <div class=\"modal-content\">\n                  <div class=\"modal-body\">\n                      <p>\u00BFEst\u00E1 seguro que desea eliminar el sub proceso seleccionada?</p>\n                  </div> <!--Modal Body-->\n                  <div class=\"modal-footer\">\n                      <button type=\"button\" class=\"btn btn-primary\" (click)=\"deleteSubProcesoDialog.hide()\">Cancelar</button>\n                      <button type=\"button\" class=\"btn btn-danger\" (click)=\"onConfirmDeleteSubProceso()\">Aceptar</button>\n                  </div> <!--Modal Footer-->\n\n              </div> <!-- Modal Content-->\n          </div> <!--Modal-->\n      </div> <!--Modal directive-->\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return ProcesosEditor_1; })
                },
                {
                    provide: CatalogService, useExisting: ProcesoService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, FormBuilder, ChangeDetectorRef,
            Context, Location, ProcesoService])
    ], ProcesosEditor);
    return ProcesosEditor;
}(CatalogEditor));
export { ProcesosEditor };
