var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, forwardRef, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators } from '@angular/forms';
import { Location } from '@angular/common';
//Azteca Kernel
import { Context, BaseComponent, CatalogService, RolService, RolInfo } from '../../core';
import { CatalogEditor } from '../../editors';
//Features
var RolesEditor = /** @class */ (function (_super) {
    __extends(RolesEditor, _super);
    //
    function RolesEditor(router, route, formBuilder, changeDetector, context, location, rolService) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.changeDetector = changeDetector;
        _this.context = context;
        _this.location = location;
        _this.rolService = rolService;
        _this.rol = new RolInfo();
        _this.catalogForm = formBuilder.group({
            'codigo': ['', Validators.required],
            'nombre': ['', Validators.required],
            'url': ['', Validators.required]
        });
        return _this;
    }
    RolesEditor_1 = RolesEditor;
    RolesEditor.prototype.onConfigureCatalog = function (options) {
        this.autogeneratedCode = options.codigoAutogenerado;
        this.applyPolicies();
    };
    RolesEditor.prototype.onCreatingItem = function () {
    };
    RolesEditor.prototype.onViewingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.rolService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.rol = info;
            _this.setReadonlyMode();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    RolesEditor.prototype.onCloningItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        //
        this.rolService.clone(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.rol = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    RolesEditor.prototype.onLoadingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.rolService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.rol = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    RolesEditor.prototype.onSavingItem = function (args) {
        var _this = this;
        this.context.app.showSpinner();
        this.rolService.update(this.rol)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.rol = info;
            _this.reset();
            if (args.closeEditor)
                _this.location.back();
            else
                _this.showAlert('La información ha sido actualizada con éxito', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    var RolesEditor_1;
    RolesEditor = RolesEditor_1 = __decorate([
        Component({
            selector: 'security-rol-editor',
            template: "\n      <form [formGroup]=\"catalogForm\">\n\n          <azteca-catalog-editor #catalogEditor\n                                 [title]=\"'Definici\u00F3n de rol'\"\n                                 [info]=\"rol\"\n                                 [valid]=\"valid\"\n                                 (configureCatalog)=\"onConfigureCatalog($event)\"\n                                 (creatingItem)=\"onCreatingItem()\"\n                                 (viewingItem)=\"onViewingItem($event)\"\n                                 (cloningItem)=\"onCloningItem($event)\"\n                                 (savingItem)=\"onSavingItem($event)\"\n                                 (loadingItem)=\"onLoadingItem($event)\">\n\n              <div class=\"row\">\n                  <div class=\"col-10 col-md-10\">\n                      <azteca-form-field [label]=\"'C\u00F3digo:'\">\n                          <catalog-code formControlName=\"codigo\" [(ngModel)]=\"rol.code\" [automatic]=\"autogeneratedCode\"></catalog-code>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Nombre:'\">\n                          <az-textbox formControlName=\"nombre\" [(ngModel)]=\"rol.nombre\"></az-textbox>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'URL:'\">\n                          <az-textbox formControlName=\"url\" [(ngModel)]=\"rol.url\"></az-textbox>\n                      </azteca-form-field>\n\n                  </div>\n              </div>\n\n          </azteca-catalog-editor>\n      </form>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return RolesEditor_1; })
                },
                {
                    provide: CatalogService, useExisting: RolService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, FormBuilder, ChangeDetectorRef,
            Context, Location, RolService])
    ], RolesEditor);
    return RolesEditor;
}(CatalogEditor));
export { RolesEditor };
