var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, forwardRef, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators } from '@angular/forms';
import { Location } from '@angular/common';
//
import { Context, BaseComponent, CatalogService, SucursalInfo, SucursalService, EmpresaService } from '../../core';
import { CatalogEditor } from '../../editors';
//
var SucursalesEditor = /** @class */ (function (_super) {
    __extends(SucursalesEditor, _super);
    function SucursalesEditor(context, router, route, location, formBuilder, changeDetector, sucursalService, empresaService) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.context = context;
        _this.router = router;
        _this.route = route;
        _this.location = location;
        _this.formBuilder = formBuilder;
        _this.changeDetector = changeDetector;
        _this.sucursalService = sucursalService;
        _this.empresaService = empresaService;
        _this.sucursal = new SucursalInfo();
        _this.catalogForm = formBuilder.group({
            'codigo': ['', Validators.required],
            'nombre': ['', Validators.required],
            'nombreLargo': [''],
            'telefono1': [''],
            'telefono2': [''],
            'fax': [''],
            'paginaWeb': [''],
            'correo': [''],
            'domicilio': ['']
        });
        _this.route.params.forEach(function (params) {
            _this.idEmpresa = +params['idEmpresa'];
        });
        return _this;
    }
    SucursalesEditor_1 = SucursalesEditor;
    SucursalesEditor.prototype.onConfigureCatalog = function (options) {
        this.autogeneratedCode = options.codigoAutogenerado;
        this.applyPolicies();
    };
    SucursalesEditor.prototype.onCreatingItem = function () {
        var _this = this;
        //Asignar y cargar datos de la empresa que dependerá la sucursal
        this.sucursal.idCompany = this.idEmpresa;
        this.empresaService.getDetailFromCache(this.idEmpresa)
            .then(function (empresa) { return _this.sucursal.empresa = empresa; })
            .catch(function (error) { return _this.handleError(error); });
    };
    SucursalesEditor.prototype.onViewingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.sucursalService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.sucursal = info;
            _this.setReadonlyMode();
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    SucursalesEditor.prototype.onCloningItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        //
        this.sucursalService.clone(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.sucursal = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    SucursalesEditor.prototype.onLoadingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.sucursalService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.sucursal = info;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    SucursalesEditor.prototype.onSavingItem = function (args) {
        var _this = this;
        this.context.app.showSpinner();
        this.sucursalService.update(this.sucursal)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.sucursal = info;
            _this.reset();
            if (args.closeEditor)
                _this.location.back();
            else
                _this.showAlert('La información ha sido actualizada con éxito', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    SucursalesEditor.prototype.onCancelingEdit = function () {
        this.location.back();
    };
    SucursalesEditor.prototype.onMenuItemClick = function (option) {
        if (option.name == 'USERS') {
            this.router.navigate(['members'], { relativeTo: this.route });
        }
    };
    SucursalesEditor.prototype.onDomicilioValidChange = function () {
        this.changeDetector.detectChanges();
    };
    var SucursalesEditor_1;
    SucursalesEditor = SucursalesEditor_1 = __decorate([
        Component({
            selector: 'azteca-sucursales-editor',
            template: "\n      <form [formGroup]=\"catalogForm\">\n          <azteca-catalog-editor #catalogEditor\n                                 [title]=\"'Sucursal'\"\n                                 [info]=\"sucursal\"\n                                 [valid]=\"valid && domicilioEditor.valid\"\n                                 (configureCatalog)=\"onConfigureCatalog($event)\"\n                                 (creatingItem)=\"onCreatingItem()\"\n                                 (viewingItem)=\"onViewingItem($event)\"\n                                 (cloningItem)=\"onCloningItem($event)\"\n                                 (savingItem)=\"onSavingItem($event)\"\n                                 (loadingItem)=\"onLoadingItem($event)\"\n                                 (menuItemClick)=\"onMenuItemClick($event)\">\n\n              <!------------------- Menu de acciones adicionales --------------------->\n              <azteca-menu-item [name]=\"'USERS'\" [icon]=\"'glyphicon glyphicon-user'\" [text]=\"'Miembros'\" [smallText]=\"'editar usuarios miembro'\"></azteca-menu-item>\n\n              <!------------------- Controles del editor ----------------------------->\n              <div class=\"row\">\n\n                  <div class=\"col-12 col-lg-10\">\n                      <azteca-form-field [label]=\"'C\u00F3digo:'\">\n                          <az-textbox formControlName=\"codigo\" [(ngModel)]=\"sucursal.code\"></az-textbox>\n                      </azteca-form-field>\n\n                      <azteca-form-field [label]=\"'Nombre:'\">\n                          <az-textbox formControlName=\"nombre\" [(ngModel)]=\"sucursal.nombre\"></az-textbox>\n                      </azteca-form-field>\n\n                      <label class=\"control-label\">Empresa:</label>\n                      <az-label [name]=\"empresa\" [text]=\"sucursal.empresa.nombre\"></az-label>\n\n                  </div>\n              </div>\n              <br />\n\n              <div class=\"row\">\n                  <div class=\"col-12 col-lg-10\">\n                      <tabset>\n                          <tab heading=\"Contacto\">\n                              <div class=\"row\">\n                                  <div class=\"col-12 col-lg-10\">\n                                      <azteca-form-field [label]=\"'Telefono 1:'\">\n                                          <az-textbox formControlName=\"telefono1\" [(ngModel)]=\"sucursal.telefono1\"></az-textbox>\n                                      </azteca-form-field>\n\n                                      <azteca-form-field [label]=\"'Telefono 2:'\">\n                                          <az-textbox formControlName=\"telefono2\" [(ngModel)]=\"sucursal.telefono2\"></az-textbox>\n                                      </azteca-form-field>\n\n                                      <azteca-form-field [label]=\"'Fax:'\">\n                                          <az-textbox formControlName=\"fax\" [(ngModel)]=\"sucursal.fax\"></az-textbox>\n                                      </azteca-form-field>\n\n                                      <azteca-form-field [label]=\"'Correo:'\">\n                                          <az-textbox formControlName=\"correo\" [(ngModel)]=\"sucursal.correo\"></az-textbox>\n                                      </azteca-form-field>\n\n\n                                  </div>\n                              </div>\n                          </tab>\n\n                          <tab heading=\"Domicilio\">\n                              <general-domicilio-editor #domicilioEditor\n                                                        formControlName=\"domicilio\"\n                                                        [(ngModel)]=\"sucursal.domicilio\"\n                                                        [poblacionRequired]=\"true\"\n                                                        [cruceUnoVisible]=\"false\"\n                                                        [cruceDosVisible]=\"false\"\n                                                        (validChange)=\"onDomicilioValidChange($event)\">\n\n                              </general-domicilio-editor>\n\n                          </tab>\n\n                      </tabset>\n                  </div>\n              </div>\n\n          </azteca-catalog-editor>\n      </form>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return SucursalesEditor_1; })
                },
                {
                    provide: CatalogService, useExisting: SucursalService
                }
            ]
        }),
        __metadata("design:paramtypes", [Context, Router, ActivatedRoute, Location, FormBuilder, ChangeDetectorRef,
            SucursalService, EmpresaService])
    ], SucursalesEditor);
    return SucursalesEditor;
}(CatalogEditor));
export { SucursalesEditor };
