var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, ViewChild } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { Location } from '@angular/common';
//Wijmo
import { CollectionView, NotifyCollectionChangedAction } from 'wijmo/wijmo';
import { CellRange } from 'wijmo/wijmo.grid';
//Kernel
import { Context, BaseComponent, UsuarioService, EmpresaService, SucursalService } from '../../core';
import { AlertsBarComponent } from '../../controls';
import { ChangeState } from '../../editors';
//Security
import { PoliticasUsuarioEditor } from './parts/politicas-usuario.editor';
import { PoliticasGlobalesEditor } from './parts/politicas-globales.editor';
var UsuarioAccesosComponent = /** @class */ (function (_super) {
    __extends(UsuarioAccesosComponent, _super);
    function UsuarioAccesosComponent(context, route, location, usuarioService, empresaService, sucursalService) {
        var _this = _super.call(this) || this;
        _this.context = context;
        _this.route = route;
        _this.location = location;
        _this.usuarioService = usuarioService;
        _this.empresaService = empresaService;
        _this.sucursalService = sucursalService;
        _this.accesos = [];
        _this.empresas = [];
        _this.idEmpresa = 0;
        _this.sucursales = [];
        _this.idSucursal = 0;
        _this.politicasMenu = [];
        _this.allowSelection = true;
        //
        _this.createPoliticasMenu();
        return _this;
    }
    UsuarioAccesosComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.route.params.forEach(function (params) {
            /*Si se pasó por parámetro un id de usuario, cargarlo y evitar que seleccionen otro, si no mostrar selector de usuarios*/
            if (params['idUsuario']) {
                var idUsuario_1 = +params['idUsuario'];
                _this.allowSelection = false;
                setTimeout(function (_) { return _this.loadUsuario(idUsuario_1); });
            }
            else {
                _this.allowSelection = true;
            }
        });
    };
    //////////////// METODOS ///////////////////////////
    UsuarioAccesosComponent.prototype.loadUsuario = function (idUsuario) {
        var _this = this;
        this.usuarioService.getDetailByID(idUsuario)
            .then(function (usuario) {
            _this.usuario = usuario;
            _this.loadEmpresasUsuario(usuario.identity);
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    UsuarioAccesosComponent.prototype.loadEmpresasUsuario = function (idUsuario) {
        var _this = this;
        this.context.app.showSpinner();
        this.empresaService.loadListByUsuario(idUsuario)
            .then(function (result) {
            _this.empresas = result;
            _this.context.app.hideSpinner();
        })
            .catch(function (error) { return _this; });
    };
    UsuarioAccesosComponent.prototype.loadSucursalesUsuario = function (idEmpresa, idUsuario) {
        var _this = this;
        this.context.app.showSpinner();
        this.sucursalService.loadListByUserCompany(idEmpresa, idUsuario)
            .then(function (result) {
            _this.sucursales = result;
            _this.context.app.hideSpinner();
        })
            .catch(function (error) { return _this; });
    };
    UsuarioAccesosComponent.prototype.loadAccesos = function (idUsuario, idSucursal) {
        var _this = this;
        this.context.app.showSpinner();
        this.usuarioService.loadProcesos(idUsuario, idSucursal)
            .then(function (result) {
            _this.accesos = result;
            _this.accesosCollection = new CollectionView(_this.accesos);
            //Filtrar sólo los procesos del módulo seleccionado
            _this.accesosCollection.filter = function (item) {
                if (_this.currentModule) {
                    return item.idModulo == _this.currentModule.identity;
                }
                else {
                    return false;
                }
            };
            //Marcar los registros modificados
            _this.accesosCollection.collectionChanged.addHandler(function (sender, args) {
                if (args.action == NotifyCollectionChangedAction.Change && args.item != null) {
                    args.item.state = ChangeState.MODIFIED;
                }
            });
            _this.context.app.hideSpinner();
        })
            .catch(function (error) { return _this; });
    };
    UsuarioAccesosComponent.prototype.saveAccesos = function () {
        var _this = this;
        this.context.app.showSpinner();
        this.usuarioService.saveProcesos(this.usuario.identity, this.idSucursal, this.accesos)
            .then(function (_) {
            _this.context.app.hideSpinner();
            _this.alerts.showAlert('Los cambios han sido guardados con éxito', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    UsuarioAccesosComponent.prototype.createPoliticasMenu = function () {
        this.politicasMenu.push({ name: 'USER_POL', icon: 'fa fa-key', text: 'Políticas de usuario', smallText: 'establecer políticas de usuario', enabled: true });
        this.politicasMenu.push({ name: 'GLOBAL_POL', icon: 'fa fa-key', text: 'Políticas globales', smallText: 'establecer políticas globales', enabled: true });
    };
    //////////////// HANDLERS ///////////////////////////
    UsuarioAccesosComponent.prototype.onUsuarioSelected = function (usuario) {
        this.usuario = usuario;
        if (usuario) {
            this.cboResets();
            this.loadEmpresasUsuario(usuario.identity);
        }
        else {
            this.accesos = [];
            this.accesosCollection = new CollectionView();
            this.cboResets();
        }
    };
    UsuarioAccesosComponent.prototype.onSelectedEmpresaChanged = function (idEmpresa) {
        if (idEmpresa > 0) {
            this.loadSucursalesUsuario(idEmpresa, this.usuario.identity);
        }
        else {
            this.accesos = [];
            this.accesosCollection = new CollectionView();
        }
    };
    UsuarioAccesosComponent.prototype.onSelectedSucursalChanged = function (idSucursal) {
        if (idSucursal > 0) {
            this.loadAccesos(this.usuario.identity, idSucursal);
        }
        else {
            this.accesos = [];
            this.accesosCollection = new CollectionView();
        }
    };
    UsuarioAccesosComponent.prototype.onMainToolbarClick = function (button) {
        if (button.name == 'SAVE') {
            this.saveAccesos();
        }
        else if (button.name == 'CLOSE') {
            this.location.back();
        }
    };
    UsuarioAccesosComponent.prototype.onModuloSelected = function (modulo) {
        this.currentModule = modulo;
        this.accesosCollection.refresh();
    };
    UsuarioAccesosComponent.prototype.procesosGridInitialized = function (grid) {
        var self = this;
        //Agregar manejador para menú contextual        
        grid.addEventListener(grid.hostElement, "contextmenu", function (e) {
            var ht = grid.hitTest(e);
            grid.select(new CellRange(ht.row, ht.col), true);
        });
    };
    UsuarioAccesosComponent.prototype.selectPoliticasAction = function (option) {
        this.currentProceso = this.accesosCollection.currentItem;
        if (option.name == 'USER_POL') {
            this.politicasUsuarioEditor.show();
        }
        else if (option.name == 'GLOBAL_POL') {
            this.politicasGlobalesEditor.show();
        }
    };
    UsuarioAccesosComponent.prototype.onProcesosToolbarClick = function (option) {
        var _this = this;
        if (option.name == 'INVSEL') {
            this.accesos.filter(function (p) { return p.idModulo == _this.currentModule.identity; })
                .forEach(function (p) {
                p.selected = !p.selected;
                p.state = ChangeState.MODIFIED;
            });
            this.accesosCollection.refresh();
        }
    };
    UsuarioAccesosComponent.prototype.politicasMenuClick = function (menu) {
        var option = this.politicasMenu[menu.selectedIndex];
        this.selectPoliticasAction(option);
    };
    UsuarioAccesosComponent.prototype.onPoliticasUsuarioUpdated = function (politicas) {
        this.currentProceso.politicas = politicas;
    };
    UsuarioAccesosComponent.prototype.onPoliticasGlobalesUpdated = function (politicas) {
        this.currentProceso.politicas = politicas;
    };
    UsuarioAccesosComponent.prototype.applyPolicy = function (policy) {
    };
    UsuarioAccesosComponent.prototype.handleError = function (error) {
        console.error(error);
        this.context.app.hideSpinner();
        this.alerts.showAlert('Ha ocurrido un error', 'danger');
    };
    UsuarioAccesosComponent.prototype.cboResets = function () {
        this.empresas = [];
        this.idEmpresa = 0;
        this.sucursales = [];
        this.idSucursal = 0;
    };
    __decorate([
        ViewChild(PoliticasUsuarioEditor),
        __metadata("design:type", PoliticasUsuarioEditor)
    ], UsuarioAccesosComponent.prototype, "politicasUsuarioEditor", void 0);
    __decorate([
        ViewChild(PoliticasGlobalesEditor),
        __metadata("design:type", PoliticasGlobalesEditor)
    ], UsuarioAccesosComponent.prototype, "politicasGlobalesEditor", void 0);
    __decorate([
        ViewChild(AlertsBarComponent),
        __metadata("design:type", AlertsBarComponent)
    ], UsuarioAccesosComponent.prototype, "alerts", void 0);
    UsuarioAccesosComponent = __decorate([
        Component({
            selector: 'security-usuario-accesos',
            template: "\n      <div class=\"card\">\n          <div class=\"card-header\">Administraci\u00F3n de accesos de usuario - {{usuario ? usuario.nombre : ''}}</div>\n          <div class=\"card-body\">\n              <div class=\"row\">\n                  <div class=\"col-12\">\n                      <alerts-bar></alerts-bar>\n                      <!--Toolbar principal-->\n                      <az-toolbar (buttonClick)=\"onMainToolbarClick($event)\">\n                          <az-toolbar-button [name]=\"'SAVE'\" [type]=\"'primary'\" [text]=\"'Guardar'\" [icon]=\"'glyphicon glyphicon-floppy-disk'\" [enabled]=\"usuario\"></az-toolbar-button>\n                          <az-toolbar-button [name]=\"'CLOSE'\" [text]=\"'Cerrar'\" [icon]=\"'glyphicon glyphicon-remove'\"></az-toolbar-button>\n                      </az-toolbar>\n\n                  </div>\n              </div>\n\n              <div class=\"row\">\n                  <div class=\"col-12 col-md-4\">\n\n\n                      <az-panel [header]=\"'M\u00F3dulos del sistema'\">\n\n                          <!--Filtro de Usuario-->\n                          <div class=\"form-group\" *ngIf=\"allowSelection\">\n                              <label>Usuario:</label>\n                              <usuario-selector (selectedItemChanged)=\"onUsuarioSelected($event)\"></usuario-selector>\n                          </div>\n\n                          <!-- Lista de empresas -->\n                          <div class=\"row\">\n                              <div class=\"col-12 col-lg-6\">\n                                  <label class=\"form-control-label\">Empresa:</label>\n                                  <az-combobox [enabled]=\"usuario\"\n                                               [items]=\"empresas\"\n                                               [valueMember]=\"'id'\"\n                                               [displayMember]=\"'nombre'\"\n                                               [(ngModel)]=\"idEmpresa\"\n                                               (selectedItemChanged)=\"onSelectedEmpresaChanged($event)\">\n                                  </az-combobox>\n                              </div>\n                          </div>\n\n                          <!-- Lista de sucursales -->\n                          <div class=\"row\">\n                              <div class=\"col-12 col-lg-6\">\n                                  <label class=\"form-control-label\">Sucursal:</label>\n                                  <az-combobox [enabled]=\"usuario\"\n                                               [items]=\"sucursales\"\n                                               [valueMember]=\"'id'\"\n                                               [displayMember]=\"'nombre'\"\n                                               [(ngModel)]=\"idSucursal\"\n                                               (selectedItemChanged)=\"onSelectedSucursalChanged($event)\">\n                                  </az-combobox>\n                              </div>\n                          </div>\n\n                          <!-- TREE DE M\u00D3DULOS -->\n                          <security-modulos-tree *ngIf=\"usuario\" (currentNodeChanged)=\"onModuloSelected($event)\"></security-modulos-tree>\n                      </az-panel>\n                  </div>\n                  <div class=\"col-12 col-lg-8\">\n\n                      <az-panel [header]=\"'Procesos permitidos'\">\n\n                          <az-toolbar (buttonClick)=\"onProcesosToolbarClick($event)\" (menuItemClick)=\"selectPoliticasAction($event)\">\n                              <az-toolbar-button [name]=\"'INVSEL'\" [text]=\"'Invertir Selecci\u00F3n'\" [icon]=\"'glyphicon glyphicon-check'\" [enabled]=\"accesosCollection && accesosCollection.itemCount > 0\"></az-toolbar-button>\n                              <az-toolbar-menu [name]=\"'POLICIES'\" [header]=\"'Pol\u00EDticas'\" [menuItems]=\"politicasMenu\" [enabled]=\"accesosCollection && accesosCollection.currentItem\"></az-toolbar-menu>                        \n                          </az-toolbar>\n\n\n                          <wj-flex-grid #procesosGrid\n                                        style=\"height:550px\" \n                                        (initialized)=\"procesosGridInitialized(procesosGrid)\"\n                                        [itemsSource]=\"accesosCollection\" \n                                        [wjContextMenu]=\"ctxPoliticasMenu\">\n\n                              <wj-flex-grid-column [header]=\"'Nombre'\" [binding]=\"'nombre'\" [width]=\"'*'\" [isReadOnly]=\"true\"></wj-flex-grid-column>\n                              <wj-flex-grid-column [header]=\"'Permitir'\" [allowResizing]=\"false\" [binding]=\"'selected'\" dataType=\"Boolean\" [width]=\"100\"></wj-flex-grid-column>\n\n                          </wj-flex-grid>\n                      </az-panel>\n\n                  </div>\n              </div>\n\n          </div>\n      </div>\n\n      <wj-menu #ctxPoliticasMenu (itemClicked)=\"politicasMenuClick(ctxPoliticasMenu, $event)\" style=\"display:none\">\n          <wj-menu-item *ngFor=\"let item of menuItems\">\n              <div *ngIf=\"item.enabled\">\n                  <span [class]=\"item.icon\"></span>\n                  <b>{{item.text}}</b>\n                  <br>\n                  <small><i>{{item.smallText}}</i></small>\n              </div>\n          </wj-menu-item>\n      </wj-menu>\n\n      <security-politicas-usuario-editor \n                                         [politicas]=\"currentProceso ? currentProceso.politicas : []\"\n                                         (politicasUpdated)=\"onPoliticasUsuarioUpdated($event)\">\n\n      </security-politicas-usuario-editor>\n\n      <security-politicas-globales-editor [politicas]=\"currentProceso ? currentProceso.politicas : []\"\n                                         (politicasUpdated)=\"onPoliticasGlobalesUpdated($event)\">\n\n      </security-politicas-globales-editor>\n    "
        }),
        __metadata("design:paramtypes", [Context, ActivatedRoute, Location, UsuarioService, EmpresaService, SucursalService])
    ], UsuarioAccesosComponent);
    return UsuarioAccesosComponent;
}(BaseComponent));
export { UsuarioAccesosComponent };
