var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
//Frameworks
import { Component, ViewChild, forwardRef, ChangeDetectorRef } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { FormBuilder, Validators } from '@angular/forms';
import { Location } from '@angular/common';
//Wijmo
import { Control } from 'wijmo/wijmo';
//Azteca Kernel
import { Context, BaseComponent, CatalogService, UsuarioService, UsuarioInfo } from '../../core';
import { CatalogEditor, TrackableCollection, ChangeState } from '../../editors/index';
import { GruposListComponent } from './dialogs/grupos-list.component';
var UsuariosEditor = /** @class */ (function (_super) {
    __extends(UsuariosEditor, _super);
    //
    function UsuariosEditor(router, route, formBuilder, changeDetector, context, location, usuarioService) {
        var _this = _super.call(this, context, router, route, changeDetector) || this;
        _this.router = router;
        _this.route = route;
        _this.formBuilder = formBuilder;
        _this.changeDetector = changeDetector;
        _this.context = context;
        _this.location = location;
        _this.usuarioService = usuarioService;
        _this.usuario = new UsuarioInfo();
        _this.gruposCollection = new TrackableCollection();
        _this.systemUser = false;
        _this.catalogForm = formBuilder.group({
            'codigo': ['', Validators.required],
            'foto': [null],
            'password': ['', Validators.required],
            'domainUser': [''],
            'correo': [''],
            'persona': [''],
            'rol': [''],
        });
        return _this;
    }
    UsuariosEditor_1 = UsuariosEditor;
    ///////////////////////// METODOS ///////////////////////////////////////
    UsuariosEditor.prototype.resetPassword = function () {
        var _this = this;
        this.context.app.showSpinner();
        this.usuarioService.resetPassword(this.usuario.identity)
            .then(function (_) {
            _this.context.app.hideSpinner();
            _this.showAlert('El password ha sido reestablecido con éxito.', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    ///////////////////////// HANDLERS ///////////////////////////////////////
    UsuariosEditor.prototype.onConfigureCatalog = function (options) {
        this.autogeneratedCode = options.codigoAutogenerado;
        this.applyPolicies();
    };
    UsuariosEditor.prototype.onCreatingItem = function () {
        this.gruposCollection.sourceCollection = this.usuario.grupos;
    };
    UsuariosEditor.prototype.onViewingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.usuarioService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.usuario = info;
            _this.setReadonlyMode();
            _this.gruposCollection.sourceCollection = info.grupos;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    UsuariosEditor.prototype.onCloningItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        //
        this.usuarioService.clone(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.usuario = info;
            _this.gruposCollection.sourceCollection = info.grupos;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    UsuariosEditor.prototype.onLoadingItem = function (id) {
        var _this = this;
        this.context.app.showSpinner();
        this.usuarioService.getDetailByID(id)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.usuario = info;
            _this.systemUser = (info.code.toLowerCase().trim() == 'admin' || info.code.toLowerCase().trim() == 'system');
            _this.gruposCollection.sourceCollection = info.grupos;
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    UsuariosEditor.prototype.onSavingItem = function (args) {
        var _this = this;
        this.context.app.showSpinner();
        this.usuarioService.update(this.usuario)
            .then(function (info) {
            _this.context.app.hideSpinner();
            _this.usuario = info;
            _this.reset();
            if (args.closeEditor)
                _this.location.back();
            else
                _this.showAlert('La información ha sido actualizada con éxito', 'success');
        })
            .catch(function (error) { return _this.handleError(error); });
    };
    UsuariosEditor.prototype.onMenuItemClick = function (option) {
        if (option.name == 'SITES') {
            this.router.navigate(['branches'], { relativeTo: this.route });
        }
        else if (option.name == 'ACCESS') {
        }
        else if (option.name == 'RESET') {
            this.resetPassword();
        }
    };
    UsuariosEditor.prototype.onPersonValidChange = function () {
        this.changeDetector.detectChanges();
    };
    ///////////////////// ADMINISTRACIÓN DE GRUPOS //////////////////////////////////////////////////
    UsuariosEditor.prototype.onGruposToolbar = function (button) {
        if (button.name == 'ADD') {
            this.gruposList.show();
        }
    };
    UsuariosEditor.prototype.onDeleteGroup = function (grupo) {
        this.gruposCollection.remove(grupo);
    };
    UsuariosEditor.prototype.onSelectedGroupsChanged = function (grupos) {
        var _this = this;
        grupos.forEach(function (grupo) {
            if (!_this.usuario.grupos.find(function (g) { return g.id == grupo.id && g.state != ChangeState.DELETED; })) {
                grupo.state = ChangeState.ADDED;
                _this.usuario.grupos.push(grupo);
            }
        });
        this.gruposCollection.refresh();
    };
    UsuariosEditor.prototype.onTabSelected = function (args) {
        if (args.heading) {
            Control.invalidateAll();
        }
    };
    var UsuariosEditor_1;
    __decorate([
        ViewChild(GruposListComponent),
        __metadata("design:type", GruposListComponent)
    ], UsuariosEditor.prototype, "gruposList", void 0);
    UsuariosEditor = UsuariosEditor_1 = __decorate([
        Component({
            selector: 'security-usuarios-editor',
            template: "\n      <form [formGroup]=\"catalogForm\">\n\n          <azteca-catalog-editor #catalogEditor \n                                 [title]=\"'Usuario'\"\n                                 [info]=\"usuario\"\n                                 [valid]=\"valid && personaEditor.valid\"\n                                 (menuItemClick)=\"onMenuItemClick($event)\"\n                                 (configureCatalog)=\"onConfigureCatalog($event)\"\n                                 (creatingItem)=\"onCreatingItem()\"\n                                 (viewingItem)=\"onViewingItem($event)\"\n                                 (cloningItem)=\"onCloningItem($event)\"\n                                 (savingItem)=\"onSavingItem($event)\"\n                                 (loadingItem)=\"onLoadingItem($event)\">\n\n              <!------------------- Menu de acciones adicionales --------------------->        \n              <azteca-menu-item [name]=\"'SITES'\" [icon]=\"'fa fa-building'\" [text]=\"'Sucursales'\" [smallText]=\"'accesos a empresas y sucursales'\"></azteca-menu-item>\n              <azteca-menu-item [name]=\"'ACCESS'\" [icon]=\"'glyphicon glyphicon-lock'\" [text]=\"'Accesos'\" [smallText]=\"'accesos a procesos y pol\u00EDticas'\"></azteca-menu-item>\n              <azteca-menu-item [name]=\"'RESET'\" [icon]=\"'glyphicon glyphicon-erase'\" [text]=\"'Reestablecer contrase\u00F1a'\" [smallText]=\"'reestablecer la contrase\u00F1a'\"></azteca-menu-item>\n\n              <!------------------- Formulario --------------------->\n\n              <div class=\"row\">\n                  <div class=\"col-4 col-md-2\">\n                      <azteca-form-field>\n                          <azteca-image-box formControlName=\"foto\" [(ngModel)]=\"usuario.foto\"></azteca-image-box>\n                      </azteca-form-field>\n                  </div>\n\n                  <div class=\"col-8 col-md-8\">\n                      <azteca-form-field [label]=\"'Usuario:'\">\n                          <catalog-code formControlName=\"codigo\" [(ngModel)]=\"usuario.code\" [enabled]=\"!systemUser\"></catalog-code>\n                      </azteca-form-field>\n                  </div>\n              </div>\n\n        \n              <div class=\"row\">\n                  <div class=\"col-12 col-md-10 col-lg-10\">\n                      <tabset>\n                          <!--------------------------- DATOS DEL USUARIO ----------------------------->\n                          <tab heading=\"General\">\n\n                              <div class=\"row\">\n                                  <div class=\"col-12 col-md-10\">\n\n                                      <azteca-form-field [label]=\"'Password:'\">\n                                          <az-password formControlName=\"password\" [(ngModel)]=\"usuario.password\"></az-password>\n                                      </azteca-form-field>\n\n                                      <azteca-form-field [label]=\"'Usuario de dominio:'\">\n                                          <az-textbox formControlName=\"domainUser\" [(ngModel)]=\"usuario.domainUser\"></az-textbox>\n                                      </azteca-form-field>\n                                \n                                      <azteca-form-field [label]=\"'Correo electr\u00F3nico:'\">\n                                          <az-textbox formControlName=\"correo\" [(ngModel)]=\"usuario.correo\"></az-textbox>\n                                      </azteca-form-field>\n\n                                      <azteca-form-field [label]=\"'Rol:'\">\n                                          <rol-selector formControlName=\"rol\"\n                                                        [(ngModel)]=\"usuario.idRol\">\n                                          </rol-selector>\n                                      </azteca-form-field>\n\n                                  </div>\n                              </div>\n\n                          </tab>\n\n                          <!--------------------------- DATOS PERSONALES ----------------------------->\n                          <tab heading=\"Datos Personales\">\n                              <general-persona-editor #personaEditor \n                                                      formControlName=\"persona\" \n                                                      [(ngModel)]=\"usuario.persona\"                                            \n                                                      [nombreRequired]=\"true\"\n                                                      [correoVisible]=\"false\"\n                                                      (validChange)=\"onPersonValidChange($event)\">\n\n                              </general-persona-editor>\n\n                          </tab>\n\n                          <!---------------------------GRUPOS DE USUARIOS ----------------------------->\n                          <tab heading=\"Grupos\" (select)=\"onTabSelected($event)\">\n\n                              <az-toolbar (buttonClick)=\"onGruposToolbar($event)\">\n                                  <az-toolbar-button [name]=\"'ADD'\" [type]=\"'primary'\" [text]=\"'Agregar'\" [icon]=\"'glyphicon glyphicon-plus'\"></az-toolbar-button>                            \n                              </az-toolbar>\n\n                              <wj-flex-grid style=\"height:300px\" [itemsSource]=\"gruposCollection\" [isReadOnly]=\"true\">                            \n\n                                  <wj-flex-grid-column [header]=\"''\" [width]=\"60\" [isReadOnly]=\"true\">\n                                      <ng-template wjFlexGridCellTemplate [cellType]=\"'Cell'\" let-cell=\"cell\">\n                                          <button type=\"button\" class=\"btn btn-default\" (click)=\"onDeleteGroup(cell.item)\">\n                                              <span class=\"glyphicon glyphicon-trash\"></span>\n                                          </button>\n                                      </ng-template>\n                                  </wj-flex-grid-column>\n\n                                  <wj-flex-grid-column [header]=\"'C\u00F3digo'\" [binding]=\"'codigo'\" [width]=\"100\"></wj-flex-grid-column>\n                                  <wj-flex-grid-column [header]=\"'Nombre'\" [binding]=\"'nombre'\" [width]=\"'*'\"></wj-flex-grid-column>\n                              </wj-flex-grid>\n\n                          </tab>\n                      </tabset>\n                  </div>\n              </div>\n            \n\n          </azteca-catalog-editor>\n      </form>\n\n      <!--------------------------DIALOGO DE GRUPOS --------------------------------->\n      <security-grupos-list   (selectedItemsChanged)=\"onSelectedGroupsChanged($event)\"\n                              [multiSelect]=\"true\">\n\n      </security-grupos-list>\n    ",
            providers: [
                {
                    provide: BaseComponent, useExisting: forwardRef(function () { return UsuariosEditor_1; })
                },
                {
                    provide: CatalogService, useExisting: UsuarioService
                }
            ]
        }),
        __metadata("design:paramtypes", [Router, ActivatedRoute, FormBuilder, ChangeDetectorRef,
            Context, Location, UsuarioService])
    ], UsuariosEditor);
    return UsuariosEditor;
}(CatalogEditor));
export { UsuariosEditor };
